% calc_ice_shelf_mass_balance

clear
close all
clc

% Add paths and libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../v2'));

% make output directory
mkdir individual_shelf_mass_balance

% use 200 m or irregularly spaced GLs
use_200m = 1;
mkdir individual_shelf_mass_balance_200m
mkdir individual_shelf_freshwater_flux_200m

% paolo or adusumilli or noel/livia melt?
basal_melt_source=3; % (1) adusumilli; (2) = paolo; (3) or noel/livia from 2010 onwards for 55 shelves, and paolo elsewhere

%% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';


%% Loop through ice shelf and calculate mass balance

% Loop
for i = 1:numel(GL_labels)
    
    % Get shelf gates
    tic;
    shelf_name = GL_labels(i).Name;
    disp(' ');
    disp(['Starting shelf number: ' num2str(i) ' - ' shelf_name ]);
    
    % Load datasets
    if use_200m == 1
        D = load(['../grounding_line_discharge/discharge/individual_shelf_discharge_200m_consolidated/' shelf_name '_discharge_timeseries.mat']); % discharge
    else
        D = load(['../grounding_line_discharge/discharge/individual_shelf_discharge_consolidated/' shelf_name '_discharge_timeseries.mat']); % discharge
    end
    S = load(['../SMB/individual_shelf_SMB_timeseries_consolidated/' shelf_name '_SMB_timeseries.mat']);
    if basal_melt_source == 1
        B = load(['../submarine_melt/individual_shelf_submarine_melt_consolidated/' shelf_name '_submarine_melt_timeseries.mat']);
    elseif basal_melt_source == 2
        B = load(['../submarine_melt/individual_shelf_submarine_melt_consolidated/' shelf_name '_submarine_melt_timeseries_paolo.mat']);
    elseif basal_melt_source == 3
        B = load(['../submarine_melt/individual_shelf_submarine_melt_consolidated/' shelf_name '_submarine_melt_timeseries_noel.mat']);
    end
    try
        C = load(['../calving/individual_shelf_calving_flux/' shelf_name '_calving_timeseries.mat']);
    catch
        parts = split(shelf_name,'_');
        tmp = [parts{1} ' ' parts{2}];
        C = load(['../calving/individual_shelf_calving_flux/' tmp '_calving_timeseries.mat']);
    end
    
    % if thwaites, then we need to load a different calving dataset
    if strcmp(shelf_name,'Thwaites')
        C = load(['../calving/individual_shelf_calving_flux/' shelf_name '_calving_timeseries_combined.mat']);
    end
    
    % Interpolate to regular time
    %mb_time = [C.time(1), datenum(1998:1999,3,15), C.time(2:end)];
    mb_time = datenum(1997:2021,3,15);
    %   - calving
    C.c_reg = [C.c(1), C.ssc,C.ssc, C.c(2:end)];
    C.c_err_reg = [C.c_err(1), C.ssc_err,C.ssc_err, C.c_err(2:end)];
    %   - SMB
    S.smb_reg = zeros(size(mb_time)).*NaN;
    for j = 1:length(mb_time)
        idx = find(S.time>=mb_time(j)-365.25/2 & S.time<=mb_time(j)+365.25/2);
        S.smb_reg(j) = nanmean(S.smb_ts(idx));
    end
    idx = find(S.time>=datenum(1979,1,1) & S.time<datenum(2009,1,1));
    S.smb_clim = nanmean(S.smb_ts(idx));
    clear idx
%     S.smb_reg = interp1gap(S.time,S.smb_ts,mb_time);
%     S.smb_reg = fillmissing(S.smb_reg,'Previous');
%     S.smb_reg = fillmissing(S.smb_reg,'Next');
    S.smb_err_reg = S.smb_reg.*0.148;
    %   - submarine melting
    B.flux_reg = zeros(size(mb_time)).*NaN;
    B.flux_err_reg = zeros(size(mb_time)).*NaN;
    for j = 1:length(mb_time)
        idx = find(B.time>=mb_time(j)-365.25/2 & B.time<=mb_time(j)+365.25/2);
        tmp = nanmean(B.melt_flux_ts(idx));
        B.flux_reg(j) = nanmean(B.melt_flux_ts(idx));
        B.flux_err_reg(j) = sqrt(nansum(B.melt_flux_err_ts(idx).^2));
    end
    B.flux_reg(isnan(B.flux_reg)) = nanmedian(B.flux_reg);
    B.flux_err_reg(isnan(B.flux_err_reg)) = nanmedian(B.flux_err_reg);
    %   - discharge
    D.Q_reg_mb = interp1gap(D.time,D.Q_filled,mb_time);
    D.Q_reg_mb = fillmissing(D.Q_reg_mb,'Previous');
    D.Q_reg_mb = fillmissing(D.Q_reg_mb,'Next');
    D.Q_reg_err_mb = interp1gap(D.time,D.Q_error,mb_time);
    D.Q_reg_err_mb = fillmissing(D.Q_reg_err_mb,'Previous');
    D.Q_reg_err_mb = fillmissing(D.Q_reg_err_mb,'Next');
    
    % Calculate mass balance
    massBalance = D.Q_reg_mb + S.smb_reg - C.c_reg - B.flux_reg;
    massBalanceError = sqrt(D.Q_reg_err_mb.^2 + S.smb_err_reg.^2 + C.c_err_reg.^2 + B.flux_err_reg.^2);
    freshwaterFlux = B.flux_reg + C.c_reg;
    freshwaterFluxError = sqrt(C.c_err_reg.^2 + B.flux_err_reg.^2);
    
    % Calculate total mass change
    cumulativeMassChange = cumsum(massBalance); % can do basic cumulative sum because we have annual values in units of Gt/yr
    cumulativeMassChangeError = zeros([1,length(cumulativeMassChange)]).*NaN; % root sum square of annual errors
    totalMassChange = cumulativeMassChange(end);
    totalMassChangeError = sqrt(rssq(D.Q_reg_err_mb)^2 + rssq(S.smb_err_reg)^2 + rssq(B.flux_err_reg)^2 + C.dmdt_tot_err^2);
    
    % Calculate export of freshwater to southern ocean
    cumulativeFreshwaterFlux = cumsum(freshwaterFlux);
    cumulativeFreshwaterFluxError = zeros([1,length(cumulativeMassChange)]).*NaN; 
    cumulativeCalvingFlux = cumsum(C.c_reg);
    cumulativeCalvingFluxError = zeros([1,length(cumulativeMassChange)]).*NaN; 
    cumulativeMeltFlux = cumsum(B.flux_reg);
    cumulativeMeltFluxError = zeros([1,length(cumulativeMassChange)]).*NaN; 
    for j = 1:length(cumulativeMassChange)
        if j == 1
            cumulativeMassChangeError(j) = massBalanceError(j);
            cumulativeFreshwaterFluxError(j) = freshwaterFluxError(j);
            cumulativeCalvingFluxError(j) = C.c_err_reg(j);
            cumulativeMeltFluxError(j) = B.flux_err_reg(j);
        else
            cumulativeMassChangeError(j) = rssq(massBalanceError(1:j));
            cumulativeFreshwaterFluxError(j) = rssq(freshwaterFluxError(1:j));
            cumulativeCalvingFluxError(j) = rssq(C.c_err_reg(1:j));
            cumulativeMeltFluxError(j) = rssq(B.flux_err_reg(1:j));
        end
    end 
    
    % Calculate balance melt rate and melt excess from other components
    B.ssc_flux_calc = D.Q_reg_mb(1) + S.smb_clim - C.ssc;
    
    % Calculate timeseries of mass change due to each component
    thinningTimeseries = (B.flux_reg-B.ssc_flux_calc).*-1; % negative = excess melt = thinning due to melt
    retreatTimeseries = (C.c_reg-C.ssc).*-1; % negative = excess calving = retreat
    dischargeChangeTimeseries = D.Q_reg_mb-D.Q_reg_mb(1); % positive = excess discharge = mass gain
    smbAnomalyTimeseries = S.smb_reg-S.smb_clim; % positive = excess SMB = mass gain
    %   - and errors
    smbAnomalyTimeseriesError = sqrt((S.smb_reg(:).*0.148).^2+(S.smb_clim*0.148)^2);
    thinningTimeseriesError = sqrt(B.flux_err_reg(:).^2 + (B.ssc_flux_calc*0.1)^2);
    retreatTimeseriesError = sqrt(C.c_err_reg(:).^2 + C.ssc_err^2);
    dischargeChangeTimeseriesError = sqrt(D.Q_reg_err_mb(:).^2 + D.Q_reg_err_mb(1)^2);
    
    % Calculate cumulative mass change due to retreat, thinning, SMB and discharge
    cumulativeSMBAnomaly = cumsum(S.smb_reg-S.smb_clim);
    cumulativeThinning = cumsum(thinningTimeseries);
    cumulativeRetreat = cumsum(retreatTimeseries);
    cumulativeDischargeChange = cumsum(D.Q_reg_mb-D.Q_reg_mb(1));
    cumulativeSMBAnomalyError = zeros([1,length(cumulativeSMBAnomaly)]).*nan;
    cumulativeThinningError = zeros([1,length(cumulativeSMBAnomaly)]).*nan;
    cumulativeRetreatError = zeros([1,length(cumulativeSMBAnomaly)]).*nan;
    cumulativeDischargeChangeError = zeros([1,length(cumulativeSMBAnomaly)]).*nan;
    for j = 1:length(cumulativeSMBAnomaly)
        if j == 1
            cumulativeSMBAnomalyError(j) = smbAnomalyTimeseriesError(j);
            cumulativeThinningError(j) = thinningTimeseriesError(j);
            cumulativeRetreatError(j) = retreatTimeseriesError(j);
            cumulativeDischargeChangeError(j) = dischargeChangeTimeseriesError(j);
        else
            cumulativeSMBAnomalyError(j) = rssq(smbAnomalyTimeseriesError(1:j));
            cumulativeThinningError(j) = rssq(thinningTimeseriesError(1:j));
            cumulativeRetreatError(j) = rssq(retreatTimeseriesError(1:j));
            cumulativeDischargeChangeError(j) = rssq(dischargeChangeTimeseriesError(1:j));
        end
    end
    
    % Save
    time = D.time_reg;
    calving = C.c_reg;
    calvingError = C.c_err_reg;
    melt = B.flux_reg;
    meltError = B.flux_err_reg;
    discharge = D.Q_reg_mb;
    dischargeError = D.Q_reg_err_mb;
    smb = S.smb_reg;
    smbError = S.smb_err_reg;
    totalRetreatError = C.dmdt_tot_err;
    steadyStateMelt = B.ssc_flux_calc;
    steadyStateMeltError = B.ssc_flux_calc*0.1;
    steadyStateCalving = C.ssc;
    steadyStateCalvingError = C.ssc_err;
    steadyStateDischarge = D.Q_reg_mb(1);
    steadyStateDischargeError = D.Q_reg_err_mb(1);
    steadyStateSMB = S.smb_clim;
    steadyStateSMBError = S.smb_clim*0.148;
    % various older formats using differnet basal melt data and lower
    % resolution flux gates, that I stopped maintaining... 
    if use_200m == 1
        if basal_melt_source == 1
            save(['individual_shelf_mass_balance_200m/' shelf_name '_mass_balance.mat'],...
                'mb','mb_err','mb_cum','mb_cum_err','time','Q_reg_mb','Q_reg_err_mb','smb_reg','smb_reg_err');
            save(['individual_shelf_freshwater_flux_200m/' shelf_name '_freshwater_flux.mat'],...
                'fw','fw_err','fw_cum','fw_cum_err','time','c_reg','c_err_reg','c_cum','c_cum_err',...
                'melt_flux','melt_flux_err','melt_flux_cum','melt_flux_cum_err');
        elseif basal_melt_source == 2
            save(['individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_paolo.mat'],...
                'mb','mb_err','mb_cum','mb_cum_err','time','Q_reg_mb','Q_reg_err_mb','smb_reg','smb_reg_err');
            save(['individual_shelf_freshwater_flux_200m/' shelf_name '_freshwater_flux_paolo.mat'],...
                'fw','fw_err','fw_cum','fw_cum_err','time','c_reg','c_err_reg','c_cum','c_cum_err',...
                'melt_flux','melt_flux_err','melt_flux_cum','melt_flux_cum_err');
        elseif basal_melt_source == 3
            save(['individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel.mat'],'time',...
                'massBalance','massBalanceError',...
                'discharge','dischargeError','smb','smbError','melt','meltError','calving','calvingError',...
                'cumulativeMassChange','cumulativeMassChangeError','totalMassChange','totalMassChangeError',...
                ...
                'thinningTimeseries','retreatTimeseries','dischargeChangeTimeseries','smbAnomalyTimeseries',...
                'thinningTimeseriesError','retreatTimeseriesError','dischargeChangeTimeseriesError','smbAnomalyTimeseriesError',...
                ...
                'cumulativeSMBAnomaly','cumulativeThinning','cumulativeRetreat','cumulativeDischargeChange',...
                'cumulativeSMBAnomalyError','cumulativeThinningError','cumulativeRetreatError','cumulativeDischargeChangeError',...
                'totalRetreatError',...
                'steadyStateMelt','steadyStateCalving','steadyStateDischarge','steadyStateSMB',...
                'steadyStateMeltError','steadyStateCalvingError','steadyStateDischargeError','steadyStateSMBError');
            save(['individual_shelf_freshwater_flux_200m/' shelf_name '_freshwater_flux_noel.mat'],'time',...
                'melt','meltError','calving','calvingError',...
                'cumulativeMeltFlux','cumulativeMeltFluxError','cumulativeCalvingFlux','cumulativeCalvingFluxError',...
                'freshwaterFlux','freshwaterFluxError','cumulativeFreshwaterFlux','cumulativeFreshwaterFluxError');
        end
    else
        if basal_melt_source == 1
            save(['individual_shelf_mass_balance/' shelf_name '_mass_balance.mat'],...
                'mb','mb_err','mb_cum','mb_cum_err','time','Q_reg','Q_reg_err','smb_reg','smb_reg_err');
            save(['individual_shelf_freshwater_flux/' shelf_name '_freshwater_flux.mat'],...
                'fw','fw_err','fw_cum','fw_cum_err','time','c_reg','c_err_reg','c_cum','c_cum_err',...
                'melt_flux','melt_flux_err','melt_flux_cum','melt_flux_cum_err');
        elseif basal_melt_source == 2
            save(['individual_shelf_mass_balance/' shelf_name '_mass_balance_paolo.mat'],...
                'mb','mb_err','mb_cum','mb_cum_err','time','Q_reg','Q_reg_err','smb_reg','smb_reg_err');
            save(['individual_shelf_freshwater_flux/' shelf_name '_freshwater_flux_paolo.mat'],...
                'fw','fw_err','fw_cum','fw_cum_err','time','c_reg','c_err_reg','c_cum','c_cum_err',...
                'melt_flux','melt_flux_err','melt_flux_cum','melt_flux_cum_err');
        elseif basal_melt_source == 3
            save(['individual_shelf_mass_balance/' shelf_name '_mass_balance_noel.mat'],...
                'mb','mb_err','mb_cum','mb_cum_err','time','Q_reg','Q_reg_err','smb_reg','smb_reg_err','smb_cum','smb_cum_err','melt_cum','melt_cum_err','calv_cum','calv_cum_err','discharge_cum','discharge_cum_err');
            save(['individual_shelf_freshwater_flux/' shelf_name '_freshwater_flux_noel.mat'],...
                'fw','fw_err','fw_cum','fw_cum_err','time','c_reg','c_err_reg','c_cum','c_cum_err',...
                'melt_flux','melt_flux_err','melt_flux_cum','melt_flux_cum_err');
        end
    end
   
%     % Plot components as bar chart
%     fig = figure('units','inches','outerposition',[5 5 3.6 2],'color','w','visible','off');
%     newAxSize = [3.5, 1.25]; % inches
%     % Plot observations
%     y = [discharge(:) , smb(:), -calving(:), -melt(:)];
%     y_err = [dischargeError(:) , smbError(:), -calvingError(:), -meltError(:)];
%     y1 = [discharge(:) , smb(:)];
%     y1_err = [dischargeError(:) , smb(:)];
%     y2 = [-calving(:), -melt(:)];
%     y2_err = [-calvingError(:), -meltError(:)];
%     h = bar(y,'stacked'); hold on;
%     %legend('Discharge','SMB','Calving','Melt','autoupdate','off','location','northeastoutside');
%     errorbar(cumsum(y1')',y1_err,'.k');
%     errorbar(cumsum(y2')',y2_err,'.k');
%     plot(massBalance,'w','linewidth',3);
%     plot(massBalance,'k','linewidth',2);
%     h = patch([1:25,25:-1:1],[massBalance+massBalanceError,fliplr(massBalance)-fliplr(massBalanceError)],'k','edgecolor','none','facealpha',.3);
%     h.FaceColor = [.8 .8 .8];
%     % also plot thinning and retreat timeseries (i.e. difference from
%     % balance rates (a bit too much information...)
%     %plot(retreatTimeseries,'k','linewidth',3);
%     %plot(retreatTimeseries,'color',[0.9290 0.6940 0.1250],'linewidth',2);
%     %plot(thinningTimeseries,'w','linewidth',3);
%     %plot(thinningTimeseries,'color',[0.4940 0.1840 0.5560],'linewidth',2);
%     %   - replot mass balance on top
%     plot(massBalance,'w','linewidth',3);
%     plot(massBalance,'k','linewidth',2);
%     % labels
%     ylabel('Mass flux (Gt yr^{-1})');
%     set(gca,'FontSize',10,'FontName','Helvetica')
%     box('on')
%     % Set ticks
%     set(gca,'XTick',[1:25]); % currently plotting as a series that assumes regular spacing, but calving is not regularly spaced!
%     set(gca,'XTickLabel',{' ','1998',' ','2000',...
%         ' ','2002',' ','2004',' ','2006',' ','2008',' ','2010',...
%         ' ','2012',' ','2014',' ','2016',' ','2018',' ','2020',' '});
%     set(gca,'XLim',[.5 25.5]);
%     xtickangle(90);
%     ylim = get(gca,'YLim');
%     ylim = max(abs(ylim));
%     % check size
%     ax = gca(fig); 
%     ax.Units = 'Inches';
%     sizeDiff = newAxSize - ax.Position(3:4); 
%     fig.Units = 'Inches'; 
%     fig.Position(3:4) = fig.Position(3:4) + sizeDiff; 
%     ax.Position(3:4) = newAxSize;
%     %set(gca,'Position',[5 5 5 2.8]);
%     % Save
%     if use_200m == 1
%         if basal_melt_source == 1
%             export_fig(['individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_components.png'],'-dpng','-r300');
%         elseif basal_melt_source == 2
%             export_fig(['individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_components_paolo.png'],'-dpng','-r300');
%         elseif basal_melt_source == 3
%             export_fig(['individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_components_noel.png'],'-dpng','-r1200');
%         end
%     else
%         export_fig(['individual_shelf_mass_balance/' shelf_name '_mass_balance_components.png'],'-dpng','-r300');
%     end
%     close
%     
%     %%%
%     % Plot cumulative changes 
%     fig = figure('units','inches','outerposition',[5 5 3.6 2],'color','w','visible','on');
%     newAxSize = [3.5, 1.25]; % inches
%     plot([1,length(cumulativeMassChange)],[0 0],'k'); hold on
%     % Plot cumulative mass change
%     sb1 = shadedErrorBar(1:length(cumulativeMassChange),cumulativeMassChange,cumulativeMassChangeError); 
%     sb1.patch.FaceAlpha = 0.2;
%     sb1.patch.EdgeColor = 'none';
%     sb1.patch.FaceColor = [0.3 0.3 .3];
%     sb1.mainLine.Color = [0 0 0];
%     sb1.mainLine.LineWidth = 1.2;
%     sb1.edge(1).Color = 'none';
%     sb1.edge(2).Color = 'none';
%     %   - cumulative SMB change
%     sb2 = shadedErrorBar(1:length(cumulativeSMBAnomaly),cumulativeSMBAnomaly,cumulativeSMBAnomalyError);
%     sb2.patch.FaceAlpha = 0.2;
%     sb2.patch.EdgeColor = 'none';
%     sb2.patch.FaceColor = [0.8500 0.3250 0.0980];
%     sb2.mainLine.Color = [0.8500 0.3250 0.0980];
%     sb2.mainLine.LineWidth = 1.2;
%     sb2.edge(1).Color = 'none';
%     sb2.edge(2).Color = 'none';
%     %   - cumulative melt change
%     sb3 = shadedErrorBar(1:length(cumulativeThinning),cumulativeThinning,cumulativeThinningError);
%     sb3.patch.FaceAlpha = 0.2;
%     sb3.patch.EdgeColor = 'none';
%     sb3.patch.FaceColor = [0.4940 0.1840 0.5560];
%     sb3.mainLine.Color = [0.4940 0.1840 0.5560];
%     sb3.mainLine.LineWidth = 1.2;
%     sb3.edge(1).Color = 'none';
%     sb3.edge(2).Color = 'none';
%     %   - cumulative calv change
%     sb4 = shadedErrorBar(1:length(cumulativeRetreat),cumulativeRetreat,cumulativeRetreatError);
%     sb4.patch.FaceAlpha = 0.2;
%     sb4.patch.EdgeColor = 'none';
%     sb4.patch.FaceColor = [0.9290 0.6940 0.1250];
%     sb4.mainLine.Color = [0.9290 0.6940 0.1250];
%     sb4.mainLine.LineWidth = 1.2;
%     sb4.edge(1).Color = 'none';
%     sb4.edge(2).Color = 'none';
%     % cumulative discharge change
%     sb5 = shadedErrorBar(1:length(cumulativeDischargeChange),cumulativeDischargeChange,cumulativeDischargeChangeError);
%     sb5.patch.FaceAlpha = 0.2;
%     sb5.patch.EdgeColor = 'none';
%     sb5.patch.FaceColor = [0 0.4470 0.7410];
%     sb5.mainLine.Color = [0 0.4470 0.7410];
%     sb5.mainLine.LineWidth = 1.2;
%     sb5.edge(1).Color = 'none';
%     sb5.edge(2).Color = 'none';
%     % labels
%     ylabel('Mass change (Gt)');
%     set(gca,'FontSize',10,'FontName','Helvetica')
%     box('on')
%     % Set ticks
%     set(gca,'XTick',[1:25]); % currently plotting as a series that assumes regular spacing, but calving is not regularly spaced!
%     set(gca,'XTickLabel',{' ','1998',' ','2000',...
%         ' ','2002',' ','2004',' ','2006',' ','2008',' ','2010',...
%         ' ','2012',' ','2014',' ','2016',' ','2018',' ','2020',' '});
%     set(gca,'XLim',[.5 25.5]);
%     xtickangle(90);
%     ylim = get(gca,'YLim');
%     ylim = max(abs(ylim));
%     % check size
%     ax = gca(fig); 
%     ax.Units = 'Inches';
%     sizeDiff = newAxSize - ax.Position(3:4); 
%     fig.Units = 'Inches'; 
%     fig.Position(3:4) = fig.Position(3:4) + sizeDiff; 
%     ax.Position(3:4) = newAxSize;
%     grid on
%     set(gca,'XGrid','off');
%     %set(gca,'Position',[5 5 5 2.8]);
%     % Save
%     export_fig(['individual_shelf_mass_balance_200m/' shelf_name '_cumulative_mass_changes_noel.png'],'-dpng','-r1200');
%     close
    
end
    
    
    
    
    
    
    