% calc_init_mass

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%% Prep

% load ice shelf locations
L = shaperead('ice_shelf_circle_locs_manual.shp');

%% Main

fn = 'greene_Supplementary_Table_1.xlsx';

% Get all excel ice shelf names
[~,names] = xlsread(fn,'B7:B187');

final_mass = zeros([numel(L),1]).*nan;
init_mass = zeros([numel(L),1]).*nan;
for i = 1:numel(L)
    
    % Get shelf name
    shelf_name = L(i).Name;
    
    % in some cases, Chad has multiple shelves where I have one shelf. For
    % these shelves, we need to read multiple lines of Chad's data.
    if strcmp(shelf_name,'Abbot')
        start = 7;
        stop = 13;
    elseif strcmp(shelf_name,'Getz')
        start = 67;
        stop = 69;
    elseif strcmp(shelf_name,'Larsen_D')
        start = 93;
        stop = 94;
    elseif strcmp(shelf_name,'Wordie')
        start = 180;
        stop = 184;
    else
        clear idx
        % do a first check for matches
        idx = find(strcmpi(names,shelf_name)==1);
        % some of chads shelves do not have underscores, but mine do...
        if isempty(idx)
            name_parts = split(shelf_name,'_');
            for j = 1:numel(name_parts)
                if j == 1
                    shelf_name = name_parts{j};
                else
                    shelf_name = [shelf_name ' ' name_parts{j}];
                end
            end
        end
        if strcmp(shelf_name,'Riiser_Larsen') || strcmp(shelf_name,'Riiser Larsen')
            shelf_name = 'Riiser-Larsen';
        end
        if strcmp(shelf_name,'Wilma Robert Downer')
            shelf_name = 'Wilma/Robert/Downer';
        end
        if strcmp(shelf_name,'Smith Inlet')
            shelf_name = 'SmithInlet';
        end
        if strcmp(shelf_name,'Geikie Inlet')
            shelf_name = 'GeikieInlet';
        end
        % look again for matches
        idx = find(strcmpi(names,shelf_name)==1);
        if isempty(idx)
            disp(['Couldn''t find matching shelf for shelf number ' num2str(i) ' - ' shelf_name]);
            return
        end
        % excel sheet data starts at 6
        start = idx+6; 
        stop = idx+6;
    end
    
    % load initial mass
    if strcmp(shelf_name,'Whittle')
        final_mass(i) = xlsread(fn,'BK175:BK175');
        final_mass(i) = final_mass(i) + xlsread(fn,'BK59:BK59');
        init_mass(i) = xlsread(fn,'O175:O175');
        init_mass(i) = final_mass(i) + xlsread(fn,'O59:O59');
    else
        final_mass(i) = sum(xlsread(fn,['BK' num2str(start) ':BK' num2str(stop)]));
        init_mass(i) = sum(xlsread(fn,['O' num2str(start) ':O' num2str(stop)]));
    end
end
save('final_mass_greene.mat','final_mass','L');
save('init_mass_greene.mat','init_mass','L');

