% calc_paper_statistics

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));


%% Load data

% Ice shelf names
load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\grounding_line_discharge\flux_gates/GL_consolidated_200m.mat');
shelves = shelf_names;

% mass budget data
load('../../mass_balance/mass_balance_components_all_shelves.mat');
load('../../mass_balance/individual_shelf_mass_balance_200m/Wordie_mass_balance_noel_update_v2.mat','time');

% initial mass
load('../relative_mass_change/init_mass_greene.mat','init_mass');
L = shaperead('ice_shelf_circle_locs_manual.shp');
for i = 1:numel(L)
    L_names{i} = L(i).Name;
end

%% Get totals and change names to simplify code

cumulativeThinning = cumulativeThinningForce1997AllShelves;
cumulativeDischargeChange = cumulativeDischargeChange1997AllShelves;
delThick = cumulativeThinningForce1997AllShelves(:,end);
delThickE = cumulativeThinningForce1997ErrorAllShelves(:,end);
delArea = totalRetreatAllShelves;
delAreaE = totalRetreatErrorAllShelves;
delDischarge = cumulativeDischargeChange1997AllShelves(:,end);
delDischargeE = cumulativeDischargeChange1997ErrorAllShelves(:,end);
delSMB = cumulativeSMBAnomalyAllShelves(:,end);
delSMBE = cumulativeSMBAnomalyErrorAllShelves(:,end);
delMass = totalMassChangeAllShelves;
delMassE = totalMassChangeErrorAllShelves;

% Add mass change due to grounding line migration at ASE ice shelves
GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
for i = 1:numel(GLmass.ASE_shelves)
    idx = find(strcmp(GLmass.ASE_shelves{i},shelf_names)==1);
    delMass(idx) = delMass(idx) + GLmass.mass_change_GL(i);
    delMassE(idx) = rssq([delMassE(idx),GLmass.mass_change_err(i)]);
end

% Get significant mass change
sigMass = logical(1-double(delMass+delMassE>0 & delMass-delMassE<0)); % logical 1 where mass change is significant

% Get relative trends
relMassTrendAllShelves = zeros([numel(shelves),1]).*NaN;
relMassPAllShelves = zeros([numel(shelves),1]).*NaN;
relMassChangeAllShelves = zeros([numel(shelves),1]).*NaN;
for i = 1:numel(shelves)
    % load data
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelves{i} '_mass_balance_noel_update_v2.mat'],'totalMassChange','totalMassChangeError','cumulativeMassChange','time');
    if strcmp(shelves{i},'Pine_Island') || strcmp(shelves{i},'Thwaites') || strcmp(shelves{i},'Crosson') || strcmp(shelves{i},'Dotson')
        GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
        idx = find(contains(GLmass.ASE_shelves,shelves{i})==1);
        cumuGLmass = linspace(0,GLmass.mass_change_GL(idx),length(cumulativeMassChange));
        cumulativeMassChange = cumulativeMassChange + cumuGLmass;
    end
    % Get some other stats and save everything to a table
    [mass_trend,ptrend] = trend(cumulativeMassChange,time);
    mass_trend = mass_trend.*365.25; % convert to Gt/yr
    clear ind
    ind = find(strcmp(shelves{i},L_names)==1);
    rel_mass_trend = mass_trend/init_mass(ind)*100;
    relMassTrendAllShelves(i) = rel_mass_trend;
    relMassPAllShelves(i) = ptrend;
    relMassChangeAllShelves(i) = cumulativeMassChange(end)/init_mass(ind)*100;
end
clear rel_mass_trend mass_trend ptrend relMassChange totalMassChange 

%% Display totals

disp('%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%% TOTAL MASS CHANGE %%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Antarctic totals
disp(' ')
disp('Antarctic partitioning totals:');
disp([' - Total mass change is: ' num2str(nansum(delMass)) ' +- ' num2str(rssq(delMassE)) ' Gt']);
disp([' - Total mass change due to discharge is: ' num2str(nansum(delDischarge)) ' +- ' num2str(rssq(delDischargeE)) ' Gt']);
disp([' - Total mass change due to calving is: ' num2str(nansum(delArea)) ' +- ' num2str(rssq(delAreaE)) ' Gt']);
disp([' - Total mass change due to SMB is: ' num2str(nansum(delSMB)) ' +- ' num2str(rssq(delSMBE)) ' Gt']);
disp([' - Total mass change due to melt is: ' num2str(nansum(delThick)) ' +- ' num2str(rssq(delThickE)) ' Gt']);
disp([' - Total mass change due to grounding line retreat is: ' num2str(sum(GLmass.mass_change_GL)) ' +- ' num2str(sum(GLmass.mass_change_err)) ' Gt']);

disp(' ');
disp('Ice shelf gains vs losses:')
disp([' - ' num2str(sum(delMass>0 & sigMass==1)) ' shelves gained mass (significantly)']); 
disp([' - ' num2str(sum(delMass<0 & sigMass==1)) ' shelves lost mass (significantly)']); 
disp([' - ' num2str(sum(sigMass==0)) ' had no significant mass change']); 
disp([' - The ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that significantly lost mass totalled ' num2str(sum(delMass(delMass<0 & sigMass==1))) ' +/- ' num2str(rssq(delMassE(delMass<0 & sigMass==1))) ' Gt of mass loss'])
disp([' - The ' num2str(sum(delMass>0 & sigMass==1)) ' shelves that significantly gained mass totalled ' num2str(sum(delMass(delMass>0 & sigMass==1))) ' +/- ' num2str(rssq(delMassE(delMass>0 & sigMass==1))) ' Gt of mass loss'])

disp(' ');
disp('Individual ice shelves dominate Antarctic ice shelf mass gains and losses:')
[delMassSort,iv] = sort(delMass,'descend');
shelvesSort = shelves(iv);
disp([' - The 5 most significant shelves in terms of gross mass loss (' shelvesSort{end} ',' shelvesSort{end-1} ',' shelvesSort{end-2} ',' shelvesSort{end-3} ',' shelvesSort{end-4} ') contributed ' num2str(sum(delMassSort(end-4:end))/sum(delMass(delMass<0 & sigMass==1))*100) '% to gross ice shelf mass loss'])
disp([' - The 5 most significant shelves in terms of gross mass gain (' shelvesSort{1} ',' shelvesSort{2} ',' shelvesSort{3} ',' shelvesSort{4} ',' shelvesSort{5} ') contributed ' num2str(sum(delMassSort(1:5))/sum(delMass(delMass>0 & sigMass==1))*100) '% to gross ice shelf mass gain'])


% Mass trends
disp(' ')
disp('Mass trends:');
[massTrendAllShelves,massPAllShelves] = trend(cumulativeMassChangeAllShelves,time,'dim',2);
massTrendAllShelves = massTrendAllShelves.*365.25;
disp([num2str(sum(massTrendAllShelves<0 & massPAllShelves<0.05 & delMass<0 & sigMass==1)) ' shelves have a significant trend for mass loss']);
disp([num2str(sum(relMassTrendAllShelves<0 & relMassPAllShelves<0.05 & delMass<0 & sigMass==1)) ' shelves have a significant relative trend for mass loss']);
disp([num2str(sum(relMassTrendAllShelves<-2 & relMassPAllShelves<0.05 & delMass<0 & sigMass==1)) ' shelves have a significant relative trend greater than 2% per year for mass loss']);

% Relative mass change
disp(' ');
disp('Relative mass change');
disp([num2str(sum(relMassChangeAllShelves<-10)) ' ice shelves have lost more than 10% of their mass']);
disp([num2str(sum(relMassChangeAllShelves<-30)) ' ice shelves have lost more than 30% of their mass']);

%% Discharge changes

disp(' ')
disp(' ')
disp(' ')
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%% DISCHARGE CHANGE %%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')

disp(' ')
disp('Discharge increases:')
disp([' - ' num2str(sum(delDischarge>0 & delDischarge-delDischargeE>0)) ' shelves had significant increases in discharge' ]);
disp([' - ' num2str(sum(delDischarge>0)) ' shelves had any overall increase in discharge' ]);
disp([' - All shelves with significant increases in discharge: ' shelves{delDischarge>0 & delDischarge-delDischargeE>0} ]);
disp([' - All shelves with any increase in overall discharge: ' shelves{delDischarge>0} ]);
disp([' - All discharge increases contributed ' num2str(sum(delDischarge(delDischarge>0))) ' +/- '  num2str(rssq(delDischargeE(delDischarge>0))) ' Gt to ice shelf mass loss']);

%
disp(' ')
disp('Discharge decreases:')
disp([' - ' num2str(sum(delDischarge<0 & delDischarge+delDischargeE<0)) ' shelves had significant decreases in discharge' ]);
disp([' - ' num2str(sum(delDischarge<0)) ' shelves had any overall decrease in discharge' ]);
disp([' - All shelves with significant decrease in discharge: ' shelves{delDischarge<0 & delDischarge+delDischargeE<0} ]);
disp([' - All shelves with any overall decrease in discharge: ' shelves{delDischarge<0} ]);
disp([' - All discharge decreases contributed ' num2str(sum(delDischarge(delDischarge<0))) ' +/- '  num2str(rssq(delDischargeE(delDischarge<0))) ' Gt to ice shelf mass loss']);
disp([' - Significant discharge decreases contributed ' num2str(sum(delDischarge(delDischarge<0 & delDischarge+delDischargeE<0))) ' +/- '  num2str(rssq(delDischarge(delDischarge<0 & delDischarge+delDischargeE<0))) ' Gt to ice shelf mass loss']);


%% Contributions

disp(' ')
disp(' ')
disp(' ')
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%% CONTRIBUTIONS %%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')


% which shelves, if any, had a significant contribution from delSMB
sigSMB = logical(1-double(delSMB+delSMBE>0 & delSMB-delSMBE<0));
[delSMB_sort,iv] = sort(delSMB,'descend');
delSMBE_sort = delSMBE(iv);
delMass_sort = delMass(iv);
shelves_SMB = shelves(iv);
sigSMB_sort = sigSMB(iv);
SMBprop = delSMB./delMass.*100;
SMBprop_sort = SMBprop(iv);
SMB_T = table(shelves_SMB(:),delSMB_sort(:),delSMBE_sort(:),SMBprop_sort(:),sigSMB_sort,delMass_sort(:),'variableNames',{'Shelves','SMB change (Gt)','error (Gt)','prop (%)','Significant','mass change Gt'});
[SMBprop_sort,iv] = sort(SMBprop,'descend');
shelves_SMB = shelves(iv);
SMBprop_minus = (delSMB-delSMBE)./delMass.*100;
SMBprop_plus = (delSMB+delSMBE)./delMass.*100;
SMBprop_min = min([SMBprop_minus,SMBprop_plus],[],2);
SMBprop_max = max([SMBprop_minus,SMBprop_plus],[],2);
SMBprop_min_sort = SMBprop_min(iv);
SMBprop_max_sort = SMBprop_max(iv);
delMass_sort = delMass(iv);
PropSMB_T = table(shelves_SMB(:),SMBprop_sort(:),SMBprop_min_sort(:),SMBprop_max_sort(:),nanmean([SMBprop_max_sort(:)-SMBprop_sort(:).*100,SMBprop_sort(:).*100-SMBprop_min_sort(:)],2),delMass_sort(:),'variableNames',{'Shelves','prop','prop max','prop_min','prop error %','mass change (Gt)'});

% which shelves had a significant contribution from retreat/advance
sigArea= logical(1-double(delArea+delAreaE>0 & delArea-delAreaE<0));
[delArea_sort,iv] = sort(delArea,'descend');
delAreaE_sort = delAreaE(iv);
delMass_sort = delMass(iv);
shelves_Area = shelves(iv);
sigArea_sort = sigArea(iv);
Areaprop = delArea./delMass.*100;
Areaprop_sort = Areaprop(iv);
Area_T = table(shelves_Area(:),delArea_sort(:),delAreaE_sort(:),Areaprop_sort(:),sigArea_sort(:),'variableNames',{'Shelves','area change (Gt)','error (Gt)','prop (%)','Significant'});
[Areaprop_sort,iv] = sort(Areaprop,'descend');
shelves_Area = shelves(iv);
Areaprop_minus = (delArea-delAreaE)./delMass.*100;
Areaprop_plus = (delArea+delAreaE)./delMass.*100;
Areaprop_min = min([Areaprop_minus,Areaprop_plus],[],2);
Areaprop_max = max([Areaprop_minus,Areaprop_plus],[],2);
Areaprop_min_sort = Areaprop_min(iv);
Areaprop_max_sort = Areaprop_max(iv);
PropArea_T = table(shelves_Area(:),Areaprop_sort(:),Areaprop_min_sort(:),Areaprop_max_sort(:),nanmean([Areaprop_max_sort(:)-Areaprop_sort(:).*100,Areaprop_sort(:).*100-Areaprop_min_sort(:)],2),delArea_sort(:),'variableNames',{'Shelves','prop','prop max','prop_min','prop error %','area change'});

% which shelves had a significant contribution from thickness changes
sigThick= logical(1-double(delThick+delThickE>0 & delThick-delThickE<0));
[delThick_sort,iv] = sort(delThick,'descend');
delThickE_sort = delThickE(iv);
delMass_sort = delMass(iv);
shelves_Thick = shelves(iv);
sigThick_sort = sigThick(iv);
Thickprop = delThick./delMass.*100;
Thickprop_sort = Thickprop(iv);
Thick_T = table(shelves_Thick(:),delThick_sort(:),delThickE_sort(:),Thickprop_sort(:),sigThick_sort(:),'variableNames',{'Shelves','thickness change (Gt)','error (Gt)','prop (%)','Significant'});
[Thickprop_sort,iv] = sort(Thickprop,'descend');
shelves_Thick = shelves(iv);
Thickprop_minus = (delThick-delThickE)./delMass.*100;
Thickprop_plus = (delThick+delThickE)./delMass.*100;
Thickprop_min = min([Thickprop_minus,Thickprop_plus],[],2);
Thickprop_max = max([Thickprop_minus,Thickprop_plus],[],2);
Thickprop_min_sort = Thickprop_min(iv);
Thickprop_max_sort = Thickprop_max(iv);
PropThick_T = table(shelves_Thick(:),Thickprop_sort(:),Thickprop_min_sort(:),Thickprop_max_sort(:),nanmean([Thickprop_max_sort(:)-Thickprop_sort(:).*100,Thickprop_sort(:).*100-Thickprop_min_sort(:)],2),delThick_sort(:),'variableNames',{'Shelves','prop','prop max','prop_min','prop error %','area change'});

% which shelves had a significant contribution from thickness changes
sigDischarge= logical(1-double(delDischarge+delDischargeE>0 & delDischarge-delDischargeE<0));
[delDischarge_sort,iv] = sort(delDischarge,'descend');
delDischargeE_sort = delDischargeE(iv);
delMass_sort = delMass(iv);
shelves_Discharge = shelves(iv);
sigDischarge_sort = sigDischarge(iv);
Dischargeprop = delDischarge./delMass.*100;
Dischargeprop_sort = Dischargeprop(iv);
Discharge_T = table(shelves_Discharge(:),delDischarge_sort(:),delDischargeE_sort(:),Dischargeprop_sort(:),sigDischarge_sort(:),'variableNames',{'Shelves','discharge change (Gt)','error (Gt)','prop (%)','Significant'});
[Dischargeprop_sort,iv] = sort(Dischargeprop,'descend');
shelves_Discharge = shelves(iv);
Dischargeprop_minus = (delDischarge-delDischargeE)./delMass.*100;
Dischargeprop_plus = (delDischarge+delDischargeE)./delMass.*100;
Dischargeprop_min = min([Dischargeprop_minus,Dischargeprop_plus],[],2);
Dischargeprop_max = max([Dischargeprop_minus,Dischargeprop_plus],[],2);
Dischargeprop_min_sort = Dischargeprop_min(iv);
Dischargeprop_max_sort = Dischargeprop_max(iv);
PropDischarge_T = table(shelves_Discharge(:),Dischargeprop_sort(:),Dischargeprop_min_sort(:),Dischargeprop_max_sort(:),nanmean([Dischargeprop_max_sort(:)-Dischargeprop_sort(:).*100,Dischargeprop_sort(:).*100-Dischargeprop_min_sort(:)],2),delDischarge_sort(:),'variableNames',{'Shelves','prop','prop max','prop_min','prop error %','area change'});


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Contributions for individual shelves
disp(' ');
prop_m_change = delThick./delMass.*100;
prop_m_change_minus = (delThick-delThickE)./delMass.*100;
prop_m_change_plus = (delThick+delThickE)./delMass.*100;
prop_m_change_min = min([prop_m_change_minus,prop_m_change_plus],[],2);
prop_m_change_max = max([prop_m_change_minus,prop_m_change_plus],[],2);
prop_c_change = delArea./delMass.*100;
prop_c_change_minus = (delArea-delAreaE)./delMass.*100;
prop_c_change_plus = (delArea+delAreaE)./delMass.*100;
prop_c_change_min = min([prop_c_change_minus,prop_c_change_plus],[],2);
prop_c_change_max = max([prop_c_change_minus,prop_c_change_plus],[],2);
disp('Contributions to mass loss:')
disp('Basal melt caused >50% mass loss at some shelves:');
central_count = sum(delMass<0 & sigMass==1 & prop_m_change>=50);
upper_count = sum(delMass<0 & sigMass==1 & prop_m_change_min>=50);
lower_count = sum(delMass<0 & sigMass==1 & prop_m_change_max>=50);
disp([' - central estimate: For ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly), basal melting caused >50% of that loss at ' num2str(central_count) ' (' num2str(central_count/sum(delMass<0 & sigMass==1)*100) '%)' ]); 
disp(['   with a range of: ' num2str(lower_count) '-' num2str(upper_count) '(' num2str(lower_count/sum(delMass<0 & sigMass==1).*100) '-' num2str(upper_count/sum(delMass<0 & sigMass==1).*100) '%)' ]); 

disp(' ');
disp('Basal melt caused >50% mass gain at some shelves:');
central_count = sum(delMass>0 & sigMass==1 & prop_m_change>=50);
upper_count = sum(delMass>0 & sigMass==1 & prop_m_change_min>=50);
lower_count = sum(delMass>0 & sigMass==1 & prop_m_change_max>=50);
disp([' - central estimate: For ' num2str(sum(delMass>0 & sigMass==1)) ' shelves that gained mass (significantly), basal melting caused >50% of gain loss at ' num2str(central_count) ' (' num2str(central_count/sum(delMass>0 & sigMass==1)*100) '%)' ]); 
disp(['   with a range of: ' num2str(lower_count) '-' num2str(upper_count) '(' num2str(lower_count/sum(delMass>0 & sigMass==1).*100) '-' num2str(upper_count/sum(delMass>0 & sigMass==1).*100) '%)' ]); 

disp(' ');
disp('Some shelves lost mass entirely due to thinning:')
central_count = sum(delMass<0 & sigMass==1 & prop_c_change<=0);
upper_count = sum(delMass<0 & sigMass==1 & prop_c_change_min<=0);
lower_count = sum(delMass<0 & sigMass==1 & prop_c_change_max<=0);
disp([' - central estimate: For ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly), basal melting caused all of that loss at ' num2str(central_count) ' (' num2str(central_count/sum(delMass<0 & sigMass==1)*100) '%)' ]); 
disp(['   with a range of: ' num2str(lower_count) '-' num2str(upper_count) '(' num2str(lower_count/sum(delMass<0 & sigMass==1)) '-' num2str(upper_count/sum(delMass<0 & sigMass==1)) '%)' ]); 

disp(' ');
disp('Some shelves lost mass entirely due to retreat:')
central_count = sum(delMass<0 & sigMass==1 & prop_m_change<=0);
upper_count = sum(delMass<0 & sigMass==1 & prop_m_change_min<=0);
lower_count = sum(delMass<0 & sigMass==1 & prop_m_change_max<=0);
disp([' - central estimate: For ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly), basal melting caused all of that loss at ' num2str(central_count) ' (' num2str(central_count/sum(delMass<0 & sigMass==1)*100) '%)' ]); 
disp(['   with a range of: ' num2str(lower_count) '-' num2str(upper_count) '(' num2str(lower_count/sum(delMass<0 & sigMass==1)) '-' num2str(upper_count/sum(delMass<0 & sigMass==1)) '%)' ]); 


%%%%%%%%%%%%%%%%%%%%%%
disp(' ');
disp(' ');
disp('Contributions to mass gain:')
disp('Some shelves gained mass entirely because of thickening:')
central_count = sum(delMass>0 & sigMass==1 & prop_c_change>=0);
upper_count = sum(delMass>0 & sigMass==1 & prop_c_change_min>=0);
lower_count = sum(delMass>0 & sigMass==1 & prop_c_change_max>=0);
disp([' - central estimate: For ' num2str(sum(delMass>0 & sigMass==1)) ' shelves that gained mass (significantly), ' num2str(central_count) ' (' num2str(central_count/sum(delMass>0 & sigMass==1)*100) '%) did so despite retreating' ]); 
disp(['   with a range of: ' num2str(lower_count) '-' num2str(upper_count) '(' num2str(lower_count/sum(delMass>0 & sigMass==1)) '-' num2str(upper_count/sum(delMass>0 & sigMass==1)) '%)' ]); 

disp(' ');
disp('Some shelves gained mass entirely because of advance:')
central_count = sum(delMass>0 & sigMass==1 & prop_m_change>=0);
upper_count = sum(delMass>0 & sigMass==1 & prop_m_change_min>=0);
lower_count = sum(delMass>0 & sigMass==1 & prop_m_change_max>=0);
disp([' - central estimate: For ' num2str(sum(delMass>0 & sigMass==1)) ' shelves that gained mass (significantly), ' num2str(central_count) ' (' num2str(central_count/sum(delMass>0 & sigMass==1)*100) '%) did so despite thinning' ]); 
disp(['   with a range of: ' num2str(lower_count) '-' num2str(upper_count) '(' num2str(lower_count/sum(delMass>0 & sigMass==1)) '-' num2str(upper_count/sum(delMass>0 & sigMass==1)) '%)' ]); 




%% Correlations

disp(' ')
disp(' ')
disp(' ')
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%% Correlations %%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Correlations
sigDischargeIncrease = (delDischarge-delDischargeE)>0; %R_all_time>0.25 & P_all_time<0.05; %tmp>0 & tmp2>0;
justThinningAndAnyDischargeIncrease = delThick<0 & delDischarge>0;
justRetreatAndAnyDischargeIncrease = delArea<0 & delDischarge>0;
ASE_shelves = {'Pine_Island','Thwaites','Crosson','Dotson','Getz'};
ASE_ind = [107,139,26,32,52];
C = load('../correlations/ice_shelf_correlation_data.mat');
disp(' ');
disp('Mass loss vs discharge timeseries');
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & delDischarge-delDischargeE>0)) ' had a significant increase in discharge (cumulativeDischargeChange, accounting for error)']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & C.R_DischargeVsTime>0.5 & C.P_DischargeVsTime<0.05)) ' had a significant (P<0.05) positive (R>0.5) discharge trend']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & C.R_DischargeVsTime>0.5)) ' had a positive (R>0.5) discharge trend']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05)) ' had a significant (P<0.05) positive (R>0.5) cumulative discharge trend']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & C.R_CumulativeDischargeVsTime>0.5)) ' had a positive (R>0.5) cumulative discharge trend']);


% discharge vs mass change
disp(' ');
disp('discharge vs mass');
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass overall (significantly) ' num2str(sum(delMass<0 & sigMass==1 & C.R_DischargeVsTime>0.5 & C.P_DischargeVsTime<0.05)) ' had significant positive correlation between annual grounding line discharge and time']);
    disp(['Alternatively: Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass overall (significantly) ' num2str(sum(delMass<0 & sigMass==1 & C.dischargeTrendAllShelves>0 & C.dischargePAllShelves<0.05)) ' had significant positive trend in grounding line discharge']);
disp(['and ' num2str(sum(delMass<0 & sigMass==1 & delDischarge-delDischargeE>0)) ' had a significant overall increase in grounding line discharge']);
disp(['However, only ' num2str(sum(delMass<0 & sigMass==1 & C.R_DischargeVsTime>0.5 & C.P_DischargeVsTime<0.05 & C.R_MassVsTime<0.5 & C.P_MassVsTime<0.05)) ' also had significant negative correlations between mass balance through time']);
    disp(['alternatively: ' num2str(sum(delMass<0 & sigMass==1 & C.massBalanceTrendAllShelves<0 & C.massBalancePAllShelves<0.05 )) ' had significant trends for decreasing mass balance through time']);

% just discharge
disp(' ')
disp(['Amongst all studied shelves ' num2str(sum(C.R_DischargeVsTime>0.5 & C.P_DischargeVsTime<0.05)) ' had a significant correlation between discharge and time']);
disp(['and ' num2str(sum(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05)) ' had a significant correlation between cumulative discharge and time']);

% Thinning vs cumulative discharge
disp(' ');
disp('thinning vs cumulative discharge timeseries');
disp(['Of those, there is a significant positive correlation between cumulative thinning and cumulative discharge change at ' num2str(sum(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05)) ' shelves']);
    disp(['...other method: there was a significant positive correlation between cumulative thinning and cumulative discharge change at ' num2str(sum(C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05)) ' shelves']);
disp(['The relationship between cumulative thinning and cumulative discharge change is strongest in the ASE: R^2=' num2str(nanmean([C.R_CumulativeDischargeVsCumulativeThinning(ASE_ind)])) ', p=' num2str(nanmean([C.P_CumulativeDischargeVsCumulativeThinning(ASE_ind)]))]);
disp(['The strength of the relationship varies from ' num2str(min(C.cumulativeThinningTrendAllShelves(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))) ' to ' num2str(max(C.cumulativeThinningTrendAllShelves(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))) ' (negative) Gt per year']);
thinVsDischargeConvert = gradient(delDischarge)./gradient(delThick.*-1); % time-series of Gt of discharge change per Gt of thinning (cumulative). So positive is what you'd expect at Pine Island.
TF = isoutlier(thinVsDischargeConvert,2);
thinVsDischargeConvert(TF) = NaN;
thinVsDischargeConvert = nanmean(thinVsDischargeConvert,2);
disp(['The relationship between cumulative thinning and cumulative discharge change is strongest in the ASE: ' num2str(nanmean(thinVsDischargeConvert(ASE_ind))) ' +/- ' num2str(nanstd(thinVsDischargeConvert(ASE_ind))) ' Gt of discharge increase per Gt of thinning']);
disp(['The relationship between cumulative thinning and cumulative discharge change is strongest in the ASE ' num2str(nanmean(delDischarge(ASE_ind,end)./(delThick(ASE_ind,end).*-1))) ' +/-' num2str(nanstd(delDischarge(ASE_ind,end)./(delThick(ASE_ind,end).*-1))) ' Gt of discharge increase per Gt of thinning']);
thinVsDischargeConvert = gradient(delDischarge)./gradient(delThick.*-1); % time-series of Gt of discharge change per Gt of thinning (cumulative). So positive is what you'd expect at Pine Island.
nanmax(thinVsDischargeConvert(ASE_ind,:),[],2)


shelves(find(thinVsDischargeConvert==min(thinVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))))
shelves(find(thinVsDischargeConvert==max(thinVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))))
disp(['The strength of the relationship varies from ' num2str(min(thinVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))) ' to ' num2str(max(thinVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))) ' Gt of discharge increase per Gt of thinning']);
disp(['The average strength of the relationship at shelves with increasing discharge is ' num2str(nanmean(thinVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))) ' +/- ' num2str(nanstd(thinVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05))) ' Gt of discharge increase per Gt of thinning']);
ind = C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05;
disp(['The average strength of the relationship at shelves with increasing discharge is ' num2str(nanmean(delDischarge(ind,end)./(delThick(ind,end).*-1))) ' +/- ' num2str(nanstd(delDischarge(ind,end)./(delThick(ind,end).*-1))) ' Gt of discharge increase per Gt of thinning']);
%
figure;plot(time,dischargeChangeTimeseriesRel1997AllShelves(find(strcmp(shelves,'Thwaites')==1),:)./thinningTimeseriesForce1997AllShelves(find(strcmp(shelves,'Thwaites')==1),:).*-1); datetick('x')
figure;scatter(thinningTimeseriesForce1997AllShelves(find(strcmp(shelves,'Crosson')==1),:).*-1,dischargeChangeTimeseriesRel1997AllShelves(find(strcmp(shelves,'Crosson')==1),:),[],colorcet('Gouldian','N',25))
figure;scatter(thinningTimeseriesForce1997AllShelves(find(strcmp(shelves,'Crosson')==1),:).*-1,dischargeChangeTimeseriesRel1997AllShelves(find(strcmp(shelves,'Crosson')==1),:),[],colorcet('Gouldian','N',25))

figure;plot(time,dischargeChangeTimeseriesRel1997AllShelves(find(strcmp(shelves,'Totten')==1),:)./thinningTimeseriesForce1997AllShelves(find(strcmp(shelves,'Totten')==1),:).*-1); datetick('x')
hold on;
yyaxis right
plot(time,massBalanceAllShelves(find(strcmp(shelves,'Totten')==1),:),'k')


% Retreat vs cumulative discharge
disp(' ');
disp('retreat vs cumulative discharge timeseries');
disp(['Of those, there is a significant positive correlation between cumulative thinning and cumulative discharge change at ' num2str(sum(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05)) ' shelves']);
    disp(['...other method: there was a significant positive correlation between cumulative retreat and cumulative discharge change at ' num2str(sum(C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05)) ' shelves']);
disp(['The relationship between cumulative retreat and cumulative discharge change is strongest in the ASE: R^2=' num2str(nanmean(C.R_CumulativeDischargeVsCumulativeRetreat(ASE_ind))) ', p=' num2str(nanmean(C.P_CumulativeDischargeVsCumulativeRetreat(ASE_ind)))]);
disp(['The strength of the relationship varies from ' num2str(min(C.cumulativeRetreatTrendAllShelves(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05))) ' to ' num2str(max(C.cumulativeRetreatTrendAllShelves(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05))) ' (negative) Gt per year']);
retreatVsDischargeConvert = delDischarge./cumulativeRetreatBalanceAllShelves.*-1; % time-series of Gt of discharge change per Gt of retreat (cumulative). So positive is what you'd expect at Pine Island.
TF = isoutlier(retreatVsDischargeConvert,2);
retreatVsDischargeConvert(TF) = NaN;
retreatVsDischargeConvert = nanmean(retreatVsDischargeConvert,2);
shelves(find(retreatVsDischargeConvert==min(retreatVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05))))
shelves(find(retreatVsDischargeConvert==max(retreatVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05))))
disp(['The strength of the relationship varies from ' num2str(min(retreatVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05))) ' to ' num2str(max(retreatVsDischargeConvert(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05))) ' Gt of discharge increase per Gt of retreat']);

ind = C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05;
disp(['The average strength of the relationship at shelves with increasing discharge is ' num2str(nanmean(delDischarge(ind,end)./(cumulativeRetreatBalanceAllShelves(ind,end).*-1))) ' +/- ' num2str(nanstd(delDischarge(ind,end)./(cumulativeRetreatBalanceAllShelves(ind,end).*-1))) ' Gt of discharge increase per Gt of retreat']);
disp(['The relationship between cumulative retreat and cumulative discharge change is strongest in the ASE ' num2str(nanmean(delDischarge(ASE_ind,end)./(cumulativeRetreatBalanceAllShelves(ASE_ind,end).*-1))) ' +/-' num2str(nanstd(delDischarge(ASE_ind,end)./(cumulativeRetreatBalanceAllShelves(ASE_ind,end).*-1))) ' Gt of discharge increase per Gt of retreat']);


% Combined retreat and thinning
disp(' ');
disp('Combined');
disp(['There is a significant positive correlation between cumultive thinning, cumulative retreat and cumulative discharge change at ' num2str(sum(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05 & C.R_CumulativeDischargeVsCumulativeRetreat>0.5 & C.P_CumulativeDischargeVsCumulativeRetreat<0.05 & C.R_CumulativeDischargeVsCumulativeThinning>0.5 & C.P_CumulativeDischargeVsCumulativeThinning<0.05)) ' of ' num2str(sum(C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05)) ' shelves that also had significant postitive cumulative discharge']);
disp(['Only ' num2str(sum(C.R_CumulativeDischargeVsCumulativeRetreat<0.5 & C.R_CumulativeDischargeVsCumulativeThinning<0.5 & C.R_CumulativeDischargeVsTime>0.5 & C.P_CumulativeDischargeVsTime<0.05)) ' shelves with significant positive cumulative discharge trends had no relationship to cumulative retreat or cumulative thinning (melt anomaly)']);


%% Freshwater flux

disp(' ')
disp(' ')
disp(' ')
disp(' ')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')
disp('%%% FRESHWATER FLUX %%%')
disp('%%%%%%%%%%%%%%%%%%%%%%%%%')

% Get totals
freshwaterAllShelves = calvingAllShelves + meltAllShelves;
freshwaterErrorAllShelves = sqrt(calvingErrorAllShelves.^2 + meltErrorAllShelves.^2);
cumulativeCalvingAllShelves = cumsum(calvingAllShelves,2);
cumulativeMeltAllShelves = cumsum(meltAllShelves,2);
cumulativeFreshwaterAllShelves = cumsum(freshwaterAllShelves,2);
cumulativeCalvingErrorAllShelves = rssq(calvingErrorAllShelves,2);
cumulativeMeltErrorAllShelves = rssq(meltErrorAllShelves,2);
cumulativeFreshwaterErrorAllShelves = rssq(freshwaterErrorAllShelves,2);

% Get trends
%   - individual ice shelves
[calvingTrendAllShelves,calvingPAllShelves] = trend(calvingAllShelves,time,'dim',2);
calvingTrendAllShelves = calvingTrendAllShelves.*365.25;
[meltTrendAllShelves,meltPAllShelves] = trend(meltAllShelves,time,'dim',2);
meltTrendAllShelves = meltTrendAllShelves.*365.25;
[freshwaterTrendAllShelves,freshwaterPAllShelves] = trend(freshwaterAllShelves,time,'dim',2);
freshwaterTrendAllShelves = freshwaterTrendAllShelves.*365.25;
relFreshwaterTrendAllShelves = freshwaterTrendAllShelves./mean(freshwaterAllShelves,2).*100;
relMeltTrendAllShelves = meltTrendAllShelves./mean(meltAllShelves,2).*100;
relCalvingTrendAllShelves = calvingTrendAllShelves./mean(calvingAllShelves,2).*100;
%   - Antarctic total
[calvingTrendAIS,calvingPAIS] = trend(sum(calvingAllShelves,1),time);
calvingTrendAIS = calvingTrendAIS.*365.25;
[meltTrendAIS,meltPAIS] = trend(sum(meltAllShelves,1),time);
meltTrendAIS = meltTrendAIS.*365.25;
[freshwaterTrendAIS,freshwaterPAIS] = trend(sum(freshwaterAllShelves,1),time);
freshwaterTrendAIS = freshwaterTrendAIS.*365.25;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Total freshwater flux
disp('Antarctic totals');
disp(['Total freshwaster: ' num2str(sum(freshwaterAllShelves(:))) ' +/- ' num2str(rssq(rssq(freshwaterErrorAllShelves,2))) ' Gt of freshwater to the Southern Ocean since 1997']);
disp(['Calving has provided ' num2str(sum(calvingAllShelves(:))) ' +/- ' num2str(rssq(rssq(calvingErrorAllShelves,2))) ' Gt of freshwater to the Southern Ocean since 1997. ' num2str(sum(calvingAllShelves(:))/sum(freshwaterAllShelves(:))*100) '% of total' ]);
disp(['Melt has provided ' num2str(sum(meltAllShelves(:))) ' +/- ' num2str(rssq(rssq(meltErrorAllShelves,2))) ' Gt of freshwater to the Southern Ocean since 1997. ' num2str(sum(meltAllShelves(:))/sum(freshwaterAllShelves(:))*100) '% of total']);

% Annual freshwater flux
disp(' ');
disp('Annual fluxes:');
disp(['Annual freshwater flux Antarctica: ' num2str(sum(freshwaterAllShelves(:))/25) ' +/- ' num2str(rssq(mean(freshwaterErrorAllShelves,2))) ' Gt'])
disp(['Annual calving flux Antarctica: ' num2str(sum(calvingAllShelves(:))/25) ' +/- ' num2str(rssq(mean(calvingErrorAllShelves,2))) ' Gt'])
disp(['Annual melt flux Antarctica: ' num2str(sum(meltAllShelves(:))/25) ' +/- ' num2str(rssq(mean(meltErrorAllShelves,2))) ' Gt'])

% Annual variability:
disp(' ');
disp('Annual standard deviation');
disp(['Standard deviation of annual Antarctic freshwater flux: ' num2str(nanstd(nansum(freshwaterAllShelves,1))) ' Gt'])
disp(['Standard deviation of annual Antarctic calving flux: ' num2str(nanstd(nansum(calvingAllShelves,1))) ' Gt'])
disp(['Standard deviation of annual Antarctic melt flux: ' num2str(nanstd(nansum(meltAllShelves,1))) ' Gt'])

% Liquid vs solid contribution
disp(' ');
disp('solid vs liquid contributions:');
disp([' - Liquid contribution Antarctica: ' num2str(sum(cumulativeMeltAllShelves(:,end))/sum(cumulativeFreshwaterAllShelves(:,end))*100) ' %']);
[~,iv] = sort(cumulativeCalvingAllShelves(:,end),'ascend');
smallCalvings = iv(1:end-5); % all but the largest 5 calving events
disp([' - Liquid contribution Antarctica (ignoring the largest 5 calving events): ' num2str(sum(cumulativeMeltAllShelves(:,end))/sum(cumulativeFreshwaterAllShelves(smallCalvings,end))*100) ' %']);
disp(['        - Nb: the largest 5 calving events account for: ' num2str( sum(cumulativeCalvingAllShelves(iv(end-4:end),end)) / sum(cumulativeCalvingAllShelves(:,end)) *100) '% of the total calving flux']);
calvingFreshwaterContrib = cumulativeCalvingAllShelves(:,end)./cumulativeFreshwaterAllShelves(:,end).*100;
disp([' - Calving provides more than 50% of the total freshwater export at ' num2str(sum(calvingFreshwaterContrib>50)) ' (' num2str(sum(calvingFreshwaterContrib>50)/162*100) '%) ice shelves']);

% Calving rate is highly variable, so melt probably dominanted in some
% years. How many?
disp(' ');
meltAnnualContrib = sum(meltAllShelves,1)./sum(freshwaterAllShelves,1).*100;
disp('Number of years where liquid contribution dominanted at Antarctic scale');
disp(['Melt provided over 50% of the total freshwater export in ' num2str(sum(meltAnnualContrib>50)) ' years (' num2str(sum(meltAnnualContrib>50)/25*100) '% of years)']);



% Trends
disp(' ')
disp('Freshwater trends:');
disp([' - Antarctic freshwater trend : ' num2str(freshwaterTrendAIS) ' Gt/yr (p=' num2str(freshwaterPAIS) ')']);
disp([' - Antarctic calving trend : ' num2str(calvingTrendAIS) ' Gt/yr (p=' num2str(calvingPAIS) ')']);
disp([' - Antarctic melt trend : ' num2str(meltTrendAIS) ' Gt/yr (p=' num2str(meltPAIS) ')']);
disp(' ');
disp([' - all shelves freshwater trends: ' num2str(sum(freshwaterTrendAllShelves>0 & freshwaterPAllShelves<0.05)) ' shelves have a positive freshwater flux trend']);
disp([' - all shelves calving trends: ' num2str(sum(calvingTrendAllShelves>0 & calvingPAllShelves<0.05)) ' shelves have a positive calving flux trend']);
disp([' - all shelves melt trends: ' num2str(sum(meltTrendAllShelves>0 & meltPAllShelves<0.05)) ' shelves have a positive melt flux trend']);
disp(' ');
disp([' - all shelves relative freshwater trends: ' num2str(sum(relFreshwaterTrendAllShelves>5 & freshwaterPAllShelves<0.05)) ' shelves have a positive freshwater flux trend greater than 5% year']);
disp([' - all shelves relative calving trends: ' num2str(sum(relCalvingTrendAllShelves>2.5 & calvingPAllShelves<0.05)) ' shelves have a positive calving flux trend greater than 2.5% year']);
disp([' - all shelves relative melt trends: ' num2str(sum(relMeltTrendAllShelves>5 & meltPAllShelves<0.05)) ' shelves have a positive melt flux trend greater than 5% year']);
disp([shelves(relCalvingTrendAllShelves>5 & calvingPAllShelves<0.05) ' is the ice shelf with a positive calving trend. The trend is: ' num2str(relCalvingTrendAllShelves(calvingTrendAllShelves>0 & calvingPAllShelves<0.05)) '%/yr'])
disp('The shelves with a positive melt flux are:')
shelves(relMeltTrendAllShelves>5 & meltPAllShelves<0.05)
