% calc_thwaites_calving_flux_julia

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%% Prep

rho_ice = 917;

%% Get mask bounds

% Get list of masks
mask_list = dir('D:/work/Fellowship_Leeds/Data/Calving_front_locations/Thwaites/Thwaites_ShelfArea/*shp');
% Get min/max extent of masks
for i = 1:numel(mask_list)
    mask = shaperead([mask_list(i).folder '/' mask_list(i).name]);
    x = mask.X;
    y = mask.Y;
    if i == 1
        min_x = nanmin(x);
        max_x = nanmax(x);
        min_y = nanmin(y);
        max_y = nanmax(y);
    else
        if nanmin(x)<min_x
            min_x = nanmin(x);
        end
        if nanmax(x)>max_x
            max_x = nanmax(x);
        end
        if nanmin(y)<min_y
            min_y = nanmin(y);
        end
        if nanmax(y)>max_y
            max_y = nanmax(y);
        end
    end
end
xlim = [min_x max_x];
ylim = [min_y max_y];
clear min_x max_x min_y max_y x y i

%% Load velocity data

% Load ITS_LIVE data: 
[vxi,x,y] = itslive_data('vx',xlim,ylim); 
vyi = itslive_data('vy',xlim,ylim); 
wi = 1./itslive_data('v_err',xlim,ylim).^2; % weights
v_source = zeros(size(vxi),'uint8'); 
[X,Y] = meshgrid(x,y); 

% Indices of missing ITS_LIVE data: 
indi = ~isfinite(vxi) | ~isfinite(vyi) | ~isfinite(wi); 
vxi(indi) = 0; 
vyi(indi) = 0; 
wi(indi) = 0; 

% Load Measures data: 
[vxm,vym] = measures_interp('velocity',X,Y); 
wm = 1./measures_interp('error',X,Y).^2; 

% Indices of missing Measures data: 
indm = ~isfinite(vxm) | ~isfinite(vym) | ~isfinite(wm); 
vxm(indm) = 0; 
vym(indm) = 0; 
wm(indm) = 0; 

% Weighted mean velocity components: 
vx = (vxi.*wi + vxm.*wm)./(wi + wm); 
vy = (vyi.*wi + vym.*wm)./(wi + wm); 

% Replace the completely unknown values with NaNs: 
vx(indi & indm) = nan; 
vy(indi & indm) = nan; 

vx = double(vx); 
vy = double(vy); 

v_source(~indi & indm) = 1; % ITS_LIVE
v_source(indi & ~indm) = 2; % Measures v2
v_source(~indi & ~indm) = 3; % Blend of ITS_LIVE and MEasures 

% Fill any nan holes in the velocity field, but don't fill the ocean: 
L = bwlabel(isnan(vx)); % Label the nan regions, and the ocean will be L=1.  
vx = regionfill(vx,L>1); 
vy = regionfill(vy,L>1);
v_source(L>1) = 4; % interpolated
v = hypot(vx,vy); 

% Clear some variables
clear vxi vyi wi vxm vym wm L

%% Firn air

% Start with simple mask
mask_bm = bedmachine_interp('mask',X,Y);
grounded = ismember(mask_bm,[1 2 4]); 

% Get firn air content from Paolo's data
fac = ncread('ANT_G1920V01_IceShelfMelt.nc','fac');
Hx = ncread('ANT_G1920V01_IceShelfMelt.nc','x');
Hy = ncread('ANT_G1920V01_IceShelfMelt.nc','y');
[HX,HY] = meshgrid(Hx,Hy);
firn_time = ncread('ANT_G1920V01_IceShelfMelt.nc','time') + datenum(1950,1,1);
ind = find(firn_time>=datenum(2010,1,1) & firn_time<=datenum(2021,12,31));
fac = nanmean(fac(:,:,ind),3);
fac = flipud(rot90(fac)); 
fac = interp2(HX,HY,fac,X,Y);
clear firn_time ind Hx Hy HX HY

% Fill any nan holes in the firn air field, but don't fill the ocean: 
L = bwlabel(isnan(fac) & isfinite(v) & ~grounded); % Label the nan regions, and the ocean will be L=1. 
%   - constrain region fill by setting edges to 0
fill = zeros(size(fac));
fill([1,end],:) = 1;
fill(:,[1 end]) = 1;
fill(isfinite(fac))=0;
fac(logical(fill))=0;
%   - fill regions
fac = regionfill(fac,isnan(fac)); 
fac(L==0 & isnan(v))=NaN;

% Housekeeping
clear L fn firn_lat firn_lon firn_x firn_y num_ts F  fill L


%% Thickness

% Start with the BedMachine surface: 
H_bm = bedmachine_interp('thickness',X,Y);

% Load REMA data: 
h_rema = wgs2gl04c(X,Y,rema_interp(X,Y,'res',200));
h_rema(bwdist(~isfinite(h_rema))*.5<5) = NaN; % eliminates everything within 5 km of NaNs because of weird icebergs at the edge of Ronne 

% % Load Bedmap2 data: 
% h_b2 = bedmap2_interp(X,Y,'surface'); 
% isn = ~(h_b2>0);  
% h_b2(isn) = bedmap2_interp(X(isn),Y(isn),'surface','nearest'); 
% 
% % load bamber: 
% h_bam = wgs2gl04c(X,Y,bamberdem_interp(X,Y));
% h_bam(bwdist(~isfinite(h_bam))*.5<10) = NaN; % Eliminates 10 km perimeter b/c drooping ice sheet edges in Bamber and RAMP dems
% 
% % RAMP2:
% [h_ramp,xramp,yramp] = geoimread('ramp2_dem_osu91a200m.tif',xlim,ylim); % The OSU version of the file is referenced to the geoid whereas the RAM2_DEM.tif is referenced to wgs84. Use OSU.  
% [xramp,yramp] = meshgrid(xramp,yramp);
% h_ramp = double(h_ramp); 
% h_ramp(h_ramp==0) = NaN; % Convert zeros to NaN so interpolation won't produce thin ice shelf edges.  
% h_ramp = interp2(xramp,yramp,h_ramp,X,Y); 
% h_ramp(bwdist(~isfinite(h_ramp))*.5<10) = NaN;  % Eliminates 10 km perimeter b/c drooping ice sheet edges in Bamber and RAMP dems
% clear xramp yramp

% Remove firn air content and convert elevation to thickness
hydro = 9.3364; % factor for converting surface elevation to thickness. 
H_rema = (h_rema - fac)*hydro; 
% H_b2 = (h_b2 - fac)*hydro; 
% H_bam = (h_bam-fac)*hydro; 
% H_ramp = (h_ramp-fac)*hydro; 
clear h_rema% h_b2 h_bam h_ramp

% Prevent new grounding: 
H_max = -1.12*bedmachine_interp('bed',X,Y); % maximum thickness that could exist at neutral buoyancy (no new grounding). if hydrostatic factor thickness2freeboard(1)=0.1071, then H_max = bed/(0.1071-1) = 1.1199*bed.   
H_rema(H_rema>H_max) = H_max(H_rema>H_max); 
% H_b2(H_b2>H_max) = H_max(H_b2>H_max); 
% H_bam(H_bam>H_max) = H_max(H_bam>H_max); 
% H_ramp(H_ramp>H_max) = H_max(H_ramp>H_max); 

% Eliminate negative thickness: 
H_rema(H_rema<0) = nan; 
% H_b2(H_b2<0) = nan; 
% H_bam(H_bam<0) = nan; 
% H_ramp(H_ramp<0) = nan; 

% Combine thickness 
% Distance in kilometers to BedMachine ocean data: 
D = bwdist(mask_bm==0)*0.5; 
D_thresh = 10; % replace thin ice within 10 km of ocean (for example, where Mertz Glacier tongue broke off and is now thin on its end in the BedMachinne data, overwrite that thin ice with the full thickness from Bedmap2.) 

% Start with BedMachine as the basis: 
H_source = zeros(size(H_bm),'uint8'); 
H_source(H_bm>0 | grounded) = 1; 

% Overwrite
%   - REMA
H_source(H_bm<(H_rema/2) & D<D_thresh & ~grounded) = 2; 
H_bm(H_source==2) = H_rema(H_source==2); 
% %   - bedmap2
% H_source(H_bm<(H_b2/2) & D<D_thresh & ~grounded) = 3; 
% H_bm(H_source==3) = H_b2(H_source==3); 
% %   - bamber
% H_source(H_bm<(H_bam/2) & D<D_thresh & ~grounded) = 4; 
% H_bm(H_source==4) = H_bam(H_source==4); 
% %   - RAMP
% H_source(H_bm<(H_ramp/2) & D<D_thresh & ~grounded) = 5; 
% H_bm(H_source==5) = H_ramp(H_source==5); 
%   - zeros
H_bm(H_bm==0 & ~grounded) = nan; 
%   - fill gaps
L = bwlabel(isnan(H_bm)); 
H_bm = regionfill(H_bm,L>1); 
H_source(L>1) = 6; % interpolated

% Overwrite with Paolo mean thickness where possible
H_p = ncread('ANT_G1920V01_IceShelfMelt.nc','thickness_mean');
Hx = ncread('ANT_G1920V01_IceShelfMelt.nc','x');
Hy = ncread('ANT_G1920V01_IceShelfMelt.nc','y');
[HX,HY] = meshgrid(Hx,Hy);
H_p = flipud(rot90(H_p));
H_p = interp2(HX,HY,H_p,X,Y);
H_source(isfinite(H_p)) = 6;
H_bm(H_source==6)=H_p(H_source==6);

% Finalise
H = H_bm;

% housekeeping
clear H_* L D D_thresh hydro

% make velocity and thickness have consistent extents
nan0 = isnan(H) | isnan(v);
H(nan0) = nan;
v(nan0) = nan;
clear nan0

%% Downscale and Inpaint the flow direction grids. 
% Inpainting H*v (rather than just v) effectively weights the flow directions 
% by how much ice is actually flowing, therefore preventing very thin ice
% from having too much influence on the hypothetical flow of a thick
% glacier. 
% 
% This code section takes about two minutes to inpaint at 1/4 scale. 

sc = 1/4; % scale for resizing velocity (for flow *directions* only) 
[vx_r,x_r,y_r] = demresize(vx,x,y,sc); 
vy_r = imresize(vy,sc); 
H_r = imresize(H,sc); 

Hvx_r = inpaint_nans(H_r.*vx_r,4); 
Hvy_r = inpaint_nans(H_r.*vy_r,4); 
Hv_r = hypot(Hvx_r,Hvy_r); 

% Displacement vectors will be used for the flow directions when extrapolating terminus speeds. 
dx = interp2(x_r,y_r,Hvx_r./Hv_r,X,Y); 
dy = interp2(x_r,y_r,Hvy_r./Hv_r,X,Y); 

%% Create streamlines for velocity
% This coarse resolution round is only to constrain the faraway bits later
% when the entire grid is inpainted. There's no real practical scientific
% purpose to this coarse resolution, but it does ultimately help us create
% a beautiful velocity map, and so it's well worth the extra ten minutes or
% so that it takes for this section to run. 
% 
% We're doing multiple rounds simply because of memory and speed
% limitations on my laptop. Ideally we'd do like a million steps in increments 
% of 0.01 or something, but my lil laptop just can't handle it, so this'll
% have to do. 

% Use the perimeter of the velocity measurements as the seed locations: 
perim = bwperim(isfinite(vx));
xseed = X(perim); 
yseed = Y(perim); 
[row,col] = find(perim); 
XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.005 6000]);

% Loop through each seed location to extrapolate terminus velocity and ice shelf name along flowlines:  
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = v(row(k),col(k)); 
   V{k}(:,2) = v(row(k),col(k)).*0+1; 
end

% Concatenate the cells into nan-separated arrays: 
M = [];
V2 = [];
for i = 1:numel(XY)
    if ~isempty(XY{i})
        M = [M; XY{i}; [NaN,NaN]];
        V2 = [V2; V{i}; [NaN,NaN]];
    end
end
V = V2; clear V2

% Are the seed locations captured in M? I'm not sure, so for good measure we'll create these arrays:  
xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
vv = [v(perim);V(:,1)] ;

% Remove NaNs: 
isf = isfinite(vv);
xx = xx(isf);
yy = yy(isf);
vv = vv(isf);

% Grid up the streamline data:  
vg = gridbin(xx,yy,vv,x,y); % gridbin is on my GitHub. It bins the average velocity observation in each grid cell. It's not as beautiful as gridfit, but it's the only way to deal with nearly a billion scattered data points.   

% Wherever gridbin gives us data, overwrite tmpvx, tmpvy, and tmpvs:  
isf = isfinite(vg);
vx(isf) = dx(isf).*vg(isf); 
vy(isf) = dy(isf).*vg(isf); 

% Fill holes in the velocity data: 
vx = regionfill(vx,isnan(vx)); 
vy = regionfill(vy,isnan(vy)); 
figure
imagescn(x,y,hypot(vx,vy))
cmocean thermal
hgl = bedmachine('gl','color','k');
hold on
axis off
set(gca,'colorscale','log')
caxis([1.5 5000])

% housekeeping
clear vg isf dx dy xx yy vv V M XY row col xseed yseed perim k i

%% Extrude Thickness Round 1 

perim = bwperim(imfill(H>=10,'holes'));
xseed = X(perim); 
yseed = Y(perim); 
[row,col] = find(perim); 

Hf = filt2(H,240,5e3,'lp'); 

XY = stream2(x_r,y_r,Hvx_r,Hvy_r,xseed,yseed,[0.005 6000]);
V = XY; 
for k = 1:length(V) 
   V{k}(:,1) = Hf(row(k),col(k)); 
end

% Concat
M = [];
V2 = [];
for i = 1:numel(XY)
    if ~isempty(XY{i})
        M = [M; XY{i}; [NaN,NaN]];
        V2 = [V2; V{i}; [NaN,NaN]];
    end
end
V = V2; clear V2

xx = [X(perim);M(:,1)] ;
yy = [Y(perim);M(:,2)] ;
hh = [H(perim);V(:,1)] ;
isf = isfinite(hh);
xx = xx(isf);
yy = yy(isf);
hh = hh(isf);

hg = gridbin(xx,yy,hh,x,y);

tmpH = H; 
isf = isfinite(hg);
tmpH(isf) = hg(isf); 

% fill gaps
H = regionfill(tmpH,isnan(tmpH)); 

% housekeeping
clear tmpH isf xx yy hh V M XY Hf row col xseed yseed perim k i hg

%% Calculate time-varying thickness

% Load time-series paolo thickness
H_p = ncread('ANT_G1920V01_IceShelfMelt.nc','thickness');
H_time = ncread('ANT_G1920V01_IceShelfMelt.nc','time') + datenum(1950,1,1);
Hx = ncread('ANT_G1920V01_IceShelfMelt.nc','x');
Hy = ncread('ANT_G1920V01_IceShelfMelt.nc','y');
[HX,HY] = meshgrid(Hx,Hy);
clear Hx Hy

% set time
years = 2009:2019;

% Modify baseline thickness based on fit with time-varying thickness of
% Paolo
H_ts = zeros([size(H,1),size(H,2),length(years)]).*nan;
for i = 1:length(years)
    % get annual thickness
    ind = find(H_time>=datenum(years(i),1,1) & H_time<=datenum(years(i),12,31));
    H_layer = nanmean(H_p(:,:,ind),3);
    H_layer = flipud(rot90(H_layer));
    H_layer = interp2(HX,HY,H_layer,X,Y);
    % get fit
    nan0 = ~isnan(H_layer(:)) & ~isnan(H(:));
    p = polyfit(H(nan0),H_layer(nan0),1);
    H_ts(:,:,i) = polyval(p,H);
end

% housekeeping
clear p nan0 H_layer ind H_p H_time Hx Hy HX HY

%% Calculate ice mass time-series

% Determine area of each grid cell
[Lat,~] = ps2ll(X,Y); 
A = (diff(x(1:2)) ./ psdistortion(Lat) ).^2;
clear Lat

% Set thickness error
H_err = 30; % metres

% pre-allocate
totalMass = zeros([length(years),1]).*nan;
totalMass_plusH = zeros([length(years),1]).*nan;
totalMass_minusA = zeros([length(years),1]).*nan;

% Calculate ice mass
for i = 1:length(years)
    
    % Load mask
    if years(i)>2019
        gmask = load([shelf_name '_mask_islands_removed_data.mat'],'coast_time_all','shelf_x','shelf_y');
        if years(i)==2020
            gidx = 23; % 2020
        else
            gidx = 24; % 2021
        end
        x_use = shelf_x{gidx};
        y_use = shelf_y{gidx};
        clear mask
        mask.X = x_use;
        mask.Y = y_use;
    else
        mask = shaperead(['D:/work/Fellowship_Leeds/Data/Calving_front_locations/Thwaites/Thwaites_ShelfArea/' num2str(years(i)) 'tw_area3.shp']);
    end
    
    
    % Get ice mass per pixel
    iceMass = rho_ice.*H.*A.*1e-12; % ice mass in each grid cell (Gt)
    iceMass_plusH = rho_ice.*(H+H_err).*A.*1e-12;

    % Mask
    in = inpoly2([X(:),Y(:)],[mask.X(:),mask.Y(:)]);
    out = logical(1-in);
    tmp=zeros(size(iceMass));
    tmp(in)=1;
    tmp = logical(tmp);
    
    % Erode mask to get estimate of digitisation error
    mask_erode = imerode(tmp,strel('disk',1)); 
    
    % Get total mass
    massPerGridCell = local(iceMass,tmp,'weight',A);
    massPerGridCell_plusH = local(iceMass_plusH,tmp,'weight',A);
    totalMass(i) = massPerGridCell*sum(tmp(:));
    totalMass_plusH(i) = massPerGridCell_plusH*sum(tmp(:));
    totalMass_minusA(i) = massPerGridCell*sum(mask_erode(:));
    
end

% Calc ice mass errors
totalMass_err_H = totalMass_plusH - totalMass;
totalMass_err_A = totalMass - totalMass_minusA;
totalMass_err = hypot(totalMass_err_H,totalMass_err_A); 


%% Calculate calving flux as changing in volume

% Load greene ice mass time-series
I = load('individual_shelf_calving_flux/Thwaites_calving_timeseries.mat','time','c','c_err','tim','dmdt','tim_err','dmdt_err','ssc','ssc_err','dmdt_tot','dmdt_tot_err');

% Combine ice mass time-series
idx = find(I.time>=datenum(years(1),1,1) & I.time<=datenum(years(end),12,31));
I.tim(idx) = totalMass;
I.tim_err(idx) = totalMass_err;

% Calculate calving flux
dmdt = diff(I.tim); % positive = ice shelf gain in mass = calving is less than steady state
dmdt = [0,dmdt]; % i.e. assign changes in mass to subsequent year;
dmdt_tot = I.tim(end)-I.tim(1);
dmdt_tot_err = sqrt(I.tim_err(end).^2 + I.tim_err(end-1).^2);
dmdt_err = zeros(size(dmdt)).*NaN;
for kk = 1:length(dmdt)
    if kk == 1
        dmdt_err(kk) = 0;
    else
        dmdt_err(kk) = sqrt(I.tim_err(kk-1).^2 + I.tim_err(kk).^2);
    end
end
% calculate calving excess directly from initial measurement?
dm_from_init = zeros(size(I.tim)).*NaN;
dm_from_init_err = zeros(size(I.tim)).*NaN;
for kk = 1:length(dmdt)
    if kk == 1
        dm_from_init(kk) = 0;
        dm_from_init_err(kk) = 0;
    else
        dm_from_init(kk) = I.tim(kk)-I.tim(1); % positive = increase in ice shelf mass, so calving was less than steady-state
        dm_from_init_err(kk) = sqrt(I.tim_err(kk).^2 + I.tim_err(1).^2);
    end
end
% dmdt_err = sqrt(diff(I.tim_err.^2));
% dmdt_err = [0,dmdt_err];
c = I.ssc + dmdt.*-1;
c_err = sqrt(I.ssc_err^2 + dmdt_err.^2);
    
% Don't allow negative calving (i.e. where, for some reason, the ice
% shelf mass has increased by more than the ssc. For example, because
% the ice shelf increased in speed relative to the speed used to
% calculate ssc
%c(c<0)=0;
    
%% Save

time = I.time;
ssc = I.ssc;
ssc_err = I.ssc_err;
tim = I.tim;
tim_err = I.tim_err;
save('individual_shelf_calving_flux/Thwaites_calving_timeseries_combined.mat','time','c','c_err','tim','dmdt','tim_err','dmdt_err','ssc','ssc_err','dmdt_tot','dmdt_tot_err');

