% combine_datasets_publication

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% Load grounding lines
load('GL_consolidated_200m.mat');

% pre-allocate
dummyTS =  zeros([numel(GL),25]).*NaN;
dummy = zeros([numel(GL),1]).*NaN;
massBalanceAllShelves = dummyTS;
massBalanceErrorAllShelves = dummyTS;
dischargeAllShelves = dummyTS;
dischargeErrorAllShelves = dummyTS;
calvingAllShelves = dummyTS;
calvingErrorAllShelves = dummyTS;
meltAllShelves = dummyTS;
meltErrorAllShelves = dummyTS;
smbAllShelves = dummyTS;
smbErrorAllShelves = dummyTS;
%
ssMeltAllShelves = dummy;
ssDischargeAllShelves = dummy;
ssCalvingAllShelves = dummy;
ssSMBAllShelves = dummy;
ssMeltErrorAllShelves = dummy;
ssDischargeErrorAllShelves = dummy;
ssCalvingErrorAllShelves = dummy;
ssSMBErrorAllShelves = dummy;
%
totalMassChangeAllShelves = dummy;
totalMassChangeErrorAllShelves = dummy;
%
cumulativeMassChangeAllShelves = dummyTS;
cumulativeMassChangeErrorAllShelves = dummyTS;
cumulativeSMBAnomalyAllShelves = dummyTS;
cumulativeSMBAnomalyErrorAllShelves = dummyTS;
cumulativeThinningAllShelves = dummyTS;
cumulativeThinningErrorAllShelves = dummyTS;
cumulativeRetreatAllShelves = dummyTS;
cumulativeRetreatErrorAllShelves = dummyTS;
cumulativeDischargeChangeAllShelves = dummyTS;
cumulativeDischargeChangeErrorAllShelves = dummyTS;
totalRetreatErrorAllShelves = dummy;
%
cen_lat = dummy;
cen_lon = dummy;
%
cumulativeMassTrendAllShelves = dummy;
cumulativeMassPValAllShelves = dummy;

% Loop through shelves and load data
for i = 1:numel(GL)
    
    % Get ice shelf name
    shelf_name = GL(i).Name;
    
    % Load key datasets
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel.mat'],...
        'massBalance','massBalanceError',...
        'discharge','dischargeError',...
        'smb','smbError',...
        'melt','meltError',...
        'calving','calvingError',...
        ...
        'steadyStateMelt','steadyStateCalving','steadyStateDischarge','steadyStateSMB',...
        'steadyStateMeltError','steadyStateCalvingError','steadyStateDischargeError','steadyStateSMBError',...
        ...
        'totalMassChange','totalMassChangeError',...
        ...
        'cumulativeSMBAnomaly','cumulativeThinning','cumulativeRetreat','cumulativeDischargeChange',...
        'cumulativeSMBAnomalyError','cumulativeThinningError','cumulativeRetreatError','cumulativeDischargeChangeError',...
        'totalRetreatError','cumulativeMassChange','cumulativeMassChangeError','time'); 
    
    % Build full arrays
    massBalanceAllShelves(i,:) = massBalance;
    massBalanceErrorAllShelves(i,:) = massBalanceError;
    dischargeAllShelves(i,:) = discharge;
    dischargeErrorAllShelves(i,:) = dischargeError;
    smbAllShelves(i,:) = smb;
    smbErrorAllShelves(i,:) = smbError;
    meltAllShelves(i,:) = melt;
    meltErrorAllShelves(i,:) = meltError;
    calvingAllShelves(i,:) = calving;
    calvingErrorAllShelves(i,:) = calvingError;
    %
    ssMeltAllShelves(i) = steadyStateMelt;
    ssMeltErrorAllShelves(i) = steadyStateMeltError;
    ssCalvingAllShelves(i) = steadyStateCalving;
    ssCalvingErrorAllShelves(i) = steadyStateCalvingError;
    ssDischargeAllShelves(i) = steadyStateDischarge;
    ssDischargeErrorAllShelves(i) = steadyStateDischargeError;
    ssSMBAllShelves(i) = steadyStateSMB;
    ssSMBErrorAllShelves(i) = steadyStateSMBError;
    %
    totalMassChangeAllShelves(i) = totalMassChange;
    totalMassChangeErrorAllShelves(i) = totalMassChangeError;
    %
    cumulativeMassChangeAllShelves(i,:) = cumulativeMassChange;
    cumulativeMassChangeErrorAllShelves(i,:) = cumulativeMassChangeError;
    cumulativeSMBAnomalyAllShelves(i,:) = cumulativeSMBAnomaly;
    cumulativeSMBAnomalyErrorAllShelves(i,:) = cumulativeSMBAnomalyError;
    cumulativeThinningAllShelves(i,:) = cumulativeThinning;
    cumulativeThinningErrorAllShelves(i,:) = cumulativeThinningError;
    cumulativeRetreatAllShelves(i,:) = cumulativeRetreat;
    cumulativeRetreatErrorAllShelves(i,:) = totalRetreatError;
    cumulativeDischargeChangeAllShelves(i,:) = cumulativeDischargeChange;
    cumulativeDischargeChangeErrorAllShelves(i,:) = cumulativeDischargeChangeError;
    totalRetreatErrorAllShelves(i) = totalRetreatError;
    %
    [tr,p_m] = trend(cumulativeMassChange,time);
    tr = tr.*365.25;
    cumulativeMassTrendAllShelves(i) = tr;
    cumulativeMassPValAllShelves(i) = p_m;
    
    % get central lat/lon
%     if iscell(GL(i).X)
%         GL(i).X = GL(i).X{1};
%         GL(i).Y = GL(i).Y{1};
%     end
    [cen_x,cen_y] = centroid(polyshape(GL(i).X,GL(i).Y));
    [cen_lat(i),cen_lon(i)] = ps2ll(cen_x,cen_y);
    
end
clear tr p_m totalRetreatError cumulativeDischargeChangeError cumulativeDischargeChange cumulativeRetreat
clear cumulativeThinning cumulativeThinningError cumulativeSMBAnomaly cumulativeSMBAnomalyError 
clear cumulativeMassChange cumulativeMassChangeError totalMassChange totalMassChangeError
clear steadyStateSMB steadyStateSMBError steadyStateDischarge steadyStateDischargeError
clear steadyStateCalving steadyStateCalvingError steadyStateMelt steadyStateMeltError
clear calving calvingError melt meltError smb smbError discharge dischargeError massBalance massBalanceError
clear dummy dummyTs i shelf_name

% rearrange so errors follow estimate - copy and paste these into excel
shelf_names = convertCharsToStrings(shelf_names');
cen_loc = [cen_lat,cen_lon];
%
M = reshape([massBalanceAllShelves;massBalanceErrorAllShelves], size(massBalanceAllShelves,1), []);
D = reshape([dischargeAllShelves;dischargeErrorAllShelves], size(dischargeAllShelves,1), []);
B = reshape([meltAllShelves;meltErrorAllShelves], size(meltAllShelves,1), []);
S = reshape([smbAllShelves;smbErrorAllShelves], size(smbAllShelves,1), []);
C = reshape([calvingAllShelves;calvingErrorAllShelves], size(calvingAllShelves,1), []);
%
Mtotal = [totalMassChangeAllShelves,totalMassChangeErrorAllShelves];
Dtotal = [cumulativeDischargeChangeAllShelves(:,end),cumulativeDischargeChangeErrorAllShelves(:,end)];
Btotal = [cumulativeThinningAllShelves(:,end),cumulativeThinningErrorAllShelves(:,end)];
Stotal = [cumulativeSMBAnomalyAllShelves(:,end),cumulativeSMBAnomalyErrorAllShelves(:,end)];
Ctotal = [cumulativeRetreatAllShelves(:,end),totalRetreatErrorAllShelves(:)];
tr = [cumulativeMassTrendAllShelves,cumulativeMassPValAllShelves];
totals = [Mtotal,tr,Dtotal,Btotal,Ctotal,Stotal];
%
Mcumulative = reshape([cumulativeMassChangeAllShelves;cumulativeMassChangeErrorAllShelves], size(cumulativeMassChangeAllShelves,1), []);
Dcumulative = reshape([cumulativeDischargeChangeAllShelves;cumulativeDischargeChangeErrorAllShelves], size(cumulativeDischargeChangeAllShelves,1), []);
Bcumulative = reshape([cumulativeThinningAllShelves;cumulativeThinningErrorAllShelves], size(cumulativeThinningAllShelves,1), []);
Scumulative = reshape([cumulativeSMBAnomalyAllShelves;cumulativeSMBAnomalyErrorAllShelves], size(cumulativeSMBAnomalyAllShelves,1), []);
Ccumulative = reshape([cumulativeRetreatAllShelves;cumulativeRetreatErrorAllShelves], size(cumulativeRetreatAllShelves,1), []);
%
Dss = [ssDischargeAllShelves,ssDischargeErrorAllShelves];
Bss = [ssMeltAllShelves,ssMeltErrorAllShelves];
Sss = [ssSMBAllShelves,ssSMBErrorAllShelves];
Css = [ssCalvingAllShelves,ssCalvingErrorAllShelves];
steadyStateAllIceShelves = [Dss,Bss,Css,Sss];
clear Dss Bss Sss Css

% Antarctic totals
AntarcticaTotalIceShelfMassChange = [nansum(totalMassChangeAllShelves),rssq(totalMassChangeErrorAllShelves)];
[trAIS,p_ais] = trend(nansum(cumulativeMassChangeAllShelves,1),time);
AntarcticaTotalIceShelfMassTrend = [trAIS,p_ais];
AntarcticaTotalIceShelfDischargeChange = [nansum(Dtotal(:,1)),rssq(Dtotal(:,2))];
AntarcticaTotalIceShelfThinning = [nansum(Btotal(:,1)),rssq(Btotal(:,2))];
AntarcticaTotalIceShelfRetreat = [nansum(Ctotal(:,1)),rssq(Ctotal(:,2))];
AntarcticaTotalIceShelfSMBAnomaly = [nansum(Stotal(:,1)),rssq(Stotal(:,2))];

% Antarctic timeseries
AntarcticaIceShelfMassBalance = reshape([nansum(massBalanceAllShelves,1);rssq(massBalanceErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfDischarge = reshape([nansum(dischargeAllShelves,1);rssq(dischargeErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfMelt = reshape([nansum(meltAllShelves,1);rssq(meltErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfCalving = reshape([nansum(calvingAllShelves,1);rssq(calvingErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfSMB = reshape([nansum(smbAllShelves,1);rssq(smbErrorAllShelves,1)], 1,50, []);

% Antarctic cumulative timeseries
AntarcticaIceShelfCumulativeMassChange = reshape([nansum(cumulativeMassChangeAllShelves,1);rssq(cumulativeMassChangeErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfCumulativeDischargeChange = reshape([nansum(cumulativeDischargeChangeAllShelves,1);rssq(cumulativeDischargeChangeErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfCumulativeThinning = reshape([nansum(cumulativeThinningAllShelves,1);rssq(cumulativeThinningErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfCumulativeRetreat = reshape([nansum(cumulativeRetreatAllShelves,1);rssq(cumulativeRetreatErrorAllShelves,1)], 1,50, []);
AntarcticaIceShelfCumulativeSMBAnomaly = reshape([nansum(cumulativeSMBAnomalyAllShelves,1);rssq(cumulativeSMBAnomalyErrorAllShelves,1)], 1,50, []);


