% compile_bed_data

clear
close all
clc

%% Preliminaries

% addpaths to data and libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));

time = datenum(1985:2021,1,365.25/2);

%% Bed

% Load BedMachine bed
[BM_bed,BM_x,BM_y] = bedmachine_data('bed','xy');
[BM_X,BM_Y] = meshgrid(BM_x,BM_y);

% Replace with Princess Elizabeth Land Bed
%   - load
[new_bed,new_x,PEL_y] = geoimread('D:\work\Fellowship_Leeds\Data\Elevation\Antarctica\Cui_2020_PEL/Bed_elevation.tif');
new_bed(abs(new_bed)>20000) = NaN;
[new_X,new_Y] = meshgrid(new_x,PEL_y);
%   - Interpolate PEL bed to BedMachine grid
new_bed = interp2(new_X,new_Y,new_bed,BM_X,BM_Y);
%   - Reset BedMachine value to PEL and Huss values where appropriate
BM_bed(~isnan(new_bed)) = new_bed(~isnan(new_bed));

% Replace with Huss Peninsula data
%   - load
[new_bed,new_x,new_y] = geoimread('D:\work\Fellowship_Leeds\Data\Elevation\Antarctica\Huss_2013_Peninsula\SOM\bedrock/bedrock.tif');
new_bed = double(new_bed);
new_bed(new_bed==-9999) = NaN;
[new_X,new_Y] = meshgrid(new_x,new_y);
%   - interpolate Huss bed to BedMachine grid
new_bed = interp2(new_X,new_Y,new_bed,BM_X,BM_Y);
%   - Reset BedMachine value to PEL and Huss values where appropriate
BM_bed(~isnan(new_bed)) = new_bed(~isnan(new_bed));

% clear variables to save space
clear new_bed new_X new_Y new_x new_y

%% Save
bed = BM_bed;
x = BM_x;
y = BM_y;
save('merged_bed.mat','bed','x','y');

% Also save as geotiff
xlimits = [min(x(:)) max(x(:))]; 
ylimits = [min(y(:)) max(y(:))]; 
raster_size = size(bed); 
R = maprefcells(xlimits,ylimits,raster_size,...
    'ColumnsStartFrom','North'); % https://uk.mathworks.com/help/map/ref/maprefpostings.html
tiffTags = struct('Compression',Tiff.Compression.LZW);
geotiffwrite('merged_bed.tif',bed,R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);

%% Repeat with error

% Load BedMachine bed
[BM_bed_err,BM_x,BM_y] = bedmachine_data('errbed','xy');
[BM_X,BM_Y] = meshgrid(BM_x,BM_y);

% Replace with Huss Peninsula data
%   - load
[new_bed,new_x,new_y] = geoimread('D:\work\Fellowship_Leeds\Data\Elevation\Antarctica\Huss_2013_Peninsula\SOM\uncertainty/uncertainty.tif');
new_bed = double(new_bed);
new_bed(new_bed==-9999) = NaN;
[new_X,new_Y] = meshgrid(new_x,new_y);
%   - interpolate Huss bed to BedMachine grid
new_bed = interp2(new_X,new_Y,new_bed,BM_X,BM_Y);
%   - Reset BedMachine value to PEL and Huss values where appropriate
BM_bed_err(~isnan(new_bed)) = new_bed(~isnan(new_bed));

% clear variables to save space
clear new_bed new_X new_Y new_x new_y

bed_err = BM_bed_err;
x = BM_x;
y = BM_y;
save('merged_bed_err.mat','bed_err','x','y');

% Also save as geotiff
xlimits = [min(x(:)) max(x(:))]; 
ylimits = [min(y(:)) max(y(:))]; 
raster_size = size(bed_err); 
R = maprefcells(xlimits,ylimits,raster_size,...
    'ColumnsStartFrom','North'); % https://uk.mathworks.com/help/map/ref/maprefpostings.html
tiffTags = struct('Compression',Tiff.Compression.LZW);
geotiffwrite('merged_bed_err.tif',bed_err,R,'CoordRefSysCode','EPSG:3031','TiffTags',tiffTags);




