function compile_ice_velocity(migrated_pixels)

% add paths to libraries
if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
end

%% Load flux gate

load('../flux_gates/flux_gates_migrated.mat');
gate_x = gate_x_migrate{migrated_pixels};
gate_y = gate_y_migrate{migrated_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrate

migration_distance = 0:200:3000; % metres
migration_distance = migration_distance(migrated_pixels);

%% Load velocity 

% MEaSUREs annual data, 1x1 km
%   - get measures coordinates
filename = ['Antarctica_ice_velocity_2000_2001_1km_v01.1.nc'];
xM = ncread(filename,'x');
yM = ncread(filename,'y');
%   - pre-allocate output
vxM = zeros([length(gate_x),length([2000,2005:2015])]).*NaN;
vyM = zeros([length(gate_x),length([2000,2005:2015])]).*NaN;
vxM_err = zeros([length(gate_x),length([2000,2005:2015])]).*NaN;
vyM_err = zeros([length(gate_x),length([2000,2005:2015])]).*NaN;
timeM = datenum([2000,2005:2015],12,30); % annual products are averaged between July 1st and June 30th each year. Dec 30th is mid-date in non-leap year
sourceM = ones([length([2000,2005:2015]),1]);
counter = 1;
% loop through annual products and extract
for i = [2000,2005:2015] % these are available up to 2020 now, but we have higher resolution options after 2015 
    if i == 2000
        filename = ['Antarctica_ice_velocity_' num2str(i) '_' num2str(i+1) '_1km_v01.1.nc'];
    else
        filename = ['Antarctica_ice_velocity_' num2str(i) '_' num2str(i+1) '_1km_v01.nc'];
    end
    % vx
    data = double(flipud(rot90(ncread(filename,'VX'))));
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vxM(:,counter) = data;
    % vy
    data = double(flipud(rot90(ncread(filename,'VY'))));
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vyM(:,counter) = data;
    % vx error
    data = double(flipud(rot90(ncread(filename,'ERRX'))));
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vxM_err(:,counter) = data;
    % vy error
    data = double(flipud(rot90(ncread(filename,'ERRY')))); 
    data = interp2(xM,yM,data,gate_x,gate_y,'linear');
    vyM_err(:,counter) = data;
    % increment counter
    counter=counter+1;
end

% ENVEO monthly data
%   - get filelist
if ispc
    nc_list = dir('D:/work/Fellowship_Leeds/Data/Velocity/Antarctica/ENVEO/monthly/*.nc');
else
    nc_list = dir('/resstore/b0133/Data/Velocity/ENVEO/monthly/*.nc');
end
%   - Get mid-date of all netcdf files
timeS1 = zeros([numel(nc_list),1]).*NaN;
for i = 1:numel(nc_list)
    nc_file = nc_list(i).name;
    Y = str2double(nc_file(1:4));
    M = str2double(nc_file(5:6));
    D = str2double(nc_file(7:8));
    timeS1(i) = datenum(Y,M,D) + (datenum(Y,M+1,D)-datenum(Y,M,D))/2;
end
%   - Load coordinates and get index of gate locations
xS1 = ncread([nc_list(i).folder '/' nc_list(i).name],'x');
yS1 = ncread([nc_list(i).folder '/' nc_list(i).name],'y');
%   - pre-allocate output
vxS1 = zeros([length(gate_x),numel(nc_list)]).*NaN;
vyS1 = zeros([length(gate_x),numel(nc_list)]).*NaN;
vxS1_err = zeros([length(gate_x),numel(nc_list)]).*NaN;
vyS1_err = zeros([length(gate_x),numel(nc_list)]).*NaN;
sourceS1 = ones([numel(nc_list),1]).*2;
%   - Loop through nc files and load data at gate locations
for i = 1:numel(nc_list)
    % Vx
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_easting_velocity'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vxS1(:,i) = data;
    % Vy
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_northing_velocity'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vyS1(:,i) = data;
    % Vx error
    data = double(rot90(flipud(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_easting_stddev'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vxS1_err(:,i) = data;
    % Vy error
    data = double(rot90(flipud(ncread([nc_list(i).folder '/' nc_list(i).name],'land_ice_surface_northing_stddev'))));
    data(abs(data)>20000) = NaN;
    data = data.*365.25; % convert to m/yr
    data = interp2(xS1,yS1,data,gate_x,gate_y,'linear');
    vyS1_err(:,i) = data;
end

% Merged 1996 data
%   - load
load('ASE_1996/ASE_1996_merged.mat')
%   - extract at gate
vxERS = interp2(x_1996,y_1996,vx_1996,gate_x,gate_y,'linear');
vyERS = interp2(x_1996,y_1996,vy_1996,gate_x,gate_y,'linear');
timeERS = datenum(1996,1,1) + 365/2;
vxERS_err = abs(vxERS).*0.1; % assume 10% velocity error
vyERS_err = abs(vyERS).*0.1; % assume 10% velocity error
sourceERS = 3;

% ITSLIVE annual velocity
%   - get filelist
if ispc
    nc_list1 = dir('D:\work\Fellowship_Leeds\Data\Velocity\Antarctica\ITSLIVE/*_19*.nc');
    nc_list2 = dir('D:\work\Fellowship_Leeds\Data\Velocity\Antarctica\ITSLIVE/*_20*.nc');
    nc_list = [nc_list1;nc_list2];
else
    nc_list1 = dir('/resstore/b0133/Data/Velocity/ITSLIVE/*_19*.nc');
    nc_list2 = dir('/resstore/b0133/Data/Velocity/ITSLIVE/*_20*.nc');
    nc_list = [nc_list1;nc_list2];
    clear nc_list1 nc_list2
end
%   - Get mid-date of all netcdf files
timeI = zeros([numel(nc_list),1]).*NaN;
for i = 1:numel(nc_list)
    nc_file = nc_list(i).name;
    Y = str2double(nc_file(11:14));
    timeI(i) = datenum(Y,1,1) + (datenum(Y,12,31)-datenum(Y,1,1))/2;
end
%   - Load coordinates and get index of gate locations
xI = ncread([nc_list(i).folder '/' nc_list(i).name],'x');
yI = ncread([nc_list(i).folder '/' nc_list(i).name],'y');
%   - pre-allocate output
vxI = zeros([length(gate_x),length(timeI)]).*NaN;
vyI = zeros([length(gate_x),length(timeI)]).*NaN;
vxI_err = zeros([length(gate_x),length(timeI)]).*NaN;
vyI_err = zeros([length(gate_x),length(timeI)]).*NaN;
%   - Loop through nc files and load data at gate locations
sourceI = ones([length(timeI),1]).*4;
for i = 1:numel(nc_list)
    % Vx
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vx'))));
    data(abs(data(:))>20000) = NaN;
    vxI(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
    % Vy
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vy'))));
    data(abs(data(:))>20000) = NaN;
    vyI(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
    % Vx error
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vx_err'))));
    data(abs(data)>20000) = NaN;
    vxI_err(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
    % Vy error
    data = double(flipud(rot90(ncread([nc_list(i).folder '/' nc_list(i).name],'vy_err'))));
    data(abs(data)>20000) = NaN;
    vyI_err(:,i) = interp2(xI,yI,data,gate_x,gate_y,'linear');
end

% MEaSUREs 1995-2001 mosaic
%   - info
filename = 'antarctica_ice_velocity_1995-2001_450m_v01.0.nc';
timeM95 = datenum(1995,7,1) + (datenum(2001,6,30)-datenum(1995,7,1))/2;
xM95 = ncread(filename,'x');
yM95 = ncread(filename,'y');
%   - vx
data = ncread(filename,'VX');
data = flipud(double(rot90(data)));
vxM95 = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
%   - vy
data = ncread(filename,'VY');
data = flipud(double(rot90(data)));
vyM95 = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
% vx err
data = ncread(filename,'ERRX');
data = flipud(double(rot90(data)));
vxM95_err = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
% vy err
data = ncread(filename,'ERRY');
data = flipud(double(rot90(data)));
vyM95_err = interp2(xM95,yM95,data,gate_x,gate_y,'linear');
sourceM95 = 5;


%% Concatenate velocity measurements

% concatenate
vx_raw = [vxM, vxS1, vxI, vxERS, vxM95];
vy_raw = [vyM, vyS1, vyI, vyERS, vyM95];
vxE_raw = [vxM_err, vxS1_err, vxI_err, vxERS_err, vxM95_err];
vyE_raw = [vyM_err, vyS1_err, vyI_err, vyERS_err, vyM95_err];
time_vel = [timeM(:)', timeS1(:)', timeI(:)', timeERS, timeM95];
source_vel = [sourceM(:)', sourceS1(:)', sourceI(:)', sourceERS, sourceM95];

% Sort
[~,iv] = sort(time_vel,'ascend');
time_vel = time_vel(iv);
vx_raw = vx_raw(:,iv);
vy_raw = vy_raw(:,iv);
vxE_raw = vxE_raw(:,iv);
vyE_raw = vyE_raw(:,iv);
source_vel = source_vel(iv);


%% Save raw velocity timeseries

save(['gate_vel_raw_linear_migrate_' num2str(migration_distance) 'm_compiled.mat'],'vx_raw','vy_raw','vxE_raw','vyE_raw','source_vel','time_vel');

