% consolidate_SMB_to_calving_shelf_names

clear
close all
clc

% make output dirs
mkdir individual_shelf_SMB_timeseries_consolidated

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all_200m.mat');
GL = GL200;
GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Loop through shelves and consolidate

for i = 1:numel(GL_labels)
    
    sn = GL_labels(i).Name;
    
    if i == 45
        copyfile('individual_shelf_SMB_timeseries/Fox_2_SMB_timeseries.mat','individual_shelf_SMB_timeseries_consolidated/Fox_Ice_Stream_SMB_timeseries.mat');
    elseif i == 47
        S1 = load('individual_shelf_SMB_timeseries/Frost_1_SMB_timeseries.mat');
        S2 = load('individual_shelf_SMB_timeseries/Frost_2_SMB_timeseries.mat');
        S3 = load('individual_shelf_SMB_timeseries/Frost_3_SMB_timeseries.mat');
        A_ts = S1.A_ts + S2.A_ts + S3.A_ts;
        smb_ts = S1.smb_ts + S2.smb_ts + S3.smb_ts;
        time = S1.time;
        save('individual_shelf_SMB_timeseries_consolidated/Frost_SMB_timeseries.mat','A_ts','time','smb_ts');
    elseif i==56
        S1 = load('individual_shelf_SMB_timeseries/Hannan_1_SMB_timeseries.mat');
        S2 = load('individual_shelf_SMB_timeseries/Hannan_2_SMB_timeseries.mat');
        A_ts = S1.A_ts + S2.A_ts;
        smb_ts = S1.smb_ts + S2.smb_ts;
        time = S1.time;
        save('individual_shelf_SMB_timeseries_consolidated/Hannan_SMB_timeseries.mat','A_ts','time','smb_ts');
    elseif i==61
        S1 = load('individual_shelf_SMB_timeseries/Holmes_1_SMB_timeseries.mat');
        S2 = load('individual_shelf_SMB_timeseries/Holmes_2_SMB_timeseries.mat');
        S3 = load('individual_shelf_SMB_timeseries/Holmes_3_SMB_timeseries.mat');
        S4 = load('individual_shelf_SMB_timeseries/Holmes_4_SMB_timeseries.mat');
        A_ts = S1.A_ts + S2.A_ts + S3.A_ts + S4.A_ts;
        smb_ts = S1.smb_ts + S2.smb_ts + S3.smb_ts + S4.smb_ts;
        time = S1.time;
        save('individual_shelf_SMB_timeseries_consolidated/Holmes_SMB_timeseries.mat','A_ts','time','smb_ts');
    elseif i==62
        copyfile('individual_shelf_SMB_timeseries/Horn_Bluff_SMB_timeseries.mat','individual_shelf_SMB_timeseries_consolidated/HornBluff_SMB_timeseries.mat');
    elseif i==77
        copyfile('individual_shelf_SMB_timeseries/Larsen_F_1_SMB_timeseries.mat','individual_shelf_SMB_timeseries_consolidated/Larsen_F_SMB_timeseries.mat');
    elseif i==78
        copyfile('individual_shelf_SMB_timeseries/Larsen_F_2_SMB_timeseries.mat','individual_shelf_SMB_timeseries_consolidated/Larsen_G_SMB_timeseries.mat');
    elseif i==94
        copyfile('individual_shelf_SMB_timeseries/Moscow_University_1_SMB_timeseries.mat','individual_shelf_SMB_timeseries_consolidated/Moscow_University_SMB_timeseries.mat');
    elseif i==110
        S1 = load('individual_shelf_SMB_timeseries/Prince_Harald_1_SMB_timeseries.mat');
        S2 = load('individual_shelf_SMB_timeseries/Prince_Harald_2_SMB_timeseries.mat');
        A_ts = S1.A_ts + S2.A_ts;
        smb_ts = S1.smb_ts + S2.smb_ts;
        time = S1.time;
        save('individual_shelf_SMB_timeseries_consolidated/Prince_Harald_SMB_timeseries.mat','A_ts','time','smb_ts');
    elseif i==149
        S1 = load('individual_shelf_SMB_timeseries/Vincennes_Bay_1_SMB_timeseries.mat');
        S2 = load('individual_shelf_SMB_timeseries/Vincennes_Bay_2_SMB_timeseries.mat');
        S3 = load('individual_shelf_SMB_timeseries/Vincennes_Bay_3_SMB_timeseries.mat');
        S4 = load('individual_shelf_SMB_timeseries/Vincennes_Bay_4_SMB_timeseries.mat');
        A_ts = S1.A_ts + S2.A_ts + S3.A_ts + S4.A_ts;
        smb_ts = S1.smb_ts + S2.smb_ts + S3.smb_ts + S4.smb_ts;
        time = S1.time;
        save('individual_shelf_SMB_timeseries_consolidated/Vincennes_Bay_SMB_timeseries.mat','A_ts','time','smb_ts');
    else
        copyfile(['individual_shelf_SMB_timeseries/' sn '_SMB_timeseries.mat'],['individual_shelf_SMB_timeseries_consolidated/' sn '_SMB_timeseries.mat']);
    end
            
    
end
        
    
    
    
    