% consolidate_discharge_to_calving_shelf_names

clear
close all
clc

% make output dirs
mkdir individual_shelf_discharge_200m_consolidated

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all_200m.mat');
GL = GL200;
GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Loop through shelves and consolidate

for i = 1:numel(GL_labels)
    
    sn = GL_labels(i).Name;
    
    if i == 45
        copyfile('individual_shelf_discharge_200m/Fox_2_discharge_timeseries.mat','individual_shelf_discharge_200m_consolidated/Fox_Ice_Stream_discharge_timeseries.mat');
    elseif i == 47
        S1 = load('individual_shelf_discharge_200m/Frost_1_discharge_timeseries.mat');
        S2 = load('individual_shelf_discharge_200m/Frost_2_discharge_timeseries.mat');
        S3 = load('individual_shelf_discharge_200m/Frost_3_discharge_timeseries.mat');
        Q_annual = S1.Q_annual + S2.Q_annual + S3.Q_annual;
        Q_annual_staticH = S1.Q_annual_staticH + S2.Q_annual_staticH + S3.Q_annual_staticH;
        Q_err_annual = S1.Q_err_annual + S2.Q_err_annual + S3.Q_err_annual;
        Q_err_annual_staticH = S1.Q_err_annual_staticH + S2.Q_err_annual_staticH + S3.Q_err_annual_staticH;
        Q_error = S1.Q_error + S2.Q_error + S3.Q_error;
        Q_error_staticH = S1.Q_error_staticH + S2.Q_error_staticH + S3.Q_error_staticH;
        Q_filled = S1.Q_filled + S2.Q_filled + S3.Q_filled;
        Q_max = S1.Q_max + S2.Q_max + S3.Q_max;
        Q_max_staticH = S1.Q_max_staticH + S2.Q_max_staticH + S3.Q_max_staticH;
        Q_min = S1.Q_min + S2.Q_min + S3.Q_min;
        Q_min_staticH = S1.Q_min_staticH + S2.Q_min_staticH + S3.Q_min_staticH;
        Q_raw = S1.Q_raw + S2.Q_raw + S3.Q_raw;
        Q_reg = S1.Q_reg + S2.Q_reg + S3.Q_reg;
        Q_reg_err = S1.Q_reg_err + S2.Q_reg_err + S3.Q_reg_err;
        Q_reg_err_staticH = S1.Q_reg_err_staticH + S2.Q_reg_err_staticH + S3.Q_reg_err_staticH;
        Q_reg_staticH = S1.Q_reg_staticH + S2.Q_reg_staticH + S3.Q_reg_staticH;
        Q_staticH = S1.Q_staticH + S2.Q_staticH + S3.Q_staticH;
        time = S1.time;
        time_reg = S1.time_reg;
        ann_time = S1.ann_time;
        save('individual_shelf_discharge_200m_consolidated/Frost_discharge_timeseries.mat',...
            'Q_annual','Q_annual_staticH','Q_err_annual','Q_err_annual_staticH','Q_error',...
            'Q_error_staticH','Q_filled','Q_max','Q_max_staticH','Q_min','Q_min_staticH','Q_raw',...
            'Q_reg','Q_reg_err','Q_reg_err_staticH','Q_reg_staticH','Q_staticH',...
            'time','time_reg','ann_time');
    elseif i==56
        S1 = load('individual_shelf_discharge_200m/Hannan_1_discharge_timeseries.mat');
        S2 = load('individual_shelf_discharge_200m/Hannan_2_discharge_timeseries.mat');
        Q_annual = S1.Q_annual + S2.Q_annual;
        Q_annual_staticH = S1.Q_annual_staticH + S2.Q_annual_staticH;
        Q_err_annual = S1.Q_err_annual + S2.Q_err_annual;
        Q_err_annual_staticH = S1.Q_err_annual_staticH + S2.Q_err_annual_staticH;
        Q_error = S1.Q_error + S2.Q_error;
        Q_error_staticH = S1.Q_error_staticH;
        Q_filled = S1.Q_filled + S2.Q_filled;
        Q_max = S1.Q_max + S2.Q_max;
        Q_max_staticH = S1.Q_max_staticH + S2.Q_max_staticH;
        Q_min = S1.Q_min + S2.Q_min;
        Q_min_staticH = S1.Q_min_staticH + S2.Q_min_staticH;
        Q_raw = S1.Q_raw + S2.Q_raw;
        Q_reg = S1.Q_reg + S2.Q_reg;
        Q_reg_err = S1.Q_reg_err + S2.Q_reg_err;
        Q_reg_err_staticH = S1.Q_reg_err_staticH + S2.Q_reg_err_staticH;
        Q_reg_staticH = S1.Q_reg_staticH + S2.Q_reg_staticH;
        Q_staticH = S1.Q_staticH + S2.Q_staticH;
        time = S1.time;
        time_reg = S1.time_reg;
        ann_time = S1.ann_time;
        save('individual_shelf_discharge_200m_consolidated/Hannan_discharge_timeseries.mat',...
            'Q_annual','Q_annual_staticH','Q_err_annual','Q_err_annual_staticH','Q_error',...
            'Q_error_staticH','Q_filled','Q_max','Q_max_staticH','Q_min','Q_min_staticH','Q_raw',...
            'Q_reg','Q_reg_err','Q_reg_err_staticH','Q_reg_staticH','Q_staticH',...
            'time','time_reg','ann_time');
    elseif i==61
        S1 = load('individual_shelf_discharge_200m/Holmes_1_discharge_timeseries.mat');
        S2 = load('individual_shelf_discharge_200m/Holmes_2_discharge_timeseries.mat');
        S3 = load('individual_shelf_discharge_200m/Holmes_3_discharge_timeseries.mat');
        S4 = load('individual_shelf_discharge_200m/Holmes_4_discharge_timeseries.mat');
        Q_annual = S1.Q_annual + S2.Q_annual + S3.Q_annual + S4.Q_annual;
        Q_annual_staticH = S1.Q_annual_staticH + S2.Q_annual_staticH + S3.Q_annual_staticH + S4.Q_annual_staticH;
        Q_err_annual = S1.Q_err_annual + S2.Q_err_annual + S3.Q_err_annual + S4.Q_err_annual;
        Q_err_annual_staticH = S1.Q_err_annual_staticH + S2.Q_err_annual_staticH + S3.Q_err_annual_staticH + S4.Q_err_annual_staticH;
        Q_error = S1.Q_error + S2.Q_error + S3.Q_error + S4.Q_error;
        Q_error_staticH = S1.Q_error_staticH + S2.Q_error_staticH + S3.Q_error_staticH + S4.Q_error_staticH;
        Q_filled = S1.Q_filled + S2.Q_filled + S3.Q_filled + S4.Q_filled;
        Q_max = S1.Q_max + S2.Q_max + S3.Q_max + S4.Q_max;
        Q_max_staticH = S1.Q_max_staticH + S2.Q_max_staticH + S3.Q_max_staticH + S4.Q_max_staticH;
        Q_min = S1.Q_min + S2.Q_min + S3.Q_min + S4.Q_min;
        Q_min_staticH = S1.Q_min_staticH + S2.Q_min_staticH + S3.Q_min_staticH + S4.Q_min_staticH;
        Q_raw = S1.Q_raw + S2.Q_raw + S3.Q_raw + S4.Q_raw;
        Q_reg = S1.Q_reg + S2.Q_reg + S3.Q_reg + S4.Q_reg;
        Q_reg_err = S1.Q_reg_err + S2.Q_reg_err + S3.Q_reg_err + S4.Q_reg_err;
        Q_reg_err_staticH = S1.Q_reg_err_staticH + S2.Q_reg_err_staticH + S3.Q_reg_err_staticH + S4.Q_reg_err_staticH;
        Q_reg_staticH = S1.Q_reg_staticH + S2.Q_reg_staticH + S3.Q_reg_staticH + S4.Q_reg_staticH;
        Q_staticH = S1.Q_staticH + S2.Q_staticH + S3.Q_staticH + S4.Q_staticH;
        time = S1.time;
        time_reg = S1.time_reg;
        ann_time = S1.ann_time;
        save('individual_shelf_discharge_200m_consolidated/Holmes_discharge_timeseries.mat',...
            'Q_annual','Q_annual_staticH','Q_err_annual','Q_err_annual_staticH','Q_error',...
            'Q_error_staticH','Q_filled','Q_max','Q_max_staticH','Q_min','Q_min_staticH','Q_raw',...
            'Q_reg','Q_reg_err','Q_reg_err_staticH','Q_reg_staticH','Q_staticH',...
            'time','time_reg','ann_time');
    elseif i==62
        copyfile('individual_shelf_discharge_200m/Horn_Bluff_discharge_timeseries.mat','individual_shelf_discharge_200m_consolidated/HornBluff_discharge_timeseries.mat');
    elseif i==77
        copyfile('individual_shelf_discharge_200m/Larsen_F_1_discharge_timeseries.mat','individual_shelf_discharge_200m_consolidated/Larsen_F_discharge_timeseries.mat');
    elseif i==78
        copyfile('individual_shelf_discharge_200m/Larsen_F_2_discharge_timeseries.mat','individual_shelf_discharge_200m_consolidated/Larsen_G_discharge_timeseries.mat');
    elseif i==94
        copyfile('individual_shelf_discharge_200m/Moscow_University_1_discharge_timeseries.mat','individual_shelf_discharge_200m_consolidated/Moscow_University_discharge_timeseries.mat');
    elseif i==110
        S1 = load('individual_shelf_discharge_200m/Prince_Harald_1_discharge_timeseries.mat');
        S2 = load('individual_shelf_discharge_200m/Prince_Harald_2_discharge_timeseries.mat');
        Q_annual = S1.Q_annual + S2.Q_annual;
        Q_annual_staticH = S1.Q_annual_staticH + S2.Q_annual_staticH;
        Q_err_annual = S1.Q_err_annual + S2.Q_err_annual;
        Q_err_annual_staticH = S1.Q_err_annual_staticH + S2.Q_err_annual_staticH;
        Q_error = S1.Q_error + S2.Q_error;
        Q_error_staticH = S1.Q_error_staticH;
        Q_filled = S1.Q_filled + S2.Q_filled;
        Q_max = S1.Q_max + S2.Q_max;
        Q_max_staticH = S1.Q_max_staticH + S2.Q_max_staticH;
        Q_min = S1.Q_min + S2.Q_min;
        Q_min_staticH = S1.Q_min_staticH + S2.Q_min_staticH;
        Q_raw = S1.Q_raw + S2.Q_raw;
        Q_reg = S1.Q_reg + S2.Q_reg;
        Q_reg_err = S1.Q_reg_err + S2.Q_reg_err;
        Q_reg_err_staticH = S1.Q_reg_err_staticH + S2.Q_reg_err_staticH;
        Q_reg_staticH = S1.Q_reg_staticH + S2.Q_reg_staticH;
        Q_staticH = S1.Q_staticH + S2.Q_staticH;
        time = S1.time;
        time_reg = S1.time_reg;
        ann_time = S1.ann_time;
        save('individual_shelf_discharge_200m_consolidated/Prince_Harald_discharge_timeseries.mat',...
            'Q_annual','Q_annual_staticH','Q_err_annual','Q_err_annual_staticH','Q_error',...
            'Q_error_staticH','Q_filled','Q_max','Q_max_staticH','Q_min','Q_min_staticH','Q_raw',...
            'Q_reg','Q_reg_err','Q_reg_err_staticH','Q_reg_staticH','Q_staticH',...
            'time','time_reg','ann_time');
    elseif i==149
        S1 = load('individual_shelf_discharge_200m/Vincennes_Bay_1_discharge_timeseries.mat');
        S2 = load('individual_shelf_discharge_200m/Vincennes_Bay_2_discharge_timeseries.mat');
        S3 = load('individual_shelf_discharge_200m/Vincennes_Bay_3_discharge_timeseries.mat');
        S4 = load('individual_shelf_discharge_200m/Vincennes_Bay_4_discharge_timeseries.mat');
        Q_annual = S1.Q_annual + S2.Q_annual + S3.Q_annual + S4.Q_annual;
        Q_annual_staticH = S1.Q_annual_staticH + S2.Q_annual_staticH + S3.Q_annual_staticH + S4.Q_annual_staticH;
        Q_err_annual = S1.Q_err_annual + S2.Q_err_annual + S3.Q_err_annual + S4.Q_err_annual;
        Q_err_annual_staticH = S1.Q_err_annual_staticH + S2.Q_err_annual_staticH + S3.Q_err_annual_staticH + S4.Q_err_annual_staticH;
        Q_error = S1.Q_error + S2.Q_error + S3.Q_error + S4.Q_error;
        Q_error_staticH = S1.Q_error_staticH + S2.Q_error_staticH + S3.Q_error_staticH + S4.Q_error_staticH;
        Q_filled = S1.Q_filled + S2.Q_filled + S3.Q_filled + S4.Q_filled;
        Q_max = S1.Q_max + S2.Q_max + S3.Q_max + S4.Q_max;
        Q_max_staticH = S1.Q_max_staticH + S2.Q_max_staticH + S3.Q_max_staticH + S4.Q_max_staticH;
        Q_min = S1.Q_min + S2.Q_min + S3.Q_min + S4.Q_min;
        Q_min_staticH = S1.Q_min_staticH + S2.Q_min_staticH + S3.Q_min_staticH + S4.Q_min_staticH;
        Q_raw = S1.Q_raw + S2.Q_raw + S3.Q_raw + S4.Q_raw;
        Q_reg = S1.Q_reg + S2.Q_reg + S3.Q_reg + S4.Q_reg;
        Q_reg_err = S1.Q_reg_err + S2.Q_reg_err + S3.Q_reg_err + S4.Q_reg_err;
        Q_reg_err_staticH = S1.Q_reg_err_staticH + S2.Q_reg_err_staticH + S3.Q_reg_err_staticH + S4.Q_reg_err_staticH;
        Q_reg_staticH = S1.Q_reg_staticH + S2.Q_reg_staticH + S3.Q_reg_staticH + S4.Q_reg_staticH;
        Q_staticH = S1.Q_staticH + S2.Q_staticH + S3.Q_staticH + S4.Q_staticH;
        time = S1.time;
        time_reg = S1.time_reg;
        ann_time = S1.ann_time;
        save('individual_shelf_discharge_200m_consolidated/Vincennes_Bay_discharge_timeseries.mat',...
            'Q_annual','Q_annual_staticH','Q_err_annual','Q_err_annual_staticH','Q_error',...
            'Q_error_staticH','Q_filled','Q_max','Q_max_staticH','Q_min','Q_min_staticH','Q_raw',...
            'Q_reg','Q_reg_err','Q_reg_err_staticH','Q_reg_staticH','Q_staticH',...
            'time','time_reg','ann_time');
    else
        copyfile(['individual_shelf_discharge_200m/' sn '_discharge_timeseries.mat'],['individual_shelf_discharge_200m_consolidated/' sn '_discharge_timeseries.mat']);
    end
            
    
end
        
    
    
    
    