function extract_FAC(migrated_pixels)

if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/RACMO/Antarctica/FDM_2021_update_FAC_detrended'));
end

%% Load flux gate

load('../flux_gates/flux_gates_migrated.mat');
gate_x = gate_x_migrate{migrated_pixels};
gate_y = gate_y_migrate{migrated_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrated

migration_distance = 0:200:3000; % metres
migration_distance = migration_distance(migrated_pixels);

%% Load RACMO data

% Filename
fn='FDMv1.2A_FirnAir_ANT27_1979-2021_detrended.nc';

% Time
num_ts =  length(ncread(fn,'time'));
time = datenum(1979,1,10):10:datenum(1979,1,10)+(num_ts-1)*10;
tidx = find(time >= datenum(1979,1,1)); % Get index for time steps since 2005
time = time(tidx); % subsample time period

% Get grids
lat = ncread(fn,'lat');
lon = ncread(fn,'lon');
[x,y] = ll2ps(lat,lon);

% Read gridded data
zs = ncread(fn,'FirnAir');

%% Make long-term and monthly climatologies for gap filling and routine updates

% Make 30-year climatology
idx = find(time>=datenum(1979,1,1) & time<=datenum(2009,1,1));
zs_clim_2D = nanmean(zs(:,:,idx),3); 

% Make monthly climatologies
dt_time = datetime(time(idx),'convertFrom','datenum');
zs_trim = zs(:,:,idx);
zs_monthly_clim_2D = zeros([size(zs,1),size(zs,2),12]).*NaN;
for i = 1:12
    idx = ismember(month(dt_time),i);
    tmp = zs_trim(:,:,idx); % all jans, febs, marchs etc...
    zs_monthly_clim_2D(:,:,i) = nanmean(tmp,3);
end
clear zs_trim idx tmp

% Fill gaps in climatologies using regionfill
%   - constrain region fill by setting the edge values
zs_clim_2D([1,end],:) = 0;
zs_clim_2D(:,[1,end]) = 0;
zs_clim_2D = regionfill(zs_clim_2D,isnan(zs_clim_2D));
for i = 1:12
    tmp = zs_monthly_clim_2D(:,:,i);
    tmp([1,end],:) = 0;
    tmp(:,[1,end]) = 0;
    tmp = regionfill(tmp,isnan(tmp));
    zs_monthly_clim_2D(:,:,i) = tmp;
end
clear tmp

% Convert daily FAC to monthly
dt_time = datetime(time,'convertFrom','datenum');
TT = timetable(dt_time(:),cube2rect(zs));
TT = retime(TT,'monthly','mean');
zs = rect2cube(TT.Var1,size(zs));
mtime = datenum(TT.Time);
fac_time = mtime;

    
% climatological fac
% interpolate climatological mean
F = scatteredInterpolant(x(:),y(:),zs_clim_2D(:));
fac_clim = F(gate_x,gate_y);
fac_clim(gate_nan) = NaN;
% pre-allocate monthly climatology for this gate
fac_monthly_clim = zeros([length(gate_x),12]).*NaN;
% loop through months
for j = 1:12
    tmp = zs_monthly_clim_2D(:,:,j);
    F.Values = tmp(:);
    fac_monthly_clim(:,j) = F(gate_x,gate_y);
    fac_monthly_clim(gate_nan,j) = NaN;
end
clear tmp

% pre-allocate monthly timeseries for this gate
fac_monthly = zeros([length(gate_x),length(mtime)]).*NaN;
for j = 1:length(mtime)
    tmp = zs(:,:,j);
    tmp([1,end],:) = 0;
    tmp(:,[1,end]) = 0;
    tmp = regionfill(tmp,isnan(tmp));
    F.Values = tmp(:);
    fac_monthly(:,j) = F(gate_x,gate_y);
    fac_monthly(gate_nan,j) = NaN;
end

% Save
save(['FAC_migrate_' num2str(migration_distance) 'm.mat'],'fac_clim','fac_monthly_clim','fac_monthly','fac_time');
    


