% extract_greene_calving_flux

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../v2'));

% make output directory
mkdir individual_shelf_calving_flux

%% Load gates

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all.mat','GL');
GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Load calving flux

fn = 'greene_Supplementary_Table_1.xlsx';

% Get all excel ice shelf names
[~,names] = xlsread(fn,'B7:B187');

% Get calving flux times
time = xlsread(fn,'O5:BJ5');
time = time(1:2:end);
time = datenum(time,1,1);
time(3) = []; % remove 1st oct 2000

% Loop through each ice shelf and calving data for that shelf
for i = 1:numel(GL_edit)
    
    % Get shelf name
    shelf_name = GL_edit(i).Name;
    label_name = GL_labels(i).Name;
    
    % in some cases, Chad has multiple shelves where I have one shelf. For
    % these shelves, we need to read multiple lines of Chad's data.
    if strcmp(shelf_name,'Abbot')
        start = 7;
        stop = 13;
    elseif strcmp(shelf_name,'Getz')
        start = 67;
        stop = 69;
    elseif strcmp(shelf_name,'Larsen_D')
        start = 93;
        stop = 94;
    elseif strcmp(shelf_name,'Wordie')
        start = 180;
        stop = 184;
    else
        clear idx
        % do a first check for matches
        idx = find(strcmpi(names,shelf_name)==1);
        % some of chads shelves do not have underscores, but mine do...
        if isempty(idx)
            name_parts = split(shelf_name,'_');
            for j = 1:numel(name_parts)
                if j == 1
                    shelf_name = name_parts{j};
                else
                    shelf_name = [shelf_name ' ' name_parts{j}];
                end
            end
        end
        % look again for matches
        idx = find(strcmpi(names,shelf_name)==1);
        if isempty(idx)
            disp(['Couldn''t find matching shelf for shelf number ' num2str(i) ' - ' shelf_name]);
            return
        end
        % excel sheet data starts at 6
        start = idx+6; 
        stop = idx+6;
    end
    
    % Load steady-state calving flux (Gt/yr)
    if strcmp(shelf_name,'Whittle')
        ssc = xlsread(fn,'K175:K175');
        ssc = ssc + xlsread(fn,'K59:K59');
        ssc_err = xlsread(fn,'L175:L175');
        ssc_err = sqrt(ssc_err^2 + xlsread(fn,'L59:L59')^2);
    else
        ssc = xlsread(fn,['K' num2str(start) ':K' num2str(stop)]);
        ssc_err = xlsread(fn,['L' num2str(start) ':L' num2str(stop)]);
    end
    ssc = nansum(ssc,1);
    ssc_err = sqrt(nansum(ssc_err.^2,1));
    
    % Load total ice mass (Gt)
    if strcmp(shelf_name,'Whittle')
        tim = xlsread(fn,'O175:BJ175');
        tim_err = tim(:,2:2:end);
        tim = tim(:,1:2:end);
        tim2 = xlsread(fn,'O59:BJ59');
        tim2_err = tim2(:,2:2:end);
        tim2 = tim2(:,1:2:end);
        tim = tim+tim2;
        tim_err = sqrt(tim_err.^2 + tim2_err.^2);
        clear tim2 tim2_err
    else
        tim = xlsread(fn,['O' num2str(start) ':BJ' num2str(stop)]);
        tim_err = tim(:,2:2:end);
        tim = tim(:,1:2:end);
        tim = nansum(tim,1); % add over all subshelves
        tim_err = sqrt(nansum(tim_err.^2,1)); % add over all subshelves
    end
    
    % Remove 3rd measuremet (1st Oct 2000)
    tim(3) = [];
    tim_err(3) = [];
    
    % Calculate full calving flux
    %dmdt = diff(tim)./(diff(time)./365.25);
    dmdt = diff(tim); % positive = ice shelf gain in mass = calving is less than steady state
    dmdt = [0,dmdt]; % i.e. assign changes in mass to subsequent year;
    dmdt_tot = tim(end)-tim(1);
    dmdt_tot_err = sqrt(tim_err(end).^2 + tim_err(end-1).^2);
    %dmdt_err = sqrt((diff(tim_err)./(diff(time)./365.25)).^2);
    dmdt_err = zeros(size(dmdt)).*NaN;
    for kk = 1:length(dmdt)
        if kk == 1
            dmdt_err(kk) = 0;
        else
            dmdt_err(kk) = sqrt(tim_err(kk-1).^2 + tim_err(kk).^2);
        end
    end
    % calculate calving excess directly from initial measurement?
    dm_from_init = zeros(size(tim)).*NaN;
    dm_from_init_err = zeros(size(tim)).*NaN;
    for kk = 1:length(dmdt)
        if kk == 1
            dm_from_init(kk) = 0;
            dm_from_init_err(kk) = 0;
        else
            dm_from_init(kk) = tim(kk)-tim(1); % positive = increase in ice shelf mass, so calving was less than steady-state
            dm_from_init_err(kk) = sqrt(tim_err(kk).^2 + tim_err(1).^2);
        end
    end
    %dmdt_err = sqrt(nansum(tim_err.^2)));
    %dmdt_err = [0,dmdt_err];
    c = ssc + dmdt.*-1; % minus dmdt, because positive is a gain in mass, so the true calving flux must be lower than the steady-state flux
    c_err = sqrt(ssc_err^2 + dmdt_err.^2); % assume the errors are uncorrelated...
    
    % Don't allow negative calving (i.e. where, for some reason, the ice
    % shelf mass has increased by more than the ssc. For example, because
    % the ice shelf increased in speed relative to the speed used to
    % calculate ssc
    % I'm commenting this out because if I set c to zero during these
    % times, then the reconstructed ice mass change doesn't balance the
    % mass budget. If the ssc were perfect and changed through time, then c
    % should never be zero. However, ssc here is not perfect and is static,
    % so these 'negative' calving fluxes indicate times when the true ssc
    % had changed from that given here. 
    %c(c<0)=0;
    
    % Plot total ice mass
    figure('units','inches','outerposition',[5 5 7 3],'color','w','visible','off')
    llim = nanmin(tim)-nanmean(tim)*0.01;
    ulim = nanmax(tim)+nanmean(tim)*0.01;
    axUnder = cla(); % Underlying axis handle
    ax = copyobj(axUnder, ancestor(axUnder,'figure')); % main axis handle.
    % shade every other year
    for j = 1996:2:2020
        h = patch([datenum(j,1,1) datenum(j,1,1) datenum(j,12,31) datenum(j,12,31) datenum(j,1,1)],[llim ulim ulim llim llim],'k','edgecolor','none','facealpha',.2);
        h.FaceColor = [173 216 230]./255;
        h.Parent = ax;
        if j == 1996; hold(ax,'on'); end
    end
    % Plot observations
    plot(ax,time,tim,'k','linewidth',2);
    h = patch([time,fliplr(time)],[tim+tim_err,fliplr(tim)-fliplr(tim_err)],'k','edgecolor','none','facealpha',.2);
    h.FaceColor = [.8 .8 .8];
    h.Parent = ax;
    % date axis
    startDate = dateshift(datetime(datenum(1997,1,1),'convertFrom','datenum'), 'start', 'year'); 
    endDate = dateshift(datetime(datenum(2021,12,31),'convertFrom','datenum'), 'start', 'year') + calyears(1);
    dtTicks = startDate : calmonths(6) :  endDate; % 6-month interval date ticks
    %   - set  xticks of the main axis to Jan 1st of each year but remove labels
    xticks = dtTicks(1:2:end);
    xtickLabs = repmat({' '},size(xticks)); % to get the xlabel spacing right
    set(ax, 'XTick', datenum(1997:2022,1,1), 'XLim', [datenum(1997,1,1),datenum(2027,1,1)],'XTickLabel',xtickLabs)
    %   - Set xticks of underlying axis to July 1st of each year, use Jan 1st tick labels
    % We also need to plot an invisible data point on the underlying axis to force the 
    % xaxis to be datetimeruler.
    plot(axUnder, time(1), nan, 'x') % will not appear.
    dtTicksLabs = cellstr(datestr(dtTicks(1:2:end),'yyyy')); 
    set(axUnder, 'XTick', datenum(1997:2021,7,1),'XTickLabel', dtTicksLabs, 'xlim', ax.XLim)
    xtickangle(axUnder,90);
    axUnder.YTick = []; 
    pos = get(axUnder, 'Position');
    pos(2) = pos(2)+0.1;
    pos(4) = pos(4)-0.1;
    set(axUnder, 'Position', pos)
    pos = get(ax, 'Position');
    pos(2) = pos(2)+0.1;
    pos(4) = pos(4)-0.1;
    set(ax, 'Position', pos)
    %   - labels
    set(ax,'YLim',[llim ulim]);
    ylabel(ax,'Mass (Gt)');
    set(ax,'FontSize',10,'FontName','Helvetica')
    box(ax,'on')
    set(ax,'XLim',[datenum(1997,1,1),datenum(2021,12,31)]);
    % Must come after converting axUnder to datetimeruler. 
    linkprop([ax,axUnder],{'Position','InnerPosition','XLim'}); % add more as needed
    axUnder.HandleVisibility = 'off';  % avoid accidentally accessing the underlying axis
    % Save
    export_fig(['individual_shelf_calving_flux/' label_name '_total_ice_mass.png'],'-dpng','-r300');
    close
    
    % Plot dM/dt
    figure('units','inches','outerposition',[5 5 7 3],'color','w','visible','off')
    llim = nanmin(dmdt)-abs(nanmean(dmdt)*0.05);
    ulim = nanmax(dmdt)+abs(nanmean(dmdt)*0.05);
    axUnder = cla(); % Underlying axis handle
    ax = copyobj(axUnder, ancestor(axUnder,'figure')); % main axis handle.
    % shade every other year
    for j = 1996:2:2020
        h = patch([datenum(j,1,1) datenum(j,1,1) datenum(j,12,31) datenum(j,12,31) datenum(j,1,1)],[llim ulim ulim llim llim],'k','edgecolor','none','facealpha',.2);
        h.FaceColor = [173 216 230]./255;
        h.Parent = ax;
        if j == 1996; hold(ax,'on'); end
    end
    % Plot observations
    plot(ax,time,dmdt,'k','linewidth',2);
    h = patch([time,fliplr(time)],[dmdt+dmdt_err,fliplr(dmdt)-fliplr(dmdt_err)],'k','edgecolor','none','facealpha',.2);
    h.FaceColor = [.8 .8 .8];
    h.Parent = ax;
    % date axis
    startDate = dateshift(datetime(datenum(1997,1,1),'convertFrom','datenum'), 'start', 'year'); 
    endDate = dateshift(datetime(datenum(2021,12,31),'convertFrom','datenum'), 'start', 'year') + calyears(1);
    dtTicks = startDate : calmonths(6) :  endDate; % 6-month interval date ticks
    %   - set  xticks of the main axis to Jan 1st of each year but remove labels
    xticks = dtTicks(1:2:end);
    xtickLabs = repmat({' '},size(xticks)); % to get the xlabel spacing right
    set(ax, 'XTick', datenum(1996:2022,1,1), 'XLim', [datenum(1996,1,1),datenum(2022,1,1)],'XTickLabel',xtickLabs)
    %   - Set xticks of underlying axis to July 1st of each year, use Jan 1st tick labels
    % We also need to plot an invisible data point on the underlying axis to force the 
    % xaxis to be datetimeruler.
    plot(axUnder, time(1), nan, 'x') % will not appear.
    dtTicksLabs = cellstr(datestr(dtTicks(1:2:end),'yyyy')); 
    set(axUnder, 'XTick', datenum(1997:2021,7,1),'XTickLabel', dtTicksLabs, 'xlim', ax.XLim)
    xtickangle(axUnder,90);
    axUnder.YTick = []; 
    pos = get(axUnder, 'Position');
    pos(2) = pos(2)+0.1;
    pos(4) = pos(4)-0.1;
    set(axUnder, 'Position', pos)
    pos = get(ax, 'Position');
    pos(2) = pos(2)+0.1;
    pos(4) = pos(4)-0.1;
    set(ax, 'Position', pos)
    %   - labels
    set(ax,'YLim',[llim ulim]);
    ylabel(ax,'dM/dt (Gt yr^{-1})');
    set(ax,'FontSize',10,'FontName','Helvetica')
    box(ax,'on')
    set(ax,'XLim',[datenum(1997,1,1),datenum(2021,12,31)]);
    % Must come after converting axUnder to datetimeruler. 
    linkprop([ax,axUnder],{'Position','InnerPosition','XLim'}); % add more as needed
    axUnder.HandleVisibility = 'off';  % avoid accidentally accessing the underlying axis
    % Save
    export_fig(['individual_shelf_calving_flux/' label_name '_dMdt.png'],'-dpng','-r300');
    close
    
    % plot calving flux
    figure('units','inches','outerposition',[5 5 7 3],'color','w','visible','off')
    llim = nanmin(c)-abs(nanmean(c)*0.05);
    ulim = nanmax(c)+abs(nanmean(c)*0.05);
    axUnder = cla(); % Underlying axis handle
    ax = copyobj(axUnder, ancestor(axUnder,'figure')); % main axis handle.
    % shade every other year
    for j = 1996:2:2020
        h = patch([datenum(j,1,1) datenum(j,1,1) datenum(j,12,31) datenum(j,12,31) datenum(j,1,1)],[llim ulim ulim llim llim],'k','edgecolor','none','facealpha',.2);
        h.FaceColor = [173 216 230]./255;
        h.Parent = ax;
        if j == 1996; hold(ax,'on'); end
    end
    % Plot observations
    %   - steady state calving
    plot(ax,[time(1) time(end)],[ssc ssc],'r','linewidth',1);
    h = patch([time(1) time(1) time(end) time(end) time(1)],[ssc-ssc_err ssc+ssc_err ssc+ssc_err ssc-ssc_err ssc-ssc_err],'r','edgecolor','none','facealpha',.2);
    h.FaceColor = [.8 .0 0];
    h.Parent = ax;
    %   - observed calving
    plot(ax,time,c,'k','linewidth',2);
    h = patch([time,fliplr(time)],[c+c_err,fliplr(c)-fliplr(c_err)],'k','edgecolor','none','facealpha',.2);
    h.FaceColor = [.8 .8 .8];
    h.Parent = ax;
    % date axis
    startDate = dateshift(datetime(datenum(1997,1,1),'convertFrom','datenum'), 'start', 'year'); 
    endDate = dateshift(datetime(datenum(2021,12,31),'convertFrom','datenum'), 'start', 'year') + calyears(1);
    dtTicks = startDate : calmonths(6) :  endDate; % 6-month interval date ticks
    %   - set  xticks of the main axis to Jan 1st of each year but remove labels
    xticks = dtTicks(1:2:end);
    xtickLabs = repmat({' '},size(xticks)); % to get the xlabel spacing right
    set(ax, 'XTick', datenum(1996:2022,1,1), 'XLim', [datenum(1996,1,1),datenum(2022,1,1)],'XTickLabel',xtickLabs)
    %   - Set xticks of underlying axis to July 1st of each year, use Jan 1st tick labels
    % We also need to plot an invisible data point on the underlying axis to force the 
    % xaxis to be datetimeruler.
    plot(axUnder, time(1), nan, 'x') % will not appear.
    dtTicksLabs = cellstr(datestr(dtTicks(1:2:end),'yyyy')); 
    set(axUnder, 'XTick', datenum(1997:2021,7,1),'XTickLabel', dtTicksLabs, 'xlim', ax.XLim)
    xtickangle(axUnder,90);
    axUnder.YTick = []; 
    pos = get(axUnder, 'Position');
    pos(2) = pos(2)+0.1;
    pos(4) = pos(4)-0.1;
    set(axUnder, 'Position', pos)
    pos = get(ax, 'Position');
    pos(2) = pos(2)+0.1;
    pos(4) = pos(4)-0.1;
    set(ax, 'Position', pos)
    %   - labels
    set(ax,'YLim',[llim ulim]);
    ylabel(ax,'Calving flux (Gt yr^{-1})');
    set(ax,'FontSize',10,'FontName','Helvetica')
    box(ax,'on')
    set(ax,'XLim',[datenum(1997,1,1),datenum(2021,12,31)]);
    % Must come after converting axUnder to datetimeruler. 
    linkprop([ax,axUnder],{'Position','InnerPosition','XLim'}); % add more as needed
    axUnder.HandleVisibility = 'off';  % avoid accidentally accessing the underlying axis
    % Save
    export_fig(['individual_shelf_calving_flux/' label_name '_calving_flux.png'],'-dpng','-r300');
    close
    
    % Save data
    save(['individual_shelf_calving_flux/' label_name '_calving_timeseries.mat'],'time','c','c_err','tim','dmdt','tim_err','dmdt_err','ssc','ssc_err','dmdt_tot','dmdt_tot_err','dm_from_init','dm_from_init_err');
    
end
    
    
    
    
    
    
    
    