% extract_ice_shelf_grounding_line_thickness

clear
close all
clc


% Set paths and libraries
if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
    addpath(genpath('../flux_gates'));
    addpath(genpath('../../ice_shelf_masks_greene'));
    addpath(genpath('D:\work\Fellowship_Leeds\Papers\Research\AIS_discharge\thickness'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/DEMs/Antarctica/REMA'));
    addpath(genpath('/resstore/b0133/Data/BedMachine'));
    addpath(genpath('../flux_gates'));
    addpath(genpath('../../ice_shelf_masks_greene'));
end

% Make output directory
mkdir individual_shelf_thickness

% Uxse 200 m gates?
use_200m = 1;
mkdir individual_shelf_thickness_200m

%% Load gates

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

%% Load thickness data

% Compilation of bed data (see compile_bed_data.mat)
load('merged_bed.mat')
load('merged_bed_err.mat');
[bed_X,bed_Y] = meshgrid(x,y);

% REMA 200m surface
[surf,surf_x,surf_y,~] = geoimread('REMA_200m_dem_filled.tif');
[surf_X,surf_Y] = meshgrid(surf_x,surf_y);
surf(surf==-9999)=0;

% Interpolate bed to surface grid
bed = interp2(bed_X,bed_Y,bed,surf_X,surf_Y);
bed_err = interp2(bed_X,bed_Y,bed_err,surf_X,surf_Y);
clear bed_x bed_y bed_X bed_Y

% Thickness grid
H = surf - bed;
H(H<0)=0;

%% Extract thickness at each shelf

for i = 169%1:numel(GL)%1:numel(GL)
   
    % Get shelf info
    tic;
    shelf_name = GL(i).Name;
    gate_x = GL(i).X;
    gate_y = GL(i).Y;
    if strcmp(shelf_name,'Wordie') || strcmp(shelf_name,'Larsen_B')
        gate_x_all = gate_x;
        gate_y_all = gate_y;
    end
    disp(' ');
    disp(['Starting shelf number: ' num2str(i) ' - ' shelf_name ]);
    
    % Get thickness and thickness error
    % For Wordie and Larsen B, load the relevant shelf
    if strcmp(shelf_name,'Larsen_B')
        H_shelf = cell(3,1);
        H_err_shelf = cell(3,1);
        for j = 1:3
            gate_x = gate_x_all{j};
            gate_y = gate_y_all{j};
            H_shelf_tmp = interp2(surf_X,surf_Y,H,gate_x(:),gate_y(:));
            H_err_shelf_tmp = interp2(surf_X,surf_Y,bed_err,gate_x(:),gate_y(:));
            e2 = bedmachine_interp('errbed',gate_x(:),gate_y(:));
            H_err_shelf_tmp(isnan(H_err_shelf_tmp)) = e2(isnan(H_err_shelf_tmp));
            H_shelf_tmp(isnan(gate_x)) = NaN;
            H_err_shelf_tmp(isnan(gate_x)) = NaN;
            H_err_shelf_tmp(isnan(H_err_shelf_tmp)) = H_shelf_tmp(isnan(H_err_shelf_tmp)).*0.1;
            H_shelf{j} = H_shelf_tmp;
            H_err_shelf{j} = H_err_shelf_tmp;
        end
    elseif strcmp(shelf_name,'Wordie')
        load([shelf_name '_mask_islands_removed_data.mat'],'coast_time_all');
        H_shelf = cell(length(coast_time_all),1);
        H_shelf_err = cell(length(coast_time_all),1);
        for j = 1:length(coast_time_all)
            gate_x = gate_x_all{j};
            gate_y = gate_y_all{j};
            H_shelf_tmp = interp2(surf_X,surf_Y,H,gate_x(:),gate_y(:));
            H_err_shelf_tmp = interp2(surf_X,surf_Y,bed_err,gate_x(:),gate_y(:));
            e2 = bedmachine_interp('errbed',gate_x(:),gate_y(:));
            H_err_shelf_tmp(isnan(H_err_shelf_tmp)) = e2(isnan(H_err_shelf_tmp));
            H_shelf_tmp(isnan(gate_x)) = NaN;
            H_err_shelf_tmp(isnan(gate_x)) = NaN;
            H_err_shelf_tmp(isnan(H_err_shelf_tmp)) = H_shelf_tmp(isnan(H_err_shelf_tmp)).*0.1;
            H_shelf{j} = H_shelf_tmp;
            H_err_shelf{j} = H_err_shelf_tmp;
        end
    else
        H_shelf = interp2(surf_X,surf_Y,H,gate_x(:),gate_y(:));
        H_err_shelf = interp2(surf_X,surf_Y,bed_err,gate_x(:),gate_y(:));
        e2 = bedmachine_interp('errbed',gate_x(:),gate_y(:));
        H_err_shelf(isnan(H_err_shelf)) = e2(isnan(H_err_shelf));
        H_shelf(isnan(gate_x)) = NaN;
        H_err_shelf(isnan(gate_x)) = NaN;
        H_err_shelf(isnan(H_err_shelf)) = H_shelf(isnan(H_err_shelf)).*0.1;
    end
    % Save data for this shelf
    if use_200m == 1
        save(['individual_shelf_thickness_200m/' shelf_name '_thickness_mergedBed_REMAsurface_no_corrections.mat'],...
            'H_shelf','H_err_shelf');
    else
         save(['individual_shelf_thickness/' shelf_name '_thickness_mergedBed_REMAsurface_no_corrections.mat'],...
            'H_shelf','H_err_shelf');
    end
    
%     % And build up a structure of all gate data
%     GL_thickness(i).Name = shelf_name;
%     GL_thickness(i).H = H_shelf;
%     GL_thickness(i).err = H_err_shelf;
    toc;
    
end

% % Save structure of all gate data
% save('all_shelf_gate_thickness_mergedBed_REMAsurface_no_corrections.mat','GL_thickness','-v7.3');



