function fill_ice_velocity(migrated_pixels)

% add paths to libraries
if ispc
    addpath(genpath('D:/work/Fellowship_Leeds/Data'));
else
    addpath(genpath('/resstore/b0133/Data/MATLAB_tools'));
    addpath(genpath('/resstore/b0133/Data/Velocity'));
end

%% Load flux gate

load('../flux_gates/flux_gates_migrated.mat');
gate_x = gate_x_migrate{migrated_pixels};
gate_y = gate_y_migrate{migrated_pixels};
gate_nan = isnan(gate_x); % indices of gate nans
clear gate_x_migrate gate_y_migrated

migration_distance = 0:200:3000; % metres
migration_distance = migration_distance(migrated_pixels);

%% Load raw velocity

load(['gate_vel_raw_linear_migrate_' num2str(migration_distance) 'm.mat'])

%% Load reference velocity

ref = load(['../reference_data/reference_gate_data_migrate_' num2str(migration_distance) 'm.mat'],'gate_vx','gate_vy','gate_vx_err','gate_vy_err');

%% Remove outliers

% initialise
vx_clean = vx_raw;
vy_clean = vy_raw;
vxE_clean = vxE_raw;
vyE_clean = vyE_raw;

% scaling factor for outlier removal 
c=-1/(sqrt(2)*erfcinv(3/2));

% add some negligible noise to the time vector, to permit detrending with
% duplicate times
a = -0.000001;
b = 0.000001;
r = a + (b-a).*rand(1,length(time_vel));
tmp = time_vel + r;
tmp = sort(tmp);

% Prepare data cleaning
sp = hypot(vx_clean,vy_clean);
spE = hypot(vxE_clean,vyE_clean);
removed = zeros(size(vx_clean));

% Global outlier removal
sp_detrend = detrend(sp',1,'omitnan','samplepoints',datetime(tmp,'convertfrom','datenum'))'; % remove linear trend from all timeseries; takes a while...
sMAD = c.*nanmedian(abs(sp_detrend-nanmedian(sp_detrend,2)),2);
removed(abs(sp_detrend-nanmedian(sp_detrend,2)) > sMAD.*5) = 1;
sp(logical(removed)) = NaN;
spE(logical(removed)) = NaN;

% Local outlier removal
win_size = 365/2; % days; full window length of 1 year
for i = 1:length(time_vel)
    ind = find(time_vel>=time_vel(i)-win_size & time_vel<=time_vel(i)+win_size);
    if length(ind)>=5
        timek = time_vel(ind);
        spk = sp(:,ind); % 1 year kernal for every gate pixel
        spEk = spE(:,ind); % 1 year kernal for every gate pixel
        snr = spk./spEk;
        midval = sp(:,ceil(nanmedian(ind))); % get middle kernal value in every gate pixel
        midloc_full = find(time_vel==time_vel(ceil(nanmedian(ind))));
        midloc_k = find(timek==time_vel(ceil(nanmedian(ind))));
        spk(:,midloc_k) = NaN; % set middle value to NaN, so it doesn't affect the mean
        spm = wmean(spk,snr,'dim',2,'omitnan'); % SNR-weighted mean of the kernal velocities
        spstd = nanstd(spk,[],2); % get local standard deviation, excluding middle value
        spk(:,midloc_k)=midval; % reinstate middle value
        removek = spk > spm+spstd*3; % remove gate pixels more than 3 standard deviations from the SNR-weighted mean
        removek = any(removek>0,2); % always remove middle pixel in kernal
        sp(removek,i) = NaN; % remove outliers as we slide the kernal
        removed(removek,i) = 1; % keep track of which pixels are removed
    end
end
removed = logical(removed);
vx_clean(removed) = NaN;
vy_clean(removed) = NaN;
vxE_clean(removed) = NaN;
vyE_clean(removed) = NaN;

% save
save(['gate_vel_clean_migrate_' num2str(migration_distance) 'm.mat'],'vx_clean','vy_clean','vxE_clean','vyE_clean','time_vel','source_vel','removed');

%% Fill gaps

% initialise
vx_filled = vx_clean;
vy_filled = vy_clean;
vxE_filled = vxE_clean;
vyE_filled = vyE_clean;

% Fill gaps
filled = zeros(size(vx_filled));
for i = 1:length(gate_x)
    if isfinite(gate_x(i))
        % vx
        ts = vx_filled(i,:);
        if sum(isfinite(ts))>1
            ts = fillmissing(ts,'linear','EndValues','none');
            ts = fillmissing(ts,'next');
            ts = fillmissing(ts,'previous');
        end
        vx_filled(i,:) = ts;
        % vy
        ts = vy_filled(i,:);
        if sum(isfinite(ts))>1
            ts = fillmissing(ts,'linear','EndValues','none');
            ts = fillmissing(ts,'next');
            ts = fillmissing(ts,'previous');
        end
        vy_filled(i,:) = ts;
    end
end

% Any timeseries that had just 1 or no observations still need filling.
% Fill these using the reference velocity
for i = 1:length(time_vel)
    % vx
    tmp_vx = vx_filled(:,i);
    tmp_vxE = vxE_filled(:,i);
    isn = isnan(tmp_vx);
    tmp_vx(isn) = ref.gate_vx(isn);
    tmp_vxE(isn) = ref.gate_vx_err(isn);
    vx_filled(:,i) = tmp_vx;
    vxE_filled(:,i) = tmp_vxE;
    % vy
    tmp_vy = vy_filled(:,i);
    tmp_vyE = vyE_filled(:,i);
    isn = isnan(tmp_vy);
    tmp_vy(isn) = ref.gate_vy(isn);
    tmp_vyE(isn) = ref.gate_vy_err(isn);
    vy_filled(:,i) = tmp_vy;
    vxE_filled(:,i) = tmp_vyE;
end

% Set error to 10% of velocity where we have filled gaps
isn = isnan(vxE_filled);
vxE_filled(isn) = abs(vx_filled(isn)).*0.1;
vyE_filled(isn) = abs(vy_filled(isn)).*0.1;

% Make sure there are gaps in velocity where there are gaps in the gate
vx_filled(gate_nan,:) = NaN;
vy_filled(gate_nan,:) = NaN;
vxE_filled(gate_nan,:) = NaN;
vyE_filled(gate_nan,:) = NaN;
filled(isfinite(vx_filled) & isnan(vx_clean)) = 1;
  
% Save
save(['gate_vel_filled_migrate_' num2str(migration_distance) 'm.mat'],'vx_filled','vy_filled','vxE_filled','vyE_filled','time_vel','source_vel','filled')



