% make_getz_mask


clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../grounding_line_discharge'));
addpath(genpath('D:\work\Fellowship_Leeds\Papers\Research\ASE_discharge'));

mkdir masks
mkdir masks/all_years

%% Load grounding lines

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all.mat','GL');


%% Load time-varying coastlines

coast_list = dir('D:\work\Fellowship_Leeds\Data\calving_front_locations_greene\coastline_data/antarctic_coastline_*.txt');

coast_time_all = zeros([numel(coast_list),1]).*NaN;
dec_year_all = zeros([numel(coast_list),1]).*NaN;
for i = 1:numel(coast_list)
    d = importdata([coast_list(i).folder '/' coast_list(i).name]); 
    coast{i} = d.data;
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    mkdir(['masks/' coast_time_str]);
    coast_time_all(i) = datenum(str2double(coast_time),1,1);
    dec_year_all(i) = str2double(coast_time);
end

% make colormap for coast time
cmap = colorcet('Gouldian','N',numel(coast_list));

%% Make mask

shelf_name = GL(54).Name;
gate_x = GL(54).X;
gate_y = GL(54).Y;

% Get sections of GL
sections = regionprops(~isnan(gate_x), gate_x,'pixelIdxList','PixelValues');

% Loop through coastline
for i = 1:numel(coast)
    
    % Get coastline coordinates and time
    coast_x = coast{i}(:,1);
    coast_y = coast{i}(:,2);
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    coast_time = coast_time_all(i);
    
    % Section 1
    x1 = gate_x(sections(1).PixelIdxList);
    y1 = gate_y(sections(1).PixelIdxList);
    d = sqrt((x1(1)-coast_x).^2 + (y1(1)-coast_y).^2);
    idx1_start = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((x1(end-1)-coast_x).^2 + (y1(end-1)-coast_y).^2);
    idx1_end = find(d(:) == nanmin(d(:)),1,'first');
    
    % links
    % - 1
    L1 = shaperead('tmp/Getz_link.shp');
    d = sqrt((L1.X(end-1)-coast_x).^2 + (L1.Y(end-1)-coast_y).^2);
    link1_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((L1.X(1)-coast_x).^2 + (L1.Y(1)-coast_y).^2);
    link1_start = find(d(:) == nanmin(d(:)),1,'first');
    % - 2
    L2 = shaperead('tmp/Getz_link2.shp');
    d = sqrt((L2.X(end-1)-coast_x).^2 + (L2.Y(end-1)-coast_y).^2);
    link2_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((L2.X(1)-coast_x).^2 + (L2.Y(1)-coast_y).^2);
    link2_start = find(d(:) == nanmin(d(:)),1,'first');
    % - 3
    L3 = shaperead('tmp/Getz_link3.shp');
    d = sqrt((L3.X(end-1)-coast_x).^2 + (L3.Y(end-1)-coast_y).^2);
    link3_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((L3.X(1)-coast_x).^2 + (L3.Y(1)-coast_y).^2);
    link3_start = find(d(:) == nanmin(d(:)),1,'first');
    % - 4
    L4 = shaperead('tmp/Getz_link4.shp');
    d = sqrt((L4.X(end-1)-coast_x).^2 + (L4.Y(end-1)-coast_y).^2);
    link4_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((L4.X(1)-coast_x).^2 + (L4.Y(1)-coast_y).^2);
    link4_start = find(d(:) == nanmin(d(:)),1,'first');
    % - 5
    L5 = shaperead('tmp/Getz_link5.shp');
    d = sqrt((L5.X(end-1)-coast_x).^2 + (L5.Y(end-1)-coast_y).^2);
    link5_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((L5.X(1)-coast_x).^2 + (L5.Y(1)-coast_y).^2);
    link5_start = find(d(:) == nanmin(d(:)),1,'first');
    
    % Make main section
    main_x = [x1(1:end-1) ; ...
        coast_x(idx1_end:link5_start); L5.X(1:end-1)';...
        coast_x(link5_end:link1_start) ; L1.X(1:end-1)' ; ...
        coast_x(link1_end:link2_start) ; L2.X(1:end-1)' ; ...
        coast_x(link2_end:link3_start) ; L3.X(1:end-1)' ; ...
        coast_x(link3_end:link4_start) ; L4.X(1:end-1)' ; ...
        coast_x(link4_end:idx1_start) ; x1(1)];
    main_y = [y1(1:end-1) ; ...
        coast_y(idx1_end:link5_start); L5.Y(1:end-1)';...
        coast_y(link5_end:link1_start) ; L1.Y(1:end-1)' ; ...
        coast_y(link1_end:link2_start) ; L2.Y(1:end-1)' ; ...
        coast_y(link2_end:link3_start) ; L3.Y(1:end-1)' ; ...
        coast_y(link3_end:link4_start) ; L4.Y(1:end-1)' ; ...
        coast_y(link4_end:idx1_start) ; y1(1)];
    
    % Start full mask
    full_x = [main_x; NaN];
    full_y = [main_y; NaN];
    
    % Then do next two sections
    for j = [2,3] % other sections are no good
        x_tmp = gate_x(sections(j).PixelIdxList);
        y_tmp = gate_y(sections(j).PixelIdxList);
        d = sqrt((x_tmp(1)-coast_x).^2 + (y_tmp(1)-coast_y).^2);
        idx1 = find(d(:) == nanmin(d(:)),1,'first');
        d = sqrt((x_tmp(end-1)-coast_x).^2 + (y_tmp(end-1)-coast_y).^2);
        idx2 = find(d(:) == nanmin(d(:)),1,'first');
        if idx1 < idx2
            sect_x = [x_tmp(1:end-1) ; flipud(coast_x(idx1:idx2)) ; x_tmp(1)];
            sect_y = [y_tmp(1:end-1) ; flipud(coast_y(idx1:idx2)) ; y_tmp(1)];
        else
            sect_x = [x_tmp(1:end-1) ; coast_x(idx2:idx1) ; x_tmp(1)];
            sect_y = [y_tmp(1:end-1) ; coast_y(idx2:idx1) ; y_tmp(1)];
        end
        % build full mask
        full_x = [full_x(:) ; sect_x(:); NaN];
        full_y = [full_y(:) ; sect_y(:); NaN];
    end
    
    % Save full data
    shelf_x{i} = full_x;
    shelf_y{i} = full_y;
    
end

% Plot this shelf mask for each time
cen_x = nanmean(shelf_x{1});
cen_y = nanmean(shelf_y{1});
[cen_lat,cen_lon] = ps2ll(cen_x,cen_y);
x_len = (nanmax(shelf_x{1}) - nanmin(shelf_x{1}) ) /1000;
y_len = (nanmax(shelf_y{1}) - nanmin(shelf_y{1}) ) /1000;
len = max([x_len,y_len]);
[moa,modis_x,modis_y,~] = geoimread('moa125_2014_hp1_v01.tif',shelf_x{1},shelf_y{1},5000);
moa=uint16(moa);
RGB = mat2im(moa,gray(256),[1 20000]); 
figure('color','w','visible','on');
da = daspect; 
da = [1 1 da(3)];
hm = image(modis_x,modis_y,RGB); axis xy
set(hm,'alphadata',moa>0)
uistack(hm,'bottom') 
ax = axis;
axis xy 
daspect(da)
hold on
for j = 1:numel(shelf_x)
    plot(shelf_x{j},shelf_y{j},'color',cmap(j,:),'linewidth',1)
    if j == 1
        min_x = nanmin(shelf_x{j});
        min_y = nanmin(shelf_y{j});
        max_x = nanmax(shelf_x{j});
        max_y = nanmax(shelf_y{j});
    else
        if nanmin(shelf_x{j}) < min_x
            min_x = nanmin(shelf_x{j});
        end
        if nanmin(shelf_y{j}) < min_y
            min_y = nanmin(shelf_y{j});
        end
        if nanmax(shelf_x{j}) > max_x
            max_x = nanmax(shelf_x{j});
        end
        if nanmax(shelf_y{j}) > max_y
            max_y = nanmax(shelf_y{j});
        end
    end
end
set(gca,'XLim',[min_x-20000 max_x+20000]);
set(gca,'YLim',[min_y-20000 max_y+20000]);
cb = colorbar;
colormap(cmap);
ylabel(cb,'Time');
xlabel('Easting (km)');
ylabel('Northing (km)');
caxis([min(dec_year_all) max(dec_year_all)]);
plot(gate_x,gate_y,'k','linewidth',1);
try; measuresps('vel','k'); end
scalebarps
export_fig(['masks/all_years/Getz_mask_overview.shp']);
%close

% Save
save('masks/all_years/Getz_mask_data.mat','coast_time_all','shelf_x','shelf_y');
    
