% make_ice_shelf_grounding_line_flux_gates

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));

%% Load data

% Load minimum ice shelf mask
S = shaperead('../../ice_shelf_masks/complete/minimum_ice_shelf_mask_Antarctica_BJD_v03.shp');

% MEaSUREs grounding line
M = shaperead('GroundingLine_Antarctica_v02.shp');
Mx = M.X;
My = M.Y;
sections = regionprops(~isnan(Mx), My,'pixelIdxList','PixelValues');
lens = zeros([numel(sections),1]).*NaN;
for i = 1:length(sections)
    lens(i) = length(sections(i).PixelIdxList);
end
[~,iv] = sort(lens);
Mx_grounded = [Mx(sections(iv(end)).PixelIdxList) , NaN, Mx(sections(iv(end-1)).PixelIdxList), NaN,...
    Mx(sections(iv(end-2)).PixelIdxList), NaN, Mx(sections(iv(end-3)).PixelIdxList), NaN,...
    Mx(sections(iv(end-10)).PixelIdxList)];
My_grounded = [My(sections(iv(end)).PixelIdxList) , NaN, My(sections(iv(end-1)).PixelIdxList), NaN,...
    My(sections(iv(end-2)).PixelIdxList), NaN, My(sections(iv(end-3)).PixelIdxList), NaN,...
    My(sections(iv(end-10)).PixelIdxList)];

% Basins and islands
basins = shaperead('Basins_IMBIE_Antarctica_v02.shp');

% Get version of grounding line without islands
[~,on] = inpoly2([Mx(:),My(:)],[basins(1).X(:),basins(1).Y(:)]);
on = logical(1-on); % invert
Mx = Mx(on);
My = My(on);

% BedMachine grounding line
[Bx,By] = bedmachine_data('gl');
sections = regionprops(~isnan(Bx), By,'pixelIdxList','PixelValues');
lens = zeros([numel(sections),1]).*NaN;
for i = 1:length(sections)
    lens(i) = length(sections(i).PixelIdxList);
end
[~,iv] = sort(lens);
Bx_grounded = [Bx(sections(iv(end)).PixelIdxList); NaN; Bx(sections(iv(end-1)).PixelIdxList); NaN; Bx(sections(iv(end-2)).PixelIdxList);NaN;...
    Bx(sections(iv(end-10)).PixelIdxList)];
By_grounded = [By(sections(iv(end)).PixelIdxList); NaN; By(sections(iv(end-1)).PixelIdxList); NaN; By(sections(iv(end-2)).PixelIdxList);NaN;...
    By(sections(iv(end-10)).PixelIdxList)];

% List of shelves to use MEaSUREs grounding line (BedMachine for all others)
M_shelves = {'Ronne','Larsen_C','Larsen_B_2','Wilkins','Stange','Abbot',...
    'Hamilton_Piedmont','Hummer_Point','Harmon_Bay','Swinburne','Ross_East',...
    'Ross_West','Nansen','Ninnis','Moscow_University_1','Shackleton','Baudouin',...
    'Fimbul','Riiser_Larsen','Brunt_Stancomb','Filchner','Wordie','Sulzberger'};

%% Get bedmachine and MEaSUREs grounding line pixels on ice shelf mask

for i = 1%:numel(S)
    
    % Load current ice shelf
    x = S(i).X;
    y = S(i).Y;
    sections = regionprops(~isnan(x), x,'pixelIdxList','PixelValues');
    
    % Compare with measures
    if sum(contains(M_shelves,S(i).Name))>0
        gl_x = [];
        gl_y = [];
        for j = 1:numel(sections)
            x_tmp = x(sections(j).PixelIdxList);
            y_tmp = y(sections(j).PixelIdxList);
            total_length = arclength(x_tmp(:),y_tmp(:));
            xy = interparc(0:(200/total_length):1,x_tmp(:),y_tmp(:),'linear');
            x_tmp = xy(:,1); y_tmp = xy(:,2);
            [in,on] = inpoly2([x_tmp(:),y_tmp(:)],[Mx_grounded(:),My_grounded(:)],[],1e-6);
            x_keep = x_tmp(on);
            y_keep = y_tmp(on);
            % If there are big spaces in the coordinates, then the ice shelf
            % probably has two sides, which we need to break up
            if length(x_keep)>1
                d = pathdistps(x_keep,y_keep);
                if max(gradient(d))>250
                    sections2 = regionprops(gradient(d)<2000,x_keep,'pixelIdxList');
                    x_tmp = [];
                    y_tmp = [];
                    for k = 1:length(sections2)
                        if k == 1
                            x_tmp = x_keep(sections2(k).PixelIdxList);
                            y_tmp = y_keep(sections2(k).PixelIdxList);
                        else
                            x_tmp = [x_tmp; NaN; x_keep(sections2(k).PixelIdxList)];
                            y_tmp = [y_tmp; NaN; y_keep(sections2(k).PixelIdxList)];
                        end
                    end
                else
                    x_tmp = x_keep(:);
                    y_tmp = y_keep(:);
                end   
                % build full grounding line
                if j == 1
                    gl_x = x_tmp(:);
                    gl_y = y_tmp(:);
                else
                    gl_x = [gl_x(:); NaN; x_tmp(:)];
                    gl_y = [gl_y(:); NaN; y_tmp(:)];
                end
            end
        end
        % Write individual grounding line to shapefile
        clear GL
        GL.Geometry = 'Line';
        GL.X = gl_x;
        GL.Y = gl_y;
        GL.Name = S(i).Name;
        shapewrite(GL,['individual_GLs/' S(i).Name '_GL.shp']);
    else
        % or compare with bedmachine
        gl_x = [];
        gl_y = [];
        for j = 1:numel(sections)
            x_tmp = x(sections(j).PixelIdxList);
            y_tmp = y(sections(j).PixelIdxList);
            total_length = arclength(x_tmp(:),y_tmp(:));
            xy = interparc(0:(200/total_length):1,x_tmp(:),y_tmp(:),'linear');
            x_tmp = xy(:,1); y_tmp = xy(:,2);
            [in,on] = inpoly2([x_tmp(:),y_tmp(:)],[Bx_grounded(:),By_grounded(:)],[],1e-6);
            x_keep = x_tmp(on);
            y_keep = y_tmp(on);
            % If there are big spaces in the coordinates, then the ice shelf
            % probably has two sides, which we need to break up
            if length(x_keep)>1
                d = pathdistps(x_keep,y_keep);
                if max(gradient(d))>250
                    sections2 = regionprops(gradient(d)<2000,x_keep,'pixelIdxList');
                    x_tmp = [];
                    y_tmp = [];
                    for k = 1:length(sections2)
                        if k == 1
                            x_tmp = x_keep(sections2(k).PixelIdxList);
                            y_tmp = y_keep(sections2(k).PixelIdxList);
                        else
                            x_tmp = [x_tmp; NaN; x_keep(sections2(k).PixelIdxList)];
                            y_tmp = [y_tmp; NaN; y_keep(sections2(k).PixelIdxList)];
                        end
                    end
                else
                    x_tmp = x_keep(:);
                    y_tmp = y_keep(:);
                end   
                % build full grounding line
                if j == 1
                    gl_x = x_tmp(:);
                    gl_y = y_tmp(:);
                else
                    gl_x = [gl_x(:); NaN; x_tmp(:)];
                    gl_y = [gl_y(:); NaN; y_tmp(:)];
                end
            end
        end
        
        [~,on] = inpoly2([x(:),y(:)],[Bx_grounded(:),By_grounded(:)]);
        gl_x = x(on);
        gl_y = y(on);
        % Write individual grounding line to shapefile
        clear GL
        GL.Geometry = 'Line';
        GL.X = gl_x;
        GL.Y = gl_y;
        GL.Name = S(i).Name;
        shapewrite(GL,['individual_GLs/' S(i).Name '_GL.shp']);
    end
end

% Test plot
% close all
% antbounds('coast','k'); hold on
% plot(Mx_grounded,My_grounded,'b');
% scatter(x_tmp(on),y_tmp(on),5,'r','filled');
% set(gca,'XLim',[min(x_tmp)-5000 max(x_tmp)+5000]);
% set(gca,'YLim',[min(y_tmp)-5000 max(y_tmp)+5000]);
% sections = regionprops(~isnan(gl_x), gl_x,'pixelIdxList','PixelValues');
% cmap = cbrewer('qual','Set1',numel(sections));
% cmap(cmap>1)=1; cmap(cmap<0)=0;
% for k = 1:numel(sections)
%     plot(gl_x(sections(k).PixelIdxList),gl_y(sections(k).PixelIdxList),'color',cmap(k,:))
% end

%% Make manual edits to the following shelves (where gate doesn't cover entire front)

% Thwaites
% Eltanin Bay
% Rydberg Peninsula 1 & 2
% Britten
% Larsen B 1
% Fox 2
% Rose Point
% Kirkby (do this before adjusting order of points)
% Voyeykov

%% We had to create some ice shelves from scractch

% Hamilton
% West

%% We had to add some new lines to thwaites, so pull them into one nan-separated file here

clear
S = shaperead('individual_GLs/Thwaites_GL.shp');
for i = 1:numel(S)
    if i == 1
        gl_x = S(i).X;
        gl_y = S(i).Y;
    else
        gl_x = [gl_x(:) ; S(i).X(:)];
        gl_y = [gl_y(:) ; S(i).Y(:)];
    end
end
clear GL
GL.Geometry = 'Line';
GL.X = gl_x;
GL.Y = gl_y;
GL.Name = 'Thwaites';
shapewrite(GL,'individual_GLs/Thwaites_GL.shp');
        
%% George VI is also a pain, so I just drew that myself. Pull it together here.

clear
S = shaperead('individual_GLs/manually_digitised/George_VI_GL.shp');
for i = 1:numel(S)
    if i == 1
        gl_x = S(i).X;
        gl_y = S(i).Y;
    else
        gl_x = [gl_x(:) ; S(i).X(:)];
        gl_y = [gl_y(:) ; S(i).Y(:)];
    end
end
clear GL
GL.Geometry = 'Line';
GL.X = gl_x;
GL.Y = gl_y;
GL.Name = 'George_VI';
shapewrite(GL,'individual_GLs/George_VI_GL.shp');

%% And wordie

clear
S = shaperead('individual_GLs/Wordie_GL.shp');
for i = 2:numel(S)
    if i == 2
        gl_x = S(i).X;
        gl_y = S(i).Y;
    else
        gl_x = [gl_x(:) ; S(i).X(:)];
        gl_y = [gl_y(:) ; S(i).Y(:)];
    end
end
clear GL
GL.Geometry = 'Line';
GL.X = gl_x;
GL.Y = gl_y;
GL.Name = 'Wordie';
shapewrite(GL,'individual_GLs/Wordie_GL.shp');
    

%% Make some small adjustments to ensure points are in order

clear

% List of shelves to tweak
shelves_to_reorder = {'Bach','Richter','Nordenskjold',...
    'Marin','Harbord Glacier','Cheetham','Geikie_Inlet','Drygalski',...
    'Campbell','Cape_Washington','Tinker','Parker','Fitzgerald','Wylde',...
    'Suter','Mariner','Mandible_Cirque','Manhaul','Ironside','Moubray',...
    'Smith_Inlet','Kirkby','Lillie','Chugonov','Barber','Gannutz','Rennick',...
    'Suvorov','Gillet','Noll','Mcleod','Matusevitch','Drury','Lauritzen',...
    'Andreyev','Slava','Cook','Deakin','Horn_Bluff','Fisher','Mertz','Watt_Bay',...
    'Zelee','Astrolabe','Francais','Marret','Commandant_Charcot','Pourqoi_Pas',...
    'Dibble','May_Glacier','Morse','Sandford','Frost_1','Frost_2','Frost_3',...
    'Holmes_1','Holmes_2','Holmes_3','Holmes_4','Whittle','Vincennes_Bay_1',...
    'Vincennes_Bay_2','Vincennes_Bay_3','Vincennes_Bay_4','Underwood','Conger_Glenzer',...
    'Helen','Sorsdal','Hovde','Flatnes','Dalk','Publications','Amery','Utsikkar',...
    'Mulebreen','Cirque_Fjord','Hoseason','Rund_Bay','Wilma_Robert_Downer','Edward_VIII',...
    'Myers','Porter','Zubchatyy','Rayner_Thyer','Hannan_1','Hannan_2','Telen','Skalen',...
    'Shirase','Prince_Harald_1','Prince_Harold_2','Borchgrevink','Lazarev','Nivl','Vigrid',...
    'Jelbart','Ekstrom'};

mkdir reordered_shelves
for i = 1:numel(shelves_to_reorder)
    
    % Load shapefile
    S = shaperead(['individual_GLs/' shelves_to_reorder{i} '_GL.shp']);
    
    % Get coordinates
    x = S.X(1:end-1);
    y = S.Y(1:end-1);

    % Make sure grounding line starts at end
    [lat_tmp,lon_tmp] = ps2ll(x,y);
    d = pathdistps(lat_tmp,lon_tmp);
    dx = gradient(d);
    % if difference between start and end point is biggest, then
    % segment already starts at end, so we don't want to change that
    if (nanmax(dx) - max(pathdistps([lat_tmp(1),lat_tmp(end)],[lon_tmp(1),lon_tmp(end)]))) > 1
        remove = find(dx==nanmax(dx),1,'first');
        if remove == 1
            x = [x(1) , x(end:-1:2)];
            y = [y(1) , y(end:-1:2)];
        elseif remove == length(x)
            x = [x(remove) , x(1:end-1)];
            y = [y(remove) , y(1:end-1)];
        else
            % is the point before or after this the big gap?
            dist1 = max(pathdistps([lat_tmp(remove),lat_tmp(remove+1)],[lon_tmp(remove),lon_tmp(remove+1)]));
            dist2 = max(pathdistps([lat_tmp(remove),lat_tmp(remove-1)],[lon_tmp(remove),lon_tmp(remove-1)]));
            % reorder points accordingly
            if dist1 > dist2
                if length(x) > remove+1
                    x = [x(remove:-1:1) , x(end:-1:remove+1)];
                    y = [y(remove:-1:1) , y(end:-1:remove+1)];
                else
                    x = [x(remove:-1:1) , x(end:remove+1)];
                    y = [y(remove:-1:1) , y(end:remove+1)];
                end
            else
                x = [x(remove:end) , x(1:remove-1)];
                y = [y(remove:end) , y(1:remove-1)];
            end
        end
    end
    
    % Write to new grounding line
    clear GL
    GL.Geometry = 'Line';
    GL.X = x;
    GL.Y = y;
    GL.Name = shelves_to_reorder{i};
    shapewrite(GL,['reordered_shelves/' shelves_to_reorder{i} '_GL.shp']);
    
end

% Then I manually checked the above and made a handful of minor edits
% (extending grounding line a pixel or two, or removing grounindg line
% pixels). Then copied the reordered shelves to the individual shelves
% folder.

%% Delete getz oddity

clear
S = shaperead('individual_GLs/Getz_GL.shp');
gl_x = S(1).X;
gl_y = S(1).Y;
clear GL
GL.Geometry = 'Line';
GL.X = gl_x;
GL.Y = gl_y;
GL.Name = 'Getz';
shapewrite(GL,'individual_GLs/Getz_GL.shp');


% and, aftre manually digitising the sub shelves...
clear
S = shaperead('individual_GLs/Getz_GL.shp');
for i = 1:numel(S)
    if i == 1
        gl_x = S(i).X;
        gl_y = S(i).Y;
    else
        gl_x = [gl_x(:) ; S(i).X(:)];
        gl_y = [gl_y(:) ; S(i).Y(:)];
    end
end
clear GL
GL.Geometry = 'Line';
GL.X = gl_x;
GL.Y = gl_y;
GL.Name = 'Getz';
shapewrite(GL,'individual_GLs/Getz_GL.shp');
    

%% Finally, make sure they all have regular 200 m spacing

clear
mkdir individual_GLs/regularly_spaced

filelist = dir('individual_GLs/*.shp');

for i = 1:numel(filelist)
    
    % load shapefile
    S = shaperead(['individual_GLs/' filelist(i).name]);
    x = S.X(1:end-1);
    y = S.Y(1:end-1);
    sections = regionprops(~isnan(x), x,'pixelIdxList','PixelValues');

    % Make each section regularly spaced (200 m)
    gl_x = [];
    gl_y = [];
    for j = 1:numel(sections)
        x_tmp = x(sections(j).PixelIdxList);
        y_tmp = y(sections(j).PixelIdxList);
        total_length = arclength(x_tmp(:),y_tmp(:));
        xy = interparc(0:(200/total_length):1,x_tmp(:),y_tmp(:),'linear');
        x_tmp = xy(:,1); y_tmp = xy(:,2);
        if j == 1
            gl_x = x_tmp(:);
            gl_y = y_tmp(:);
        else
            gl_x = [gl_x(:); NaN; x_tmp(:)];
            gl_y = [gl_y(:); NaN; y_tmp(:)];
        end
    end
    
    % And write to new file
    clear GL
    GL.Geometry = 'Line';
    GL.X = x;
    GL.Y = y;
    GL.Name = extractBefore(filelist(i).name,'_GL.shp');
    shapewrite(GL,['individual_GLs/regularly_spaced/' filelist(i).name ]);
    
end

%% Finally, combine them all into one shapefile and one matlab structure.

clear
filelist = dir('individual_GLs/regularly_spaced/*.shp');

for i = 1:numel(filelist)
    
    % Load data
    S = shaperead(['individual_GLs/regularly_spaced/' filelist(i).name ]);
    x = S.X;
    y = S.Y;
    
    if ~isnan(x(end))
        x = [x(:) ; NaN];
    else
        x = x(:);
    end
    if ~isnan(y(end))
        y = [y(:) ; NaN];
    else
        y = y(:);
    end
    
    if i == 1
        gl_x = x;
        gl_y = y;
    else
        gl_x = [gl_x ; x];
        gl_y = [gl_y ; y];
    end
    
    % Build structure
    GL(i).Geometry = 'Line';
    GL(i).X = x;
    GL(i).Y = y;
    GL(i).Name = extractBefore(filelist(i).name,'_GL.shp');
    
end

% Save structure containing individual GLs as shapefile
shapewrite(GL,'merged_shelf_GLs_struct.shp');

% Save 'continuous' GL as shapefile
GLcon.Geometry = 'Line';
GLcon.X = gl_x;
GLcon.Y = gl_y;
shapewrite(GLcon,'merged_shelf_GLs_continuous.shp');

% And save as matfile
save('merged_shelf_GLs_all_200m.mat','gl_x','gl_y','GL');
    

    