% make_ice_shelf_masks_from_coastline

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../grounding_line_discharge'));
addpath(genpath('D:\work\Fellowship_Leeds\Papers\Research\ASE_discharge'));

mkdir masks
mkdir masks/all_years

%% Load grounding lines

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all.mat','GL');


%% Load time-varying coastlines

coast_list = dir('D:\work\Fellowship_Leeds\Data\calving_front_locations_greene\coastline_data/antarctic_coastline_*.txt');

coast_time_all = zeros([numel(coast_list),1]).*NaN;
dec_year_all = zeros([numel(coast_list),1]).*NaN;
for i = 1:numel(coast_list)
    d = importdata([coast_list(i).folder '/' coast_list(i).name]); 
    coast{i} = d.data;
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    mkdir(['masks/' coast_time_str]);
    coast_time_all(i) = datenum(str2double(coast_time),1,1);
    dec_year_all(i) = str2double(coast_time);
end

% make colormap for coast time
cmap = colorcet('Gouldian','N',numel(coast_list));

%% Loop through shelves and join coast with grounding line

skip_count = 1;
for i = 11%1:numel(GL)
    
    % Get shelf info
    tic;
    shelf_name = GL(i).Name;
    gate_x = GL(i).X;
    gate_y = GL(i).Y;
    disp(' ');
    disp(['Starting shelf number: ' num2str(i) ' - ' shelf_name ]);
    
    % Get number of sections, and only continue if there is one section
    sections = regionprops(~isnan(gate_x), gate_x,'pixelIdxList','PixelValues');
    
    % Hamilton Piedmont etc fix
    if i == 57 || i == 61 || i == 72
        gate_x = [gate_x(sections(2).PixelIdxList) ; gate_x(sections(1).PixelIdxList)];
        gate_y = [gate_y(sections(2).PixelIdxList) ; gate_y(sections(1).PixelIdxList)];
        sections = regionprops(~isnan(gate_x), gate_x,'pixelIdxList','PixelValues');
    end
    
    if i == 106
        gate_x = gate_x(sections(1).PixelIdxList);
        gate_y = gate_y(sections(1).PixelIdxList);
        sections = regionprops(~isnan(gate_x), gate_x,'pixelIdxList','PixelValues');
    end
    
    if numel(sections) == 1
    
        % Loop through coastline
        for j = 1:numel(coast)

            % Get coastline coordinates and time
            coast_x = coast{j}(:,1);
            coast_y = coast{j}(:,2);
            coast_time = extractBefore(coast_list(j).name,'.txt');
            coast_time = extractAfter(coast_time,'coastline_');
            coast_time_str = coast_time;
            coast_time = coast_time_all(j);
            
            % Get closest coastline coordinate to grounding line end points
            %   - start of GL
            d = sqrt((gate_x(1)-coast_x).^2 + (gate_y(1)-coast_y).^2);
            idx1 = find(d(:) == nanmin(d(:)),1,'first');
            %   - end of GL
            d = sqrt((gate_x(end-1)-coast_x).^2 + (gate_y(end-1)-coast_y).^2);
            idx2 = find(d(:) == nanmin(d(:)),1,'first');

            % Create full ice shelf coastline
            if idx1 < idx2
                full_x = [flipud(gate_x(1:end-1)) ; coast_x(idx1:idx2) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; coast_y(idx1:idx2) ; gate_y(end-1)];
            else
                full_x = [gate_x(1:end-1) ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            
            % If doing certain ice shelves, we need to make some other adjustments
            if strcmp(shelf_name,'Crosson') % 26
                L = shaperead('tmp/Crosson_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Dotson') % 32
                L = shaperead('tmp/Dotson_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Filchner') % 40
                L = shaperead('tmp/Filchner_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Geikie_Inlet') 
                L = shaperead('tmp/Geikie_Inlet_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Larsen_C') 
                L = shaperead('tmp/Larsen_C_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Manhaul') 
                L = shaperead('tmp/Manhaul_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Nansen') 
                L = shaperead('tmp/Nansen_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Ronne') 
                L = shaperead('tmp/Ronne_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Larsen_D') 
                L = shaperead('tmp/Larsen_D_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Ross_East') 
                L = shaperead('tmp/Ross_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Ross_West') 
                L = shaperead('tmp/Ross_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Shackleton') 
                L = shaperead('tmp/Shackleton_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                sect_x = coast_x(1:idx1);
                sect_y = coast_y(1:idx1);
                subsects = regionprops(~isnan(sect_x),sect_x,'PixelIdxList');
                lens = zeros([numel(subsects),1]).*NaN;
                for k = 1:numel(subsects)
                    lens(k) = length(subsects(k).PixelIdxList);
                end
                use = find(lens==max(lens));
                sect1_x = sect_x(subsects(use).PixelIdxList);
                sect1_y = sect_y(subsects(use).PixelIdxList);
                sect_x = coast_x(idx2:end);
                sect_y = coast_y(idx2:end);
                subsects = regionprops(~isnan(sect_x),sect_x,'PixelIdxList');
                d = zeros([numel(subsects),1]).*NaN;
                for k = 1:numel(subsects)
                    tmp_x = sect_x(subsects(k).PixelIdxList);
                    tmp_y = sect_y(subsects(k).PixelIdxList);
                    d(k) = sqrt((tmp_x(end)-sect1_x(1))^2 + (tmp_y(end)-sect1_y(1))^2);
                end
                use = find(d==nanmin(d));
                sect2_x = sect_x(subsects(use).PixelIdxList);
                sect2_y = sect_y(subsects(use).PixelIdxList);
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(sect1_x) ; flipud(sect2_x) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(sect1_y) ; flipud(sect2_y) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Atka') 
                L = shaperead('tmp/Atka_link1.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Drygalski') 
                L = shaperead('tmp/Drygalski_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; (coast_x(idx1:idx2)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; (coast_y(idx1:idx2)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Fitzgerald') 
                L = shaperead('tmp/Fitzgerald_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; (coast_x(idx1:idx2)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; (coast_y(idx1:idx2)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Jelbart') 
                L1 = shaperead('tmp/Jelbart_link1.shp');
                L2 = shaperead('tmp/Jelbart_link2.shp');
                d = sqrt((L1.X(end-1)-coast_x).^2 + (L1.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L2.X(end-1)-coast_x).^2 + (L2.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L1.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; fliplr(L2.X(1:end-1))' ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L1.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; fliplr(L2.Y(1:end-1))' ; gate_y(1)];
            end
            if strcmp(shelf_name,'Lazarev') 
                L = shaperead('tmp/Lazarev_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Tracy_Tremenchus') 
                L = shaperead('tmp/Tracy_Tremenchus_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Brunt_Stancomb') 
                L = shaperead('tmp/Brunt_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx1 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [flipud(gate_x(1:end-1)) ; L.X(1:end-1)' ; flipud(coast_x(idx2:idx1)) ; gate_x(end-1)];
                full_y = [flipud(gate_y(1:end-1)) ; L.Y(1:end-1)' ; flipud(coast_y(idx2:idx1)) ; gate_y(end-1)];
            end
            if strcmp(shelf_name,'Fimbul') 
                L = shaperead('tmp/Fimbul_link.shp');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Nickerson') 
                L = shaperead('tmp/Nickerson_link.shp');
                d = sqrt((L.X(1)-coast_x).^2 + (L.Y(1)-coast_y).^2);
                link_start = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                link_end = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; coast_x(idx2:link_end) ; fliplr(L.X(1:end-1))' ; coast_x(link_start:idx1); gate_x(1)];
                full_y = [gate_y(1:end-1) ; coast_y(idx2:link_end) ; fliplr(L.Y(1:end-1))' ; coast_y(link_start:idx1); gate_y(1)];
            end
            if strcmp(shelf_name,'Riiser_Larsen') 
                L1 = shaperead('tmp/Riiser_Larsen_link1.shp');
                d = sqrt((L1.X(1)-coast_x).^2 + (L1.Y(1)-coast_y).^2);
                link1_start = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L1.X(end-1)-coast_x).^2 + (L1.Y(end-1)-coast_y).^2);
                link1_end = find(d(:) == nanmin(d(:)),1,'first');
                L2 = shaperead('tmp/Riiser_Larsen_link2.shp');
                d = sqrt((L2.X(1)-coast_x).^2 + (L2.Y(1)-coast_y).^2);
                link2_start = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L2.X(end-1)-coast_x).^2 + (L2.Y(end-1)-coast_y).^2);
                link2_end = find(d(:) == nanmin(d(:)),1,'first');
                L3 = shaperead('tmp/Riiser_Larsen_link3.shp');
                d = sqrt((L3.X(1)-coast_x).^2 + (L3.Y(1)-coast_y).^2);
                link3_start = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L3.X(end-1)-coast_x).^2 + (L3.Y(end-1)-coast_y).^2);
                link3_end = find(d(:) == nanmin(d(:)),1,'first');
                L4 = shaperead('tmp/Riiser_Larsen_link4.shp');
                d = sqrt((L4.X(1)-coast_x).^2 + (L4.Y(1)-coast_y).^2);
                link4_start = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L4.X(end-1)-coast_x).^2 + (L4.Y(end-1)-coast_y).^2);
                link4_end = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; ...
                    L1.X(1:end-1)'; coast_x(link1_end:link2_start) ;...
                    L2.X(1:end-1)'; coast_x(link2_end:link3_start) ;...
                    L3.X(1:end-1)'; coast_x(link3_end:link4_start) ;...
                    L4.X(1:end-1)'; coast_x(link4_end:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; ...
                    L1.Y(1:end-1)'; coast_y(link1_end:link2_start) ;...
                    L2.Y(1:end-1)'; coast_y(link2_end:link3_start) ;...
                    L3.Y(1:end-1)'; coast_y(link3_end:link4_start) ;...
                    L4.Y(1:end-1)'; coast_y(link4_end:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Slava') 
                L1 = shaperead('tmp/Slava_link.shp');
                d = sqrt((L1.X(1)-coast_x).^2 + (L1.Y(1)-coast_y).^2);
                link1_start = find(d(:) == nanmin(d(:)),1,'first');
                d = sqrt((L1.X(end-1)-coast_x).^2 + (L1.Y(end-1)-coast_y).^2);
                link1_end = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; coast_x(idx2:link1_start); ...
                    L1.X(1:end-1)'; coast_x(link1_end:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ;  coast_y(idx2:link1_start); ...
                    L1.Y(1:end-1)'; coast_y(link1_end:idx1) ; gate_y(1)];
            end
            if strcmp(shelf_name,'Borchgrevink') 
                L1 = shaperead('tmp/Borchgrevink_link.shp');
                d = sqrt((L1.X(end-1)-coast_x).^2 + (L1.Y(end-1)-coast_y).^2);
                link1_end = find(d(:) == nanmin(d(:)),1,'first');
                L2 = shaperead('tmp/Borchgrevink_link2.shp');
                d = sqrt((L2.X(end-1)-coast_x).^2 + (L2.Y(end-1)-coast_y).^2);
                link2_end = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L1.X(1:end-1)' ; flipud(coast_x(link2_end:link1_end)); fliplr(L2.X(1:end-1))' ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L1.Y(1:end-1)' ; flipud(coast_y(link2_end:link1_end)); fliplr(L2.Y(1:end-1))' ; gate_y(1)];
            end
            if strcmp(shelf_name,'Baudouin') 
                L = shaperead('tmp/Borchgrevink_link.shp'); % NOT a type, just same shapefile
                d = sqrt((L.X(end-1)-coast_x).^2 + (L.Y(end-1)-coast_y).^2);
                idx2 = find(d(:) == nanmin(d(:)),1,'first');
                full_x = [gate_x(1:end-1) ; L.X(1:end-1)' ; coast_x(idx2:idx1) ; gate_x(1)];
                full_y = [gate_y(1:end-1) ; L.Y(1:end-1)' ; coast_y(idx2:idx1) ; gate_y(1)];
            end
            
            % build time-varying cell for this shelf
            shelf_x{j} = full_x;
            shelf_y{j} = full_y;

            % Save this shelf as a shapefile
            clear shelf
            shelf.Geometry = 'Polygon';
            shelf.X = full_x;
            shelf.Y = full_y;
            shelf.Name = shelf_name;
            shapewrite(shelf,['masks/' coast_time_str '/' shelf_name '_' coast_time_str '_mask.shp']);

        end

        % Plot this shelf mask for each time
        cen_x = nanmean(shelf_x{j});
        cen_y = nanmean(shelf_y{j});
        [cen_lat,cen_lon] = ps2ll(cen_x,cen_y);
        x_len = (nanmax(shelf_x{j}) - nanmin(shelf_x{j}) ) /1000;
        y_len = (nanmax(shelf_y{j}) - nanmin(shelf_y{j}) ) /1000;
        len = max([x_len,y_len]);
        if strcmp(shelf_name,'Shackleton') || strcmp(shelf_name,'Voyeykov')
            [moa,modis_x,modis_y,~] = geoimread('moa750_2014_hp1_v01.tif',shelf_x{j},shelf_y{j},5000);
        else
            [moa,modis_x,modis_y,~] = geoimread('moa125_2014_hp1_v01.tif',shelf_x{j},shelf_y{j},5000);
        end
        moa=uint16(moa);
        RGB = mat2im(moa,gray(256),[1 20000]); 
        figure('color','w','visible','off');
        da = daspect; 
        da = [1 1 da(3)];
        %antbounds('coast','w'); hold on
        %antbounds('gl','w');
        hm = image(modis_x,modis_y,RGB); axis xy
        set(hm,'alphadata',moa>0)
        uistack(hm,'bottom') 
        ax = axis;
        axis xy 
        daspect(da)
        hold on
        for j = 1:numel(shelf_x)
            plot(shelf_x{j},shelf_y{j},'color',cmap(j,:),'linewidth',1)
            if j == 1
                min_x = nanmin(shelf_x{j});
                min_y = nanmin(shelf_y{j});
                max_x = nanmax(shelf_x{j});
                max_y = nanmax(shelf_y{j});
            else
                if nanmin(shelf_x{j}) < min_x
                    min_x = nanmin(shelf_x{j});
                end
                if nanmin(shelf_y{j}) < min_y
                    min_y = nanmin(shelf_y{j});
                end
                if nanmax(shelf_x{j}) > max_x
                    max_x = nanmax(shelf_x{j});
                end
                if nanmax(shelf_y{j}) > max_y
                    max_y = nanmax(shelf_y{j});
                end
            end
        end
        set(gca,'XLim',[min_x-1000 max_x+1000]);
        set(gca,'YLim',[min_y-1000 max_y+1000]);
        cb = colorbar;
        colormap(cmap);
        ylabel(cb,'Time');
        xlabel('Easting (km)');
        ylabel('Northing (km)');
        caxis([min(dec_year_all) max(dec_year_all)]);
        plot(gate_x,gate_y,'k','linewidth',1);
        try; measuresps('vel','k'); end
        scalebarps
        export_fig(['masks/all_years/' shelf_name '_mask_overview.shp']);
        close

        % Save this shelf data as a matfile
        save(['masks/all_years/' shelf_name '_mask_data.mat'],'shelf_x','shelf_y','coast_time_all');
        
    else
        
        disp(['skipping shelf number ' num2str(i) '-' shelf_name ]);
        skipped_shelves{skip_count} = shelf_name;
        skip_count = skip_count + 1;
        
    end
    
    toc;
    
end
        

