% make_swinburne_mask

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../grounding_line_discharge'));
addpath(genpath('D:\work\Fellowship_Leeds\Papers\Research\ASE_discharge'));

mkdir masks
mkdir masks/all_years

%% Load grounding lines

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all.mat','GL');


%% Load time-varying coastlines

coast_list = dir('D:\work\Fellowship_Leeds\Data\calving_front_locations_greene\coastline_data/antarctic_coastline_*.txt');

coast_time_all = zeros([numel(coast_list),1]).*NaN;
dec_year_all = zeros([numel(coast_list),1]).*NaN;
for i = 1:numel(coast_list)
    d = importdata([coast_list(i).folder '/' coast_list(i).name]); 
    coast{i} = d.data;
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    mkdir(['masks/' coast_time_str]);
    coast_time_all(i) = datenum(str2double(coast_time),1,1);
    dec_year_all(i) = str2double(coast_time);
end

% make colormap for coast time
cmap = colorcet('Gouldian','N',numel(coast_list));

%% Make mask

shelf_name = GL(144).Name;
gate_x = GL(144).X;
gate_y = GL(144).Y;

% Get sections of GL
sections = regionprops(~isnan(gate_x), gate_x,'pixelIdxList','PixelValues');

% Loop through coastline
for i = 1:numel(coast)
    
    % Get coastline coordinates and time
    coast_x = coast{i}(:,1);
    coast_y = coast{i}(:,2);
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    coast_time = coast_time_all(i);
    
    % Section 1
    x1 = gate_x(sections(1).PixelIdxList);
    y1 = gate_y(sections(1).PixelIdxList);
    d = sqrt((x1(end)-coast_x).^2 + (y1(end)-coast_y).^2);
    idx1_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((x1(1)-coast_x).^2 + (y1(1)-coast_y).^2);
    idx1_start = find(d(:) == nanmin(d(:)),1,'first');
    seg_x = [x1;coast_x(idx1_end:idx1_start);x1(1)];
    seg_y = [y1;coast_y(idx1_end:idx1_start);y1(1)];
    
    % Section 4
    x4 = gate_x(sections(4).PixelIdxList);
    y4 = gate_y(sections(4).PixelIdxList);
    d = sqrt((x4(end)-coast_x).^2 + (y4(end)-coast_y).^2);
    idx4_end = find(d(:) == nanmin(d(:)),1,'first');
    d = sqrt((x4(1)-coast_x).^2 + (y4(1)-coast_y).^2);
    idx4_start = find(d(:) == nanmin(d(:)),1,'first');
    seg4_x = [x4;coast_x(idx4_end:idx4_start);x4(1)];
    seg4_y = [y4;coast_y(idx4_end:idx4_start);y4(1)];
    
    % section 5
%     x5 = gate_x(sections(5).PixelIdxList);
%     y5 = gate_y(sections(5).PixelIdxList);
%     d = sqrt((x5(end)-coast_x).^2 + (y5(end)-coast_y).^2);
%     idx5_end = find(d(:) == nanmin(d(:)),1,'first');
%     d = sqrt((x5(1)-coast_x).^2 + (y5(1)-coast_y).^2);
%     idx5_start = find(d(:) == nanmin(d(:)),1,'first');
%     seg5_x = [x5;coast_x(idx5_end:idx5_start);x5(1)];
%     seg5_y = [y5;coast_y(idx5_end:idx5_start);y5(1)];
    
    % Build full mask
%     full_x = [seg_x; NaN; seg4_x; NaN; seg5_x; NaN];
%     full_y = [seg_y; NaN; seg4_y; NaN; seg5_y; NaN];
    full_x = [seg_x; NaN; seg4_x; NaN];
    full_y = [seg_y; NaN; seg4_y; NaN];
    
    % Save full data
    shelf_x{i} = full_x;
    shelf_y{i} = full_y;
    
end


% Plot this shelf mask for each time
cen_x = nanmean(shelf_x{1});
cen_y = nanmean(shelf_y{1});
[cen_lat,cen_lon] = ps2ll(cen_x,cen_y);
x_len = (nanmax(shelf_x{1}) - nanmin(shelf_x{1}) ) /1000;
y_len = (nanmax(shelf_y{1}) - nanmin(shelf_y{1}) ) /1000;
len = max([x_len,y_len]);
[moa,modis_x,modis_y,~] = geoimread('moa125_2014_hp1_v01.tif',shelf_x{1},shelf_y{1},5000);
moa=uint16(moa);
RGB = mat2im(moa,gray(256),[1 20000]); 
figure('color','w','visible','on');
da = daspect; 
da = [1 1 da(3)];
hm = image(modis_x,modis_y,RGB); axis xy
set(hm,'alphadata',moa>0)
uistack(hm,'bottom') 
ax = axis;
axis xy 
daspect(da)
hold on
for j = 1:numel(shelf_x)
    plot(shelf_x{j},shelf_y{j},'color',cmap(j,:),'linewidth',1)
    if j == 1
        min_x = nanmin(shelf_x{j});
        min_y = nanmin(shelf_y{j});
        max_x = nanmax(shelf_x{j});
        max_y = nanmax(shelf_y{j});
    else
        if nanmin(shelf_x{j}) < min_x
            min_x = nanmin(shelf_x{j});
        end
        if nanmin(shelf_y{j}) < min_y
            min_y = nanmin(shelf_y{j});
        end
        if nanmax(shelf_x{j}) > max_x
            max_x = nanmax(shelf_x{j});
        end
        if nanmax(shelf_y{j}) > max_y
            max_y = nanmax(shelf_y{j});
        end
    end
end
set(gca,'XLim',[min_x-20000 max_x+20000]);
set(gca,'YLim',[min_y-20000 max_y+20000]);
cb = colorbar;
colormap(cmap);
ylabel(cb,'Time');
xlabel('Easting (km)');
ylabel('Northing (km)');
caxis([min(dec_year_all) max(dec_year_all)]);
plot(gate_x,gate_y,'k','linewidth',1);
try; measuresps('vel','k'); end
scalebarps
export_fig(['masks/all_years/Swinburne_mask_overview.shp']);
%close

% Save
save('masks/all_years/Swinburne_mask_data.mat','coast_time_all','shelf_x','shelf_y');
    




    