% plot_AIS_components

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% Load GL structure
load('GL_consolidated_200m.mat');

%% Set colors

mass_col = 'k';
SMB_col = [0.8500 0.3250 0.0980];
melt_col = [0.4940 0.1840 0.5560];
calv_col = [0.9290 0.6940 0.1250];
discharge_col = [0 0.4470 0.7410];

%% Load data

% total mass change
mb_all = zeros([numel(GL),25]).*NaN;
mb_err_all = zeros([numel(GL),25]).*NaN;
for i = 1:numel(GL)
    shelf_name = GL(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeMassChange','cumulativeMassChangeError','time');
    
    if strcmp(GL(i).Name,'Pine_Island') || strcmp(GL(i).Name,'Thwaites') || strcmp(GL(i).Name,'Crosson') || strcmp(GL(i).Name,'Dotson')
        GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
        idx = find(contains(GLmass.ASE_shelves,GL(i).Name)==1);
        cumuGLmass = linspace(0,GLmass.mass_change_GL(idx),length(cumulativeMassChange));
        cumulativeMassChange = cumulativeMassChange + cumuGLmass;
    end
    
    mb_all(i,:) = cumulativeMassChange;
    mb_err_all(i,:) = cumulativeMassChangeError;
end
mb_tot = sum(mb_all,1);
mb_err = rssq(mb_err_all,1);
mb_time = time;

% Melt
m_all = zeros([numel(GL),25]).*NaN;
m_err_all = zeros([numel(GL),25]).*NaN;
for i = 1:numel(GL)
    shelf_name = GL(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'time','cumulativeThinningForce1997','cumulativeThinningForce1997Error');
    m_all(i,:) = cumulativeThinningForce1997;
    m_err_all(i,:) = cumulativeThinningForce1997Error;
end
m_tot = nansum(m_all,1);
m_err = rssq(m_err_all,1);

% Calving
c_all = zeros([numel(GL),25]).*NaN;
c_err_all = zeros([numel(GL),25]).*NaN;
for i = 1:numel(GL)
    shelf_name = GL(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeRetreatBalance','cumulativeRetreatBalanceError');
    c_all(i,:) = cumulativeRetreatBalance;
    c_err_all(i,:) = cumulativeRetreatBalanceError;
end
c_tot = sum(c_all);
c_err = rssq(c_err_all,1);

% Discharge
Q_all = zeros([numel(GL),25]).*NaN;
Q_err_all = zeros([numel(GL),25]).*NaN;
for i = 1:numel(GL)
    shelf_name = GL(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeDischargeChangeRel1997','cumulativeDischargeChangeRel1997Error');
    Q_all(i,:) = cumulativeDischargeChangeRel1997;
    Q_err_all(i,:) = cumulativeDischargeChangeRel1997Error;
end
Q_tot = sum(Q_all,1);
Q_err = rssq(Q_err_all,1);

% SMB
smb_all = zeros([numel(GL),298]).*NaN;
smb_err_all = zeros([numel(GL),298]).*NaN;
for i = 1:numel(GL)
    shelf_name = GL(i).Name;
    load(['../../SMB/individual_ice_shelf_SMB_ensemble/' shelf_name '_SMB_ensemble.mat'],'smb_ts','smb_clim_ts','smb_clim_err_ts','time');
    if i == 1
        sample_idx = find(time>=datenum(1997,3,1));
    end
    smb_change = smb_ts(sample_idx)-smb_clim_ts(sample_idx);
    smb_change_err = sqrt((smb_ts(sample_idx).*0.148).^2 + smb_clim_err_ts(sample_idx).^2);
    smb_all(i,:) = cumsum(smb_change./12);
    smb_err_all(i,:) = rssq(smb_change_err./12);
end
smb_tot = nansum(smb_all,1);
smb_err = rssq(smb_err_all,1);
smb_time = time(sample_idx);
time = mb_time;
time(end) = datenum(2021,12,31);

%% Plot

% initilise figure
figure('color','w','units','inches','position',[2 2 4.3 2]);
plot([time(1) time(end)],[0 0],'k','linestyle','--'); datetick('x'); hold on
%   - cumulative SMB change
sb2 = shadedErrorBar(smb_time,smb_tot,smb_err);
sb2.patch.FaceAlpha = 0.2;
sb2.patch.EdgeColor = 'none';
sb2.patch.FaceColor = [0.8500 0.3250 0.0980];
sb2.mainLine.Color = [0.8500 0.3250 0.0980];
sb2.mainLine.LineWidth = 1.5;
sb2.edge(1).Color = 'none';
sb2.edge(2).Color = 'none';
%   - cumulative melt change
sb3 = shadedErrorBar(time,m_tot,m_err);
sb3.patch.FaceAlpha = 0.2;
sb3.patch.EdgeColor = 'none';
sb3.patch.FaceColor = [0.4940 0.1840 0.5560];
sb3.mainLine.Color = [0.4940 0.1840 0.5560];
sb3.mainLine.LineWidth = 1.5;
sb3.edge(1).Color = 'none';
sb3.edge(2).Color = 'none';
%   - cumulative calv change
sb4 = shadedErrorBar(time,c_tot,c_err);
sb4.patch.FaceAlpha = 0.2;
sb4.patch.EdgeColor = 'none';
sb4.patch.FaceColor = [0.9290 0.6940 0.1250];
sb4.mainLine.Color = [0.9290 0.6940 0.1250];
sb4.mainLine.LineWidth = 1.5;
sb4.edge(1).Color = 'none';
sb4.edge(2).Color = 'none';
% cumulative discharge change
sb5 = shadedErrorBar(time,Q_tot,Q_err);
sb5.patch.FaceAlpha = 0.2;
sb5.patch.EdgeColor = 'none';
sb5.patch.FaceColor = [0 0.4470 0.7410];
sb5.mainLine.Color = [0 0.4470 0.7410];
sb5.mainLine.LineWidth = 1.5;
sb5.edge(1).Color = 'none';
sb5.edge(2).Color = 'none';
% Plot cumulative mass change
sb1 = shadedErrorBar(time,mb_tot,mb_err); 
sb1.patch.FaceAlpha = 0.2;
sb1.patch.EdgeColor = 'none';
sb1.patch.FaceColor = [0.3 0.3 .3];
sb1.mainLine.Color = [0 0 0];
sb1.mainLine.LineWidth = 1.5;
sb1.edge(1).Color = 'none';
sb1.edge(2).Color = 'none';

% Visuals
%ylabel('Mass change (Gt)');
set(gca,'FontSize',8,'FontName','Helvetica')
box('on')
set(gca,'XTickLabel',{' '});
set(gca,'color','w');
set(gca,'XLim',[datenum(1997,7,1) datenum(2021,7,1)]);
set(gca,'YGrid','on','GridColor',[.7 .7 .7],'GridAlpha',1);
set(gca,'XTick',datenum(1997:2:2021,7,1));
set(gca,'YLim',[-12000,3000]);

export_fig('AIS_components_timeseries.png','-dpng','-r1800');
export_fig('AIS_components_timeseries.fig');
exportgraphics(gcf,'AIS_components_timeseries.pdf','ContentType','vector')


