% plot_contributions_scatter_hist

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));


%% Load data

% Ice shelf names
load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\grounding_line_discharge\flux_gates/GL_consolidated_200m.mat');
shelves = shelf_names;

% mass budget data
load('../../mass_balance/mass_balance_components_all_shelves.mat');

% Ice shelf mask
load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks_greene\masks\merged/greene_intersect_mask_merged.mat');

no_melt_data = {'Alison','Andreyev','Astrolabe','Cirque_Fjord','Commandant_Charcot',...
    'Eltanin_Bay','Falkner','Flatnes','Fox_Ice_Stream','Francais','Hamilton_Piedmont',...
    'Hayes_Coats_Coast','Hovde','Liotard','Marret','Mcleod','Quatermain_Point','Rose_Point',...
    'Rund_Bay','Rydberg_Peninsula_1','Rydberg_Peninsula_2','Sandford','Skallen','Telen',...
    'Underwood','Whittle'};
for i = 1:numel(no_melt_data)
    no_melt_idx(i) = find(strcmp(no_melt_data{i},shelf_names)==1);
end


% Get shelf central longitude
cen_x = zeros([numel(shelf_names),1]).*NaN;
cen_y = zeros([numel(shelf_names),1]).*NaN;
cen_lat = zeros([numel(shelf_names),1]).*NaN;
cen_lon = zeros([numel(shelf_names),1]).*NaN;
for i = 1:numel(shelf_names)
    P(i) = polyshape(x_all{i},y_all{i});
    [cen_x(i),cen_y(i)] = centroid(P(i));
    [cen_lat(i),cen_lon(i)] = ps2ll(cen_x(i),cen_y(i));
end
cmap = phasemap(length(cen_lon));
lon_scale = linspace(-180,180,length(cen_lon));
col = mat2rgb(cen_lon,cmocean('phase'),[-1 1]*180); 

%% Get totals

% D1997,Bmod
delMass = cumulativeDischargeChange1997AllShelves(:,end) + cumulativeSMBAnomalyAllShelves(:,end) + cumulativeRetreatBalanceAllShelves(:,end) + cumulativeThinningForce1997AllShelves(:,end);
delMassE = rssq([cumulativeDischargeChange1997ErrorAllShelves(:,end),cumulativeSMBAnomalyErrorAllShelves(:,end),totalRetreatErrorAllShelves,cumulativeThinningForce1997ErrorAllShelves(:,end)],2);
delThick = cumulativeThinningForce1997AllShelves(:,end);
delThickE = cumulativeThinningForce1997ErrorAllShelves(:,end);
delArea = cumulativeRetreatBalanceAllShelves(:,end);
delAreaE = totalRetreatErrorAllShelves;

% Add mass change due to grounding line migration at ASE ice shelves
GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
for i = 1:numel(GLmass.ASE_shelves)
    idx = find(strcmp(GLmass.ASE_shelves{i},shelf_names)==1);
    delMass(idx) = delMass(idx) + GLmass.mass_change_GL(i);
    delMassE(idx) = rssq([delMassE(idx),GLmass.mass_change_err(i)]);
end

% Check where mass loss is significantly different from zero
sigMass = logical(1-double(delMass+delMassE>0 & delMass-delMassE<0)); % logical 1 where mass change is significant

%% Calculate contributions

% contributions  
%   - basal melt induced changes in thickness
prop_m_change = delThick./delMass.*100;
prop_m_change_minus = (delThick-delThickE)./delMass.*100;
prop_m_change_plus = (delThick+delThickE)./delMass.*100;
prop_m_change_min = min([prop_m_change_minus,prop_m_change_plus],[],2);
prop_m_change_max = max([prop_m_change_minus,prop_m_change_plus],[],2);

%   - calving induced changes in area
prop_c_change = delArea./delMass.*100;
prop_c_change_minus = (delArea-delAreaE)./delMass.*100;
prop_c_change_plus = (delArea+delAreaE)./delMass.*100;
prop_c_change_min = min([prop_c_change_minus,prop_c_change_plus],[],2);
prop_c_change_max = max([prop_c_change_minus,prop_c_change_plus],[],2);

% Determine regime
con = zeros([length(delMass),1]).*NaN;
%   - mass loss
con(delMass<0 & delThick<0 & delArea<0) = -1; % lost mass; thinned and retreated
con(delMass<0 & delThick<0 & delArea>=0) = -2; % lost mass; thinned and advanced
con(delMass<0 & delThick>=0 & delArea<0) = -3; % lost mass; thickened and retreated
con(delMass<0 & delThick>=0 & delArea>=0) = -4; % lost mass; thickened and advanced
%   - mass gain
con(delMass>=0 & delThick<0 & delArea<0) = 1; % gained mass; thinned and retreated
con(delMass>=0 & delThick<0 & delArea>=0) = 2; % gained mass; thinned and advanced
con(delMass>=0 & delThick>=0 & delArea<0) = 3; % gained mass; thickened and retreated
con(delMass>=0 & delThick>=0 & delArea>=0) = 4; % gained mass; thickened and advanced
con(no_melt_idx) = 0;

% Get shelf names
loss_shelves = shelves(delMass<0);
gain_shelves = shelves(delMass>0);

%% Print some statistics

% Print info
disp(' ')
disp('D1997, Bmod - any mass loss')
disp(['For ' num2str(sum(delMass<0)) ' shelves that are losing mass, basal melting caused >50% of that loss at ' num2str(sum(delMass<0 & prop_m_change>=50)/sum(delMass<0)*100) '%)' ]); 
disp(['For ' num2str(sum(delMass<0)) ' shelves that are losing mass (significantly), basal melting caused >50% of that loss, within error, at ' num2str(sum(delMass<0 & prop_m_change_min>=50)/sum(delMass<0)*100) '%)' ]); 
disp(['For ' num2str(sum(delMass<0)) ' shelves that are losing mass (significantly), basal melting caused >50% of that loss, within error, at ' num2str(sum(delMass<0 & prop_m_change_max>=50)/sum(delMass<0)*100) '%)' ]); 

disp(' ')
disp('D1997, Bmod - significant mass loss')
disp(['For ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that are losing mass (significantly), basal melting caused >50% of that loss at ' num2str(sum(delMass<0 & sigMass==1 & prop_m_change>=50)/sum(delMass<0 & sigMass==1)*100) '%)' ]); 
disp(['For ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that are losing mass (significantly), basal melting caused >50% of that loss, within error, at ' num2str(sum(delMass<0 & sigMass==1 & prop_m_change_min>=50)/sum(delMass<0 & sigMass==1)*100) '%)' ]); 
disp(['For ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that are losing mass (significantly), basal melting caused >50% of that loss, within error, at ' num2str(sum(delMass<0 & sigMass==1 & prop_m_change_max>=50)/sum(delMass<0 & sigMass==1)*100) '%)' ]); 

disp(' ')
disp('D1997, Bmod - all shelves')
disp(['For ' num2str(numel(delMass)) ' shelves, basal melting caused >50% of the mass change at ' num2str(sum(prop_m_change>=50)/numel(delMass)*100) '%)' ]); 
disp(['For ' num2str(numel(delMass)) ' shelves, basal melting caused >50% of the mass change, within error, at ' num2str(sum(prop_m_change_min>=50)/numel(delMass)*100) '%)' ]); 
disp(['For ' num2str(numel(delMass)) ' shelves, basal melting caused >50% of the mass change, within error, at ' num2str(sum(prop_m_change_max>=50)/numel(delMass)*100) '%)' ]); 


%% Plot scatter

% Plot all
figure('units','inches','position',[2,2,5,5],'color','w');
% plot background
patch([-650 650 650 -650],[650,-650,650, 650],[65,105,225]./255,'facealpha',0.2,'edgecolor','none'); hold on
patch([-650 650 -650 -650],[650 -650 -650 650],[178,34,34]./255,'facealpha',0.2,'edgecolor','none'); 
% And plot lines
plot([-650 650],[0 0],'k','linewidth',1.5); hold on
plot([0 0],[-650 650],'k','linewidth',1.5);
%plot([-650 650],[650 -650],'k');

% Plot errors
for i = -4:4 % loop through regimes
    
    % plot errors
    % - shelves with significant mass change
    use = con==i & sigMass==1;
    cen_lon_samp = cen_lon(use);
    lon_scale_samp = lon_scale(use);
    cmap_samp = cmap(use,:);
    x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    x_data_min = prop_m_change_min(use).*(abs(i)/i);
    x_data_max = prop_m_change_max(use).*(abs(i)/i);
    y_data_min = prop_c_change_min(use).*(abs(i)/i);
    y_data_max = prop_c_change_max(use).*(abs(i)/i);
    yneg = y_data-y_data_min;
    ypos = y_data_max-y_data;
    xneg = x_data-x_data_min;
    xpos = x_data_max-x_data;
    if length(cen_lon_samp)>0
        for j = 1:length(cen_lon_samp)
            [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
            errorbar(x_data(j),y_data(j),yneg(j),ypos(j),xneg(j),xpos(j),...
                'LineStyle','none','MarkerSize',6,...
                'MarkerEdgeColor','none',...
                'Color',[.6 .6 .6 .25],...
                'LineWidth',0.5,...
                'Marker','v');
        end
    end
%     % - shelves with insignificant mass change: ends up a bit hard to read
%     use = con==i & sigMass==0;
%     cen_lon_samp = cen_lon(use);
%     lon_scale_samp = lon_scale(use);
%     cmap_samp = cmap(use,:);
%     x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
%     y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
%     x_data_min = prop_m_change_min(use).*(abs(i)/i);
%     x_data_max = prop_m_change_max(use).*(abs(i)/i);
%     y_data_min = prop_c_change_min(use).*(abs(i)/i);
%     y_data_max = prop_c_change_max(use).*(abs(i)/i);
%     yneg = y_data-y_data_min;
%     ypos = y_data_max-y_data;
%     xneg = x_data-x_data_min;
%     xpos = x_data_max-x_data;
%     if length(cen_lon_samp)>0
%         for j = 1:length(cen_lon_samp)
%             [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
%             errorbar(x_data(j),y_data(j),yneg(j),ypos(j),xneg(j),xpos(j),...
%                 'LineStyle','none','MarkerSize',6,...
%                 'MarkerEdgeColor','none',...
%                 'MarkerFaceColor','none',...
%                 'Color',[.8 .8 .8],...
%                 'LineWidth',0.1,...
%                 'Marker','v'); 
%         end
%     end
    
end

% plot markers
for i = -4:4 % loop through regimes
    
    % plot markers
    % - shelves with significant mass change
    use = con==i & sigMass==1;
    cen_lon_samp = cen_lon(use);
    lon_scale_samp = lon_scale(use);
    cmap_samp = cmap(use,:);
    x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    if length(cen_lon_samp)>0
        for j = 1:length(cen_lon_samp)
            [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
            scatter(x_data(j),y_data(j),30,cmap_samp(ind,:),'v','filled');
        end
    end
    % - shelves with insignificant mass change
    use = con==i & sigMass==0;
    cen_lon_samp = cen_lon(use);
    lon_scale_samp = lon_scale(use);
    cmap_samp = cmap(use,:);
    x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    if length(cen_lon_samp)>0
        for j = 1:length(cen_lon_samp)
            [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
            scatter(x_data(j),y_data(j),30,cmap_samp(ind,:),'v');
        end
    end
    
end

% size
set(gca,'YLim',[-150 150]);
set(gca,'XLim',[-150 150]);
set(gca,'XTick',[-150:25:150]);
set(gca,'XTickLabel',{abs(-150:25:150)});
set(gca,'YTick',[-150:25:150]);
set(gca,'YTickLabel',{abs(-150:25:150)});
axis square
box on
xlabel({'             Thinning                       Thickening              ','Contribution of thickness changes to net mass change (%)'},'fontsize',8);
ylabel({'Contribution of area changes to net mass change (%)','    Retreat                        Advance   '},'fontsize',8);
set(gca,'fontsize',8)

% plot something off grid that uses the full colormap
% scatter(linspace(-1000,-1000+size(cmap,1),size(cmap,1)),linspace(-1000,-1000+size(cmap,1),size(cmap,1)),1,cmap);
% cb=phasebar_thin('deg','location','northwest');
% cb.Colormap = cmap;

% label 
text(-125,-125,'Thinning','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold'); text(-125,-135,'& retreat','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold');% top right, mostly red % top right, mostly red
text(-125,135,'Thinning','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold'); text(-125,125,'& advance','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold');  % bottom right; blue dots
text(125,-125,'Thickening','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold'); text(125,-135,'& retreat','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold');  % top left; green dots
%text(115,135,'Thickening','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold');text(115,125,'& advance','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold'); % top right, mostly red; [255,20,147]./255
text(30,135,'Thickening','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold');text(30,125,'& advance','color','k','horizontalAlignment','center','fontsize',7,'fontweight','bold'); % top right, mostly red; [255,20,147]./255
set(gca,'Fontsize',8);

% % move colorbar
% pos = cb.Position;
% cb.Position = [pos(1)+0.55 pos(2)+0.0 pos(3)*0.9 pos(4)*0.9];
% cb.Children(1).String = ' ';
% cb.Children(2).String = ' ';
% cb.Children(3).String = ' ';
% cb.Children(4).String = ' ';

% Add labels?
% for i = 1:numel(loss_shelves)
%     idx = find(strcmp(shelf_names,loss_shelves{i})==1);
%     text(prop_m_change(idx)*-1,prop_c_change(idx)*-1,loss_shelves{i},'color','k','horizontalAlignment','left','fontsize',8);
% end
% %  - gaining mass
% for i = 1:numel(gain_shelves)
%     idx = find(strcmp(shelf_names,gain_shelves{i})==1);%lab_search{i})==1);
%     text(prop_m_change(idx),prop_c_change(idx),gain_shelves{i},'color','k','horizontalAlignment','right','fontsize',8);
% end

% save
export_fig('thinning_vs_retreat_mass_change_scatter_noel_zoom_loncol_update_v4_errbar.png','-dpng','-r1800');
close

%% Plot antarctica ice shelves coloured by central lonigutde

figure('units','inches','position',[2,2,4,4],'color','none');
antbounds('gl','k'); hold on
%fill([-2.5081 -2.5081 2.6757 2.6757 -2.5081]*1e6,[-2.1439 2.1903 2.1903 -2.1439 -2.1439]*1e6,'k');
h=antbounds('gl','polyshape','facecolor','w','facealpha',1);
for k = 1:numel(shelf_names)
    plot(P(k),'facecolor',col(k,:),'facealpha',1,'edgecolor','none')
end
set(gca,'XColor','none','ycolor','none');
%export_fig('ice_shelf_lon_col_fill.png','-dpng','-r600','-transparent');

%% Plot contributions agains, but without zooming in, so we can see all the points


% Plot all
figure('units','inches','position',[2,2,7,7],'color','w');
% plot background
patch([-650 650 650 -650],[650,-650,650, 650],[65,105,225]./255,'facealpha',0.2,'edgecolor','none'); hold on
patch([-650 650 -650 -650],[650 -650 -650 650],[178,34,34]./255,'facealpha',0.2,'edgecolor','none'); 
% And plot lines
plot([-650 650],[0 0],'k','linewidth',1.5); hold on
plot([0 0],[-650 650],'k','linewidth',1.5);
%plot([-650 650],[650 -650],'k');

% Plot errors
for i = -4:4 % loop through regimes
    
    % plot errors
    % - shelves with significant mass change
    use = con==i & sigMass==1;
    cen_lon_samp = cen_lon(use);
    lon_scale_samp = lon_scale(use);
    cmap_samp = cmap(use,:);
    x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    x_data_min = prop_m_change_min(use).*(abs(i)/i);
    x_data_max = prop_m_change_max(use).*(abs(i)/i);
    y_data_min = prop_c_change_min(use).*(abs(i)/i);
    y_data_max = prop_c_change_max(use).*(abs(i)/i);
    yneg = y_data-y_data_min;
    ypos = y_data_max-y_data;
    xneg = x_data-x_data_min;
    xpos = x_data_max-x_data;
    if length(cen_lon_samp)>0
        for j = 1:length(cen_lon_samp)
            [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
            errorbar(x_data(j),y_data(j),yneg(j),ypos(j),xneg(j),xpos(j),...
                'LineStyle','none','MarkerSize',6,...
                'MarkerEdgeColor','none',...
                'Color',[.4 .4 .4],...
                'LineWidth',0.5,...
                'Marker','v');
        end
    end
%     % - shelves with insignificant mass change
%     use = con==i & sigMass==0;
%     cen_lon_samp = cen_lon(use);
%     lon_scale_samp = lon_scale(use);
%     cmap_samp = cmap(use,:);
%     x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
%     y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
%     x_data_min = prop_m_change_min(use).*(abs(i)/i);
%     x_data_max = prop_m_change_max(use).*(abs(i)/i);
%     y_data_min = prop_c_change_min(use).*(abs(i)/i);
%     y_data_max = prop_c_change_max(use).*(abs(i)/i);
%     yneg = y_data-y_data_min;
%     ypos = y_data_max-y_data;
%     xneg = x_data-x_data_min;
%     xpos = x_data_max-x_data;
%     if length(cen_lon_samp)>0
%         for j = 1:length(cen_lon_samp)
%             [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
%             errorbar(x_data(j),y_data(j),yneg(j),ypos(j),xneg(j),xpos(j),...
%                 'LineStyle','none','MarkerSize',6,...
%                 'MarkerEdgeColor','none',...
%                 'MarkerFaceColor','none',...
%                 'Color',[.8 .8 .8],...
%                 'LineWidth',0.1,...
%                 'Marker','v'); 
%         end
%     end
    
end

% plot markers
for i = -4:4 % loop through regimes
    
    % plot markers
    % - shelves with significant mass change
    use = con==i & sigMass==1;
    cen_lon_samp = cen_lon(use);
    lon_scale_samp = lon_scale(use);
    cmap_samp = cmap(use,:);
    x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    if length(cen_lon_samp)>0
        for j = 1:length(cen_lon_samp)
            [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
            scatter(x_data(j),y_data(j),30,cmap_samp(ind,:),'v','filled');
        end
    end
    % - shelves with insignificant mass change
    use = con==i & sigMass==0;
    cen_lon_samp = cen_lon(use);
    lon_scale_samp = lon_scale(use);
    cmap_samp = cmap(use,:);
    x_data = prop_m_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    y_data = prop_c_change(use).*(abs(i)/i); % set to negative if we're in a mass loss regime
    if length(cen_lon_samp)>0
        for j = 1:length(cen_lon_samp)
            [~,ind] = findNearest(lon_scale_samp,cen_lon_samp(j));
            scatter(x_data(j),y_data(j),30,cmap_samp(ind,:),'v');
        end
    end
    
end

% size
set(gca,'YLim',[-650 650]);
set(gca,'XLim',[-650 650]);
set(gca,'XTick',[-600:100:600]);
set(gca,'XTickLabel',{abs(-600:100:600)});
set(gca,'YTick',[-600:100:600]);
set(gca,'YTickLabel',{abs(-600:100:600)});
axis square
box on
xlabel({'             Thinning                      Thickening              ','Contribution of thickness changes to net mass change (%)'});
ylabel({'Contribution of area changes to net mass change (%)','    Retreat                        Advance   '});
set(gca,'fontsize',8)
% Label some shelves?
%idx = find(strcmp(shelf_names,'Pine_Island')==1);
%text(prop_m_change(idx)*-1,prop_c_change(idx)*-1,'Pine Island','color','k','horizontalAlignment','center','fontsize',8);

% plot something off grid that uses the full cmap
scatter(linspace(-1000,-1000+size(cmap,1),size(cmap,1)),linspace(-1000,-1000+size(cmap,1),size(cmap,1)),1,cmap);
cb=phasebar('deg','location','northwest');
cb.Colormap = cmap;

% label 
% text(-120,-125,'Thinning','color',[0,191,255]./255,'horizontalAlignment','center','fontsize',10); text(-120,-135,'& retreat','color',[0,191,255]./255,'horizontalAlignment','center','fontsize',10);% top right, mostly red % top right, mostly red
% text(-120,135,'Thinning','color','w','horizontalAlignment','center','fontsize',10); text(-120,125,'& advance','color','w','horizontalAlignment','center','fontsize',10);  % bottom right; blue dots
% text(120,-125,'Thickening','color',[255,215,0]./255,'horizontalAlignment','center','fontsize',10); text(120,-135,'& retreat','color',[255,215,0]./255,'horizontalAlignment','center','fontsize',10);  % top left; green dots
% text(120,135,'Thickening','color','k','horizontalAlignment','center','fontsize',10);text(120,125,'& advance','color','k','horizontalAlignment','center','fontsize',10); % top right, mostly red; [255,20,147]./255
text(-540,-545,'Thinning','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold'); text(-540,-575,'& retreat','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold');% top right, mostly red % top right, mostly red
text(-540,575,'Thinning','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold'); text(-540,545,'& advance','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold');  % bottom right; blue dots
text(540,-545,'Thickening','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold'); text(540,-575,'& retreat','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold');  % top left; green dots
text(540,575,'Thickening','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold');text(540,545,'& advance','color','k','horizontalAlignment','center','fontsize',10,'fontweight','bold'); % top right, mostly red; [255,20,147]./255
set(gca,'Fontsize',10);

% move colorbar
pos = cb.Position;
cb.Position = [pos(1)+0.6 pos(2)-0 pos(3)*0.6 pos(4)*0.6];

% % Add labels?
for i = 1:numel(loss_shelves)
    idx = find(strcmp(shelf_names,loss_shelves{i})==1);
    text(prop_m_change(idx)*-1,prop_c_change(idx)*-1,loss_shelves{i},'color','k','horizontalAlignment','left','fontsize',8);
end
% %   - gaining mass
% for i = 1:numel(gain_shelves)
%     idx = find(strcmp(shelf_names,gain_shelves{i})==1);%lab_search{i})==1);
%     text(prop_m_change(idx),prop_c_change(idx),gain_shelves{i},'color','k','horizontalAlignment','right','fontsize',8);
% end

% save
%export_fig('thinning_vs_retreat_mass_change_scatter_noel_loncol_update_v3_errbar.png','-dpng','-r1800');

%% Plot histogram for shelves that are losing mass

% get histogram info for shelves that are losing mass
d1 = histogram(prop_m_change(con==-1),-1000:10:3000,'FaceColor','k','facealpha',0.8);  % lost mass; thinned and retreated
h1.BinEdges = d1.BinEdges; h1.BinCounts = d1.BinCounts; close; clear d1
d1 = histogram(prop_m_change(con==-2),-1000:10:3000,'FaceColor','w','facealpha',0.8); % lost mass; thinned and advanced
h2.BinEdges = d1.BinEdges; h2.BinCounts = d1.BinCounts; close; clear d1
d1 = histogram(prop_m_change(con==-3),-1000:10:3000,'FaceColor',[255,215,0]./255,'facealpha',0.8); % lost mass; thickened and retreated
h3.BinEdges = d1.BinEdges; h3.BinCounts = d1.BinCounts; close; clear d1
d1 = histogram(prop_m_change(con==-4),-1000:10:3000,'FaceColor',[255,215,0]./255,'facealpha',0.8); % lost mass; thickened and advanced
h4.BinEdges = d1.BinEdges; h4.BinCounts = d1.BinCounts; close; clear d1

% Plot histogram for shelves that are losing mass
figure('units','inches','position',[2,2,5,2.4],'color','w'); 
%   - set background as red
patch([-100 -100 250 250 -100],[0 16 16 0 0],[178,34,34]./255,'facealpha',0.2); hold on
% - plot each histogram bar individually, to get order right
%   - first plot shelves that thinned and retreated
for i = 1:length(h1.BinCounts)
    patch([h1.BinEdges(i) h1.BinEdges(i) h1.BinEdges(i+1) h1.BinEdges(i+1) h1.BinEdges(i)],[0 h1.BinCounts(i) h1.BinCounts(i) 0 0],'k','facecolor',[0,191,255]./255,'facealpha',1,'edgecolor','k'); 
end
%   - then plot shelves that thinned but advanced, and split the width if
%   it overlaps with the first regime
for i = 1:length(h2.BinCounts)
    if h2.BinCounts(i) == h1.BinCounts(i)
        if h2.BinCounts(i)>0
            binWidth = (h2.BinEdges(i+1)-h2.BinEdges(i))/2;
            patch([h2.BinEdges(i)+binWidth h2.BinEdges(i)+binWidth h2.BinEdges(i+1) h2.BinEdges(i+1) h2.BinEdges(i)],[0 h2.BinCounts(i) h2.BinCounts(i) 0 0],'w','facealpha',1,'edgecolor','k');
        end
    else
        patch([h2.BinEdges(i) h2.BinEdges(i) h2.BinEdges(i+1) h2.BinEdges(i+1) h2.BinEdges(i)],[0 h2.BinCounts(i) h2.BinCounts(i) 0 0],'w','facealpha',1,'edgecolor','k');
    end
end
%   - repeat above, but for shelves that thickened and retreated
for i = 1:length(h3.BinCounts)
    if h3.BinCounts(i) == h1.BinCounts(i) && h3.BinCounts(i) ~= h2.BinCounts(i)
        if h3.BinCounts(i)>0
            binWidth = (h3.BinEdges(i+1)-h3.BinEdges(i))/2;
            patch([h3.BinEdges(i)+binWidth h3.BinEdges(i)+binWidth h3.BinEdges(i+1) h3.BinEdges(i+1) h3.BinEdges(i)],[0 h3.BinCounts(i) h3.BinCounts(i) 0 0],'k','facecolor',[255,215,0]./255,'facealpha',1,'edgecolor','k');
        end
    elseif h3.BinCounts(i) == h1.BinCounts(i) && h3.BinCounts(i) == h2.BinCounts(i)
        if h3.BinCounts(i)>0
            binWidth = (h3.BinEdges(i+1)-h3.BinEdges(i))/3;
            patch([h1.BinEdges(i) h1.BinEdges(i) h1.BinEdges(i)+binWidth h1.BinEdges(i)+binWidth h1.BinEdges(i)],[0 h1.BinCounts(i) h1.BinCounts(i) 0 0],'k','facecolor',[0,191,255]./255,'facealpha',1,'edgecolor','k');
            patch([h2.BinEdges(i)+binWidth h2.BinEdges(i)+binWidth h2.BinEdges(i+1)-binWidth h2.BinEdges(i+1)-binWidth h2.BinEdges(i)+binWidth],[0 h2.BinCounts(i) h2.BinCounts(i) 0 0],'w','facealpha',1,'edgecolor','k');
            patch([h3.BinEdges(i+1)-binWidth h3.BinEdges(i+1)-binWidth h3.BinEdges(i+1) h3.BinEdges(i+1) h3.BinEdges(i+1)-binWidth],[0 h3.BinCounts(i) h3.BinCounts(i) 0 0],'k','facecolor',[255,215,0]./255,'facealpha',1,'edgecolor','k');
        end
    else
        patch([h3.BinEdges(i) h3.BinEdges(i) h3.BinEdges(i+1) h3.BinEdges(i+1) h3.BinEdges(i)],[0 h3.BinCounts(i) h3.BinCounts(i) 0 0],'k','facecolor',[255,215,0]./255,'facealpha',1,'edgecolor','k');
    end
end
%   - set visuals
set(gca,'XLim',[-100 250])
set(gca,'YDir','reverse');
grid on
ylabel('Count','fontsize',10,'fontname','Helvetica');
xlabel('Contribution of thinning to mass loss (%)','fontsize',10,'fontname','Helvetica');
set(gca,'YLim',[0 16]);
set(gca,'YTick',[0:3:15]);
set(gca,'YTickLabel',{' ','3','6','9','12','15'});
set(gca,'fontsize',8,'fontname','Helvetica');
%   - save
%export_fig('melt_contrib_mass_loss_hist_update_v2_smooth.png','-dpng','-r1800');
close

%% Plot histogram for shelves that are gaining mass

% get histogram info for shelves that are gaining mass
clear d1 h1 h2 h3
d1 = histogram(prop_m_change(con==2),-1000:10:3000,'FaceColor','k','facealpha',0.8); % gained mass; thinned and advanced
h2.BinEdges = d1.BinEdges; h2.BinCounts = d1.BinCounts; close; clear d1
d1 = histogram(prop_m_change(con==3),-1000:10:3000,'FaceColor','w','facealpha',0.8); % gained mass; thickened and retreated
h3.BinEdges = d1.BinEdges; h3.BinCounts = d1.BinCounts; close; clear d1
d1 = histogram(prop_m_change(con==4),-1000:10:3000,'FaceColor',[255,215,0]./255,'facealpha',0.8); % gained mass; thickened and advanced
h4.BinEdges = d1.BinEdges; h4.BinCounts = d1.BinCounts; close; clear d1

% Plot histogram for shelves that are gaining mass
figure('units','inches','position',[2,2,5,1.82],'color','w'); 
%   - set background as blue
patch([-100 -100 250 250 -100],[0 12 12 0 0],[65,105,225]./255,'facealpha',0.2); hold on
% - plot each histogram bar individually, to get order right
%   - first plot shelves that thinned and retreated
for i = 1:length(h2.BinCounts)
    patch([h2.BinEdges(i) h2.BinEdges(i) h2.BinEdges(i+1) h2.BinEdges(i+1) h2.BinEdges(i)],[0 h2.BinCounts(i) h2.BinCounts(i) 0 0],'w','facealpha',1,'edgecolor','k');
end
%   - then plot shelves that thinned but advanced, and split the width if
%   it overlaps with the first regime
for i = 1:length(h3.BinCounts)
    if h3.BinCounts(i) == h2.BinCounts(i)
        if h3.BinCounts(i)>0
            binWidth = (h3.BinEdges(i+1)-h3.BinEdges(i))/2;
            patch([h3.BinEdges(i)+binWidth h3.BinEdges(i)+binWidth h3.BinEdges(i+1) h3.BinEdges(i+1) h3.BinEdges(i)],[0 h3.BinCounts(i) h3.BinCounts(i) 0 0],'w','facecolor',[255,215,0]./255,'facealpha',1,'edgecolor','k');
        end
    else
        patch([h3.BinEdges(i) h3.BinEdges(i) h3.BinEdges(i+1) h3.BinEdges(i+1) h3.BinEdges(i)],[0 h3.BinCounts(i) h3.BinCounts(i) 0 0],'w','facecolor',[255,215,0]./255,'facealpha',1,'edgecolor','k');
    end
end
%   - repeat above, but for shelves that thickened and retreated
for i = 1:length(h4.BinCounts)
    if h4.BinCounts(i) == h2.BinCounts(i) && h4.BinCounts(i) ~= h3.BinCounts(i)
        if h4.BinCounts(i)>0
            binWidth = (h4.BinEdges(i+1)-h4.BinEdges(i))/2;
            patch([h4.BinEdges(i)+binWidth h4.BinEdges(i)+binWidth h4.BinEdges(i+1) h4.BinEdges(i+1) h4.BinEdges(i)],[0 h4.BinCounts(i) h4.BinCounts(i) 0 0],'k','facealpha',1,'edgecolor','w');
        end
    elseif h4.BinCounts(i) == h2.BinCounts(i) && h4.BinCounts(i) == h3.BinCounts(i)
        if h4.BinCounts(i)>0
            binWidth = (h4.BinEdges(i+1)-h4.BinEdges(i))/3;
            patch([h2.BinEdges(i) h2.BinEdges(i) h2.BinEdges(i)+binWidth h2.BinEdges(i)+binWidth h2.BinEdges(i)],[0 h2.BinCounts(i) h2.BinCounts(i) 0 0],'w','facealpha',1,'edgecolor','w');
            patch([h3.BinEdges(i)+binWidth h3.BinEdges(i)+binWidth h3.BinEdges(i+1)-binWidth h3.BinEdges(i+1)-binWidth h3.BinEdges(i)+binWidth],[0 h3.BinCounts(i) h3.BinCounts(i) 0 0],'w','facecolor',[255,215,0]./255,'facealpha',1,'edgecolor','k');
            patch([h4.BinEdges(i+1)-binWidth h4.BinEdges(i+1)-binWidth h4.BinEdges(i+1) h4.BinEdges(i+1) h4.BinEdges(i+1)-binWidth],[0 h4.BinCounts(i) h4.BinCounts(i) 0 0],'k','facealpha',1,'edgecolor','w');
        end
    else
        patch([h4.BinEdges(i) h4.BinEdges(i) h4.BinEdges(i+1) h4.BinEdges(i+1) h4.BinEdges(i)],[0 h4.BinCounts(i) h4.BinCounts(i) 0 0],'k','facealpha',1,'edgecolor','w');
    end
end
%   - set visuals
set(gca,'XLim',[-100 250])
grid on
ylabel('Count','fontsize',10,'fontname','Helvetica');
xlabel('Contribution of thickening to mass gain (%)','fontsize',10,'fontname','Helvetica');
set(gca,'Xaxislocation','top');
set(gca,'YLim',[0 11]);
set(gca,'YTick',[0:2:10]);
set(gca,'YTickLabel',{' ','2','4','6','8','10'});
set(gca,'fontsize',8,'fontname','Helvetica');
% save
%export_fig('melt_contrib_mass_gain_hist_update_v2_smooth.png','-dpng','-r1800');


%% Get histogram stats

% To get proportion of mass loss due to melt or calving at shelves where
% loss is due to both, just do:
ind = find(delThick(con==-1 | con==-2)<delArea(con==-1 | con==-2)); % to get all those where melt excess exceeds calving excess
length(ind)/sum(con==-1 | con==-2) % to get proportion of these shelves where melt dominates

% Get histogram bin counts
edges = -1000:10:3000;
[Nm1,~,bins] = histcounts(prop_m_change(con==-1),edges);
Nm2 = histcounts(prop_m_change(con==-2),edges);
Nm3 = histcounts(prop_m_change(con==-3),edges);
N2 = histcounts(prop_m_change(con==2),edges);
N3 = histcounts(prop_m_change(con==3),edges);
N4 = histcounts(prop_m_change(con==4),edges);

% Get number of shelves where melt contributes >50% to mass loss
ind = find(edges>=50,1,'first');
Nm1_count = sum(Nm1(ind:end)); % where both melt and calvign contribute to mass loss
Nm2_count = sum(Nm2(ind:end)); % where melt contributes to loss, but the front is advancing
Nm3_count = sum(Nm3(ind:end)); % where the shelf is thickening, but retreating enough to cause mass loss
N2_count = sum(N2(ind:end)); % where the shelf is thinning, but advance causes net mass gain
N3_count = sum(N3(ind:end)); % thickening and advance, with mass gain
N4_count = sum(N4(ind:end)); % where the shelf is gaining mass due to both thickneing and advance
disp(['For ' num2str(sum(totalMassChangeAllShelves<0)) ' shelves that are losing mass, basal melting caused >50% of that loss at ' num2str(Nm1_count + Nm2_count) ' (' num2str((Nm1_count + Nm2_count)/sum(totalMassChangeAllShelves<0)*100) '%)' ]); 
disp(['For ' num2str(sum(totalMassChangeAllShelves>0)) ' shelves that are gaining mass, basal melt deficits caused >50% of that gain at ' num2str(N3_count + N4_count) ' (' num2str((N3_count + N4_count)/sum(totalMassChangeAllShelves>0)*100) '%)' ]); 

% Repeat only for 'significna't mass change
edges = -1000:10:3000;
[Nm1,~,bins] = histcounts(prop_m_change(con==-1 & sigMass==1),edges);
Nm2 = histcounts(prop_m_change(con==-2 & sigMass==1),edges);
Nm3 = histcounts(prop_m_change(con==-3 & sigMass==1),edges);
N2 = histcounts(prop_m_change(con==2 & sigMass==1),edges);
N3 = histcounts(prop_m_change(con==3 & sigMass==1),edges);
N4 = histcounts(prop_m_change(con==4 & sigMass==1),edges);

% Get number of shelves where melt contributes >50% to mass loss
ind = find(edges>=50,1,'first');
Nm1_count = sum(Nm1(ind:end)); % where both melt and calvign contribute to mass loss
Nm2_count = sum(Nm2(ind:end)); % where melt contributes to loss, but the front is advancing
N3_count = sum(Nm2(ind:end)); % where the shelf is thickening, but retreating enough to cause mass loss
N2_count = sum(N2(ind:end)); % where the shelf is thinning, but advance causes net mass gain
N3_count = sum(N3(ind:end)); % thickening and advance, with mass gain
N4_count = sum(N4(ind:end)); % where the shelf is gaining mass due to both thickneing and advance
disp(['For ' num2str(sum(totalMassChangeAllShelves<0 & sigMass==1)) ' shelves that are losing mass, basal melting caused >50% of that loss at ' num2str(Nm1_count + Nm2_count) ' (' num2str((Nm1_count + Nm2_count)/sum(totalMassChangeAllShelves<0 & sigMass==1)*100) '%)' ]); 
disp(['For ' num2str(sum(totalMassChangeAllShelves>0 & sigMass==1)) ' shelves that are gaining mass, basal melt deficits caused >50% of that gain at ' num2str(N3_count + N4_count) ' (' num2str((N3_count + N4_count)/sum(totalMassChangeAllShelves>0 & sigMass==1)*100) '%)' ]); 

disp('')
disp(['There are ' num2str(sum(con==-2 & sigMass==1)) ' that lost mass entirely because of excess melting']);
disp(['There are ' num2str(sum(con==-3 & sigMass==1)) ' that lost mass entirely because of excess calving']);
disp(['Similarly ' num2str(sum(con==2 & sigMass==1)) ' shelves gained mass entirely because of advance']);
disp(['and ' num2str(sum(con==3 & sigMass==1)) ' shelves gained mass entirely because of thickening']);


%% Plot
% some old bits I tried to understand the data distribution...
% figure;
% scatter(prop_m_change(con1b),prop_c_change(con1b),20,'r','x'); hold on
% scatter(prop_m_change(con2b),prop_c_change(con2b),20,'b','x'); hold on
% scatter(prop_m_change(con3b),prop_c_change(con3b),20,'g','x'); hold on
% scatter(prop_m_change(con4b),prop_c_change(con4b),20,'k','x'); hold on
% scatter(prop_m_change(con1),prop_c_change(con1),10,'r','filled'); hold on
% scatter(prop_m_change(con2),prop_c_change(con2),10,'b','filled'); hold on
% scatter(prop_m_change(con3),prop_c_change(con3),10,'g','filled'); hold on
% scatter(prop_m_change(con4),prop_c_change(con4),10,'k','filled'); hold on
% set(gca,'XLim',[-650 650]);
% set(gca,'YLim',[-650 650]);
% hold on
% plot([-650 650],[0 0],'k');
% plot([0 0],[-650 650],'k');
% text(300,300,'If mass loss: Thinning & retreat','color','r');% top right, mostly red
% text(300,250,'If mass gain: Thickening & advance','color','k');% top right, mostly red
% text(300,-250,'If mass gain: Thickening & retreat','color','g'); % bottom right; green crosses 
% text(300,-300,'If mass loss: Thinning & advance','color','b');  % bottom right; blue dots
% text(-300,-300,'Mass loss despite thickening & advance','color','b','horizontalAlignment','center');  % bottom left
% text(-300,300,'If mass loss: Thickening & retreat','color','b','horizontalAlignment','center');  % top left; green dots
% text(-300,250,'If mass gain: Thinning & advance','color','g','horizontalAlignment','center'); % bottom left; black dot
% 
% 
% % plot absolute
% figure;
% scatter(totalThinningAllShelves,totalRetreatAllShelves)
% set(gca,'XLim',[-500 500]);
% set(gca,'YLim',[-500 500]);
% hold on
% plot([-500 500],[0 0],'k');
% plot([0 0],[-500 500],'k');
% text(-300,300,'Thinning'); text(-300,250,'& advance'); % top left
% text(300,300,'Thickening'); text(300,250,'& advance'); % top right
% text(300,-250,'Thickening'); text(300,-300,'& retreat'); % bottom right
% text(-300,-250,'Thinning'); text(-300,-300,'& retreat'); % bottom left
% xlabel('<-- Thinning  ---------  thickening --> (Gt)');
% ylabel('<-- Retreat  ---------  advance --> (Gt)');
% size(c_all)
% 
% % Get data density
% xd = [prop_m_change(con1).*-1 ; prop_m_change(con2).*-1 ; prop_m_change(con3).*-1 ;...
%     prop_m_change(con1b) ; prop_m_change(con2b) ; prop_m_change(con3b) ; prop_m_change(con4b)];
% yd = [prop_c_change(con1).*-1 ; prop_c_change(con2).*-1 ; prop_c_change(con3).*-1 ;...
%     prop_c_change(con1b) ; prop_c_change(con2b) ; prop_c_change(con3b) ; prop_c_change(con4b)];
% % dmap = dataDensity(xd,yd,300,300,[-150 150 -150 150]);
% % imagesc(flipud(dmap),'alphadata',flipud(dmap)>0.5);
% % colorcet('Gouldian');
% 
% % alternative method
% % Define grid
% xgrid=-150:150;
% ygrid=-150:150;
% [x1,y1] = meshgrid(xgrid, ygrid);
% % Perform kernel density estimate
% % [x y] is actual data, xi is the desired grid points to evaluate
% % f is an estimate of the density, ep(:,1) is the X location, ep(:,2) is the y location
% xi = [x1(:) y1(:)];
% [f,ep]=ksdensity([xd yd],xi); % remove the outputs to see a 3D plot of the distribution
% % format data in matrix for contourf and plot
% Xd = reshape(ep(:,1),length(xgrid),length(ygrid));
% Yd = reshape(ep(:,2),length(xgrid),length(ygrid));
% Z = reshape(f,length(xgrid),length(ygrid));
% Z(Z<1e-5)=NaN;
% % contour(Xd,Yd,(Z),20)
% % ax=gca;
% % ax.XAxis.Exponent = 0;
% % xtickformat('%.4f')
% % xlabel('col1')
% % ylabel('col2')
% % colorbar


%% 
function RGB = mat2rgb(val,cmap,limits)
% 
% 
% Chad Greene wrote this, July 2016. 

if nargin==2
   limits = [min(val) max(val)]; 
end

gray = mat2gray(val,limits); 

ind = gray2ind(gray,size(cmap,1));

RGB = cmap(ind+1,:); 

end

