% plot_correlations

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

%% Load data

% Ice shelf names
load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\grounding_line_discharge\flux_gates/GL_consolidated_200m.mat');
shelves = shelf_names;

% mass budget data
load('../../mass_balance/mass_balance_components_all_shelves.mat');
load('../../mass_balance/individual_shelf_mass_balance_200m/Wordie_mass_balance_noel_update_v2.mat','time');

% Get shelf central longitude
cen_x = zeros([numel(shelf_names),1]).*NaN;
cen_y = zeros([numel(shelf_names),1]).*NaN;
cen_lat = zeros([numel(shelf_names),1]).*NaN;
cen_lon = zeros([numel(shelf_names),1]).*NaN;
for i = 1:numel(shelf_names)
    [cen_x(i),cen_y(i)] = centroid(polyshape(GL(i).X,GL(i).Y));
    [cen_lat(i),cen_lon(i)] = ps2ll(cen_x(i),cen_y(i));
end
cmap = phasemap(length(cen_lon));
lon_scale = linspace(-180,180,length(cen_lon));

%% Get totals

% D1997,Bmod
delMass = cumulativeDischargeChange1997AllShelves(:,end) + cumulativeSMBAnomalyAllShelves(:,end) + cumulativeRetreatBalanceAllShelves(:,end) + cumulativeThinningForce1997AllShelves(:,end);
delMassE = rssq([cumulativeDischargeChange1997ErrorAllShelves(:,end),cumulativeSMBAnomalyErrorAllShelves(:,end),totalRetreatErrorAllShelves,cumulativeThinningForce1997ErrorAllShelves(:,end)],2);
delThick = cumulativeThinningForce1997AllShelves(:,end); % negative = mass loss
delThickE = cumulativeThinningForce1997ErrorAllShelves(:,end); 
delArea = cumulativeRetreatBalanceAllShelves(:,end); % negative = mass loss
delAreaE = totalRetreatErrorAllShelves;
delDischarge = cumulativeDischargeChange1997AllShelves(:,end); % negative = mass loss
delDischargeE = cumulativeDischargeChange1997ErrorAllShelves(:,end);

% Check where mass loss is significantly different from zero
sigMass = logical(1-double(delMass+delMassE>0 & delMass-delMassE<0)); % logical 1 where mass change is significant

% set some other masks
sigDischargeIncrease = (delDischarge-delDischargeE)>0; %R_all_time>0.25 & P_all_time<0.05; %tmp>0 & tmp2>0;
justThinningAndAnyDischargeIncrease = delThick<0 & delDischarge>0;
justRetreatAndAnyDischargeIncrease = delArea<0 & delDischarge>0;

%% calculate trends

% pre-allocate
%   - mass balance
massBalanceTrendAllShelves = zeros([numel(shelves),1]).*NaN;
massBalancePAllShelves = zeros([numel(shelves),1]).*NaN;
%   - cumulative mass change
cumulativeMassTrendAllShelves = zeros([numel(shelves),1]).*NaN;
cumulativeMassPAllShelves = zeros([numel(shelves),1]).*NaN;
%   - thinning (basal melt anomaly)
thinningTrendAllShelves = zeros([numel(shelves),1]).*NaN;
thinningPAllShelves = zeros([numel(shelves),1]).*NaN;
%   - cumulaive thinning (cumulative basal melt anomaly)
cumulativeThinningTrendAllShelves = zeros([numel(shelves),1]).*NaN;
cumulativeThinningPAllShelves = zeros([numel(shelves),1]).*NaN;
%   - retreat
retreatTrendAllShelves = zeros([numel(shelves),1]).*NaN;
retreatPAllShelves = zeros([numel(shelves),1]).*NaN;
%   - cumulaive retreat
cumulativeRetreatTrendAllShelves = zeros([numel(shelves),1]).*NaN;
cumulativeRetreatPAllShelves = zeros([numel(shelves),1]).*NaN;
%   - discharge
dischargeTrendAllShelves = zeros([numel(shelves),1]).*NaN;
dischargePAllShelves = zeros([numel(shelves),1]).*NaN;
%   - discharge change
dischargeChangeTrendAllShelves = zeros([numel(shelves),1]).*NaN;
dischargeChangePAllShelves = zeros([numel(shelves),1]).*NaN;
%   - cumulative discharge change
cumulativeDischargeTrendAllShelves = zeros([numel(shelves),1]).*NaN;
cumulativeDischargePAllShelves = zeros([numel(shelves),1]).*NaN;
%   - correlations
R_CumulativeDischargeVsTime = zeros([numel(shelves),1]).*NaN;
P_CumulativeDischargeVsTime = zeros([numel(shelves),1]).*NaN;
R_DischargeVsTime = zeros([numel(shelves),1]).*NaN;
P_DischargeVsTime = zeros([numel(shelves),1]).*NaN;
R_MassVsTime = zeros([numel(shelves),1]).*NaN;
P_MassVsTime = zeros([numel(shelves),1]).*NaN;
R_CumulativeDischargeVsCumulativeThinning = zeros([numel(shelves),1]).*NaN;
P_CumulativeDischargeVsCumulativeThinning = zeros([numel(shelves),1]).*NaN;
R_DischargeVsThinning = zeros([numel(shelves),1]).*NaN;
P_DischargeVsThinning = zeros([numel(shelves),1]).*NaN;
R_CumulativeDischargeVsCumulativeRetreat = zeros([numel(shelves),1]).*NaN;
P_CumulativeDischargeVsCumulativeRetreat = zeros([numel(shelves),1]).*NaN;
R_DischargeVsRetreat = zeros([numel(shelves),1]).*NaN;
P_DischargeVsRetreat = zeros([numel(shelves),1]).*NaN;
R_DischargeVsMass = zeros([numel(shelves),1]).*NaN;
P_DischargeVsMass = zeros([numel(shelves),1]).*NaN;
R_DischargeVsCumulativeMass = zeros([numel(shelves),1]).*NaN;
P_DischargeVsCumulativeMass = zeros([numel(shelves),1]).*NaN;
for i = 1:numel(shelves)
    
    % mass balance
    [tr,p_m] = trend(massBalanceAllShelves(i,:),time);
    tr = tr.*365.25;
    massBalanceTrendAllShelves(i) = tr;
    massBalancePAllShelves(i) = p_m;
    
    % Cumulative mass change
    [tr,p_m] = trend(cumulativeMassChangeAllShelves(i,:),time);
    tr = tr.*365.25;
    cumulativeMassTrendAllShelves(i) = tr;
    cumulativeMassPAllShelves(i) = p_m;
    
    % Thinning (well, basal melt anomaly)
    [tr,p_m] = trend(thinningTimeseriesForce1997AllShelves(i,:).*-1,time);
    tr = tr.*365.25;
    thinningTrendAllShelves(i) = tr;
    thinningPAllShelves(i) = p_m;
    
    % cumulative thinning (well, cumulative basal melt anomaly)
    [tr,p_m] = trend(cumulativeThinningForce1997AllShelves(i,:).*-1,time);
    tr = tr.*365.25;
    cumulativeThinningTrendAllShelves(i) = tr;
    cumulativeThinningPAllShelves(i) = p_m;
    
    % Retreat
    [tr,p_m] = trend(retreatTimeseriesBalanceAllShelves(i,:).*-1,time);
    tr = tr.*365.25;
    retreatTrendAllShelves(i) = tr;
    retreatPAllShelves(i) = p_m;
    
    % cumulative retreat
    [tr,p_m] = trend(cumulativeRetreatBalanceAllShelves(i,:).*-1,time);
    tr = tr.*365.25;
    cumulativeRetreatTrendAllShelves(i) = tr;
    cumulativeRetreatPAllShelves(i) = p_m;
    
    % Discharge
    [tr,p_m] = trend(dischargeAllShelves(i,:),time);
    tr = tr.*365.25;
    dischargeTrendAllShelves(i) = tr;
    dischargePAllShelves(i) = p_m;
    
    % Discharge change
    [tr,p_m] = trend(dischargeChangeTimeseriesRel1997AllShelves(i,:),time);
    tr = tr.*365.25;
    dischargeTrendAllShelves(i) = tr;
    dischargePAllShelves(i) = p_m;
    
    % cumulative discharge change
    [tr,p_m] = trend(cumulativeDischargeChange1997AllShelves(i,:),time);
    tr = tr.*365.25;
    cumulativeDischargeTrendAllShelves(i) = tr;
    cumulativeDischargePAllShelves(i) = p_m;
    
    % Get correlations
    [R_CumulativeDischargeVsTime(i),P_CumulativeDischargeVsTime(i)] = corr(time',cumulativeDischargeChange1997AllShelves(i,:)','type','Pearson'); % correlation with cumulative discharge change
    [R_DischargeVsTime(i),P_DischargeVsTime(i)] = corr(time',(dischargeAllShelves(i,:))','type','Pearson'); % correlation with discharge
    [R_MassVsTime(i),P_MassVsTime(i)] = corr(time',(massBalanceAllShelves(i,:))','type','Pearson'); % correlation with discharge
    [R_CumulativeDischargeVsCumulativeThinning(i),P_CumulativeDischargeVsCumulativeThinning(i)] = corr(cumulativeThinningForce1997AllShelves(i,:)'.*-1,cumulativeDischargeChange1997AllShelves(i,:)','type','Pearson');
    [R_CumulativeDischargeVsCumulativeRetreat(i),P_CumulativeDischargeVsCumulativeRetreat(i)] = corr(cumulativeRetreatBalanceAllShelves(i,:)'.*-1,cumulativeDischargeChange1997AllShelves(i,:)','type','Pearson');
    [R_DischargeVsThinning(i),P_DischargeVsThinning(i)] = corr(thinningTimeseriesForce1997AllShelves(i,:)'.*-1,dischargeAllShelves(i,:)','type','Pearson');
    [R_DischargeVsRetreat(i),P_DischargeVsRetreat(i)] = corr(retreatTimeseriesBalanceAllShelves(i,:)'.*-1,dischargeAllShelves(i,:)','type','Pearson');
    [R_DischargeVsMass(i),P_DischargeVsMass(i)] = corr(massBalanceAllShelves(i,:)'.*-1,dischargeAllShelves(i,:)','type','Pearson');
    [R_DischargeVsCumulativeMass(i),P_DischargeVsCumulativeMass(i)] = corr(cumulativeMassChangeAllShelves(i,:)'.*-1,dischargeAllShelves(i,:)','type','Pearson');

end
save('ice_shelf_correlation_data.mat','massBalanceTrendAllShelves','massBalancePAllShelves',...
    'cumulativeMassTrendAllShelves','cumulativeMassPAllShelves','thinningTrendAllShelves',...
    'thinningPAllShelves','cumulativeThinningTrendAllShelves','cumulativeThinningPAllShelves',...
    'dischargeTrendAllShelves','dischargePAllShelves','dischargeChangeTrendAllShelves',...
    'dischargeChangePAllShelves','cumulativeDischargeTrendAllShelves','cumulativeDischargePAllShelves',...
    'R_CumulativeDischargeVsTime','P_CumulativeDischargeVsTime','R_DischargeVsTime',...
    'P_DischargeVsTime','R_CumulativeDischargeVsCumulativeThinning','P_CumulativeDischargeVsCumulativeThinning',...
    'R_CumulativeDischargeVsCumulativeRetreat','P_CumulativeDischargeVsCumulativeRetreat',...
    'R_DischargeVsThinning','P_DischargeVsThinning','R_DischargeVsRetreat','P_DischargeVsRetreat',...
    'R_DischargeVsMass','P_DischargeVsMass','R_DischargeVsCumulativeMass','P_DischargeVsCumulativeMass',...
    'R_MassVsTime','P_MassVsTime','retreatTrendAllShelves','retreatPAllShelves',...
    'cumulativeRetreatTrendAllShelves','cumulativeRetreatPAllShelves');
    


%% Plot all shelves

% Make figure
figure('color','w','units','inches','position',[2 2 7 6]);
subplot = @(m,n,p) subtightplot (m, n, p,[.08 0.0],[.1 .1],[.1 .1]);
%cmap = colorcet('Gouldian','N',size(m_all,1));

% Retreat timeseries
ax1 = subplot(2,2,1);
plot([0 2000],[0 2000],'k'); hold on
for i = 1:numel(shelves)
    if R_CumulativeDischargeVsTime(i)>0.25 && P_CumulativeDischargeVsTime(i)<0.05
        [~,ind] = findNearest(lon_scale,cen_lon(i));
        scatter(cumulativeRetreatBalanceAllShelves(i,:).*-1,cumulativeDischargeChange1997AllShelves(i,:),15,cmap(ind,:),'filled');
    end
end
% plot a zoom box
plot([-200 400],[-10 -10],'k','linestyle','-');
plot([-200 400],[150 150],'k','linestyle','-');
plot([400 400],[-10 150],'k','linestyle','-');
plot([-200 -200],[-10 150],'k','linestyle','-');
% label
xlabel('Cumulative retreat (Gt)');
ylabel('Cumulative discharge change (Gt)');
set(gca,'XLim',[-750 4000]);
set(gca,'YLim',[-50 1000]);
axis square
box on
p = get(gca, 'Position');
h = axes('Parent', gcf, 'Position', [p(1)+0.147 p(2)+0.160 p(3)-0.18 p(4)-0.18]);
hold(h); 
% zoom inset
for i = 1:numel(shelves)
    if R_CumulativeDischargeVsTime(i)>0.25 && P_CumulativeDischargeVsTime(i)<0.05
        [~,ind] = findNearest(lon_scale,cen_lon(i));
        scatter(cumulativeRetreatBalanceAllShelves(i,:).*-1,cumulativeDischargeChange1997AllShelves(i,:),8,cmap(ind,:),'filled');
    end
end
set(gca,'XLim',[-200 400]);
set(gca,'YLim',[-10 150]);
axis square
box on

% Thinning timeseries
ax2=subplot(2,2,2);
plot([0 2000],[0 2000],'k'); hold on
for i = 1:numel(shelves)
    if R_CumulativeDischargeVsTime(i)>0.25 && P_CumulativeDischargeVsTime(i)<0.05
        [~,ind] = findNearest(lon_scale,cen_lon(i));
        scatter(cumulativeThinningForce1997AllShelves(i,:).*-1,cumulativeDischargeChange1997AllShelves(i,:),15,cmap(ind,:),'filled');
    end
end
% phasemasp
pos = ax2.Position;
cb = colorbar('eastoutside');
pm = phasemap(360,'deg');
colormap(cmap);
caxis([-180 180]);
ax2.Position = pos;
pos = cb.Position;
cb.Position = [pos(1)-0.05 pos(2)-0.3 pos(3)*0.7 pos(4)*1.3];
ylabel(cb,'Central longitude (\circ)');
lpos = cb.Label.Position;
cb.Label.Position = [lpos(1)-0.5 lpos(2) lpos(3)];
% plot a zoom box
plot([0 250],[0 0],'k','linestyle','-');
plot([250 250],[0 50],'k','linestyle','-');
plot([0 250],[50 50],'k','linestyle','-');
% label
xlabel('Cumulative thinning (Gt)');
%ylabel('Cumulative discharge change (Gt)');
set(gca,'YTickLabel',{' '});
set(gca,'XLim',[0 2500]);
set(gca,'YLim',[-50 1000]);
axis square
box on
p = get(gca, 'Position');
h = axes('Parent', gcf, 'Position', [p(1)+0.04 p(2)+0.165 p(3)-0.18 p(4)-0.18]);
hold(h);
for i = 1:numel(shelves)
    if R_CumulativeDischargeVsTime(i)>0.25 && P_CumulativeDischargeVsTime(i)<0.05
        [~,ind] = findNearest(lon_scale,cen_lon(i));
        scatter(cumulativeThinningForce1997AllShelves(i,:).*-1,cumulativeDischargeChange1997AllShelves(i,:),8,cmap(ind,:),'filled');
    end
end
set(gca,'XLim',[0 250]);
set(gca,'YLim',[0 50]);
axis square
box on

% Net areal change
subplot(2,2,3)
% - plot all shelves with any retreat and any discharge increase, regardless of significance as open circles
lon_keep = cen_lon(justRetreatAndAnyDischargeIncrease);
[~,iv] = sort(lon_keep);
xplot = delArea(justRetreatAndAnyDischargeIncrease).*-1; xplot = xplot(iv);
yplot = delDischarge(justRetreatAndAnyDischargeIncrease); yplot = yplot(iv);
scatter(xplot,yplot,20,cmap(justRetreatAndAnyDischargeIncrease,:)); hold on
% - plot shelves with significant discharge increase
lon_keep = cen_lon(sigDischargeIncrease);
[~,iv] = sort(lon_keep);
xplot = delArea(sigDischargeIncrease).*-1; xplot = xplot(iv);
yplot = delDischarge(sigDischargeIncrease); yplot = yplot(iv);
scatter(xplot,yplot,20,cmap(sigDischargeIncrease,:),'filled'); % only significant increases in discharge are filled
%   - visuals
plot([.01 10000],[.01 10000],'k');
set(gca,'Yscale','log');
set(gca,'Xscale','log');
axis square
XTick = [0.1,1,10,100,1000];
set(gca,'XTick',XTick);
XTickLabels = cellstr(num2str(round(log10(XTick(:))), '10^{%d}'));
set(gca,'XTickLabels',XTickLabels);
YTick = [0.01,0.1,1,10,100,1000,10000];
set(gca,'YTick',YTick);
YTickLabels = cellstr(num2str(round(log10(YTick(:))), '10^{%d}'));
set(gca,'YTickLabels',YTickLabels);
box on
xlabel('Total retreat (Gt)');
ylabel('Total discharge change (Gt)');
set(gca,'XLim',[0.01 5000]);
set(gca,'YLim',[0.01 5000]);
% add fit and equation only for significant shelves
xf_c = delArea(sigDischargeIncrease).*-1; % cumulative calving excess, where both calving excess and disscharge exces are >0
yf_c = delDischarge(sigDischargeIncrease); % cumulative discharge excess, where both calving excess and disscharge exces are >0
xf_c = xf_c(isfinite(xf_c) & isfinite(yf_c));
yf_c = yf_c(isfinite(xf_c) & isfinite(yf_c));
p_c = polyfit(log10(xf_c),log10(yf_c),1);
xf_c = sort(xf_c);
zf_c = polyval(p_c,log10(xf_c));
plot(xf_c,10.^zf_c,'color','k','linewidth',2)
grid on
expstr = @(xf_c) [xf_c(:).*10.^ceil(-log10(abs(xf_c(:))))  floor(log10(abs(xf_c(:))))]; % Mantissa & Exponent
p_c2 = expstr(10^p_c(2));
eqn = sprintf('y = %.2f\\times10^{%d}\\cdotx^{%.2f}',p_c2(1), p_c2(2), p_c(1));
text(0.02,1000, eqn)
% plot fit with all points greater than zero
xf_c = delArea(justThinningAndAnyDischargeIncrease).*-1; % cumulative melt excess, where both melt excess and disscharge exces are >0
yf_c = delDischarge(justThinningAndAnyDischargeIncrease); % cumulative discharge excess, where both melt excess and disscharge exces are >0
xf_c = xf_c(isfinite(xf_c) & isfinite(yf_c));
yf_c = yf_c(isfinite(xf_c) & isfinite(yf_c));
p_c = polyfit(log10(xf_c),log10(yf_c),1);
xf_c = sort(xf_c);
zf_c = polyval(p_c,log10(xf_c));
loglog(xf_c,10.^zf_c,'color','k','linewidth',2,'linestyle','--')
% grid on
% expstr = @(xf_m) [xf_m(:).*10.^ceil(-log10(abs(xf_m(:))))  floor(log10(abs(xf_m(:))))]; % Mantissa & Exponent
% p_m2 = expstr(10^p_m(2));
% eqn = sprintf('y = %.2f\\times10^{%d}\\cdotx^{%.2f}',p_m2(1), p_m2(2), p_m(1));
% text(0.02,1000, eqn)

% Net thickness change
subplot(2,2,4)
% - plot all shelves with any thinning and any discharge increase, regardless of significance as open circles
lon_keep = cen_lon(justThinningAndAnyDischargeIncrease);
[~,iv] = sort(lon_keep);
xplot = delThick(justThinningAndAnyDischargeIncrease).*-1; xplot = xplot(iv);
yplot = delDischarge(justThinningAndAnyDischargeIncrease); yplot = yplot(iv);
scatter(xplot,yplot,20,cmap(justThinningAndAnyDischargeIncrease,:)); hold on
% - plot shelves with significant discharge increase
lon_keep = cen_lon(sigDischargeIncrease);
[~,iv] = sort(lon_keep);
xplot = delThick(sigDischargeIncrease).*-1; xplot = xplot(iv);
yplot = delDischarge(sigDischargeIncrease); yplot = yplot(iv);
scatter(xplot,yplot,20,cmap(sigDischargeIncrease,:),'filled'); % only significant increases in discharge are filled
%   - visuals
plot([.01 10000],[.01 10000],'k');
set(gca,'Yscale','log');
set(gca,'Xscale','log');
axis square
XTick = [0.1,1,10,100,1000];
set(gca,'XTick',XTick);
XTickLabels = cellstr(num2str(round(log10(XTick(:))), '10^{%d}'));
set(gca,'XTickLabels',XTickLabels);
YTick = [0.01,0.1,1,10,100,1000,10000];
set(gca,'YTick',YTick);
YTickLabels = cellstr(num2str(round(log10(YTick(:))), '10^{%d}'));
set(gca,'YTickLabels',YTickLabels);
box on
xlabel('Total thinning (Gt)');
%ylabel('Total discharge change (Gt)');
set(gca,'XLim',[0.01 5000]);
set(gca,'YLim',[0.01 5000]);
set(gca,'YTickLabel',{' '});
% add fit and equation only for significant shelves
xf_m = delThick(sigDischargeIncrease).*-1; % cumulative melt excess, where both melt excess and disscharge exces are >0
yf_m = delDischarge(sigDischargeIncrease); % cumulative discharge excess, where both melt excess and disscharge exces are >0
xf_m = xf_m(isfinite(xf_m) & isfinite(yf_m));
yf_m = yf_m(isfinite(xf_m) & isfinite(yf_m));
p_m = polyfit(log10(xf_m),log10(yf_m),1);
xf_m = sort(xf_m);
zf_m = polyval(p_m,log10(xf_m));
loglog(xf_m,10.^zf_m,'color','k','linewidth',2)
grid on
expstr = @(xf_m) [xf_m(:).*10.^ceil(-log10(abs(xf_m(:))))  floor(log10(abs(xf_m(:))))]; % Mantissa & Exponent
p_m2 = expstr(10^p_m(2));
eqn = sprintf('y = %.2f\\times10^{%d}\\cdotx^{%.2f}',p_m2(1), p_m2(2), p_m(1));
text(0.02,1000, eqn)
% plot fit with all points greater than zero
xf_m = delThick(justThinningAndAnyDischargeIncrease).*-1; % cumulative melt excess, where both melt excess and disscharge exces are >0
yf_m = delDischarge(justThinningAndAnyDischargeIncrease); % cumulative discharge excess, where both melt excess and disscharge exces are >0
xf_m = xf_m(isfinite(xf_m) & isfinite(yf_m));
yf_m = yf_m(isfinite(xf_m) & isfinite(yf_m));
p_m = polyfit(log10(xf_m),log10(yf_m),1);
xf_m = sort(xf_m);
zf_m = polyval(p_m,log10(xf_m));
loglog(xf_m,10.^zf_m,'color','k','linewidth',2,'linestyle','--')
% grid on
% expstr = @(xf_m) [xf_m(:).*10.^ceil(-log10(abs(xf_m(:))))  floor(log10(abs(xf_m(:))))]; % Mantissa & Exponent
% p_m2 = expstr(10^p_m(2));
% eqn = sprintf('y = %.2f\\times10^{%d}\\cdotx^{%.2f}',p_m2(1), p_m2(2), p_m(1));
% text(0.02,1000, eqn)

% Save
export_fig('discharge_change_vs_calving_melt_excess_combined_noel_all_shelves_Gt_loncol_smooth.png','-dpng','-r1800');



%% Some more stats

% ASE shelves
ASE_shelves = {'Pine_Island','Thwaites','Crosson','Dotson','Getz'};
ASE_ind = [107,139,26,32,52];
%   - cumulative thinning (basal melt anomaly) vs cumulative discharge change
disp(' ');
disp('ASE cumulative thinning (basal melt anom) vs cumulative discharge change');
ASE_cumulativeDischargeVsCumulativeThinning = table(ASE_shelves',R_CumulativeDischargeVsCumulativeThinning(ASE_ind),P_CumulativeDischargeVsCumulativeThinning(ASE_ind),'variableNames',{'shelves','R','P'})
%   - cumulative retreat vs cumulative discharge change
disp(' ');
disp('ASE cumulative retreat vs cumulative discharge change');
ASE_cumulativeDischargeVsCumulativeRetreat = table(ASE_shelves',R_CumulativeDischargeVsCumulativeRetreat(ASE_ind),P_CumulativeDischargeVsCumulativeRetreat(ASE_ind),'variableNames',{'shelves','R','P'})



% Mass loss vs discharge timeseries
disp(' ');
disp('Mass loss vs discharge timeseries');
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & R_DischargeVsTime>0.25 & P_DischargeVsTime<0.05)) ' had a significant (P<0.05) positive (R>0.25) discharge trend']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & R_DischargeVsTime>0.25)) ' had a positive (R>0.25) discharge trend']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05)) ' had a significant (P<0.05) positive (R>0.25) cumulative discharge trend']);
disp(['Of the ' num2str(sum(delMass<0 & sigMass==1)) ' shelves that lost mass (significantly) ' num2str(sum(delMass<0 & sigMass==1 & R_CumulativeDischargeVsTime>0.25)) ' had a positive (R>0.25) cumulative discharge trend']);

% Thinning vs cumulative discharge
disp(' ');
disp('thinning vs cumulative discharge timeseries');
disp(['Amongst all studied shelves, ' num2str(sum(R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05)) ' had significant (P<0.05) positive (R>0.25) cumulative discharge trends']);
disp(['Of those, there is a significant positive correlation between cumulative thinning and cumulative discharge change at ' num2str(sum(R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05 & R_CumulativeDischargeVsCumulativeThinning>0.25 & P_CumulativeDischargeVsCumulativeThinning<0.05)) ' shelves']);
disp(['...Just to check: there was a significant positive correlation between cumulative thinning and cumulative discharge change at ' num2str(sum(R_CumulativeDischargeVsCumulativeThinning>0.25 & P_CumulativeDischargeVsCumulativeThinning<0.05)) ' shelves']);
disp(['The relationship between cumulative thinning and cumulative discharge change is strongest in the ASE: R^2=' num2str(nanmean([R_CumulativeDischargeVsCumulativeThinning(ASE_ind)])) ', p=' num2str(nanmean([P_CumulativeDischargeVsCumulativeThinning(ASE_ind)]))]);

% Retreat vs cumulative discharge
disp(' ');
disp('retreat vs cumulative discharge timeseries');
disp(['Amongst all studied shelves, ' num2str(sum(R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05)) ' had significant (P<0.05) positive (R>0.25) cumulative discharge trends']);
disp(['Of those, there is a significant positive correlation between cumulative retreat and cumulative discharge change at ' num2str(sum(R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05 & R_CumulativeDischargeVsCumulativeRetreat>0.25 & P_CumulativeDischargeVsCumulativeRetreat<0.05)) ' shelves']);
disp(['...Just to check: there was a significant positive correlation between cumulative retreat and cumulative discharge change at ' num2str(sum(R_CumulativeDischargeVsCumulativeRetreat>0.25 & P_CumulativeDischargeVsCumulativeRetreat<0.05)) ' shelves']);
disp(['The relationship between cumulative retreat and cumulative discharge change is strongest in the ASE: R^2=' num2str(nanmean(R_CumulativeDischargeVsCumulativeRetreat(ASE_ind))) ', p=' num2str(nanmean(P_CumulativeDischargeVsCumulativeRetreat(ASE_ind)))]);

% Combined retreat and thinning
disp(' ');
disp('Combined');
disp(['There is a significant positive correlation between cumultive thinning, cumulative retreat and cumulative discharge change at ' num2str(sum(R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05 & R_CumulativeDischargeVsCumulativeRetreat>0.25 & P_CumulativeDischargeVsCumulativeRetreat<0.05 & R_CumulativeDischargeVsCumulativeThinning>0.25 & P_CumulativeDischargeVsCumulativeThinning<0.05)) ' of ' num2str(sum(R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05)) ' shelves that also had significant postitive cumulative discharge']);
disp(['Only ' num2str(sum(R_CumulativeDischargeVsCumulativeRetreat<0.25 & R_CumulativeDischargeVsCumulativeThinning<0.25 & R_CumulativeDischargeVsTime>0.25 & P_CumulativeDischargeVsTime<0.05)) ' shelves with significant positive cumulative discharge trends had no relationship to cumulative retreat or cumulative thinning (melt anomaly)']);


%% Plot just Pine Island (PIG)

% Thinning
cmap = colorcet('Gouldian','N',7);
figure('color','w','units','inches','position',[2 2 7 6]);
subplot = @(m,n,p) subtightplot (m, n, p,[.1 0.1],[.1 .1],[.1 .1]);
subplot(2,2,2)
[~,ind] = findNearest(lon_scale,cen_lon(107));
scatter(cumulativeThinningForce1997AllShelves(107,:).*-1,cumulativeDischargeChange1997AllShelves(107,:),20,cmap(2,:),'filled'); hold on; % Pine island
plot([0 2500],[0 2500],'k'); hold on
xlabel('Cumulative thinning (Gt)');
ylabel('Cumulative discharge change (Gt)');
set(gca,'XLim',[0 2500]);
set(gca,'YLim',[-50 800]);
axis square
box on

% Retreat
subplot(2,2,1)
scatter(cumulativeRetreatBalanceAllShelves(107,:).*-1,cumulativeDischargeChange1997AllShelves(107,:),20,cmap(2,:),'filled'); hold on; % Pine island
L = legend('PIG','Thwaites','Crosson','Dotson','Getz','autoupdate','off','location','northeast','fontsize',8);
L.ItemTokenSize(1) = 10;
plot([0 2500],[0 2500],'k'); hold on
xlabel('Cumulative retreat (Gt)');
ylabel('Cumulative discharge change (Gt)');
axis square
box on
set(gca,'XLim',[-750 4000]);
set(gca,'YLim',[-50 800]);
axis square
box on
export_fig('discharge_change_vs_calving_melt_excess_combined_noel_PIG_smooth.png','-dpng','-r1800');



%% Plot just ASE

% Thinning
cmap = colorcet('Gouldian','N',7);
figure('color','w','units','inches','position',[2 2 7 6]);
subplot = @(m,n,p) subtightplot (m, n, p,[.1 0.1],[.1 .1],[.1 .1]);
subplot(2,2,2)
[~,ind] = findNearest(lon_scale,cen_lon(107));
scatter(cumulativeThinningForce1997AllShelves(107,:).*-1,cumulativeDischargeChange1997AllShelves(107,:),20,cmap(2,:),'filled'); hold on; % Pine island
scatter(cumulativeThinningForce1997AllShelves(139,:).*-1,cumulativeDischargeChange1997AllShelves(139,:),20,cmap(3,:),'filled'); % Pine island
scatter(cumulativeThinningForce1997AllShelves(26,:).*-1,cumulativeDischargeChange1997AllShelves(26,:),20,cmap(4,:),'filled'); % Crosson
scatter(cumulativeThinningForce1997AllShelves(32,:).*-1,cumulativeDischargeChange1997AllShelves(32,:),20,cmap(5,:),'filled'); % Dotson
scatter(cumulativeThinningForce1997AllShelves(52,:).*-1,cumulativeDischargeChange1997AllShelves(52,:),20,cmap(6,:),'filled'); % Getz
plot([0 2000],[0 2000],'k'); hold on
xlabel('Cumulative thinning (Gt)');
ylabel('Cumulative discharge change (Gt)');
set(gca,'XLim',[0 2500]);
set(gca,'YLim',[-50 800]);
axis square
box on

% Retreat
subplot(2,2,1)
scatter(cumulativeRetreatBalanceAllShelves(107,:).*-1,cumulativeDischargeChange1997AllShelves(107,:),20,cmap(2,:),'filled'); hold on; % Pine island
scatter(cumulativeRetreatBalanceAllShelves(139,:).*-1,cumulativeDischargeChange1997AllShelves(139,:),20,cmap(3,:),'filled'); % Pine island
scatter(cumulativeRetreatBalanceAllShelves(26,:).*-1,cumulativeDischargeChange1997AllShelves(26,:),20,cmap(4,:),'filled'); % Crosson
scatter(cumulativeRetreatBalanceAllShelves(32,:).*-1,cumulativeDischargeChange1997AllShelves(32,:),20,cmap(5,:),'filled'); % Dotson
scatter(cumulativeRetreatBalanceAllShelves(52,:).*-1,cumulativeDischargeChange1997AllShelves(52,:),20,cmap(6,:),'filled'); % Getz
L = legend('PIG','Thwaites','Crosson','Dotson','Getz','autoupdate','off','location','northeast','fontsize',8);
L.ItemTokenSize(1) = 10;
plot([0 2000],[0 2000],'k'); hold on
xlabel('Cumulative retreat (Gt)');
ylabel('Cumulative discharge change (Gt)');
axis square
box on
set(gca,'XLim',[-750 4000]);
set(gca,'YLim',[-50 800]);
axis square
box on
export_fig('discharge_change_vs_calving_melt_excess_combined_noel_ASE_smooth.png','-dpng','-r1800');


%% PLot longer term discharge change in respomnse to calving

% Andreyev
figure('color','w','units','inches','position',[2 2 3.5 3.5]);
cmap = colorcet('Gouldian','N',25);
plot([-1 10],[-1 10],'k'); hold on
for i = 5%1:size(c_all,1)
    scatter(cumulativeRetreatBalanceAllShelves(i,:).*-1,cumulativeDischargeChange1997AllShelves(i,:),30,cmap,'filled','markeredgecolor',[0 0 0]);
end
cb = colorbar;
caxis([1997 2021]);
xlabel('Cumulative retreat (Gt)');
ylabel('Cumulative discharge change (Gt)');
set(gca,'XLim',[-1 3]);
set(gca,'YLim',[-1 11]);
set(gca,'XTick',get(gca,'YTick'));
set(gca,'XTickLabel',get(gca,'YTickLabel'));
export_fig('transient_discharge_response_calving_andreyev_smooth.png','-dpng','-r1800');


% make a similar plot for all ice shelves...
% for i = 1:size(cumulativeRetreatBalanceAllShelves,1)
%     figure('color','w','units','inches','position',[2 2 3.5 3.5]);
%     cmap = colorcet('Gouldian','N',25);
%     r = cumulativeRetreatBalanceAllShelves(i,:).*-1;
%     d = cumulativeDischargeChange1997AllShelves(i,:);
%     lims = [min([min(r),min(d)]),max([max(r),max(d)])];
%     buff = max([abs(lims(1).*0.25),abs(lims(2)*0.1)]);
%     lims = [lims(1)-buff lims(2)+buff];
%     plot([lims(1) lims(2)],[lims(1) lims(2)],'k'); hold on
%     scatter(r,d,30,cmap,'filled','markeredgecolor',[0 0 0]);
%     cb = colorbar;
%     caxis([1997 2021]);
%     xlabel('Cumulative retreat (Gt)');
%     ylabel('Cumulative discharge change (Gt)');
%     set(gca,'XLim',lims);
%     set(gca,'YLim',lims);
%     set(gca,'XTick',get(gca,'YTick'));
%     set(gca,'XTickLabel',get(gca,'YTickLabel'));
%     title(shelves{i});
%     export_fig(['discharge_vs_retreat_all_shelves/' shelves{i} '_transient_discharge_response_calving_smooth.png'],'-dpng','-r150');
%     close
% end

ind = find(strcmpi(shelves,'Larsen_A')==1)
figure;
plot(time,retreatTimeseriesBalanceAllShelves(ind,:).*-1,'k'); hold on
ylabel('retreat');
yyaxis right
plot(time,dischargeAllShelves(ind,:)); datetick('x');
ylabel('discharge');

% andreyev - 5
% Clarke bay - 21
% Dalk - 27
% george VI - 51
% harmon bay - 58
% hull - 65
% larsen F - 77
% ninnis - 100
% rund bay - 122
% skallen - 128

% Just plot the best examples
figure('color','w','units','inches','position',[2 2 6 6]);
subplot = @(m,n,p) subtightplot (m, n, p,[.1 0.15],[.1 .1],[.1 .1]);
cmap = colorcet('Gouldian','N',25);
inds = [5,21,27,51,58,65,77,100,122,128];
inds = [5,21,27,65]; % just those mentioned in the text
top_count = 0;
bottom_count = 4;
for i = 1:length(inds)
    top_count = top_count+1;
    bottom_count = bottom_count+1;
    
    % plot timeseries
    subplot(4,3,[i*3-2,i*3-1]);
    plot(time,retreatTimeseriesBalanceAllShelves(inds(i),:).*-1,'k'); hold on; datetick('x');
    ylabel('Retreat (Gt yr^{-1})');
    yyaxis right
    plot(time,dischargeAllShelves(inds(i),:));
    ylabel('Discharge (Gt yr^{-1})');
    title(shelves{inds(i)},'interpreter','none');
    if i == 2; title('Clarke Bay'); end
    set(gca,'XLim',[time(1) time(end)]);
    
    % plot scatter
    subplot(4,3,i*3);
    r = cumulativeRetreatBalanceAllShelves(inds(i),:).*-1;
    d = cumulativeDischargeChange1997AllShelves(inds(i),:);
    lims = [min([min(r),min(d)]),max([max(r),max(d)])];
    buff = max([abs(lims(1).*0.25),abs(lims(2)*0.1)]);
    lims = [lims(1)-buff lims(2)+buff];
    plot([lims(1) lims(2)],[lims(1) lims(2)],'k'); hold on
    scatter(r,d,30,cmap,'filled','markeredgecolor',[0 0 0]);
    if i == 3
        cb = colorbar;
        caxis([1997 2021]);
        pos = cb.Position;
        cb.Position = [pos(1)+0.075 pos(2)+0.03 pos(3) pos(4)*3];
    end
    set(gca,'XLim',lims); set(gca,'YLim',lims);
    set(gca,'XTick',get(gca,'YTick'),'XTickLabel',get(gca,'YTickLabel'));
    axis square
    p = get(gca,'Position');
    set(gca,'Position',[p(1)-0.03 p(2) p(3)*1.4 p(4)*1.4]);
    if i == 1; set(gca,'XLim',[-22 1],'YLim',[-1 11]); set(gca,'XTick',[-20 -15 -10 -5 0]); set(gca,'XTickLabel',{'-20','-15','-10','-5','0'}); end
    if i == 4; set(gca,'XLim',[lims(1) 20]); set(gca,'XTick',[0 10 20]); set(gca,'XTickLabel',{'0','10','20'}); end
    if i == 4; xlabel('cumu. retreat (Gt)'); end
    if i == 3 || i==1; ylabel('cumu. discharge (Gt)'); end
end
export_fig('transient_discharge_response_calving_examples_smooth.png','-dpng','-r1800');

