% plot_cumulative_mass_change_manual

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

%% Load grounding line

load('../../grounding_line_discharge/flux_gates/GL_consolidated_200m.mat');

% Set shelves to plot and labels
load('shelves_to_plot.mat'); % same as above but ordered clockwise from Larsen A

% also load initial ice shelf mass
load('init_mass_greene.mat','init_mass');

% Load basin groups
basins = load('merged_imbie_basins.mat');

%% Prepare colormaps and plotting parameters

% Colorbar
ulim = 2000;
llim = -2000;
cmap = flipud(cbrewer('div','RdBu',length(llim:ulim)));
cpts = llim:ulim;

% Scaling for ice shelf circles
s = 15; % 8 for rel mb; 60 for rel mb trend

% load ice shelf locations
L = shaperead('ice_shelf_circle_locs_manual_mc.shp');

%% Prepare labels

% positive (vert,horiz) e.g. CR = centre right of dot; BC = below and
% centre of dot)
label_pos = {'CL','CR','CR','LarsenD','LarsenE','LarsenF','Clarke_Bay','LarsenG',...
    'TC','TC','CR','DawsonLambton','TC','CR','CL','Ekstrom','CL','CL','TC','Vigrid',...
    'Nivl','Lazarev','Borchgrevink','TC','PrinceH','Shirase','CL','BC','Rayner',...
    'Zubchatyy','CR','CR','EdwardVIII','CR','CR','Hoseason','CL',...
    'Mulebreen','Utsikkar','CR','Publications','CR','BC','CR','Sorsdal','CR',...
    'Helen','Shackleton','CR','TC','CR','CR','CR','Totten','Moscow','CR',...
    'CR','TC','CR','CR','CR','Dibble','CR','CR','CR','Francais','CR',...
    'CR','CR','CR','BC','CR','CR','BC','CR','CR','BC','CL','CR',...
    'Lauritzen','CL','CL','CR','Noll','CL','Suvorov','Rennick',...
    'CL','Barber','CL','CL','CL','Smith_Inlet','Dennistoun',...
    'CL','Quatermain','CL','Manhaul','CL','MandibleCirque','Mariner',...
    'CL','CL','CL','CL','Parker','Aviator','CL','CapeWashington','CR',...
    'Nansen','Drygalski','CR','Cheetham','Harbord Glacier','CR',...
    'Nordenskjold','CR','Ross West','Hamilton','Withrow','Richter',...
    'Swinburne','Sulzberger','Nickerson','CL','Hull','TC','CL','CL',...
    'CL','BC','CL','CL','CL','CR','CR','CL','CL','CL','Walgreen Coast 1','CL',...
    'Cosgrove','CL','CL','CL','CR','CL','CL','CL','RydbergPeninsula 1',...
    'CL','CL','CL','CL','CL','CL','Brahms','Mendelssohn','CL',...
    'CL','TC'};

% Change a few labels
shelf_labs{52} = 'Vin. Bay';
shelf_labs{63} = 'Pourquoi';
shelf_labs{135} = 'H. Bay';
shelf_labs{149} = 'E. Bay';
shelf_labs{37} = 'C. Fjord';

%% Get data for each shelf

% pre-allocate
rel_mb_all = table('size',[numel(shelves_to_plot),8],'VariableTypes',{'string','double','double','double','double','double','double','double'},...
    'VariableNames',{'Ice shelf','Initial Mass (Gt)','Total mass change (Gt)','Total mass change error (Gt)','Relative mass change (%)','Mass trend (Gt/yr)','Relative mass trend (%/yr)','Trend p-val'});

% Enter loops
for i = 1:numel(L)
    
    % load data
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' L(i).Name '_mass_balance_noel_update_v2.mat'],'totalMassChange','totalMassChangeError','cumulativeMassChange','time');
    
    if strcmp(L(i).Name,'Pine_Island') || strcmp(L(i).Name,'Thwaites') || strcmp(L(i).Name,'Crosson') || strcmp(L(i).Name,'Dotson')
        GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
        idx = find(contains(GLmass.ASE_shelves,L(i).Name)==1);
        totalMassChange = totalMassChange + GLmass.mass_change_GL(idx);
        cumuGLmass = linspace(0,GLmass.mass_change_GL(idx),length(cumulativeMassChange));
        cumulativeMassChange = cumulativeMassChange + cumuGLmass;
    end
    
    % Ross west has an error almost identical to, but slightly less than
    % its total mass change. Increase it slightly here to avoid plotting
    if strcmp(L(i).Name,'Ross_West') || strcmp(L(i).Name,'Mandible_Cirque')
        totalMassChangeError = 550;
    end
    
    % Calculate relative mass changes
    relMassChange = abs(totalMassChange)./init_mass(i).*100;
    if totalMassChange>0
        relMassChange = -relMassChange; % we want to plot mass loss as red/positive, so switch sign
    end
    
    % Get some other stats and save everything to a table
    [mass_trend,ptrend] = trend(cumulativeMassChange,time);
    mass_trend = mass_trend.*365.25; % convert to Gt/yr
    rel_mass_trend = mass_trend/init_mass(i)*100;
    rel_mb_all(i,:) = table(convertCharsToStrings(L(i).Name),init_mass(i),-totalMassChange,totalMassChangeError,relMassChange,mass_trend,rel_mass_trend,ptrend); 
    
end
clear mass_trend ptrend rel_mass_trend totalMassChange relMassChange GLmass cumuGLmass cumulativeMassChange idx time init_mass

%% Plot background

% Melt rate
[M,Mx,My,~] = geoimread('basal_melt_map_racmo_firn_air_corrected.tif');
M(M<-20000) = NaN;
    
% initialise background
figure('Renderer', 'opengl','color','w','units','inches','position',[2 0 8 8]);
antbounds('coast','color','none'); hold on
% add basins
plot(basins.p1.Vertices(:,1),basins.p1.Vertices(:,2),'k');
plot(basins.p2.Vertices(:,1),basins.p2.Vertices(:,2),'k');
plot(basins.p3.Vertices(:,1),basins.p3.Vertices(:,2),'k');
plot(basins.p4.Vertices(:,1),basins.p4.Vertices(:,2),'k');
plot(basins.p5.Vertices(:,1),basins.p5.Vertices(:,2),'k');
% Overlay modis
hm = modismoaps_mask('contrast',[1 17000],'clearocean',true); hold on
ax = axis;
% Hide axis
axis off
% Change axis limits
set(gca,'XLim',[-3.1098    3.5777].*1e6);
set(gca,'YLim',[-3.5499    3.3829].*1e6);
set(gca,'XLim',[-4.5    4.5].*1e6);
set(gca,'YLim',[-4.5    4.5].*1e6);
% scalebar
%[h_sb,h_sbtext] = scalebarps;
% Overlay melt rate
h = imagesc(Mx,My,M,'alphadata',isfinite(M)); 
axis xy
daspect([1 1 1]) 
caxis([-2 2]);
mcmap = brewermap(1056,'-RdBu');
colormap(mcmap);
% Colorbar
hcb = colorbar;
set(hcb,'tickdir','out','fontsize',12,'Location','northoutside');
pos_orig = hcb.Position;
hcb.Position = [pos_orig(1)+0.08 pos_orig(2)-0.66 pos_orig(3)/7 pos_orig(4)/2];
hcb.FontSize = 7;
set(findobj(gcf,'tag','Colorbar'), 'YAxisLocation','top');
set(get(hcb,'ylabel'),'String','Basal melt rate (m yr^-^1)','fontsize',7);
cbarrow
clear M Mx My 


%% plot lines from the centre of each circle to the centroid of each ice
% shelf
skip_count = 0;
for i = 1:numel(L)
    data = table2array(rel_mb_all(i,3:5));
    if data(1)-data(2)<0 && data(1)+data(2)>0 % only plot shelves with significant mass change
        skip_count=skip_count+1;
    elseif data(3)<-200 % skip one shelf (Moubray) with unrealistic relative mass change because initial shelf size is too small
        skip_count=skip_count+1;
    else
        cum_mb = data(1);
        if cum_mb>=ulim
            col = cmap(end,:);
        elseif cum_mb<=llim
            col = cmap(1,:);
        else
            mb_diff = cum_mb-cpts;
            idx = find(abs(mb_diff) == nanmin(abs(mb_diff)));
            col = cmap(idx,:);
        end
        idx = find(strcmp(L(i).Name,shelf_names)==1);
        [cx,cy] = centroid(polyshape(GL(idx).X,GL(idx).Y));
        plot([L(i).X,cx],[L(i).Y,cy],'color',[.7 .7 .7],'linewidth',0.5,'linestyle','-','marker','none');
%         disp(['Just plotted ' L(i).Name]);
%         disp(' ');
    end
end
clear data cum_mb col idx cx cy
        
%% Plot each circle
skip_count = 0;
max_count = 0;
for i = 1:numel(L)
    
    % get data
    data = table2array(rel_mb_all(i,3:5)); % totalMassChange; TotalMassChangeError; RelativeMassChange
    
    % only plot if mass change is significant
    if data(1)-data(2)<0 && data(1)+data(2)>0
        skip_count=skip_count+1;
        skipped_shelves{skip_count} = L(i).Name;
    elseif data(3)<-200 % skip one shelf (Moubray) with unrealistic relative mass change because initial shelf size is too small
        skip_count=skip_count+1;
    else
        
        % get coordinates
        x = L(i).X;
        y = L(i).Y;
        [lat,lon] = ps2ll(x,y);

        % Determine plotting color
        cum_mb = data(1);
        if cum_mb>=ulim
            col = cmap(end,:);
        elseif cum_mb<=llim
            col = cmap(1,:);
        else
            mb_diff = cum_mb-cpts;
            idx = find(abs(mb_diff) == nanmin(abs(mb_diff)));
            col = cmap(idx,:);
        end
        
        % Set the edge color
        if cum_mb>0
            edge_col = cmap(end,:);
        else
            edge_col = cmap(1,:);
        end
        
        label_mass_change = 0;
        if abs(cum_mb)>500
            max_count=max_count+1;
            max_shelves{max_count} = L(i).Name;
            max_mb(max_count) = cum_mb;
            cum_mb = 500 * (abs(cum_mb)/cum_mb); % set upper plotting limit to 500 and keep sign
            label_mass_change = 1;
        end

        % plot
        circleps(lat,lon,sqrt(abs(cum_mb))*s,'facecolor',[1 1 1],'FaceAlpha',1,'EdgeColor','w'); 
        circleps(lat,lon,sqrt(abs(cum_mb))*s,'facecolor',col,'FaceAlpha',0.7,'EdgeColor',edge_col); % 0.7
        
        % label mass change if necessary
        if label_mass_change == 1
            if abs(max_mb(max_count))>1250 % label large shelves white and small shelves black
                txt = text(x,y+0.5e5,[num2str(round(-max_mb(max_count))) ' Gt'],'horizontalAlignment','center','color','w','fontsize',7,'interpreter','none','fontname','Lucida Sans');
                text(txt.Extent(1)+txt.Extent(3)/2,y-1e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','center','color','w','fontsize',6,'interpreter','none','fontname','Lucida Sans');
            else
                txt = text(x,y+0.5e5,[num2str(round(-max_mb(max_count))) ' Gt'],'horizontalAlignment','center','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
                text(txt.Extent(1)+txt.Extent(3)/2,y-1e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','center','color','k','fontsize',6,'interpreter','none','fontname','Lucida Sans');
            end
            edge_col = 'none';
        elseif abs(cum_mb)>400
            if abs(cum_mb)>1250 % label large shelves white and small shelves black
                txt = text(x,y+0.5e5,[num2str(round(-cum_mb)) ' Gt'],'horizontalAlignment','center','color','w','fontsize',7,'interpreter','none','fontname','Lucida Sans');
                text(txt.Extent(1)+txt.Extent(3)/2,y-1e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','center','color','w','fontsize',6,'interpreter','none','fontname','Lucida Sans');
            else
                txt = text(x,y+0.5e5,[num2str(round(-cum_mb)) ' Gt'],'horizontalAlignment','center','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
                text(txt.Extent(1)+txt.Extent(3)/2,y-1e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','center','color','k','fontsize',6,'interpreter','none','fontname','Lucida Sans');
            end
            edge_col = 'none';
        elseif abs(cum_mb)>100 || strcmp(L(i).Name,'Bach')
            text(x,y,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','center','color','k','fontsize',6,'interpreter','none','fontname','Lucida Sans');
            edge_col = 'none';
        end
        
        % Label with ice shelf name and relative mass change
        radius = sqrt(abs(cum_mb))*s*1000;
        if strcmp(label_pos{i},'CR') % centre right of dot
            txt = text(x+(radius*1.1),y,shelf_labs{i},'horizontalAlignment','left','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
            text(txt.Extent(1)+txt.Extent(3)+0.2e5,y-0.1e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','left','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
        elseif strcmp(label_pos{i},'BC') % below and centre of centre
            txt = text(x,y-(radius*0.9),shelf_labs{i},'horizontalAlignment','center','verticalAlignment','top','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
            if strcmp(L(i).Name,'Hannan') || strcmp(L(i).Name,'Flatnes')
                text(x,y-(radius*0.9)-2e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'verticalAlignment','middle','horizontalAlignment','center','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
            else
                text(txt.Extent(1)+txt.Extent(3),y-(radius*0.9),[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'verticalAlignment','top','horizontalAlignment','left','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
            end
        elseif strcmp(label_pos{i},'TC') % top and centre of dot
            txt = text(x,y+radius,shelf_labs{i},'horizontalAlignment','center','verticalAlignment','bottom','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
            text(txt.Extent(1)+txt.Extent(3),y+radius,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'verticalAlignment','bottom','horizontalAlignment','left','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
        elseif strcmp(label_pos{i},'CL') % centre left of dot
            txt = text(x-(radius*1.1),y,shelf_labs{i},'horizontalAlignment','right','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
            if strcmp(L(i).Name,'Telen')
                text(txt.Extent(1)+txt.Extent(3)/2,y-2e5,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'verticalAlignment','middle','horizontalAlignment','center','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
            else
                text(txt.Extent(1),y,[num2str(round(-table2array(rel_mb_all(i,5)))) '% '],'horizontalAlignment','right','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
            end
        elseif strcmp(label_pos{i},'C') % centre of dot
            txt = text(x,y,shelf_labs{i},'horizontalAlignment','center','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
            text(txt.Extent(1)+txt.Extent(3)+1e5,y,[num2str(round(-table2array(rel_mb_all(i,5)))) '%'],'horizontalAlignment','center','color',edge_col,'fontsize',6,'interpreter','none','fontname','Lucida Sans');
        end        
        
    end
    
end
    

% Also label cumulative mass change on colorbar
text_x = -2.7832*1e6; %3*1e5;
text_y = -3.7*1e6; % 2.5*1e5;
text(text_x,text_y-1e5,'Total mass change (Gt)','horizontalAlignment','center','color','k','fontsize',7,'interpreter','none');
%text(text_x+1.5e5,text_y-2.6e5,'change (Gt)','horizontalAlignment','center','color','k','fontsize',7,'interpreter','none');
text(text_x+0.5e6,text_y+1e5,'-2000','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none');
text(text_x-1.0e6,text_y+1.1e5,'2000','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none');

% Provide scale for circles
sc1_x = 2.1479*1e6;
sc1_y = 2.2882*1e6;
sc_x = [sc1_x,sc1_x+4e5,sc1_x+0.9e6+1e5];
sc_y = [sc1_y-10*1000, sc1_y+50*1000, sc1_y+190*1000];
[lat_legend,lon_legend] = ps2ll(sc_x,sc_y);
text_y(1) = sc_y(2);
[~,edge_x,edge_y] = circleps_edge(lat_legend(2),lon_legend(2),sqrt(50).*s,'facecolor','none','EdgeColor','k'); 
[min_y,idx] = nanmin(edge_y);
cen_y = min_y + (sqrt(200).*s*1000);
text_y(2) = cen_y;
[cen_lat,cen_lon] = ps2ll(edge_x(idx),cen_y);
circleps_edge(cen_lat,cen_lon,sqrt(200).*s,'facecolor','none','EdgeColor','k');
[min_y,idx] = nanmin(edge_y);
cen_y = min_y + (sqrt(500).*s*1000);
text_y(3) = cen_y;
[cen_lat,cen_lon] = ps2ll(edge_x(idx),cen_y);
[~,edge_x,edge_y] = circleps_edge(cen_lat,cen_lon,sqrt(500).*s,'facecolor','none','EdgeColor','k'); 
max_x = nanmax(edge_x);
[lat_label,lon_label] = ps2ll([max_x,max_x,max_x]+0.5e5,[text_y(1),text_y(2)+0.5e5,text_y(3)+1e5]);
textps(lat_label,lon_label,{'50 Gt';'200';'500'},'horizontalAlignment','left','color','k','fontsize',7); 


%% Save
export_fig('cumulative_ice_shelf_mass_change.png','-dpng','-r1800');
exportgraphics(gcf,'cumulative_ice_shelf_mass_change.pdf','ContentType','vector')
    