% plot_cumulative_mass_change_timeseries

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));


%% Load grounding line

load('../../grounding_line_discharge/flux_gates/GL_consolidated_200m.mat');

% Set shelves to plot and labels
load('shelves_to_plot.mat'); % same as above but ordered clockwise from Larsen A

% also load initial ice shelf mass
load('init_mass_greene.mat','init_mass');

%% Define Groups

% Peninsula
peninsula = {'Larsen_A','Larsen_B','Larsen_C','Wordie','Wilkins',...
    'Rydberg_Peninsula_2','Verdi','Britten','Bach','Stange'};
peninsula_labels = {' ',' ','Larsen C','Wordie','Wilkins',...
    ' ',' ',' ',' ',' '};

% Amundsen
amundsen = {'Ferrigno','Thomson','Eltanin_Bay','Alison','Venable',...
    'Fox_Ice_Stream','Abbot','Pine_Island','Walgreen_Coast_2','Crosson',...
    'Hummer_Point','Thwaites','Hamilton_Piedmont','Getz','Perkins',...
    'Dotson','Philbin_Inlet','Harmon_Bay','Land','Jackson','Rose_Point',...
    'Garfield'};
amundsen_labels = {' ',' ',' ',' ',' ',...
    ' ',' ','PIG',' ','Crosson',...
    ' ','Thwaites',' ','Getz',' ',...
    ' ',' ',' ',' ',' ',' ',...
    ' '};

% Wilkes
wilkes = {'Ross_East','Marin','Campbell','Geikie_Inlet','Mcleod','Andreyev',...
    'Frost','Fitzgerald','Tinker','Falkner','Ironside','Tucker','Suter',...
    'Moubray','Gillet','Gannutz','Lillie','Chugunov','Drury','Wylde','Kirkby',...
    'Matusevitch','HornBluff','Fisher','Cook','Slava','Deakin','Ainsworth',...
    'Zelee','Mertz','Watt_Bay','Marret','Astrolabe','Ninnis','Liotard',...
    'May_Glacier','Commandant_Charcot','Morse','Pourquoi_Pas','Holmes',...
    'Sandford','Voyeykov','Whittle','Vincennes_Bay','Underwood'};
wilkes_labels = {' ',' ',' ',' ',' ',' ',...
    'Frost',' ',' ',' ',' ',' ',' ',...
    ' ',' ',' ',' ',' ',' ',' ',' ',...
    ' ',' ',' ','Cook','Slava',' ',' ',...
    ' ','Mertz',' ',' ',' ',' ',' ',...
    ' ',' ',' ',' ',' ',...
    ' ',' ','Whittle',' ',' '};

% Amery
amery = {'Conger_Glenzer','Tracy_Tremenchus','West','Hovde','Flatnes','Dalk',...
    'Amery','Rund_Bay','Wilma_Robert_Downer','Myers','Porter','Hannan',...
    'Telen','Skallen'};
amery_labels = {' ',' ','West',' ',' ',' ',...
    'Amery',' ','WRD',' ',' ',' ',...
    ' ',' '};

% Weddell
weddell = {'Baudouin','Fimbul','Jelbart','Atka','Quar','Riiser_Larsen',...
    'Brunt_Stancomb','Filchner','Hayes_Coats_Coast','Ronne'};
weddell_labels = {' ',' ',' ',' ',' ',' ',...
    'Brunt','Filchner',' ','Ronne'};



%% Prepare colormaps and plotting parameters

% Colorbar
ulim = 2000;
llim = -2000;
cmap = flipud(cbrewer('div','RdBu',length(llim:ulim)));
cpts = llim:ulim;

% Scaling for ice shelf circles
s = 16; % 8 for rel mb; 60 for rel mb trend

% load ice shelf locations
L = shaperead('ice_shelf_circle_locs_manual.shp');

%% Get data for each shelf

% pre-allocate
cum_mb_all = zeros([numel(L),25]).*NaN;
cum_mb_err_all = zeros([numel(L),25]).*NaN;
col_all = zeros([numel(L),3]).*NaN;

% Enter loops
for i = 1:numel(L)
    
    % load data
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' L(i).Name '_mass_balance_noel_update_v2.mat'],'totalMassChange','totalMassChangeError','cumulativeMassChange','cumulativeMassChangeError','time');
    
    if strcmp(L(i).Name,'Pine_Island') || strcmp(L(i).Name,'Thwaites') || strcmp(L(i).Name,'Crosson') || strcmp(L(i).Name,'Dotson')
        GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
        idx = find(contains(GLmass.ASE_shelves,L(i).Name)==1);
        totalMassChange = totalMassChange + GLmass.mass_change_GL(idx);
        cumuGLmass = linspace(0,GLmass.mass_change_GL(idx),length(cumulativeMassChange));
        cumulativeMassChange = cumulativeMassChange + cumuGLmass;
    end
    
    % Get color
    totalMassChange = totalMassChange*-1;
    if totalMassChange>=ulim
        col = cmap(end,:);
    elseif totalMassChange<=llim
        col = cmap(1,:);
    else
        mb_diff = totalMassChange-cpts;
        idx = find(abs(mb_diff) == nanmin(abs(mb_diff)));
        col = cmap(idx,:);
    end
    
    % save cumualtive mass changes
    cum_mb_all(i,:) = cumulativeMassChange;
    cum_mb_err_all(i,:) = cumulativeMassChangeError;

    col_all(i,:) = col;
    
    % Keep names
    L_names{i} = L(i).Name;
    
end

%% Get indices for each group
for i = 1:numel(peninsula)
    peninsula_idx(i) = find(strcmp(peninsula{i},L_names)==1);
end
for i = 1:numel(amundsen)
    amundsen_idx(i) = find(strcmp(amundsen{i},L_names)==1);
end
for i = 1:numel(wilkes)
    wilkes_idx(i) = find(strcmp(wilkes{i},L_names)==1);
end
for i = 1:numel(amery)
    amery_idx(i) = find(strcmp(amery{i},L_names)==1);
end
for i = 1:numel(weddell)
    weddell_idx(i) = find(strcmp(weddell{i},L_names)==1);
end

%% Plot groups of ice shelves

cum_mb_all = cum_mb_all./1000; % then need to label y axis (1000 Gt) or similar
cum_mb_err_all = cum_mb_err_all./1000;

% Plot total as timeseries
figure('color','w','units','inches','position',[1 1 3.8 1.05]);
cmap = cbrewer('qual','Set2',5);
plot([time(1) time(end)],[0 0],'color','k','linestyle','--'); hold on; datetick('x');
plot(time,sum(cum_mb_all(amery_idx,:),1),'color',cmap(1,:),'linewidth',1.5); 
plot(time,sum(cum_mb_all(wilkes_idx,:),1),'color',cmap(2,:),'linewidth',1.5);
plot(time,sum(cum_mb_all(weddell_idx,:),1),'color',cmap(3,:),'linewidth',1.5);
plot(time,sum(cum_mb_all(peninsula_idx,:),1),'color',cmap(4,:),'linewidth',1.5);
plot(time,sum(cum_mb_all(amundsen_idx,:),1),'color',cmap(5,:),'linewidth',1.5);
plot([time(1) time(end)],[0 0],'color','k','linestyle','--');
sb6 = shadedErrorBar(time,sum(cum_mb_all,1),rssq(cum_mb_err_all,1),'patchSaturation',0.1); 
text(time(end)+50,sum(cum_mb_all(peninsula_idx,end),1),'Peninsula','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
text(time(end)+50,sum(cum_mb_all(amundsen_idx,end),1),'Amundsen','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
text(time(end)+50,sum(cum_mb_all(wilkes_idx,end),1),'Wilkes','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
text(time(end)+50,sum(cum_mb_all(weddell_idx,end),1),'Weddell','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
text(time(end)+50,sum(cum_mb_all(amery_idx,end),1),'Amery','horizontalAlignment','left','color','k','fontsize',7,'interpreter','none','fontname','Lucida Sans');
xlim([min(time) max(time)]);
set(gca,'Units','Inches')
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2) 1.8 pos(4)]); 
box on
export_fig('AIS_cumulative_mass_timeseries.png','-dpng','-r1800');

% Peninsula
figure('color','w','units','inches','position',[1 1 3.8 0.9]);
plot([time(1), time(end)],[0 0],'k--'); hold on; datetick('x');
for i = 1:numel(peninsula)
    idx = find(strcmp(peninsula{i},L_names)==1);
    plot(time,cum_mb_all(idx,:),'color',col_all(idx,:),'linewidth',1,'linestyle','-','marker','none'); 
    text(time(end)+50,cum_mb_all(idx,end),peninsula_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
end
plot([time(1), time(end)],[0 0],'k--');
xlim([min(time) max(time)]);
%set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2) 1.8 pos(4)]); 
export_fig('peninsula_cumulative_mass_timeseries.png','-dpng','-r1800');

% Amundsen
figure('color','w','units','inches','position',[1 1 3.8 0.9]);
plot([time(1), time(end)],[0 0],'k--'); hold on; datetick('x');
for i = 1:numel(amundsen)
    idx = find(strcmp(amundsen{i},L_names)==1);
    plot(time,cum_mb_all(idx,:),'color',col_all(idx,:),'linewidth',1,'linestyle','-','marker','none'); 
    if strcmp(amundsen_labels{i},'PIG')
        text(time(end)+50,cum_mb_all(idx,end)+200,amundsen_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    else
        text(time(end)+50,cum_mb_all(idx,end),amundsen_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    end
end
plot([time(1), time(end)],[0 0],'k--');
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2) 1.8 pos(4)]); 
export_fig('amundsen_cumulative_mass_timeseries.png','-dpng','-r1800');

% wilkes
figure('color','w','units','inches','position',[1 1 3.8 0.9]);
plot([time(1), time(end)],[0 0],'k--'); hold on; datetick('x');
for i = 1:numel(wilkes)
    idx = find(strcmp(wilkes{i},L_names)==1);
    plot(time,cum_mb_all(idx,:),'color',col_all(idx,:),'linewidth',1,'linestyle','-','marker','none'); 
    if strcmp(wilkes_labels{i},'Whittle')
        text(time(end)+50,cum_mb_all(idx,end)-75,wilkes_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    else
        text(time(end)+50,cum_mb_all(idx,end),wilkes_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    end
end
plot([time(1), time(end)],[0 0],'k--');
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2) 1.8 pos(4)]); 
export_fig('wilkes_cumulative_mass_timeseries.png','-dpng','-r1800');


% Amery
figure('color','w','units','inches','position',[1 1 3.8 0.9]);
plot([time(1), time(end)],[0 0],'k--'); hold on; datetick('x');
for i = 1:numel(amery)
    idx = find(strcmp(amery{i},L_names)==1);
    plot(time,cum_mb_all(idx,:),'color',col_all(idx,:),'linewidth',1,'linestyle','-','marker','none'); 
    text(time(end)+50,cum_mb_all(idx,end),amery_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
end
plot([time(1), time(end)],[0 0],'k--');
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2) 1.8 pos(4)]); 
export_fig('amery_cumulative_mass_timeseries.png','-dpng','-r1800');

% Weddell
figure('color','w','units','inches','position',[1 1 3.8 0.9]);
plot([time(1), time(end)],[0 0],'k--'); hold on; datetick('x');
for i = 1:numel(weddell)
    idx = find(strcmp(weddell{i},L_names)==1);
    plot(time,cum_mb_all(idx,:),'color',col_all(idx,:),'linewidth',1,'linestyle','-','marker','none'); 
    if strcmp(weddell_labels{i},'Ronne')
        text(time(end)+50,cum_mb_all(idx,end)-150,weddell_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    elseif strcmp(weddell_labels{i},'Brunt')
        text(time(end)+50,cum_mb_all(idx,end)+150,weddell_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    else
        text(time(end)+50,cum_mb_all(idx,end),weddell_labels{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
    end
end
plot([time(1), time(end)],[0 0],'k--');
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
pos = get(gca,'Position');
set(gca,'Position',[pos(1) pos(2) 1.8 pos(4)]); 
export_fig('weddell_cumulative_mass_timeseries.png','-dpng','-r1800');
