% plot_freshwater_flux_manual

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

%% Load grounding line

load('../../grounding_line_discharge/flux_gates/GL_consolidated_200m.mat');

% Set shelves to plot and labels
load('shelves_to_plot.mat'); % same as above but ordered clockwise from Larsen A


% Load basin groups
basins = load('merged_imbie_basins.mat');

%% Prepare colormaps and plotting parameters

% colors
edge_col = [0 0 0];
calv_col = [0 0 0];
melt_col = [93,138,168]./255;
pie_col = {calv_col,melt_col};
pie_alpha = {.7,.7};

% Scaling for ice shelf circles
s = 5;

% load ice shelf locations
L = shaperead('ice_shelf_circle_locs_manual_fw.shp');

%% Prepare labels

% Change a few labels
shelf_labs{4} = 'LD';
shelf_labs{5} = 'LE';
shelf_labs{55} = 'Moscow';
shelf_labs{23} = 'Borchgrevink';

% positive (vert,horiz) e.g. CR = centre right of dot; BC = below and
% centre of dot)
label_pos = {'CR','CR','CR','CR','CR','LarsenF','Clarke_Bay','LarsenG',... % last one is Larsen G
    'TC','TC','CR','DawsonLambton','CL','CL','CL','CL','CL','CL','TC','CL',... % Vigrid
    'CR','TC','CR','CR','CR','CR','CL','CL','CR',... % Rayner
    'Zubchatyy','CR','CR','CL','CR','CR','Hoseason','CirqueFjord',... % cirque fjord
    'CR','Utsikkar','CR','CR','CR','BC','CR','Sorsdal','CR',... % West
    'CL','CR','CR','CL','CR','CR','CR','CR','CR','TC',... % Voyeykov
    'CR','TC','CR','CR','CR','CR','CR','CR','BC','CR','BC',... % Liotard
    'CR','BC','BC','BC','BC','BC','BC','BC','BC','TC','BC','TC',... % Andreyev
    'CL','CL','BC','TC','Noll','CL','Suvorov','TC',... % Rennic
    'CL','Barber','CL','CL','BC','Smith_Inlet','Dennistoun',... % Dennistoun
    'CL','Quatermain','CL','Manhaul','CL','MandibleCirque','CL',... % Mariner
    'CL','BC','CL','CL','Parker','Aviator','CL','CapeWashington','CR',... % Campbell
    'Nansen','CL','CR','Cheetham','Harbord Glacier','CR',... % Marin
    'Nordenskjold','TC','C','Hamilton','Withrow','Richter',... % Richter
    'BC','TC','BC','TC','BC','CL','CL','CL',... % Rose Point
    'BC','BC','CL','BC','CL','CR','CL','BC','BC','CL','Walgreen Coast 1','CL',... % Walgreen Coast 2
    'CR','CL','CL','CL','CL','CR','CL','CL','RydbergPeninsula 1',... % Rydberg Peninsula 2
    'CL','CL','CL','CL','BC','CL','CL','CL','CL',... % Wilkins
    'CL','TC'};

%% Get data for each shelf

% pre-allocate
calving_all = zeros([numel(L),25]).*NaN;
melt_all = zeros([numel(L),25]).*NaN;
fw_all = zeros([numel(L),25]).*NaN;

% Enter loops
for i = 1:numel(L)
    
    % load data
    load(['../../mass_balance/individual_shelf_freshwater_flux_200m/' L(i).Name '_freshwater_flux_noel_update.mat'],'cumulativeMeltFlux','cumulativeCalvingFlux','cumulativeFreshwaterFlux','time');
    
    % Checks
    tf = cumulativeMeltFlux<0;
    cumulativeMeltFlux(tf) = 0;
    cumulativeCalvingFlux(tf) = cumulativeFreshwaterFlux(tf);
    tf = cumulativeCalvingFlux<0;
    cumulativeCalvingFlux(tf) = 0;
    cumulativeMeltFlux(tf) = cumulativeFreshwaterFlux(tf);
    
    % keep
    calving_all(i,:) = cumulativeCalvingFlux;
    melt_all(i,:) = cumulativeMeltFlux;
    fw_all(i,:) = cumulativeFreshwaterFlux;
    
end

%% Plot background

% Melt rate
[M,Mx,My,~] = geoimread('basal_melt_map_racmo_firn_air_corrected.tif');
M(M<-20000) = NaN;
    
% initialise background
figure('Renderer', 'opengl','color','w','units','inches','position',[2 0 8 8]);
antbounds('coast','color','none'); hold on
% Overlay modis
hm = modismoaps('contrast',[1 17000],'clearocean',true); hold on
ax = axis;
% Hide axis
axis off
% Change axis limits
set(gca,'XLim',[-3.1098    3.5777].*1e6);
set(gca,'YLim',[-3.5499    3.3829].*1e6);
set(gca,'XLim',[-4.5    4.5].*1e6);
set(gca,'YLim',[-4.5    4.5].*1e6);
% scalebar
%[h_sb,h_sbtext] = scalebarps;
% Overlay melt rate
h = imagesc(Mx,My,M,'alphadata',isfinite(M)); 
axis xy
daspect([1 1 1]) 
caxis([-2 2]);
mcmap = brewermap(1056,'-RdBu');
colormap(mcmap);
% and grounding line
antbounds('gl','color','none');
% add basins
plot(basins.p1.Vertices(:,1),basins.p1.Vertices(:,2),'k');
plot(basins.p2.Vertices(:,1),basins.p2.Vertices(:,2),'k');
plot(basins.p3.Vertices(:,1),basins.p3.Vertices(:,2),'k');
plot(basins.p4.Vertices(:,1),basins.p4.Vertices(:,2),'k');
plot(basins.p5.Vertices(:,1),basins.p5.Vertices(:,2),'k');
% Colorbar
hcb = colorbar;
set(hcb,'tickdir','out','fontsize',12,'Location','northoutside');
pos_orig = hcb.Position;
hcb.Position = [pos_orig(1)+0.14 pos_orig(2)-0.64 pos_orig(3)/7 pos_orig(4)/2];
hcb.FontSize = 7;
set(findobj(gcf,'tag','Colorbar'), 'YAxisLocation','top');
set(get(hcb,'ylabel'),'String','Basal melt rate (m yr^-^1)','fontsize',8);
cbarrow


%% plot lines from the centre of each circle to the centroid of each ice
% shelf
for i = 1:numel(L)
    if fw_all(i,end) > 50
        idx = find(strcmp(L(i).Name,shelf_names)==1);
        [cx,cy] = centroid(polyshape(GL(idx).X,GL(idx).Y));
        plot([L(i).X,cx],[L(i).Y,cy],'color',[.7 .7 .7],'linewidth',1,'linestyle','-','marker','none');
    end
end
        
%% Plot each circle
skip_count = 0;
for i = 1:numel(L)
    
    % get data
    total_fw = fw_all(i,end); 
    total_calv = calving_all(i,end);
    total_melt = melt_all(i,end);
    prop = [total_calv/total_fw, total_melt/total_fw];
        
    % get coordinates of circle
    x = L(i).X;
    y = L(i).Y;
    [lat,lon] = ps2ll(x,y);

    % plot
    if total_fw > 50
        pieps_edge(lat,lon,sqrt(abs(total_fw))*s,prop,'facecolor',pie_col,'facealpha',pie_alpha,'EdgeColor',edge_col); 


        % Label
        radius = sqrt(abs(total_fw))*s*1000;
        if strcmp(shelf_labs{i},'Thwaites') || strcmp(shelf_labs{i},'Getz')
            radius = radius*1.2; % give thwaites a bit of breathing space
        end
        if strcmp(label_pos{i},'CR') % centre right of dot
            text(x+(radius*1.1),y,shelf_labs{i},'horizontalAlignment','left','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        elseif strcmp(label_pos{i},'BC') % below and centre of centre
            text(x,y-(radius*0.7),shelf_labs{i},'horizontalAlignment','center','verticalAlignment','top','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        elseif strcmp(label_pos{i},'TC') % top and centre of dot
            text(x,y+radius,shelf_labs{i},'horizontalAlignment','center','verticalAlignment','bottom','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        elseif strcmp(label_pos{i},'CL') % centre left of dot
            text(x-(radius*1.1),y,shelf_labs{i},'horizontalAlignment','right','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        elseif strcmp(label_pos{i},'C') % centre of dot
            text(x,y,shelf_labs{i},'horizontalAlignment','center','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        else
            disp(['no label pos for ' L(i).Name]);
            text(x,y,L(i).Name,'horizontalAlignment','center','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        end
        
    end
    
end
    

% Provide scale for circles
sc1_x = 1.6*1e6;
sc1_y = -3.0*1e6;
sc_x = [sc1_x+3.5e5,sc1_x+7.5e5,sc1_x+1.25e6+1e5];
sc_y = [sc1_y+80*1000, sc1_y+180*1000, sc1_y+350*1000];
sc_y = sc_y-2e5;
[lat_legend,lon_legend] = ps2ll(sc_x,sc_y);
% Plot circles of radii 1,10,100 Gt: 
circleps(lat_legend([1,2]),lon_legend([1,2]),sqrt([100,1000]).*s,'facecolor','w','EdgeColor','k') 
pieps_edge(lat_legend(3),lon_legend(3),sqrt(4000).*s,[0.6,0.4],'facecolor',pie_col,'facealpha',{1, 1},'edgecolor',edge_col);
% Label the circles:
[lat_label,lon_label] = ps2ll(sc_x,[sc_y(1),sc_y(1),sc_y(1)]-1.5e5);
textps(lat_label,lon_label,{'100';'1000';'4000 Gt'},'horizontalAlignment','center','color','k','fontsize',8); 


%% Save
export_fig('ice_shelf_freshwater_flux.png','-dpng','-r1800');
exportgraphics(gcf,'ice_shelf_freshwater_flux.pdf','ContentType','vector')
    