% plot_freshwater_timeseries

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));


%% Load grounding line

load('../../grounding_line_discharge/flux_gates/GL_consolidated_200m.mat');

% Set shelves to plot and labels
load('shelves_to_plot.mat'); % same as above but ordered clockwise from Larsen A

% load ice shelf locations
L = shaperead('ice_shelf_circle_locs_manual_fw.shp');

%% Define Groups

% Peninsula
peninsula = {'Larsen_G','Larsen_F','Clarke_Bay','Larsen_E','Larsen_D',...
    'Larsen_C','Larsen_B','Larsen_A','Wordie','George_VI','Wilkins',...
    'Mendelssohn','Brahms','Verdi','Bach','Britten','Stange',...
    'Rydberg_Peninsula_1','Rydberg_Peninsula_2'};
peninsula_labels = {'Larsen_G','Larsen_F','Clarke_Bay','Larsen_E','Larsen_D',...
    'Larsen_C','Larsen_B','Larsen_A','Wordie','George_VI','Wilkins',...
    'Mendelssohn','Brahms','Verdi','Bach','Britten','Stange',...
    'Rydberg_Peninsula_1','Rydberg_Peninsula_2'};

% Amundsen
amundsen = {'Eltanin_Bay','Alison','Ferrigno','Venable','Abbot','Cosgrove',...
    'Pine_Island','Walgreen_Coast_1','Walgreen_Coast_2','Thwaites','Crosson',...
    'Dotson','Hamilton_Piedmont','Hummer_Point','Harmon_Bay','Getz','Jackson',...
    'Rose_Point','Perkins','Garfield','Hull','Land','Nickerson','Sulzberger',...
    'Swinburne','Richter','Withrow','Hamilton','Ross_West'};
amundsen_labels = {'Eltanin_Bay','ALison','Ferrigno','Venable','Abbot','Cosgrove',...
    'Pine_Island','Walgreen_Coast_1','Walgreen_Coast_2','Thwaites','Crosson',...
    'Dotson','Hamilton_Piedmont','Hummer_Point','Harmon_Bay','Getz','Jackson',...
    'Rose_Point','Perkins','Garfield','Hull','Land','Nickerson','Sulzberger',...
    'Swinburne','Richter','Withrow','Hamilton','Ross_West'};

% Wilkes
wilkes = {'Ross_East','Nordenskjold','Marin','Harbord Glacier','Cheetham',...
    'Geikie_Inlet','Drygalski','Nansen','Campbell','Cape_Washington','Tinker',...
    'Aviator','Parker','Fitzgerald','Falkner','Mariner','Mandible_Cirque','Tucker',...
    'Manhaul','Ironside','Quatermain_Point','Moubray','Dennistoun','Smith_Inlet',...
    'Kirkby','Lillie','Chugunov','Barber','Rennick','Gannutz','Suvorov','Gillet',...
    'Noll','Mcleod','Matusevitch','Drury','Lauritzen','Andreyev','Slava','Cook',...
    'Deakin','Ninnis','Ainsworth','HornBluff','Fisher','Mertz','Watt_Bay','Zelee',...
    'Astrolabe','Francais','Liotard','Marret','Commandant_Charcot','Pourquoi_Pas',...
    'Dibble','May_Glacier','Morse','Sandford','Frost','Holmes','Voyeykov','Moscow_University',...
    'Totten','Whittle','Vincennes_Bay','Underwood'};
wilkes_labels = {'Ross_East','Nordenskjold','Marin','Harbord Glacier','Cheetham',...
    'Geikie_Inlet','Drygalski','Nansen','Campbell','Cape_Washington','Tinker',...
    'Aviator','Parker','Fitzgerald','Falkner','Mariner','Mandible_Cirque','Tucker',...
    'Manhaul','Ironside','Quatermain_Point','Moubray','Dennistoun','Smith_Inlet',...
    'Kirkby','Lillie','Chugunov','Barber','Rennick','Gannutz','Suvorov','Gillet',...
    'Noll','Mcleod','Matusevitch','Drury','Lauritzen','Andreyev','Slava','Cook',...
    'Deakin','Ninnis','Ainsworth','HornBluff','Fisher','Mertz','Watt_Bay','Zelee',...
    'Astrolabe','Francais','Liotard','Marret','Commandant_Charcot','Pourquoi_Pas',...
    'Dibble','May_Glacier','Morse','Sandford','Frost','Holmes','Voyeykov','Moscow_University',...
    'Totten','Whittle','Vincennes_Bay','Underwood'};

% Amery
amery = {'Conger_Glenzer','Tracy_Tremenchus','West','Hovde','Flatnes','Dalk',...
    'Amery','Rund_Bay','Wilma_Robert_Downer','Myers','Porter','Hannan',...
    'Telen','Skallen','Helen','Sorsdal','Publications','Utsikkar','Mulebreen',...
    'Cirque_Fjord','Hoseason','Edward_VIII','Zubchatyy','Rayner_Thyer','Shirase',...
    'Prince_Harald'};
amery_labels = {'Conger_Glenzer','Tracy_Tremenchus','West','Hovde','Flatnes','Dalk',...
    'Amery','Rund_Bay','Wilma_Robert_Downer','Myers','Porter','Hannan',...
    'Telen','Skallen','Helen','Sorsdal','Publications','Utsikkar','Mulebreen',...
    'Cirque_Fjord','Hoseason','Edward_VIII','Zubchatyy','Rayner_Thyer','Shirase',...
    'Prince_Harald'};

% Weddell
weddell = {'Baudouin','Borchgrevink','Lazarev','Nivl','Vigrid','Fimbul','Jelbart',...
    'Atka','Ekstrom','Quar','Riiser_Larsen','Brunt_Stancomb','Filchner','Hayes_Coats_Coast',...
    'Dawson_Lambton','Ronne'};
weddell_labels = {'Baudouin','Borchgrevink','Lazarev','Nivl','Vigrid','Fimbul','Jelbart',...
    'Atka','Ekstrom','Quar','Riiser_Larsen','Brunt_Stancomb','Filchner','Hayes_Coats_Coast',...
    'Dawson_Lambton','Ronne'};



%% Get data for each shelf

% pre-allocate
calving_all = zeros([numel(L),25]).*NaN;
melt_all = zeros([numel(L),25]).*NaN;
fw_all = zeros([numel(L),25]).*NaN;
calving_err_all = zeros([numel(L),25]).*NaN;
melt_err_all = zeros([numel(L),25]).*NaN;
fw_err_all = zeros([numel(L),25]).*NaN;

% Enter loops
for i = 1:numel(L)
    
    % load data
    load(['../../mass_balance/individual_shelf_freshwater_flux_200m/' L(i).Name '_freshwater_flux_noel_update.mat'],...
        'cumulativeMeltFlux','cumulativeMeltFluxError','cumulativeCalvingFlux','cumulativeCalvingFluxError',...
        'cumulativeFreshwaterFlux','cumulativeFreshwaterFluxError','time');
    
    % keep
    calving_all(i,:) = cumulativeCalvingFlux;
    melt_all(i,:) = cumulativeMeltFlux;
    fw_all(i,:) = cumulativeFreshwaterFlux;
    calving_err_all(i,:) = cumulativeCalvingFlux;
    melt_err_all(i,:) = cumulativeMeltFlux;
    fw_err_all(i,:) = cumulativeFreshwaterFlux;
    
    % Keep names
    L_names{i} = L(i).Name;
    
end

% Get totals for each region
clear idx
for i = 1:numel(peninsula)
    idx(i) = find(strcmp(peninsula{i},L_names)==1);
end
peninsula_calving = nansum(calving_all(idx,:),1);
peninsula_melt = nansum(melt_all(idx,:),1);
peninsula_fw = nansum(fw_all(idx,:),1);
peninsula_calving_err = rssq(calving_all(idx,:),1);
peninsula_melt_err = rssq(melt_all(idx,:),1);
peninsula_fw_err = rssq(fw_all(idx,:),1);

clear idx
for i = 1:numel(amundsen)
    idx(i) = find(strcmp(amundsen{i},L_names)==1);
end
amundsen_calving = nansum(calving_all(idx,:),1);
amundsen_melt = nansum(melt_all(idx,:),1);
amundsen_fw = nansum(fw_all(idx,:),1);
amundsen_calving_err = rssq(calving_all(idx,:),1);
amundsen_melt_err = rssq(melt_all(idx,:),1);
amundsen_fw_err = rssq(fw_all(idx,:),1);

clear idx
for i = 1:numel(wilkes)
    idx(i) = find(strcmp(wilkes{i},L_names)==1);
end
wilkes_calving = nansum(calving_all(idx,:),1);
wilkes_melt = nansum(melt_all(idx,:),1);
wilkes_fw = nansum(fw_all(idx,:),1);
wilkes_calving_err = rssq(calving_all(idx,:),1);
wilkes_melt_err = rssq(melt_all(idx,:),1);
wilkes_fw_err = rssq(fw_all(idx,:),1);

clear idx
for i = 1:numel(amery)
    idx(i) = find(strcmp(amery{i},L_names)==1);
end
amery_calving = nansum(calving_all(idx,:),1);
amery_melt = nansum(melt_all(idx,:),1);
amery_fw = nansum(fw_all(idx,:),1);
amery_calving_err = rssq(calving_all(idx,:),1);
amery_melt_err = rssq(melt_all(idx,:),1);
amery_fw_err = rssq(fw_all(idx,:),1);

clear idx
for i = 1:numel(weddell)
    idx(i) = find(strcmp(weddell{i},L_names)==1);
end
weddell_calving = nansum(calving_all(idx,:),1);
weddell_melt = nansum(melt_all(idx,:),1);
weddell_fw = nansum(fw_all(idx,:),1);
weddell_calving_err = rssq(calving_all(idx,:),1);
weddell_melt_err = rssq(melt_all(idx,:),1);
weddell_fw_err = rssq(fw_all(idx,:),1);


%% Plot groups of ice shelves

% Peninsula
figure('color','w','units','inches','position',[1 1 2.8 0.8]);
H = shadedErrorBar(time,peninsula_calving./1000,peninsula_calving_err./1000,'lineProps','-k'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
hold on; datetick('x');
H = shadedErrorBar(time,peninsula_melt./1000,peninsula_melt_err./1000,'lineProps',{'color',[93,138,168]./255}); % calving total for region
H.mainLine.LineWidth = 2;
H.patch.FaceAlpha = 0.6;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
H = shadedErrorBar(time,peninsula_fw./1000,peninsula_fw_err./1000,'lineProps','r'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
xlim([min(time) max(time)]);
%set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
box on
export_fig('peninsula_freshwater_timeseries.png','-dpng','-r1800');

% Amundsen
figure('color','w','units','inches','position',[1 1 2.8 0.8]);
H = shadedErrorBar(time,amundsen_calving./1000,amundsen_calving_err./1000,'lineProps','-k'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
hold on; datetick('x');
H = shadedErrorBar(time,amundsen_melt./1000,amundsen_melt_err./1000,'lineProps',{'color',[93,138,168]./255}); % calving total for region
H.mainLine.LineWidth = 2;
H.patch.FaceAlpha = 0.6;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
H = shadedErrorBar(time,amundsen_fw./1000,amundsen_fw_err./1000,'lineProps','r'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
box on
export_fig('amundsen_freshwater_timeseries.png','-dpng','-r1800');

% wilkes
figure('color','w','units','inches','position',[1 1 2.8 0.8]);
H = shadedErrorBar(time,wilkes_calving./1000,wilkes_calving_err./1000,'lineProps','-k'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
hold on; datetick('x');
H = shadedErrorBar(time,wilkes_melt./1000,wilkes_melt_err./1000,'lineProps',{'color',[93,138,168]./255}); % calving total for region
H.mainLine.LineWidth = 2;
H.patch.FaceAlpha = 0.6;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
H = shadedErrorBar(time,wilkes_fw./1000,wilkes_fw_err./1000,'lineProps','r'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
box on
export_fig('wilkes_freshwater_timeseries.png','-dpng','-r1800');


% Amery
figure('color','w','units','inches','position',[1 1 2.8 0.8]);
H = shadedErrorBar(time,amery_calving./1000,amery_calving_err./1000,'lineProps','-k'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
hold on; datetick('x');
H = shadedErrorBar(time,amery_melt./1000,amery_melt_err./1000,'lineProps',{'color',[93,138,168]./255}); % calving total for region
H.mainLine.LineWidth = 2;
H.patch.FaceAlpha = 0.6;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
H = shadedErrorBar(time,amery_fw./1000,amery_fw_err./1000,'lineProps','r'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
box on
export_fig('amery_freshwater_timeseries.png','-dpng','-r1800');

% Weddel
figure('color','w','units','inches','position',[1 1 2.8 0.8]);
H = shadedErrorBar(time,weddell_calving./1000,weddell_calving_err./1000,'lineProps','-k'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
hold on; datetick('x');
H = shadedErrorBar(time,weddell_melt./1000,weddell_melt_err./1000,'lineProps',{'color',[93,138,168]./255}); % calving total for region
H.mainLine.LineWidth = 2;
H.patch.FaceAlpha = 0.6;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
H = shadedErrorBar(time,weddell_fw./1000,weddell_fw_err./1000,'lineProps','r'); % calving total for region
H.mainLine.LineWidth = 1.5;
H.edge(1).Color = 'none';
H.edge(2).Color = 'none';
xlim([min(time) max(time)]);
set(gca,'XTickLabel',{' '});
set(gca,'Units','Inches')
box on
export_fig('weddell_freshwater_timeseries.png','-dpng','-r1800');
