% plot_ice_shelf_SMB_change_area_chart

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));


%% Load GL structure - contains name and xy coordinates of all shelf
load('GL_consolidated_200m.mat');
BF = load('../../partitioning/balance_fluxes.mat');

%% Make data cube

smb_all = zeros([numel(GL),298]).*NaN;
for i = 1:numel(GL)
    shelf_name = GL(i).Name;
    if i == 1
        load(['../../SMB/individual_ice_shelf_SMB_ensemble/' shelf_name '_SMB_ensemble.mat'],'smb_ts','smb_clim_ts','time');
    else
        load(['../../SMB/individual_ice_shelf_SMB_ensemble/' shelf_name '_SMB_ensemble.mat'],'smb_ts','smb_clim_ts');
    end
    %if i == 1
    %    clim_idx = find(time>=datenum(1979,1,1) & time<datenum(2009,1,1));
    %end
    %if strcmp(shelf_name,'Larsen_B') % the balance flux is calcualted over the union mask, which is big for Larsen B
    %    base = nanmean(smb_ts(clim_idx));
    %else
    %    base = BF.balance_smb(i);
    %end
    smb_change = smb_ts-smb_clim_ts;
    if i == 1
        sample_idx = find(time>=datenum(1997,3,1));
        time = time(sample_idx);
    end
    smb_change = smb_change(sample_idx);
    smb_all(i,:) = cumsum(smb_change./12);
end

% Calculate overall Antarctic ice shelf discharge change
smb_tot = nansum(smb_all,1);

% Sort by overall discharge change
[~,iv] = sort(smb_all(:,end));
smb_sort = smb_all(iv,:);

% Split shelves that have (overall) gained or lost mass
lo = smb_sort(:,end)<0;
hi = smb_sort(:,end)>0;
smb_lo = smb_sort(lo,:);
smb_hi = smb_sort(hi,:);
iv_lo = iv(lo);
iv_hi = iv(hi);

% Rotate for plotting
smb_lo = fliplr(smb_lo'); % also flip so largest overall change is at bottom
smb_hi = smb_hi';
iv_lo = flipud(iv_lo);

%% Plot prep

% Colors
cmap_hi = cmocean('balance',12*2);
cmap_hi = cmap_hi(2:12,:);
a = linspace(cmap_hi(6,1),cmap_hi(end,1),size(smb_hi,2)-5);
b = linspace(cmap_hi(6,2),cmap_hi(end,2),size(smb_hi,2)-5);
c = linspace(cmap_hi(6,3),cmap_hi(end,3),size(smb_hi,2)-5);
cmap_hi = [cmap_hi(1:5,:);[a(:),b(:),c(:)]];
cmap_hi = flipud(cmap_hi);
cmap_lo = cmocean('balance',18*2);
cmap_lo = cmap_lo(19:end,:);
a = linspace(cmap_lo(1,1),cmap_lo(end-11,1),size(smb_lo,2)-11);
b = linspace(cmap_lo(1,2),cmap_lo(end-11,2),size(smb_lo,2)-11);
c = linspace(cmap_lo(1,3),cmap_lo(end-11,3),size(smb_lo,2)-11);
cmap_lo = [[a(:),b(:),c(:)] ; cmap_lo(end-10:end,:)];

% Shelf labels
for i = 1:length(iv_lo)
    lo_labs{i} = GL(iv_lo(i)).Name;
end
for i = 1:length(iv_hi)
    hi_labs{i} = GL(iv_hi(i)).Name;
end

% Stack height
stack_lo = cumsum(smb_lo,2);
stack_hi = cumsum(smb_hi,2);
stack_lom = stack_lo + abs([zeros([length(time),1]),stack_lo(:,1:end-1)]-stack_lo)./2;
stack_him = stack_hi - abs([zeros([length(time),1]),stack_hi(:,1:end-1)]-stack_hi)./2;

%% Plot

% initilise figure
figure('color','w','units','inches','position',[2 2 4.3 2]);
% Plot areas
h_lo = area(time,smb_lo,'edgecolor','none'); hold on; datetick('x');
h_hi = area(time,smb_hi,'edgecolor','none');
% Change colors
for i = 1:length(h_lo)
    h_lo(i).FaceColor = cmap_lo(i,:);
    h_lo(i).EdgeColor = 'none';
end
for i = 1:length(h_hi)
    h_hi(i).FaceColor = cmap_hi(i,:);
    h_hi(i).EdgeColor = 'none';
end
% Plot total antarctic ice shelf mass change as line
plot(time,smb_tot,'w','linewidth',3.5);
plot(time,smb_tot,'k','linewidth',2);
plot([time(1) time(end)],[0 0],'k','linestyle','--','linewidth',1);
% Visuals
set(gca,'color','w');
set(gca,'XLim',[datenum(1997,7,1) datenum(2021,7,1)]);
set(gca,'YGrid','on','GridColor',[.7 .7 .7],'GridAlpha',1);
% Labels
%ylabel('Surface mass balance change (Gt)');
set(gca,'XTick',datenum(1997:2:2021,7,1));
set(gca,'XTickLabel',{'1997','1999','2001','2003','2005','2007','2009','2011','2013','2015','2017','2019','2021'});
set(gca,'FontSize',8,'FontName','Helvetica')
% Label some shelves
%   - lo
% for i = numel(lo_labs)-2:numel(lo_labs)
%     if contains(lo_labs{i},'_')
%         parts = split(lo_labs{i},'_');
%         tmp = [parts{1} ' ' parts{2}];
%     else
%         tmp = lo_labs{i};
%     end
%     if i == numel(lo_labs)
%         text(datenum(2018,9,1),stack_lom(end-20,i)-35,tmp,'HorizontalAlignment','center','fontsize',8,'color','k','interpreter','none');
%     else
%         text(datenum(2020,1,1),stack_lom(end-20,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%     end
% end
% %   - hi
% for i = numel(hi_labs)-2:numel(hi_labs)
%     if contains(hi_labs{i},'_')
%         parts = split(hi_labs{i},'_');
%         tmp = [parts{1} ' ' parts{2}];
%     else
%         tmp = hi_labs{i};
%     end
%     if i == numel(hi_labs)
%         text(datenum(2019,11,1),stack_him(end-20,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%     else
%         text(datenum(2019,8,1),stack_him(end-20,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%     end
% end
% text(datenum(2019,7,1),stack_him(23,end-1),hi_labs{end-1},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-2),hi_labs{end-2},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-3),hi_labs{end-3},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-4),hi_labs{end-4},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%   - Antarctica
% text(datenum(2010,1,1),1250,'Antarctica','HorizontalAlignment','center','fontsize',10,'color','r','interpreter','none');
% Title for now
%title('Mass change due to surface mass balance (Gt)');
set(gca,'YLim',[-100 500]);
% Save
export_fig('ice_shelf_SMB_change_small_smooth.png','-dpng','-r1800');
export_fig('ice_shelf_SMB_change_small_smooth.fig');
exportgraphics(gcf,'ice_shelf_SMB_change_small_smooth.pdf','ContentType','vector')


