% plot_ice_shelf_basal_melt_area_chart


clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% use 200 m or irregularly spaced GLs
use_200m = 1;

% paolo or adusumilli or noel/livia melt?
basal_melt_source=3; % (1) adusumilli; (2) = paolo; (3) or noel/livia from 2010 onwards for 55 shelves, and paolo elsewhere

%% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Make data cube

m_all = zeros([numel(GL_labels),25]).*NaN;
for i = 1:numel(GL_labels)
    shelf_name = GL_labels(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'time','cumulativeThinningForce1997','cumulativeThinningForce1997Error');
    m_all(i,:) = cumulativeThinningForce1997;
end

% Change the sign, so that negative = mass loss (or melt exceeds balance
% melt)
%m_all = m_all.*-1;

% Calculate overall Antarctic ice shelf discharge change
m_tot = nansum(m_all,1);

% Sort by overall discharge change
[~,iv] = sort(m_all(:,end));
m_sort = m_all(iv,:);

% Split shelves that have (overall) gained or lost mass
lo = m_sort(:,end)<0;
hi = m_sort(:,end)>0;
m_lo = m_sort(lo,:);
m_hi = m_sort(hi,:);
iv_lo = iv(lo);
iv_hi = iv(hi);

% Rotate for plotting
m_lo = fliplr(m_lo'); % also flip so largest overall change is at bottom
m_hi = m_hi';
iv_lo = flipud(iv_lo);

%% Plot prep

% Colors
cmap_hi = cmocean('balance',12*2);
cmap_hi = cmap_hi(2:12,:);
a = linspace(cmap_hi(6,1),cmap_hi(end,1),size(m_hi,2)-5);
b = linspace(cmap_hi(6,2),cmap_hi(end,2),size(m_hi,2)-5);
c = linspace(cmap_hi(6,3),cmap_hi(end,3),size(m_hi,2)-5);
cmap_hi = [cmap_hi(1:5,:);[a(:),b(:),c(:)]];
cmap_hi = flipud(cmap_hi);
cmap_lo = cmocean('balance',18*2);
cmap_lo = cmap_lo(19:end,:);
a = linspace(cmap_lo(1,1),cmap_lo(end-11,1),size(m_lo,2)-11);
b = linspace(cmap_lo(1,2),cmap_lo(end-11,2),size(m_lo,2)-11);
c = linspace(cmap_lo(1,3),cmap_lo(end-11,3),size(m_lo,2)-11);
cmap_lo = [[a(:),b(:),c(:)] ; cmap_lo(end-10:end,:)];

% Shelf labels
for i = 1:length(iv_lo)
    lo_labs{i} = GL_labels(iv_lo(i)).Name;
end
for i = 1:length(iv_hi)
    hi_labs{i} = GL_labels(iv_hi(i)).Name;
end

% Stack height
stack_lo = cumsum(m_lo,2);
stack_hi = cumsum(m_hi,2);
stack_lom = stack_lo + abs([zeros([length(time),1]),stack_lo(:,1:end-1)]-stack_lo)./2;
stack_him = stack_hi - abs([zeros([length(time),1]),stack_hi(:,1:end-1)]-stack_hi)./2;

%% Plot

time(end) = datenum(2021,12,31); % was 15-mar-2021. Just to get it to go to the edgeo of the plot

% initilise figure
figure('color','w','units','inches','position',[2 2 4.3 2]);
% Plot areas
h_lo = area(time,m_lo,'edgecolor','none'); hold on; datetick('x');
h_hi = area(time,m_hi,'edgecolor','none');
% Change colors
for i = 1:length(h_lo)
    h_lo(i).FaceColor = cmap_lo(i,:);
    h_lo(i).EdgeColor = 'none';
end
for i = 1:length(h_hi)
    h_hi(i).FaceColor = cmap_hi(i,:);
    h_hi(i).EdgeColor = 'none';
end
% Plot total antarctic ice shelf mass change as line
plot(time,m_tot,'w','linewidth',3.5);
plot(time,m_tot,'k','linewidth',2);
% Visuals
set(gca,'color','w');
set(gca,'XLim',[datenum(1997,7,1) datenum(2021,7,1)]);
set(gca,'YGrid','on','GridColor',[.7 .7 .7],'GridAlpha',1);
% Labels
%ylabel('Melt excess (Gt)');
set(gca,'XTick',datenum(1997:2:2021,7,1));
%set(gca,'XTickLabel',{'1997','1999','2001','2003','2005','2007','2009','2011','2013','2015','2017','2019','2021'});
set(gca,'XTickLabel',{' '});
set(gca,'FontSize',8,'FontName','Helvetica')
% Label some shelves
%   - lo
for i = numel(lo_labs)-2:numel(lo_labs)
    if contains(lo_labs{i},'_')
        parts = split(lo_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
    else
        tmp = lo_labs{i};
    end
    text(datenum(2019,7,1),stack_lom(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
end
%   - hi
for i = numel(hi_labs)-2:numel(hi_labs)
    if contains(hi_labs{i},'_')
        parts = split(hi_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
    else
        tmp = hi_labs{i};
    end
    if i == numel(hi_labs)
        text(datenum(2019,9,1),stack_him(23,i)+200,tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    elseif i == numel(hi_labs)-1
        text(datenum(2019,6,1),stack_him(23,i)+200,tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    else
        text(datenum(2019,6,1),stack_him(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    end
end
% text(datenum(2019,7,1),stack_him(23,end-1),hi_labs{end-1},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-2),hi_labs{end-2},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-3),hi_labs{end-3},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-4),hi_labs{end-4},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%   - Antarctica
%text(datenum(2010,1,1),1250,'Antarctica','HorizontalAlignment','center','fontsize',10,'color','r','interpreter','none');
% Title for now
%title('Mass change due to basal melting (Gt)');
ax = gca;
ax.YRuler.Exponent = 0;
set(gca,'YLim',[-13000 8500]);
% Save
if basal_melt_source == 1
    export_fig('ice_shelf_excess_basal_melt_flux.png','-dpng','-r1800');
elseif basal_melt_source == 2
    export_fig('ice_shelf_excess_basal_melt_flux_paolo.png','-dpng','-r1800');
elseif basal_melt_source == 3
    export_fig('ice_shelf_excess_basal_melt_flux_noel_small_smooth.png','-dpng','-r1800');
    export_fig('ice_shelf_excess_basal_melt_flux_noel_small_smooth.fig');
    exportgraphics(gcf,'ice_shelf_excess_basal_melt_flux_noel_small_smooth.pdf','ContentType','vector')
end
