% plot_ice_shelf_calving_timeseries_area_chart

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% use 200 m or irregularly spaced GLs
use_200m = 1;

use_paolo=1;

%% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Make data cube

c_all = zeros([numel(GL_labels),25]).*NaN;
for i = 1:numel(GL_labels)
    shelf_name = GL_labels(i).Name;
    if i == 1
        load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeRetreatBalance','time');
        %load(['../../calving/individual_shelf_calving_flux/' shelf_name '_calving_timeseries.mat'],'dm_from_init','time');
    else
        load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeRetreatBalance');
        %load(['../../calving/individual_shelf_calving_flux/' shelf_name '_calving_timeseries.mat'],'dm_from_init');
    end
    %c_change = c_reg-ssc;
    c_all(i,:) = cumulativeRetreatBalance;
end
time(end) = datenum(2021,12,31);

% Multiply by -1 so that calving in excess of steady state is negative
%c_all = c_all.*-1; 

% Calculate overall Antarctic ice shelf mass change due to calving
c_tot = sum(c_all,1);

% Sort by overall mass change
[~,iv] = sort(c_all(:,end));
c_sort = c_all(iv,:);

% Split shelves that have (overall) gained or lost mass due to calving
lo = c_sort(:,end)<0;
hi = c_sort(:,end)>0;
c_lo = c_sort(lo,:);
c_hi = c_sort(hi,:);
iv_lo = iv(lo);
iv_hi = iv(hi);

% Rotate for plotting
c_lo = fliplr(c_lo'); % also flip so largest overall change is at bottom
c_hi = c_hi';
iv_lo = flipud(iv_lo);

%% Plot prep

% Colors
cmap_hi = cmocean('balance',30);
cmap_hi = cmap_hi(1:15,:);
a = linspace(cmap_hi(11,1),cmap_hi(end,1),size(c_hi,2)-10);
b = linspace(cmap_hi(11,2),cmap_hi(end,2),size(c_hi,2)-10);
c = linspace(cmap_hi(11,3),cmap_hi(end,3),size(c_hi,2)-10);
cmap_hi = [cmap_hi(1:10,:);[a(:),b(:),c(:)]];
cmap_hi = flipud(cmap_hi);
% cmap_lo = cmocean('balance',length(iv_lo)*2+100);
% cmap_lo = cmap_lo(length(iv_lo)+51:end,:);
% a = linspace(cmap_lo(1,1),cmap_lo(30,1),90);
% b = linspace(cmap_lo(1,2),cmap_lo(30,2),90);
% c = linspace(cmap_lo(1,3),cmap_lo(30,3),90);
% cmap_lo = cmocean('balance',(117-100)*2+20);
% a = linspace(cmap_lo(27,1),cmap_lo(37,1),100);
% b = linspace(cmap_lo(27,2),cmap_lo(37,2),100);
% c = linspace(cmap_lo(27,3),cmap_lo(37,3),100);
% cmap_lo = cmap_lo(37:end-1,:);
% cmap_lo = [[a(:),b(:),c(:)] ; cmap_lo];
cmap_lo1 = cmocean('balance',400);
cmap_lo1 = cmap_lo1(205:205+(size(c_lo,2)-10),:);
cmap_lo2 = cmocean('balance',40);
cmap_lo2 = cmap_lo2(end-10:end-2,:);
cmap_lo = [cmap_lo1 ; cmap_lo2];


% Shelf labels
for i = 1:length(iv_lo)
    lo_labs{i} = GL_labels(iv_lo(i)).Name;
end
for i = 1:length(iv_hi)
    hi_labs{i} = GL_labels(iv_hi(i)).Name;
end

% Stack height
stack_lo = cumsum(c_lo,2);
stack_hi = cumsum(c_hi,2);
stack_lom = stack_lo + abs([zeros([length(time),1]),stack_lo(:,1:end-1)]-stack_lo)./2;
stack_him = stack_hi - abs([zeros([length(time),1]),stack_hi(:,1:end-1)]-stack_hi)./2;

%% Plot

% initilise figure
figure('color','w','units','inches','position',[2 2 4.3 2]);
% Plot areas
h_lo = area(time,c_lo,'edgecolor','none'); hold on; datetick('x');
h_hi = area(time,c_hi,'edgecolor','none');% Change colors
% Change colors
for i = 1:length(h_lo)
    h_lo(i).FaceColor = cmap_lo(i,:);
    h_lo(i).EdgeColor = 'none';
end
for i = 1:length(h_hi)
    h_hi(i).FaceColor = cmap_hi(i,:);
    h_hi(i).EdgeColor = 'none';
end
% Plot total antarctic ice shelf mass change as line
plot(time,c_tot,'w','linewidth',3.5);
plot(time,c_tot,'k','linewidth',2);
% Visuals
set(gca,'color','w');
set(gca,'XLim',[datenum(1997,7,1) datenum(2021,7,1)]);
set(gca,'YGrid','on','GridColor',[.7 .7 .7],'GridAlpha',1);
set(gca,'YTick',[-10000:2500:5000]);
set(gca,'YTickLabel',{-10000:2500:5000});
set(gca,'FontSize',8,'FontName','Helvetica')
% Labels
%ylabel('Calving excess/deficit (Gt)');
set(gca,'XTick',datenum(1997:2:2021,7,1));
%set(gca,'XTickLabel',{'1997','1999','2001','2003','2005','2007','2009','2011','2013','2015','2017','2019','2021'});
set(gca,'XTickLabel',{' '});
% Label some shelves
%   - lo
for i = numel(lo_labs)-2:numel(lo_labs)
    if contains(lo_labs{i},'_')
        parts = split(lo_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
    else
        tmp = lo_labs{i};
    end
    if i == numel(lo_labs)-2
        text(datenum(2019,7,1),stack_lom(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    else
        text(datenum(2019,7,1),stack_lom(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    end
end
%text(datenum(2004,7,1),stack_lom(8,end-4),lo_labs{end-4},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%text(datenum(2004,7,1),stack_lom(8,75),lo_labs{75},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%   - hi
for i = numel(hi_labs)-2:numel(hi_labs)
    if contains(hi_labs{i},'_')
        parts = split(hi_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
    else
        tmp = hi_labs{i};
    end
    if i == numel(hi_labs)-2
        text(datenum(2019,7,1),stack_him(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    elseif i==numel(hi_labs)-1
        text(datenum(2019,7,1),stack_him(23,i)+200,tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    else
        text(datenum(2019,7,1),stack_him(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    end
end
% Title for now
%title('Mass change due to calving (Gt)');
set(gca,'YLim',[-10500 5000]);
% Save
export_fig('ice_shelf_calving_flux_small_smooth.png','-dpng','-r1800');
export_fig('ice_shelf_calving_flux_small_smooth.fig');
exportgraphics(gcf,'ice_shelf_calving_flux_small_smooth.pdf','ContentType','vector')

