% plot_discharge_change_timeseries_area_chart_smooth

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% use 200 m or irregularly spaced GLs
use_200m = 1;


%% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Make data cube

Q_all = zeros([numel(GL_labels),25]).*NaN;
for i = 1:numel(GL_labels)
    shelf_name = GL_labels(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeDischargeChangeRel1997','cumulativeDischargeChangeRel1997Error','time');
    Q_change = cumulativeDischargeChangeRel1997(end);
    Q_all(i,:) = cumulativeDischargeChangeRel1997;
    Q_change_err(i,:) = cumulativeDischargeChangeRel1997Error;
end
time(end) = datenum(2021,12,31); % change end time so plot extends to edges

% Calculate overall Antarctic ice shelf discharge change
Q_tot = sum(Q_all,1);
Q_err_tot = sqrt(sum(Q_change_err.^2,1));

% Sort by overall discharge change
[~,iv] = sort(Q_all(:,end));
Q_sort = Q_all(iv,:);
Q_err_sort = Q_change_err(iv,:);

% Split shelves that have (overall) gained or lost mass
lo = Q_sort(:,end)<0;
hi = Q_sort(:,end)>0;
Q_lo = Q_sort(lo,:);
Q_hi = Q_sort(hi,:);
Q_err_lo = Q_err_sort(lo,:);
Q_err_hi = Q_err_sort(hi,:);
iv_lo = iv(lo);
iv_hi = iv(hi);

% Rotate for plotting
Q_lo = fliplr(Q_lo'); % also flip so largest overall change is at bottom
Q_hi = Q_hi';
Q_err_lo = fliplr(Q_err_lo');
Q_err_hi = Q_err_hi';
iv_lo = flipud(iv_lo);

%% Plot prep

% Colors
cmap_hi = cmocean('balance',12*2);
cmap_hi = cmap_hi(2:12,:);
a = linspace(cmap_hi(6,1),cmap_hi(end,1),size(Q_hi,2)-5);
b = linspace(cmap_hi(6,2),cmap_hi(end,2),size(Q_hi,2)-5);
c = linspace(cmap_hi(6,3),cmap_hi(end,3),size(Q_hi,2)-5);
cmap_hi = [cmap_hi(1:5,:);[a(:),b(:),c(:)]];
cmap_hi = flipud(cmap_hi);
cmap_lo = cmocean('balance',10*2);
cmap_lo = cmap_lo(11:end,:);
a = linspace(cmap_lo(1,1),cmap_lo(end-6,1),size(Q_lo,2)-6);
b = linspace(cmap_lo(1,2),cmap_lo(end-6,2),size(Q_lo,2)-6);
c = linspace(cmap_lo(1,3),cmap_lo(end-6,3),size(Q_lo,2)-6);
cmap_lo = [[a(:),b(:),c(:)] ; cmap_lo(end-5:end,:)];

% Shelf labels
for i = 1:length(iv_lo)
    lo_labs{i} = GL_labels(iv_lo(i)).Name;
end
for i = 1:length(iv_hi)
    hi_labs{i} = GL_labels(iv_hi(i)).Name;
end

% Stack height
stack_lo = cumsum(Q_lo,2);
stack_hi = cumsum(Q_hi,2);
stack_lom = stack_lo + abs([zeros([length(time),1]),stack_lo(:,1:end-1)]-stack_lo)./2;
stack_him = stack_hi - abs([zeros([length(time),1]),stack_hi(:,1:end-1)]-stack_hi)./2;

%% Plot

% initilise figure
figure('color','w','units','inches','position',[2 2 4.3 2]);
% Plot areas
h_lo = area(time,Q_lo,'edgecolor','none'); hold on; datetick('x');
h_hi = area(time,Q_hi,'edgecolor','none');
% Change colors
for i = 1:length(h_lo)
    h_lo(i).FaceColor = cmap_lo(i,:);
    h_lo(i).EdgeColor = 'none';
end
for i = 1:length(h_hi)
    h_hi(i).FaceColor = cmap_hi(i,:);
    h_hi(i).EdgeColor = 'none';
end
% Plot total antarctic ice shelf mass change as line
plot(time,Q_tot,'w','linewidth',3.5);
plot(time,Q_tot,'k','linewidth',2);
% Visuals
set(gca,'color','w');
set(gca,'XLim',[datenum(1997,7,1) datenum(2021,7,1)]);
set(gca,'YGrid','on','GridColor',[.7 .7 .7],'GridAlpha',1);
% Labels
%ylabel('Grounding line flux change (Gt)');
set(gca,'XTick',datenum(1997:2:2021,7,1));
set(gca,'XTickLabel',{'1997','1999','2001','2003','2005','2007','2009','2011','2013','2015','2017','2019','2021'});
set(gca,'FontSize',8,'FontName','Helvetica')
% Label some shelves
%   - lo
count = 0;
for i = numel(lo_labs)-3:numel(lo_labs)
    if contains(lo_labs{i},'_')
        parts = split(lo_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
        count = count+1;
        tmp_list{count} = tmp;
    else
        count = count+1;
        tmp = lo_labs{i};
        tmp_list{count} = tmp;
    end
end
text(datenum(2018,6,1),stack_lom(23,end)-170,tmp_list{end},'HorizontalAlignment','center','fontsize',8,'color','k','interpreter','none');
text(datenum(2019,6,1),stack_lom(23,end-1)-60,tmp_list{end-1},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
text(datenum(2019,3,1),stack_lom(23,end-2)+5,tmp_list{end-2},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%text(datenum(2019,1,1),stack_lom(23,end-3)+50,tmp_list{end-3},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%   - hi
for i = numel(hi_labs)-4:numel(hi_labs)
    if contains(hi_labs{i},'_')
        parts = split(hi_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
    else
        tmp = hi_labs{i};
    end
    if i == numel(hi_labs)-1
        text(datenum(2019,7,1),stack_him(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    else
        text(datenum(2019,7,1),stack_him(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
    end
end
% text(datenum(2019,7,1),stack_him(23,end-1),hi_labs{end-1},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-2),hi_labs{end-2},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-3),hi_labs{end-3},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
% text(datenum(2019,7,1),stack_him(23,end-4),hi_labs{end-4},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%   - Antarctica
%text(datenum(2010,1,1),1250,'Antarctica','HorizontalAlignment','center','fontsize',10,'color','r','interpreter','none');
% Title for now
%title('Mass change due to grounding line discharge (Gt)');
set(gca,'YLim',[-900 2600]);
% Save
export_fig('ice_shelf_grounding_line_discharge_change1997_small_smooth.png','-dpng','-r1800');
export_fig('ice_shelf_grounding_line_discharge_change1997_small_smooth.fig');
exportgraphics(gcf,'ice_shelf_grounding_line_discharge_change1997_small_smooth.pdf','ContentType','vector')


%% Get some stats

disp(['The overall ice shelf mass loss due to reductions in GL discahrge are: ' num2str(sum(Q_lo(end,:))) ' +/- ' num2str(rssq(Q_err_lo(end,:))) ' Gt']);

