% plot_mass_change_timeseries_area_chart

clear
close all
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% use 200 m or irregularly spaced GLs
use_200m = 1;

% paolo or adusumilli or noel/livia melt?
basal_melt_source=3; % (1) adusumilli; (2) = paolo; (3) or noel/livia from 2010 onwards for 55 shelves, and paolo elsewhere

%% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Make data cube

ncount = 0;
lcount = 0;
gcount = 0;
for i = 1:numel(GL_labels)
    shelf_name = GL_labels(i).Name;
    load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeMassChange','time','cumulativeMassChangeError','totalMassChange','totalMassChangeError');
    
    if strcmp(GL_labels(i).Name,'Pine_Island') || strcmp(GL_labels(i).Name,'Thwaites') || strcmp(GL_labels(i).Name,'Crosson') || strcmp(GL_labels(i).Name,'Dotson')
        GLmass = load('D:\work\Fellowship_Leeds\Papers\Research\ice_shelf_mass_budget\v2\ice_shelf_masks\ASE_vary_grounding_line/mass_change_ASE_grounding_line_migration.mat');
        idx = find(contains(GLmass.ASE_shelves,GL_labels(i).Name)==1);
        cumuGLmass = linspace(0,GLmass.mass_change_GL(idx),length(cumulativeMassChange));
        cumulativeMassChange = cumulativeMassChange + cumuGLmass;
    end
    
    mb_all(i,:) = cumulativeMassChange;
    mb_err_all(i,:) = cumulativeMassChangeError;
    totalMassChangeAll(i) = totalMassChange;
    totalMassChangeErrorAll(i) = totalMassChangeError;
    if totalMassChange-totalMassChangeError<0 && totalMassChange+totalMassChangeError>0
        ncount = ncount+1;
        no_sig_change{ncount} = shelf_name;
        mb_sig(i) = 0;
    else
        if totalMassChange<0
            lcount=lcount+1;
            loss_shelves{lcount} = shelf_name;
            mb_sig(i) = 1;
        else
            gcount=gcount+1;
            gain_shelves{gcount} = shelf_name;
            mb_sig(i) = 1;
        end
    end
end
time(end) = datenum(2021,12,31); % change last time so plot goes to edge

% Calculate overall Antarctic ice shelf mass change
mb_tot = sum(mb_all,1);
mb_err_tot = sqrt(sum(mb_err_all.^2,1));

% Sort by overall mass change
[~,iv] = sort(totalMassChangeAll(:));
totalMassChangeSort = totalMassChangeAll(iv);
totalMassChangeErrorSort = totalMassChangeErrorAll(iv);
mb_sort = mb_all(iv,:);
mb_err_sort = mb_err_all(iv,:);
mb_sig_sort = mb_sig(iv);

% Split shelves that have (overall) gained or lost mass
lo = mb_sort(:,end)<0;
hi = mb_sort(:,end)>0;
mb_lo = mb_sort(lo,:);
mb_hi = mb_sort(hi,:);
totalMassChange_lo = totalMassChangeSort(lo);
totalMassChange_hi = totalMassChangeSort(hi);
totalMassChangeError_lo = totalMassChangeErrorSort(lo);
totalMassChangeError_hi = totalMassChangeErrorSort(hi);
mb_err_lo = mb_err_sort(lo,:);
mb_err_hi = mb_err_sort(hi,:);
mb_sig_lo = mb_sig_sort(lo);
mb_sig_hi = mb_sig_sort(hi);
iv_lo = iv(lo);
iv_hi = iv(hi);

% Rotate for plotting
mb_lo = fliplr(mb_lo'); % also flip so largest overall change is at bottom
mb_err_lo = fliplr(mb_err_lo');
mb_hi = mb_hi';
mb_err_hi = mb_err_hi';
mb_sig_lo = fliplr(mb_sig_lo);
iv_lo = flipud(iv_lo);
totalMassChange_lo = fliplr(totalMassChange_lo);
totalMassChangeError_lo = fliplr(totalMassChangeError_lo);

%% Plot prep

% Colors
cmap_hi = cmocean('balance',12*2);
cmap_hi = cmap_hi(2:12,:);
a = linspace(cmap_hi(6,1),cmap_hi(end,1),size(mb_hi,2)-5);
b = linspace(cmap_hi(6,2),cmap_hi(end,2),size(mb_hi,2)-5);
c = linspace(cmap_hi(6,3),cmap_hi(end,3),size(mb_hi,2)-5);
cmap_hi = [cmap_hi(1:5,:);[a(:),b(:),c(:)]];
cmap_hi = flipud(cmap_hi);
cmap_lo = cmocean('balance',18*2);
cmap_lo = cmap_lo(19:end,:);
a = linspace(cmap_lo(1,1),cmap_lo(end-11,1),size(mb_lo,2)-11);
b = linspace(cmap_lo(1,2),cmap_lo(end-11,2),size(mb_lo,2)-11);
c = linspace(cmap_lo(1,3),cmap_lo(end-11,3),size(mb_lo,2)-11);
cmap_lo = [[a(:),b(:),c(:)] ; cmap_lo(end-10:end,:)];

% Shelf labels
for i = 1:length(iv_lo)
    lo_labs{i} = GL_labels(iv_lo(i)).Name;
end
for i = 1:length(iv_hi)
    hi_labs{i} = GL_labels(iv_hi(i)).Name;
end

% Stack height
stack_lo = cumsum(mb_lo,2);
stack_hi = cumsum(mb_hi,2);
stack_lom = stack_lo + abs([zeros([length(time),1]),stack_lo(:,1:end-1)]-stack_lo)./2;
stack_him = stack_hi - abs([zeros([length(time),1]),stack_hi(:,1:end-1)]-stack_hi)./2;

%% Plot

% initilise figure
figure('color','w','units','inches','position',[2 2 4.3 2]); % 5.5,3.5 for standard size
% Plot areas
h_lo = area(time,mb_lo,'edgecolor','none'); hold on; datetick('x');
h_hi = area(time,mb_hi,'edgecolor','none');
% Change colors
for i = 1:length(h_lo)
    h_lo(i).FaceColor = cmap_lo(i,:);
    h_lo(i).EdgeColor = 'none';
end
for i = 1:length(h_hi)
    h_hi(i).FaceColor = cmap_hi(i,:);
    h_hi(i).EdgeColor = 'none';
end
% Plot total antarctic ice shelf mass change as line
plot(time,mb_tot,'w','linewidth',3.5);
plot(time,mb_tot,'k','linewidth',2);
% Visuals
set(gca,'color','w');
set(gca,'XLim',[datenum(1997,7,1) datenum(2021,7,1)]);
set(gca,'YGrid','on','GridColor',[.7 .7 .7],'GridAlpha',1);
% Labels
%ylabel('Mass change (Gt)');
set(gca,'XTick',datenum(1997:2:2021,7,1));
%set(gca,'XTickLabel',{'1997','1999','2001','2003','2005','2007','2009','2011','2013','2015','2017','2019','2021'});
set(gca,'XTickLabel',{' '});
set(gca,'FontSize',8,'FontName','Helvetica')
% Label some shelves
%   - lo
for i = numel(lo_labs)-2:numel(lo_labs)
    if contains(lo_labs{i},'_')
        parts = split(lo_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
    else
        tmp = lo_labs{i};
    end
    text(datenum(2019,7,1),stack_lom(23,i),tmp,'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
end
%   - hi
count = 0;
for i = numel(hi_labs)-3:numel(hi_labs)
    if contains(hi_labs{i},'_')
        parts = split(hi_labs{i},'_');
        tmp = [parts{1} ' ' parts{2}];
        count = count+1;
        tmp_list{count} = tmp;
    else
        count = count+1;
        tmp = hi_labs{i};
        tmp_list{count} = tmp;
    end
end
text(datenum(2019,12,15),stack_him(23,end)+500,tmp_list{end},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
text(datenum(2020,1,1),stack_him(23,end-1)+600,tmp_list{end-1},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
text(datenum(2020,1,1),stack_him(23,end-2)+300,'Brunt','HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%text(datenum(2018,7,1),stack_him(23,end-3)+100,tmp_list{end-3},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%text(datenum(2020,1,1),stack_him(23,end-4),tmp_list{end-4},'HorizontalAlignment','center','fontsize',8,'color','w','interpreter','none');
%   - Antarctica
text(datenum(2001,6,1),-9000,'Antarctica','HorizontalAlignment','center','fontsize',10,'color','k','interpreter','none');
% Title for now
%title('Ice Shelf Mass Change');
ax = gca;
ax.YRuler.Exponent = 0;
set(gca,'YLim',[-17000 10000]);
% Save
if basal_melt_source == 1
    export_fig('ice_shelf_mass_change.png','-dpng','-r1800');
elseif basal_melt_source == 2
    export_fig('ice_shelf_mass_change_paolo.png','-dpng','-r1800');
elseif basal_melt_source == 3
    export_fig('ice_shelf_mass_change_noel_small_smooth.png','-dpng','-r1800');
    export_fig('ice_shelf_mass_change_noel_small_smooth.fig');
    exportgraphics(gcf,'ice_shelf_mass_change_noel_small_smooth.pdf','ContentType','vector')
end

%% Get some stats

% disp([num2str(sum(mb_sig_lo)) ' shelves have lost mass since 1996, totalling ' num2str(sum(mb_lo(end,logical(mb_sig_lo)))) ' +/- ' num2str(rssq(mb_err_lo(end,logical(mb_sig_lo)),2)) ' Gt']);
% disp(['whilst ' num2str(sum(mb_sig_hi)) ' shelves have gained mass since 1996, totalling ' num2str(sum(mb_hi(end,logical(mb_sig_hi)))) ' +/- ' num2str(rssq(mb_err_hi(end,logical(mb_sig_hi)),2)) ' Gt']);
% disp(' ');
% disp(['The 5 most significant ice shelves in terms of mass loss ' lo_labs{end} ', ' lo_labs{end-1} ', '])
% disp([lo_labs{end-2} ', ' lo_labs{end-3} ', ' lo_labs{end-4} ' account for ' num2str(sum(mb_lo(end,end-4:end)) / sum(mb_lo(end,:)) *100) ' % of all mass losses']);
% disp(' ');
% disp(['The 5 most significant ice shelves in terms of mass gain ' hi_labs{end} ', ' hi_labs{end-1} ', '])
% disp([hi_labs{end-2} ', ' hi_labs{end-3} ', ' hi_labs{end-4} ' account for ' num2str(sum(mb_hi(end,end-4:end)) / sum(mb_hi(end,:)) *100) ' % of all mass losses']);

disp([num2str(sum(mb_sig_lo)) ' shelves have lost mass since 1996, totalling ' num2str(sum(totalMassChange_lo(logical(mb_sig_lo)))) ' +/- ' num2str(rssq(totalMassChangeError_lo(logical(mb_sig_lo)))) ' Gt']);
disp(['whilst ' num2str(sum(mb_sig_hi)) ' shelves have gained mass since 1996, totalling ' num2str(sum(totalMassChange_hi(logical(mb_sig_hi)))) ' +/- ' num2str(rssq(totalMassChangeError_hi(logical(mb_sig_hi)))) ' Gt']);
disp(' ');
disp(['The 5 most significant ice shelves in terms of mass loss ' lo_labs{end} ', ' lo_labs{end-1} ', '])
disp([lo_labs{end-2} ', ' lo_labs{end-3} ', ' lo_labs{end-4} ' account for ' num2str(sum(totalMassChange_lo(end-4:end)) / sum(totalMassChange_lo(:)) *100) ' % of all mass losses']);
disp(' ');
disp(['The 5 most significant ice shelves in terms of mass gain ' hi_labs{end} ', ' hi_labs{end-1} ', '])
disp([hi_labs{end-2} ', ' hi_labs{end-3} ', ' hi_labs{end-4} ' account for ' num2str(sum(totalMassChange_hi(end-4:end)) / sum(totalMassChange_hi(:)) *100) ' % of all mass losses']);

