% plot_ice_shelf_melt_excess_ring

clear
close all 
clc

% add paths to libraries
addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../../'));

% use 200 m or irregularly spaced GLs
use_200m = 1;

% paolo or adusumilli or noel/livia melt?
basal_melt_source=3; % (1) adusumilli; (2) = paolo; (3) or noel/livia from 2010 onwards for 55 shelves, and paolo elsewhere

%% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
if use_200m == 1
    load('merged_shelf_GLs_all_200m.mat','GL200');
    GL = GL200;
    clear GL200;
else
    load('merged_shelf_GLs_all.mat','GL');
end

GL_edit = GL;

% Rename some things for consistency with Chad's data
GL_edit(124).Name = 'Riiser-Larsen';
GL_edit(137).Name = 'SmithInlet';
GL_edit(167).Name = 'Wilma/Robert/Downer';
GL_edit(52).Name = 'GeikieInlet';
GL_edit(58).Name = 'Hannan'; % was Hannan_1
GL_edit(68).Name = 'HornBluff';
GL_edit(64).Name = 'Holmes';
GL_edit(83).Name = 'Larsen_F'; % was Larsen_F_1
GL_edit(84).Name = 'Larsen_G'; % was Larsen_F_2
GL_edit(100).Name = 'Moscow_University';
GL_edit(116).Name = 'Prince_Harald'; % was Prince_Harald_1
GL_edit(156).Name = 'Vincennes_Bay'; % was Vincennes_Bay_1
GL_edit(45).Name = 'Fox_Ice_Stream'; % was Fox_2
GL_edit(47).Name = 'Frost'; % was Frost_1

% Delete some shelves where I have multiple but Chad has just one
GL_edit(157:159) = []; % Vincennes_Bay 2-4
GL_edit(117) = []; % Prince_Harald_2
GL_edit(65:67) = []; % Holmes_2, Holmes_3 and Holmes_4
GL_edit(59) = []; % Hannan_2
GL_edit(48:49) = []; % Frost_2 and Frost_3

% And make a copy for saving data and figures
GL_labels = GL_edit;
GL_labels(117).Name = 'Riiser_Larsen';
GL_labels(130).Name = 'Smith_Inlet';
GL_labels(157).Name = 'Wilma_Robert_Downer';
GL_labels(50).Name = 'Geikie_Inlet';

%% Define plotting order of ice shelves

shelves_to_plot = {'Larsen_A','Larsen_B','Larsen_C','Larsen_D','Larsen_E','Larsen_F','Clarke_bay','Larsen_G',...
    'Ronne','Filchner','Hayes_Coats_Coast','Dawson_Lambton','Brunt_Stancomb','Riiser_Larsen',...
    'Quar','Ekstrom','Atka','Jelbart','Fimbul','Vigrid','Nivl','Lazarev','Borchgrevink','Baudouin',...
    'Prince_Harald','Shirase','Skallen','Telen','Hannan','Rayner_Thyer','Zubchatyy','Porter','Myers',...
    'Edward_VIII','Wilma_Robert_Downer','Rund_Bay','Hoseason','Cirque_Fjord','Mulebreen','Utsikkar',...
    'Amery','Publications','Dalk','Flatnes','Hovde','Sorsdal','West','Helen','Shackleton','Tracy_Tremenchus',...
    'Conger_Glenzer','Underwood','Vincennes_Bay','Whittle','Totten','Moscow_University','Voyeykov',...
    'Holmes','Frost','Sandford','Morse','May_Glacier','Dibble','Pourquoi_Pas','Commandant_Charcot',...
    'Marret','Francais','Liotard','Astrolabe','Zelee','Watt_Bay','Mertz','Fisher','Ainsworth','Ninnis',...
    'HornBluff','Deakin','Cook','Slava','Andreyev','Lauritzen','Drury','Matusevitch','McLeod',...
    'Noll','Gillet','Suvorov','Rennick','Gannutz','Barber','Chugunov','Lillie','Kirkby',...
    'Smith_Inlet','Dennistoun','Moubray','Quatermain_Point','Ironside','Manhaul','Tucker','Mandible_Cirque',...
    'Mariner','Suter','Wylde','Fitzgerald','Falkner','Parker','Aviator','Tinker','Cape_Washington',...
    'Campbell','Nansen','Drygalski','Geikie_Inlet','Cheetham','Harbord Glacier','Marin','Nordenskjold',...
    'Ross_East','Ross_West','Hamilton','Withrow','Richter','Swinburne','Sulzberger','Nickerson','Land',...
    'Hull','Garfield','Perkins','Rose_Point','Jackson','Getz','Philbin_Inlet','Dotson','Harmon_Bay',...
    'Hummer_Point','Hamilton_Piedmont','Crosson','Thwaites','Pine_Island','Walgreen_Coast_1',...
    'Walgreen_Coast_2','Cosgrove','Abbot','Venable','Fox_Ice_Stream','Ferrigno','Alison','Eltanin_Bay',...
    'Thomson','Rydberg_Peninsula_1','Rydberg_Peninsula_2','Stange','George_VI','Britten','Bach',...
    'Verdi','Brahms','Mendelssohn','Wilkins','Wordie'};

shelf_labs = {'LA','LB','LC','LD','LE','LF','Clarke Bay','LG',...
    'Ronne','Filchner','HCC','Dawson Lambton','Brunt','Riiser',...
    'Quar','Ekstrom','Atka','Jelbart','Fimbul','Vigrid','Nivl','Lazarev','Borchgrevink','Baudouin',...
    'Prince Harald','Shirase','Skallen','Telen','Hannan','Rayner Thyer','Zubchatyy','Porter','Myers',...
    'Edward VIII','WRD','Rund Bay','Hoseason','Cirque Fjord','Mulebreen','Utsikkar',...
    'Amery','Publications','Dalk','Flatnes','Hovde','Sorsdal','West','Helen','Shackleton','Tracy Tremenchus',...
    'Conger','Underwood','Vincennes Bay','Whittle','Totten','Moscow','Voyeykov',...
    'Holmes','Frost','Sandford','Morse','May','Dibble','Pourquoi Pas','C. Charcot',...
    'Marret','Francais','Liotard','Astrolabe','Zelee','Watt Bay','Mertz','Fisher','Ainsworth','Ninnis',...
    'HornBluff','Deakin','Cook','Slava','Andreyev','Lauritzen','Drury','Matusevitch','McLeod',...
    'Noll','Gillet','Suvorov','Rennick','Gannutz','Barber','Chugunov','Lillie','Kirkby',...
    'Smith Inlet','Dennistoun','Moubray','Q. Point','Ironside','Manhaul','Tucker','M. Cirque',...
    'Mariner','Suter','Wylde','Fitzgerald','Falkner','Parker','Aviator','Tinker','Cape Washington',...
    'Campbell','Nansen','Drygalski','Geikie','Cheetham','Harbord Glacier','Marin','Nordenskjold',...
    'Ross E','Ross W','Hamilton','Withrow','Richter','Swinburne','Sulzberger','Nickerson','Land',...
    'Hull','Garfield','Perkins','Rose Point','Jackson','Getz','Philbin','Dotson','Harmon Bay',...
    'H. Point','H. Piedmont','Crosson','Thwaites','PIG','Walgreen C1',...
    'Walgreen C2','Cosgrove','Abbot','Venable','Fox','Ferrigno','Alison','Eltanin Bay',...
    'Thomson','R. Pen1','R. Pen2','Stange','GVI','Britten','Bach',...
    'Verdi','Brahms','Mendelssohn','Wilkins','Wordie'};

%% Prep

% Prep
ulim = 2000; % Gt
llim = -2000;
cmap1 = cmocean('balance',length(llim:0)*20);
cmap1 = cmap1(1:length(llim:0)*10,:);
cmap1 = cmap1(10:end,:);
cmap2 = cmocean('balance',length(0:ulim)*2);
cmap2 = cmap2(length(0:ulim):end-2,:);
cmap = [cmap1(end-4:end-2) ; cmap2];
cmap1 = cmocean('balance',length(llim:0)*20);
cmap(1,:) = cmap1(15,:);
cmap(2,:) = cmap1(20,:);
cpts = linspace(llim,ulim,size(cmap,1));
cpts = [cpts(1:3),0,cpts(4:end)];
cmap = [cmap(1:3,:);[1 1 1];cmap(4:end,:)];
cmap = cmocean('balance',length(llim:ulim));
cpts = linspace(llim,ulim,size(cmap,1));

% more prep
r = 2.8e6;
s = 6;

% centre coords
centre_lat = -87;
centre_lon = 90;
[centre_x,centre_y] = ll2ps(centre_lat,centre_lon);

% preliminary start coords (for Larsen A)
start_lat = -65.3954;
start_lon = -59.8732;
[start_x,start_y] = ll2ps(start_lat,start_lon);

% Also force some ice shelves to start in certain places
Quar_start_lon = -3.59;
Harald_start_lon = 30.1;
Hannan_start_lon = 46.24; % to create a gap after Skallen/Telen
EdVIII_start_lon = 55.62; % to create a gap after Myers
Amery_start_lon = 71.0;
Shackleton_start_lon = 92.0;
Totten_start_lon = 105.0;
Sandford_start_lon = 121.0;
RossE_start_lon = -179.9;
Getz_start_lon = -128.6;

% make ring two rows thick in certain places
double_start = 60; % Dibble
double_end = 118; % Nordenskjold
double2_start = 120; % Ross W
double2_end = 132; % Jackson
double3_start = 136; % Harmon bay
double3_end = 138; % Hamilton Piedmont
double4_start = 142; % Venable
double4_end = 154; % Stange
double5_start = 156; % Walgreen Coast 1
double5_end = 162; % Rydberg Peninsula 2

% define a circle on which to plot
NOP = 100000;
t = 2*pi/NOP*(1:NOP);
all_x = centre_x+r.*cos(t);
all_y = centre_y+r.*sin(t);
[all_lat,all_lon] = ps2ll(all_x,all_y);
NOP = 1000;
t = 2*pi/NOP*(1:NOP);

% Find precise starting point on this circle
d = sqrt((start_x-all_x).^2 + (start_y-all_y).^2);
idx = find(d == nanmin(d));
start_lat = all_lat(idx);
start_lon = all_lon(idx);

%% Background

% Melt rate
[M,Mx,My,~] = geoimread('basal_melt_map_racmo_firn_air_corrected.tif');
M(M<-20000) = NaN;

%% Plot

% initialise background
figure('Renderer', 'opengl','color','w','units','inches','position',[2 2 8 8]);
antbounds('coast','color','none'); hold on
% Overlay modis
hm = modismoaps('contrast',[1 17000],'clearocean',true); hold on
ax = axis;
% Hide axis
axis off
% Change axis limits
set(gca,'XLim',[-3.1098    3.5777].*1e6);
set(gca,'YLim',[-3.5499    3.3829].*1e6);
% scalebar
[h_sb,h_sbtext] = scalebarps;
% Overlay melt rate
h = imagesc(Mx,My,M,'alphadata',isfinite(M)); 
axis xy
daspect([1 1 1]) 
caxis([-2 2]);
mcmap = cmocean('balance');
colormap(mcmap);
% Colorbar
hcb = colorbar;
set(hcb,'tickdir','out','fontsize',12,'Location','northoutside');
pos_orig = hcb.Position;
hcb.Position = [pos_orig(1)+0.33 pos_orig(2)-0.25 pos_orig(3)/5 pos_orig(4)];
hcb.FontSize = 8;
set(get(hcb,'ylabel'),'String','Basal melt rate (m yr^-^1)','fontsize',8);
cbarrow

% Plot circles of mass change
skip_count=0;
for i = 1:numel(shelves_to_plot)
    
    % Get details
    shelf_name = shelves_to_plot{i};
    if basal_melt_source == 1
        load(['../../submarine_melt/individual_shelf_submarine_melt_consolidated/' shelf_name '_submarine_melt_timeseries.mat'],'ssc_melt_flux_calc','ssc_melt_flux_err_calc','melt_flux_reg','melt_flux_err_reg','reg_time','melt_flux_ts');
    elseif basal_melt_source == 2
        load(['../../submarine_melt/individual_shelf_submarine_melt_consolidated/' shelf_name '_submarine_melt_timeseries_paolo.mat'],'ssc_melt_flux_calc','ssc_melt_flux_err_calc','melt_flux_reg','melt_flux_err_reg','reg_time');
    elseif basal_melt_source == 3
        load(['../../mass_balance/individual_shelf_mass_balance_200m/' shelf_name '_mass_balance_noel_update_v2.mat'],'cumulativeThinningForce1997','cumulativeThinningForce1997Error');
    end
    m_change = cumulativeThinningForce1997(end).*-1;
    m_change_err = cumulativeThinningForce1997Error(end);
    
    % Work out what colour to plot it
    if m_change>=ulim
        col = cmap(end,:);
    elseif m_change<=llim
        col = cmap(1,:);
    else
        mb_diff = m_change-cpts;
        idx = find(abs(mb_diff) == nanmin(abs(mb_diff)));
        col = cmap(idx,:);
    end    

    % check for very small shelves
    if abs(m_change)<50
        m_cum_plot = 50;
        edge_col = [0 0 0];
        alpha=0.9;
    else
        m_cum_plot = m_change;
        edge_col = [0 0 0];
        alpha=0.7;
    end
    
    if m_change>0
        edge_col = mcmap(end-10,:);
    elseif m_change<0
        edge_col = mcmap(10,:);
    end
    if m_change-m_change_err<0 && m_change+m_change_err>0
        edge_col = 'none';
        col = [.7 .7 .7];
        alpha = 0.7;
    end

    % Plot circles
    if i == 1
        % Draw the first circle, centred over the start point
        [~,edge_x,edge_y] = circleps_edge(start_lat, start_lon,sqrt(abs(m_cum_plot))*s,'facecolor',col,'FaceAlpha',alpha,'EdgeColor',edge_col); 
        % Get the edge coordintes and radius of circle
        [edge_lat,edge_lon] = ps2ll(edge_x,edge_y);
        rad = pathdistps([edge_lat(1),start_lat],[edge_lon(1),start_lon],'km');
        rad = rad(2);
        % get the coordinates of the intersections with the guide circle
        [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y,'robust');
        xb = x_int(1);
        yb = y_int(1);
        xf = x_int(2); 
        yf = y_int(2);
        % label
        %   - find point closest to centre of AIS (or furthest if
        %   plotting outside)
        d = sqrt((edge_x-centre_x).^2 + (edge_y-centre_y).^2);
        idx = find(d == nanmax(d));
        text_lat = edge_lat(idx)+0.2;
        text_lon = edge_lon(idx);
        [text_x,text_y] = ll2ps(text_lat,text_lon);
        slope = (centre_y - start_y) ./ (centre_x - start_x);
        angle = atand(slope);
        if abs(m_cum_plot) > 1500 && ~strcmp(shelf_labs{i},'Filchner')
            %text(start_x,start_y,shelf_labs{i},'horizontalAlignment','center','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
            text(text_x,text_y,shelf_labs{i},'rotation',angle,'horizontalAlignment','right','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        else
            text(text_x,text_y,shelf_labs{i},'rotation',angle,'horizontalAlignment','right','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
        end
    else
        if [i<=double_start || i>double_end] && [i<=double2_start || i>=double2_end] && [i<=double3_start || i>=double3_end] && [i<=double4_start || i>=double4_end] && [i<=double5_start || i>=double5_end]
            % plot a dummy circle starting from xf,yf to get the centre point of the next circle
            [~,edge_x,edge_y] = circleps_edge(xf,yf,sqrt(abs(m_cum_plot))*s,'facecolor','none','FaceAlpha',0,'EdgeColor','none'); 
            [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y);
            if length(x_int) <= 1
                edge_x(end+1) = edge_x(1);
                edge_y(end+1) = edge_y(1);
                [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y);
            end
            d = zeros([length(x_int),1]).*NaN;
            for k = 1:numel(x_int)
                tmp = pathdistps([xb,x_int(k)],[yb,y_int(k)]);
                d(k) = tmp(2);
            end
            % find the guide intersection that is furthest from rear edge of
            % the previous circle
            idx = find(d == nanmax(d));
            xf = x_int(idx);
            yf = y_int(idx);
            % Then reset xb,yb to be the centre of the previous circle (which
            % is just the rear intersection of this dummy circle)
            idx = find(d == nanmin(d));
            xb = x_int(idx);
            yb = y_int(idx);
            % Plot the circle properly from the correct centre point
            [~,edge_x,edge_y] = circleps_edge(xf, yf,sqrt(abs(m_cum_plot))*s,'facecolor',col,'FaceAlpha',alpha,'EdgeColor',edge_col); 
            [edge_lat,edge_lon] = ps2ll(edge_x,edge_y);
            % Label
            d = sqrt((edge_x-centre_x).^2 + (edge_y-centre_y).^2);
            idx = find(d == nanmax(d));
            text_lat = edge_lat(idx)+0.2;
            text_lon = edge_lon(idx);
            [text_x,text_y] = ll2ps(text_lat,text_lon);
            slope = (centre_y - yf) ./ (centre_x - xf);
            angle = atand(slope);
            %if abs(m_cum_plot) > 1500 && ~strcmp(shelf_labs{i},'Filchner')
            %    text(xf,yf,shelf_labs{i},'horizontalAlignment','center','color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
            %else
                if i<21
                    text(text_x,text_y,shelf_labs{i},'horizontalAlignment','right','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                elseif i>=21 && i<58
                    text(text_x,text_y,(shelf_labs{i}),'horizontalAlignment','left','rotation',(180-(180-angle)),'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                elseif i>=58 && i<119
                    text(text_x,text_y,shelf_labs{i},'horizontalAlignment','left','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                elseif i>=119
                    text(text_x,text_y,shelf_labs{i},'horizontalAlignment','right','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                end
            %end
            % get the coordinates of the intersections with the guide circle
            [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y,'robust');
            if length(x_int) == 1
                edge_x(end+1) = edge_x(1);
                edge_y(end+1) = edge_y(1);
                [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y);
            end
            d = zeros([length(x_int),1]).*NaN;
            for k = 1:numel(x_int)
                tmp = pathdistps([xb,x_int(k)],[yb,y_int(k)]);
                d(k) = tmp(2);
            end
            % then reset xf,yf and xb,yb for the next circle
            idx = find(d == nanmin(d));
            xb = x_int(idx);
            yb = y_int(idx);
            idx = find(d == nanmax(d));
            xf = x_int(idx);
            yf = y_int(idx); 
        else
            % If making a double ring, we need to make some alterations
            if mod(i,2)==1 % isodd
                % find closest point of previous circle to centre
                d = sqrt((edge_x-centre_x).^2 + (edge_y-centre_y).^2);
                idx = find(d == nanmin(d));
                even_x = edge_x(idx);
                even_y = edge_y(idx);
                % make a dummy circle here..
                [~,even_edge_x,even_edge_y] = circleps_edge(even_x,even_y,sqrt(abs(m_cum_plot))*s,'facecolor','none','FaceAlpha',0,'EdgeColor','none'); 
                % find closest point of the dummy circle to centre 
                d = sqrt((even_edge_x-centre_x).^2 + (even_edge_y-centre_y).^2);
                idx = find(d == nanmin(d));
                even_x = even_edge_x(idx);
                even_y = even_edge_y(idx);
                [even_lat,even_lon] = ps2ll(even_x,even_y);
                even_lon = even_lon+0.4;
                [even_x,even_y] = ll2ps(even_lat,even_lon);
                % Plot the circle properly from the correct centre point
                [~,even_edge_x,even_edge_y] = circleps_edge(even_x, even_y,sqrt(abs(m_cum_plot))*s,'facecolor',col,'FaceAlpha',alpha,'EdgeColor',edge_col); 
                [even_edge_lat,even_edge_lon] = ps2ll(even_edge_x,even_edge_y);
                % Label
                d = sqrt((even_edge_x-centre_x).^2 + (even_edge_y-centre_y).^2);
                idx = find(d == nanmin(d));
                text_lat = even_edge_lat(idx)-0.2;
                text_lon = even_edge_lon(idx);
                [text_x,text_y] = ll2ps(text_lat,text_lon);
                slope = (centre_y - yf) ./ (centre_x - xf);
                angle = atand(slope);
                if angle<90 && angle>0 %(e.g. Campbell)
                    text(text_x,text_y,shelf_labs{i},'horizontalAlignment','left','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                else
                    if i>=145
                        text(text_x,text_y,shelf_labs{i},'horizontalAlignment','left','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                    else
                        text(text_x,text_y,shelf_labs{i},'horizontalAlignment','right','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                    end
                end
            else % if even, then plot along guide circle
                % plot a dummy circle starting from xf,yf to get the centre point of the next circle
                [~,edge_x,edge_y] = circleps_edge(xf,yf,sqrt(abs(m_cum_plot))*s,'facecolor','none','FaceAlpha',0,'EdgeColor','none'); 
                [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y);
                if length(x_int) <= 1
                    edge_x(end+1) = edge_x(1);
                    edge_y(end+1) = edge_y(1);
                    [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y);
                end
                d = zeros([length(x_int),1]).*NaN;
                for k = 1:numel(x_int)
                    tmp = pathdistps([xb,x_int(k)],[yb,y_int(k)]);
                    d(k) = tmp(2);
                end
                % find the guide intersection that is furthest from rear edge of
                % the previous circle
                idx = find(d == nanmax(d));
                xf = x_int(idx);
                yf = y_int(idx);
                % Then reset xb,yb to be the centre of the previous circle (which
                % is just the rear intersection of this dummy circle)
                idx = find(d == nanmin(d));
                xb = x_int(idx);
                yb = y_int(idx);
                % Plot the circle properly from the correct centre point
                [~,edge_x,edge_y] = circleps_edge(xf, yf,sqrt(abs(m_cum_plot))*s,'facecolor',col,'FaceAlpha',alpha,'EdgeColor',edge_col); 
                [edge_lat,edge_lon] = ps2ll(edge_x,edge_y);
                % Label (always outside for double)
                d = sqrt((edge_x-centre_x).^2 + (edge_y-centre_y).^2);
                idx = find(d == nanmax(d));
                text_lat = edge_lat(idx)+0.2;
                text_lon = edge_lon(idx);
                [text_x,text_y] = ll2ps(text_lat,text_lon);
                slope = (centre_y - yf) ./ (centre_x - xf);
                angle = atand(slope);
                if angle<90 && angle>0 %(e.g. Nordenskjold)
                   text(text_x,text_y,shelf_labs{i},'horizontalAlignment','right','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                else
                    if i >= 145
                        text(text_x,text_y,shelf_labs{i},'horizontalAlignment','right','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                    else
                        text(text_x,text_y,shelf_labs{i},'horizontalAlignment','left','rotation',angle,'color','k','fontsize',8,'interpreter','none','fontname','Lucida Sans');
                    end
                end
                % get the coordinates of the intersections with the guide circle
                [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y,'robust');
                if length(x_int) == 1
                    edge_x(end+1) = edge_x(1);
                    edge_y(end+1) = edge_y(1);
                    [x_int,y_int] = intersections(edge_x,edge_y,all_x,all_y);
                end
                d = zeros([length(x_int),1]).*NaN;
                for k = 1:numel(x_int)
                    tmp = pathdistps([xb,x_int(k)],[yb,y_int(k)]);
                    d(k) = tmp(2);
                end
                % then reset xf,yf and xb,yb for the next circle
                idx = find(d == nanmin(d));
                xb = x_int(idx);
                yb = y_int(idx);
                idx = find(d == nanmax(d));
                xf = x_int(idx);
                yf = y_int(idx); 
                [latf,lonf] = ps2ll(xf,yf);
                if lonf > 0
                    lonf = lonf + 0.25; % shift a bit
                end
                [xf,yf] = ll2ps(latf,lonf);
            end
        end

        % adjust start point at certain shelves to make gaps
        if strcmp(shelf_labs{i},'Baudouin') % one before Prince Harald
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Harald_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Telen') % one before Hannan
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Hannan_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Myers') % one before Edward VIII
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,EdVIII_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Utsikkar') % one before Amery
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Amery_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Helen') % one before Shackleton
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Shackleton_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Vincennes Bay') % one before Whittle/Totten
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Totten_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Frost') % one before Sandfird
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Sandford_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Nordenskjold') % one before Sandfird
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,RossE_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
        if strcmp(shelf_labs{i},'Riiser') % one before Sandfird
            [latf,lonf] = ps2ll(xf,yf);
            [xf,yf] = ll2ps(latf,Quar_start_lon);
            d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
            idx = find(d == nanmin(d));
            latf = all_lat(idx);
            lonf = all_lon(idx);
            [xf,yf] = ll2ps(latf,lonf);
        end
%         if strcmp(shelf_labs{i},'Jackson') % one before Sandfird
%             [latf,lonf] = ps2ll(xf,yf);
%             [xf,yf] = ll2ps(latf,Getz_start_lon);
%             d = sqrt((xf-all_x).^2 + (yf-all_y).^2);
%             idx = find(d == nanmin(d));
%             latf = all_lat(idx);
%             lonf = all_lon(idx);
%             [xf,yf] = ll2ps(latf,lonf);
%         end

    end
    
end


% Also label cumulative mass change on colorbar
text_x = 5.9361*1e5;
text_y = 7.2012*1e5;
text(text_x,text_y,'Melt excess/','horizontalAlignment','center','color','k','fontsize',8,'interpreter','none');
text(text_x,text_y-1.3e5,'deficit (Gt)','horizontalAlignment','center','color','k','fontsize',8);
text(text_x+5.5e5,text_y,'2000','horizontalAlignment','left','color','k','fontsize',8,'interpreter','none');
text(text_x-8.5e5,text_y,'-2000','horizontalAlignment','left','color','k','fontsize',8,'interpreter','none');


% Provide scale for circles
sc1_x = -0.92*1e5;
sc1_y = 2.3*1e5;
sc_x = [sc1_x+3e5,sc1_x+6.5e5,sc1_x+1.1e6+1e5];
sc_y = [sc1_y+60*1000, sc1_y+134*1000, sc1_y+268*1000];
sc_y = sc_y-2e5;
[lat_legend,lon_legend] = ps2ll(sc_x,sc_y);
% Plot circles of radii 1,10,100 Gt: 
circleps_edge(lat_legend([1,2,3]),lon_legend([1,2,3]),sqrt([50 500 1500]).*s,'facecolor','w','EdgeColor','k') 
% Label the circles:
[lat_label,lon_label] = ps2ll(sc_x,sc_y-[1.5e5,2.2e5,3.6e5]);
textps(lat_label,lon_label,{'50';'500';'1500 Gt'},'horizontalAlignment','center','color','k','fontsize',8); 

        
% Move scalebar and text
text_offset_x = h_sbtext.Position(1) - h_sb.XData(1);
new_left_x = 7.6221*1e5;
new_left_y = -9.3208*1e5;
sb_xlen = h_sb.XData(2)-h_sb.XData(1);
sb_ylen = h_sb.YData(2)-h_sb.YData(1);
h_sb.XData = [new_left_x, new_left_x+sb_xlen];
h_sb.YData = [new_left_y, new_left_y+sb_ylen];
h_sbtext.Position = [new_left_x+text_offset_x, new_left_y,0];

% Save
if basal_melt_source == 1
    export_fig('ice_shelf_excess_melting_ring.png','-dpng','-r1800');
elseif basal_melt_source == 2
    export_fig('ice_shelf_excess_melting_ring_paolo.png','-dpng','-r1800');
elseif basal_melt_source == 3
    export_fig('ice_shelf_excess_melting_ring_noel_update_smooth.png','-dpng','-r2000');
    exportgraphics(gcf,'ice_shelf_excess_melting_ring_noel_update_smooth.pdf','ContentType','vector')
end




