% remove_islands_from_broken_shelves

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../grounding_line_discharge'));

mkdir masks/all_years_islands_removed

%% Load grounding lines

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all.mat','GL');

%% Load islands

% Basins and islands
basins = shaperead('Basins_IMBIE_Antarctica_v02.shp');
islands_x = basins(1).X(:);
islands_y = basins(1).Y(:);
island_sections = regionprops(isfinite(islands_x),islands_x,'PixelIdxList');

%% Coastline for plotting

% make colormap for coast time
coast_list = dir('D:\work\Fellowship_Leeds\Data\calving_front_locations_greene\coastline_data/antarctic_coastline_*.txt');
cmap = colorcet('Gouldian','N',numel(coast_list));
coast_time_all = zeros([numel(coast_list),1]).*NaN;
dec_year_all = zeros([numel(coast_list),1]).*NaN;
for i = 1:numel(coast_list)
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    coast_time_all(i) = datenum(str2double(coast_time),1,1);
    dec_year_all(i) = str2double(coast_time);
end

%% List of shelves to fix

% shelves_to_fix = {'Larsen_B','Tracy_Tremenchus','Baudouin};

shelves_to_fix = {'Baudouin'};

%% Loop through shelves and remove islands

for i = 1:numel(GL)

    % Get shelf info
    tic;
    shelf_name = GL(i).Name;
    if sum(strcmp(shelf_name,shelves_to_fix))==1
        gate_x = GL(i).X;
        gate_y = GL(i).Y;
        disp(' ');
        disp(['Starting shelf number: ' num2str(i) ' - ' shelf_name ]);

        % Get shelf mask
        load(['masks/all_years/' shelf_name '_mask_data.mat']);
        
        % pre-allocate new array, with islands
        shelf_x_new = shelf_x;
        shelf_y_new = shelf_y;

        % Loop through years
        for j = 1:numel(shelf_x)
            
            % Get current cooardinates
            x = shelf_x{j};
            y = shelf_y{j};
            orig_x = shelf_x{j};
            orig_y = shelf_y{j};

            % Loop through island sections and remove edge islands
            if ~strcmp(shelf_name,'Larsen_B')
            for k = 1:numel(island_sections)
                % get island coordinates
                island_x = islands_x(island_sections(k).PixelIdxList);
                island_y = islands_y(island_sections(k).PixelIdxList);

                % Check position
                [in1,on1] = inpoly2([island_x(:),island_y(:)],[orig_x(:),orig_y(:)]); 
                [in2,on2] = inpoly2([island_x(:),island_y(:)],[orig_x(:),orig_y(:)],[],0.005);

                % Remove edge islands
                if sum(in1)>1 && sum(in1)<length(island_x)
                    only_in = in2-on2;
                    only_in(only_in==0) = NaN;
                    s = regionprops(isfinite(only_in),only_in,'PixelIdxList');
                    lens = zeros([numel(s),1]).*NaN;
                    for zz = 1:length(s)
                        lens(zz) = length(s(zz).PixelIdxList);
                    end
                    use = find(lens == nanmax(lens));
                    if ~isempty(use)
                        use = s(use).PixelIdxList;
                        px = island_x(use);
                        py = island_y(use);
                        if strcmp(shelf_name,'Tracy_Tremenchus') && j>=4 && k==201
                            in1 = single(in1);
                            in1(in1==0)=NaN;
                            s = regionprops(isfinite(in1),in1,'PixelIdxList');
                            px = [island_x(s(2).PixelIdxList) ; island_x(s(1).PixelIdxList)];
                            py = [island_y(s(2).PixelIdxList) ; island_y(s(1).PixelIdxList)];
                        end
                        d = sqrt((px(1)-orig_x).^2 + (py(1)-orig_y).^2);
                        idx1 = find(d(:) == nanmin(d(:)),1,'first');
                        d = sqrt((px(end)-orig_x).^2 + (py(end)-orig_y).^2);
                        idx2 = find(d(:) == nanmin(d(:)),1,'first');
                        % then find closest point on modified x/y
                        d = sqrt((orig_x(idx1)-x).^2 + (orig_y(idx1)-y).^2);
                        idx1 = find(d(:) == nanmin(d(:)),1,'first');
                        d = sqrt((orig_x(idx2)-x).^2 + (orig_y(idx2)-y).^2);
                        idx2 = find(d(:) == nanmin(d(:)),1,'first');
                        if idx1 < idx2
                            x = [x(1:idx1) ; px(:) ; x(idx2:end)];
                            y = [y(1:idx1) ; py(:) ; y(idx2:end)];
                        else
                            x = [x(1:idx2) ; flipud(px(:)) ; x(idx1:end)];
                            y = [y(1:idx2) ; flipud(py(:)) ; y(idx1:end)];
                        end
                    end
                end
            end
            end
            
%             antbounds('coast','w'); hold on
%             plot(x,y,'k');
%             plot(island_x,island_y,'b');
%             plot(px,py,'r');
%             set(gca,'XLim',[-1.6799   -1.0613]*1e6);
%             set(gca,'YLim',[-1.2003   -0.6839]*1e6);
%             scatter(px(1),py(1),20,'g','filled');
%             plot(x(1:idx2),y(1:idx2),'r');
            

            for k = 1:numel(island_sections)
                % get island coordinates
                island_x = islands_x(island_sections(k).PixelIdxList);
                island_y = islands_y(island_sections(k).PixelIdxList);
                % Check position
                [in1,on1] = inpoly2([island_x(:),island_y(:)],[orig_x(:),orig_y(:)]); 
                % If island falls within entirely shelf, append it to shelf data
                if sum(in1) == length(island_x)
                    x = [x(:) ; NaN ; island_x];
                    y = [y(:) ; NaN ; island_y];
                end
            end

            % Append a NaN to separate all sections
            x = [x(:) ; NaN];
            y = [y(:) ; NaN];

            % Build new array
            shelf_x_new{j} = x;
            shelf_y_new{j} = y;

        end
        
        % If doing Hamilton Piedmont, keep original shelf
        if strcmp(shelf_name,'Hamilton_Piedmont')
            % Get shelf mask
            load(['masks/all_years/' shelf_name '_mask_data.mat']);
            save(['masks/all_years_islands_removed/' shelf_name '_mask_islands_removed_data.mat'],'shelf_x','shelf_y','coast_time_all');
            sections = regionprops(~isnan(gate_x), gate_x,'pixelIdxList','PixelValues');
            gate_x = [gate_x(sections(2).PixelIdxList) ; gate_x(sections(1).PixelIdxList)];
            gate_y = [gate_y(sections(2).PixelIdxList) ; gate_y(sections(1).PixelIdxList)];
        else
            shelf_x = shelf_x_new;
            shelf_y = shelf_y_new;
            save(['masks/all_years_islands_removed/' shelf_name '_mask_islands_removed_data.mat'],'shelf_x','shelf_y','coast_time_all');
        end
                        
        % And plot
        for j = 1:numel(shelf_x)
            if j == 1
                min_x = nanmin(shelf_x{j});
                min_y = nanmin(shelf_y{j});
                max_x = nanmax(shelf_x{j});
                max_y = nanmax(shelf_y{j});
                min_x_idx = j;
                min_y_idx = j;
                max_x_idx = j;
                max_y_idx = j;
            else
                if nanmin(shelf_x{j}) < min_x
                    min_x = nanmin(shelf_x{j});
                    min_x_idx = j;
                end
                if nanmin(shelf_y{j}) < min_y
                    min_y = nanmin(shelf_y{j});
                    min_y_idx = j;
                end
                if nanmax(shelf_x{j}) > max_x
                    max_x = nanmax(shelf_x{j});
                    max_x_idx = j;
                end
                if nanmax(shelf_y{j}) > max_y
                    max_y = nanmax(shelf_y{j});
                    max_y_idx = j;
                end
            end
        end
        x_len = max_x - min_x;
        y_len = max_y - min_y;
        len = max([x_len,y_len]);
        buffer = min([len.*0.1,20000]);
        [moa,modis_x,modis_y,~] = geoimread('moa125_2014_hp1_v01.tif',[min_x max_x],[min_y max_y],buffer);
        moa=uint16(moa);
        RGB = mat2im(moa,gray(256),[1 20000]); 
        figure('color','w','visible','on');
        da = daspect; 
        da = [1 1 da(3)];
        %antbounds('coast','w'); hold on
        %antbounds('gl','w');
        hm = image(modis_x,modis_y,RGB); axis xy
        set(hm,'alphadata',moa>0)
        uistack(hm,'bottom') 
        ax = axis;
        axis xy 
        daspect(da)
        hold on
        for j = 1:numel(shelf_x)
            plot(shelf_x{j},shelf_y{j},'color',cmap(j,:),'linewidth',1,'linestyle','-','marker','none')
        end
        set(gca,'XLim',[min_x-buffer max_x+buffer]);
        set(gca,'YLim',[min_y-buffer max_y+buffer]);
        cb = colorbar;
        colormap(cmap);
        ylabel(cb,'Time');
        xlabel('Easting (km)');
        ylabel('Northing (km)');
        caxis([min(dec_year_all) max(dec_year_all)]);
        plot(gate_x,gate_y,'k','linewidth',1,'linestyle','-','marker','none');
        try; measuresps('vel','k'); end
        scalebarps
        export_fig(['masks/all_years_islands_removed/' shelf_name '_mask_islands_removed_overview.png'],'-dpng','-r600');
        close
    end
    
end
        
        
        
        
    
    