% remove_islands_from_ice_shelf_masks

clear
close all
clc

addpath(genpath('D:/work/Fellowship_Leeds/Data'));
addpath(genpath('../grounding_line_discharge'));

mkdir masks/all_years_islands_removed

%% Load grounding lines

% Load GL structure - contains name and xy coordinates of all shelf
% grounding lines
load('merged_shelf_GLs_all.mat','GL');

%% Load islands

% Basins and islands
basins = shaperead('Basins_IMBIE_Antarctica_v02.shp');
islands_x = basins(1).X(:);
islands_y = basins(1).Y(:);
island_sections = regionprops(isfinite(islands_x),islands_x,'PixelIdxList');

%% Coastline for plotting

% make colormap for coast time
coast_list = dir('D:\work\Fellowship_Leeds\Data\calving_front_locations_greene\coastline_data/antarctic_coastline_*.txt');
cmap = colorcet('Gouldian','N',numel(coast_list));
coast_time_all = zeros([numel(coast_list),1]).*NaN;
dec_year_all = zeros([numel(coast_list),1]).*NaN;
for i = 1:numel(coast_list)
    coast_time = extractBefore(coast_list(i).name,'.txt');
    coast_time = extractAfter(coast_time,'coastline_');
    coast_time_str = coast_time;
    coast_time_all(i) = datenum(str2double(coast_time),1,1);
    dec_year_all(i) = str2double(coast_time);
end

%% Loop through shelves and remove islands

for i = 1:numel(GL)

    % Get shelf info
    tic;
    shelf_name = GL(i).Name;
    gate_x = GL(i).X;
    gate_y = GL(i).Y;
    disp(' ');
    disp(['Starting shelf number: ' num2str(i) ' - ' shelf_name ]);
    
    % Get shelf mask
    load(['masks/all_years/' shelf_name '_mask_data.mat']);
    
    % pre-allocate new array, with islands
    shelf_x_new = shelf_x;
    shelf_y_new = shelf_y;
    
    % Loop through years
    for j = numel(shelf_x)%1:numel(shelf_x)
        
        % Get current cooardinates
        x = shelf_x{j};
        y = shelf_y{j};
        orig_x = shelf_x{j};
        orig_y = shelf_y{j};
        
        % Loop through island sections and check whether individual islands
        % fall within shelf
        for k = 1:numel(island_sections)
            % get island coordinates
            island_x = islands_x(island_sections(k).PixelIdxList);
            island_y = islands_y(island_sections(k).PixelIdxList);
            
            % Check position
            [in1,on1] = inpoly2([island_x(:),island_y(:)],[orig_x(:),orig_y(:)]); 
            [in2,on2] = inpoly2([island_x(:),island_y(:)],[orig_x(:),orig_y(:)],[],0.005); 
            
            % If island falls within entirely shelf, append it to shelf data
            if sum(in1) == length(island_x)
                x = [x(:) ; NaN ; island_x];
                y = [y(:) ; NaN ; island_y];
            elseif sum(in1)>1 && sum(in1)<length(island_x)
                only_in = in2-on2;
                if strcmp(shelf_name,'Getz')
                    only_in = in1-on1;
                end
                only_in(only_in==0) = NaN;
                s = regionprops(isfinite(only_in),only_in,'PixelIdxList');
                lens = zeros([numel(s),1]).*NaN;
                for zz = 1:length(s)
                    lens(zz) = length(s(zz).PixelIdxList);
                end
                use = find(lens == nanmax(lens));
                if ~isempty(use)
                    use = s(use).PixelIdxList;
                    px = island_x(use);
                    py = island_y(use);
                    d = sqrt((px(1)-x).^2 + (py(1)-y).^2);
                    idx1 = find(d(:) == nanmin(d(:)),1,'first');
                    d = sqrt((px(end)-x).^2 + (py(end)-y).^2);
                    idx2 = find(d(:) == nanmin(d(:)),1,'first');
                    if idx1 < idx2
                        x = [x(1:idx1) ; px(:) ; x(idx2:end)];
                        y = [y(1:idx1) ; py(:) ; y(idx2:end)];
                    else
                        x = [x(1:idx2) ; flipud(px(:)) ; x(idx1:end)];
                        y = [y(1:idx2) ; flipud(py(:)) ; y(idx1:end)];
                    end
                end
            end
        end
        
        % Append a NaN to separate all sections
        x = [x(:) ; NaN];
        y = [y(:) ; NaN];
        
        % Build new array
        shelf_x_new{j} = x;
        shelf_y_new{j} = y;
        
    end
    
    % Now we have all years, save to file
    shelf_x = shelf_x_new;
    shelf_y = shelf_y_new;
    % if doing slava, just keep original
    if strcmp(shelf_name,'Slava')
        load(['masks/all_years/' shelf_name '_mask_data.mat']);
    end
    save(['masks/all_years_islands_removed/' shelf_name '_mask_islands_removed_data.mat'],'shelf_x','shelf_y','coast_time_all');
    toc
    
    % And plot
    for j = 1:numel(shelf_x)
        if j == 1
            min_x = nanmin(shelf_x{j});
            min_y = nanmin(shelf_y{j});
            max_x = nanmax(shelf_x{j});
            max_y = nanmax(shelf_y{j});
        else
            if nanmin(shelf_x{j}) < min_x
                min_x = nanmin(shelf_x{j});
            end
            if nanmin(shelf_y{j}) < min_y
                min_y = nanmin(shelf_y{j});
            end
            if nanmax(shelf_x{j}) > max_x
                max_x = nanmax(shelf_x{j});
            end
            if nanmax(shelf_y{j}) > max_y
                max_y = nanmax(shelf_y{j});
            end
        end
    end
    x_len = max_x - min_x;
    y_len = max_y - min_y;
    len = max([x_len,y_len]);
    buffer = min([len.*0.1,30000]);
    [moa,modis_x,modis_y,~] = geoimread('moa125_2014_hp1_v01.tif',[min_x max_x],[min_y max_y],buffer);
    moa=uint16(moa);
    RGB = mat2im(moa,gray(256),[1 20000]); 
    figure('color','w','visible','off');
    da = daspect; 
    da = [1 1 da(3)];
    %antbounds('coast','w'); hold on
    %antbounds('gl','w');
    hm = image(modis_x,modis_y,RGB); axis xy
    set(hm,'alphadata',moa>0)
    uistack(hm,'bottom') 
    ax = axis;
    axis xy 
    daspect(da)
    hold on
    for j = 1:numel(shelf_x)
        plot(shelf_x{j},shelf_y{j},'color',cmap(j,:),'linewidth',1,'linestyle','-','marker','none')
    end
    set(gca,'XLim',[min_x-buffer max_x+buffer]);
    set(gca,'YLim',[min_y-buffer max_y+buffer]);
    cb = colorbar;
    colormap(cmap);
    ylabel(cb,'Time');
    xlabel('Easting (km)');
    ylabel('Northing (km)');
    caxis([min(dec_year_all) max(dec_year_all)]);
    %plot(gate_x,gate_y,'k','linewidth',1,'linestyle','-','marker','none');
    try; measuresps('vel','k'); end
    scalebarps
    export_fig(['masks/all_years_islands_removed/' shelf_name '_mask_islands_removed_overview.png'],'-dpng','-r600');
    close
    
end
        
        
        
        
    
    